/* SourceList.c generated by valac 0.56.13, the Vala compiler
 * generated from SourceList.vala, do not modify */

/*
 * Copyright 2019 elementary, Inc. (https://elementary.io)
 * Copyright 2012-2014 Victor Martinez <victoreduardm@gmail.com>
 * SPDX-License-Identifier: LGPL-3.0-or-later
 */
/**
     * = WORKING INTERNALS =
     *
     * In order to offer a transparent Item-based API, and avoid the need of providing methods
     * to deal with items directly on the SourceList widget, it was decided to follow a monitor-like
     * implementation, where the source list permanently monitors its root item and any other
     * child item added to it. The task of monitoring the properties of the items has been
     * divided among different objects, as shown below:
     *
     * Monitored by: Object::method that receives the signals indicating the property change.
     * Applied by: Object::method that actually updates the tree to reflect the property changes
     *             (directly or indirectly, as in the case of the tree data model).
     *
     * ---------------------------------------------------------------------------------------------
     *   PROPERTY        |  MONITORED BY                     |  APPLIED BY
     * ---------------------------------------------------------------------------------------------
     * + Item            |                                   |
     *   - parent        | Not monitored                     | N/A
     *   - name          | DataModel::on_item_prop_changed   | Tree::name_cell_data_func
     *   - editable      | DataModel::on_item_prop_changed   | Queried when needed (See Tree::start_editing_item)
     *   - visible       | DataModel::on_item_prop_changed   | DataModel::filter_visible_func
     *   - icon          | DataModel::on_item_prop_changed   | Tree::icon_cell_data_func
     *   - activatable   | Same as @icon                     | Same as @icon
     * + ExpandableItem  |                                   |
     *   - collapsible   | DataModel::on_item_prop_changed   | Tree::update_expansion
     *                   |                                   | Tree::expander_cell_data_func
     *   - expanded      | Same as @collapsible              | Same as @collapsible
     * ---------------------------------------------------------------------------------------------
     * * Only automatic properties are monitored. ExpandableItem's additions/removals are handled by
     *   DataModel::add_item() and DataModel::remove_item()
     *
     * Other features:
     * - Sorting: this happens on the tree-model level (DataModel).
     */

#include "granite.h"
#include <glib.h>
#include <gtk/gtk.h>
#include <gdk/gdk.h>
#include <glib-object.h>
#include <pango/pango.h>
#include <float.h>
#include <math.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include <gee.h>
#include <gobject/gvaluecollector.h>
#include <cairo-gobject.h>

#define GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_ITEM_PARENT_NEEDS_UPDATE "item-parent-needs-update"
#define GRANITE_WIDGETS_SOURCE_LIST_CELL_RENDERER_ICON_ICON_SIZE GTK_ICON_SIZE_MENU
#define GRANITE_WIDGETS_SOURCE_LIST_TREE_DEFAULT_STYLESHEET "\n" \
"            .sidebar.badge {\n" \
"                border-radius: 10px;\n" \
"                border-width: 0;\n" \
"                padding: 1px 2px 1px 2px;\n" \
"                font-weight: bold;\n" \
"            }\n" \
"        "
#define GRANITE_WIDGETS_SOURCE_LIST_TREE_STYLE_PROP_LEVEL_INDENTATION "level-indentation"
#define GRANITE_WIDGETS_SOURCE_LIST_TREE_STYLE_PROP_LEFT_PADDING "left-padding"
#define GRANITE_WIDGETS_SOURCE_LIST_TREE_STYLE_PROP_EXPANDER_SPACING "expander-spacing"

enum  {
	GRANITE_WIDGETS_SOURCE_LIST_SORTABLE_USER_MOVED_ITEM_SIGNAL,
	GRANITE_WIDGETS_SOURCE_LIST_SORTABLE_NUM_SIGNALS
};
static guint granite_widgets_source_list_sortable_signals[GRANITE_WIDGETS_SOURCE_LIST_SORTABLE_NUM_SIGNALS] = {0};

#define GRANITE_WIDGETS_SOURCE_LIST_TYPE_TREE (granite_widgets_source_list_tree_get_type ())
#define GRANITE_WIDGETS_SOURCE_LIST_TREE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_WIDGETS_SOURCE_LIST_TYPE_TREE, GraniteWidgetsSourceListTree))
#define GRANITE_WIDGETS_SOURCE_LIST_TREE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_WIDGETS_SOURCE_LIST_TYPE_TREE, GraniteWidgetsSourceListTreeClass))
#define GRANITE_WIDGETS_SOURCE_LIST_IS_TREE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_WIDGETS_SOURCE_LIST_TYPE_TREE))
#define GRANITE_WIDGETS_SOURCE_LIST_IS_TREE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_WIDGETS_SOURCE_LIST_TYPE_TREE))
#define GRANITE_WIDGETS_SOURCE_LIST_TREE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_WIDGETS_SOURCE_LIST_TYPE_TREE, GraniteWidgetsSourceListTreeClass))

typedef struct _GraniteWidgetsSourceListTree GraniteWidgetsSourceListTree;
typedef struct _GraniteWidgetsSourceListTreeClass GraniteWidgetsSourceListTreeClass;

#define GRANITE_WIDGETS_SOURCE_LIST_TYPE_DATA_MODEL (granite_widgets_source_list_data_model_get_type ())
#define GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_WIDGETS_SOURCE_LIST_TYPE_DATA_MODEL, GraniteWidgetsSourceListDataModel))
#define GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_WIDGETS_SOURCE_LIST_TYPE_DATA_MODEL, GraniteWidgetsSourceListDataModelClass))
#define GRANITE_WIDGETS_SOURCE_LIST_IS_DATA_MODEL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_WIDGETS_SOURCE_LIST_TYPE_DATA_MODEL))
#define GRANITE_WIDGETS_SOURCE_LIST_IS_DATA_MODEL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_WIDGETS_SOURCE_LIST_TYPE_DATA_MODEL))
#define GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_WIDGETS_SOURCE_LIST_TYPE_DATA_MODEL, GraniteWidgetsSourceListDataModelClass))

typedef struct _GraniteWidgetsSourceListDataModel GraniteWidgetsSourceListDataModel;
typedef struct _GraniteWidgetsSourceListDataModelClass GraniteWidgetsSourceListDataModelClass;
enum  {
	GRANITE_WIDGETS_SOURCE_LIST_0_PROPERTY,
	GRANITE_WIDGETS_SOURCE_LIST_ROOT_PROPERTY,
	GRANITE_WIDGETS_SOURCE_LIST_SELECTED_PROPERTY,
	GRANITE_WIDGETS_SOURCE_LIST_ELLIPSIZE_MODE_PROPERTY,
	GRANITE_WIDGETS_SOURCE_LIST_EDITING_PROPERTY,
	GRANITE_WIDGETS_SOURCE_LIST_NUM_PROPERTIES
};
static GParamSpec* granite_widgets_source_list_properties[GRANITE_WIDGETS_SOURCE_LIST_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define __vala_GtkTreePath_free0(var) ((var == NULL) ? NULL : (var = (_vala_GtkTreePath_free (var), NULL)))
#define __vala_GtkTreeIter_free0(var) ((var == NULL) ? NULL : (var = (_vala_GtkTreeIter_free (var), NULL)))
enum  {
	GRANITE_WIDGETS_SOURCE_LIST_ITEM_0_PROPERTY,
	GRANITE_WIDGETS_SOURCE_LIST_ITEM_PARENT_PROPERTY,
	GRANITE_WIDGETS_SOURCE_LIST_ITEM_NAME_PROPERTY,
	GRANITE_WIDGETS_SOURCE_LIST_ITEM_TOOLTIP_PROPERTY,
	GRANITE_WIDGETS_SOURCE_LIST_ITEM_MARKUP_PROPERTY,
	GRANITE_WIDGETS_SOURCE_LIST_ITEM_BADGE_PROPERTY,
	GRANITE_WIDGETS_SOURCE_LIST_ITEM_EDITABLE_PROPERTY,
	GRANITE_WIDGETS_SOURCE_LIST_ITEM_VISIBLE_PROPERTY,
	GRANITE_WIDGETS_SOURCE_LIST_ITEM_SELECTABLE_PROPERTY,
	GRANITE_WIDGETS_SOURCE_LIST_ITEM_ICON_PROPERTY,
	GRANITE_WIDGETS_SOURCE_LIST_ITEM_ACTIVATABLE_PROPERTY,
	GRANITE_WIDGETS_SOURCE_LIST_ITEM_ACTIVATABLE_TOOLTIP_PROPERTY,
	GRANITE_WIDGETS_SOURCE_LIST_ITEM_NUM_PROPERTIES
};
static GParamSpec* granite_widgets_source_list_item_properties[GRANITE_WIDGETS_SOURCE_LIST_ITEM_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))
enum  {
	GRANITE_WIDGETS_SOURCE_LIST_ITEM_EDITED_SIGNAL,
	GRANITE_WIDGETS_SOURCE_LIST_ITEM_ACTION_ACTIVATED_SIGNAL,
	GRANITE_WIDGETS_SOURCE_LIST_ITEM_ACTIVATED_SIGNAL,
	GRANITE_WIDGETS_SOURCE_LIST_ITEM_NUM_SIGNALS
};
static guint granite_widgets_source_list_item_signals[GRANITE_WIDGETS_SOURCE_LIST_ITEM_NUM_SIGNALS] = {0};
enum  {
	GRANITE_WIDGETS_SOURCE_LIST_EXPANDABLE_ITEM_0_PROPERTY,
	GRANITE_WIDGETS_SOURCE_LIST_EXPANDABLE_ITEM_COLLAPSIBLE_PROPERTY,
	GRANITE_WIDGETS_SOURCE_LIST_EXPANDABLE_ITEM_EXPANDED_PROPERTY,
	GRANITE_WIDGETS_SOURCE_LIST_EXPANDABLE_ITEM_N_CHILDREN_PROPERTY,
	GRANITE_WIDGETS_SOURCE_LIST_EXPANDABLE_ITEM_CHILDREN_PROPERTY,
	GRANITE_WIDGETS_SOURCE_LIST_EXPANDABLE_ITEM_NUM_PROPERTIES
};
static GParamSpec* granite_widgets_source_list_expandable_item_properties[GRANITE_WIDGETS_SOURCE_LIST_EXPANDABLE_ITEM_NUM_PROPERTIES];
enum  {
	GRANITE_WIDGETS_SOURCE_LIST_EXPANDABLE_ITEM_CHILD_ADDED_SIGNAL,
	GRANITE_WIDGETS_SOURCE_LIST_EXPANDABLE_ITEM_CHILD_REMOVED_SIGNAL,
	GRANITE_WIDGETS_SOURCE_LIST_EXPANDABLE_ITEM_TOGGLED_SIGNAL,
	GRANITE_WIDGETS_SOURCE_LIST_EXPANDABLE_ITEM_NUM_SIGNALS
};
static guint granite_widgets_source_list_expandable_item_signals[GRANITE_WIDGETS_SOURCE_LIST_EXPANDABLE_ITEM_NUM_SIGNALS] = {0};
typedef struct _GraniteWidgetsSourceListDataModelPrivate GraniteWidgetsSourceListDataModelPrivate;

#define GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_TYPE_NODE_WRAPPER (granite_widgets_source_list_data_model_node_wrapper_get_type ())
#define GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_NODE_WRAPPER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_TYPE_NODE_WRAPPER, GraniteWidgetsSourceListDataModelNodeWrapper))
#define GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_NODE_WRAPPER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_TYPE_NODE_WRAPPER, GraniteWidgetsSourceListDataModelNodeWrapperClass))
#define GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_IS_NODE_WRAPPER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_TYPE_NODE_WRAPPER))
#define GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_IS_NODE_WRAPPER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_TYPE_NODE_WRAPPER))
#define GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_NODE_WRAPPER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_TYPE_NODE_WRAPPER, GraniteWidgetsSourceListDataModelNodeWrapperClass))

typedef struct _GraniteWidgetsSourceListDataModelNodeWrapper GraniteWidgetsSourceListDataModelNodeWrapper;
typedef struct _GraniteWidgetsSourceListDataModelNodeWrapperClass GraniteWidgetsSourceListDataModelNodeWrapperClass;

#define GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_TYPE_ITEM_MONITOR (granite_widgets_source_list_data_model_item_monitor_get_type ())
#define GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_ITEM_MONITOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_TYPE_ITEM_MONITOR, GraniteWidgetsSourceListDataModelItemMonitor))
#define GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_ITEM_MONITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_TYPE_ITEM_MONITOR, GraniteWidgetsSourceListDataModelItemMonitorClass))
#define GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_IS_ITEM_MONITOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_TYPE_ITEM_MONITOR))
#define GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_IS_ITEM_MONITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_TYPE_ITEM_MONITOR))
#define GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_ITEM_MONITOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_TYPE_ITEM_MONITOR, GraniteWidgetsSourceListDataModelItemMonitorClass))

typedef struct _GraniteWidgetsSourceListDataModelItemMonitor GraniteWidgetsSourceListDataModelItemMonitor;
typedef struct _GraniteWidgetsSourceListDataModelItemMonitorClass GraniteWidgetsSourceListDataModelItemMonitorClass;
enum  {
	GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_0_PROPERTY,
	GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_ROOT_PROPERTY,
	GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_NUM_PROPERTIES
};
static GParamSpec* granite_widgets_source_list_data_model_properties[GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_NUM_PROPERTIES];
typedef enum  {
	GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_COLUMN_ITEM,
	GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_COLUMN_N_COLUMNS
} GraniteWidgetsSourceListDataModelColumn;

#define GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_TYPE_COLUMN (granite_widgets_source_list_data_model_column_get_type ())
#define _granite_widgets_source_list_data_model_node_wrapper_unref0(var) ((var == NULL) ? NULL : (var = (granite_widgets_source_list_data_model_node_wrapper_unref (var), NULL)))
#define _granite_widgets_source_list_data_model_item_monitor_unref0(var) ((var == NULL) ? NULL : (var = (granite_widgets_source_list_data_model_item_monitor_unref (var), NULL)))
typedef struct _Block12Data Block12Data;
typedef struct _GraniteWidgetsSourceListDataModelNodeWrapperPrivate GraniteWidgetsSourceListDataModelNodeWrapperPrivate;
#define __vala_GtkTreeRowReference_free0(var) ((var == NULL) ? NULL : (var = (_vala_GtkTreeRowReference_free (var), NULL)))
typedef struct _GraniteWidgetsSourceListDataModelParamSpecNodeWrapper GraniteWidgetsSourceListDataModelParamSpecNodeWrapper;
typedef struct _GraniteWidgetsSourceListDataModelItemMonitorPrivate GraniteWidgetsSourceListDataModelItemMonitorPrivate;
typedef struct _GraniteWidgetsSourceListDataModelParamSpecItemMonitor GraniteWidgetsSourceListDataModelParamSpecItemMonitor;
enum  {
	GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_ITEM_MONITOR_CHANGED_SIGNAL,
	GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_ITEM_MONITOR_NUM_SIGNALS
};
static guint granite_widgets_source_list_data_model_item_monitor_signals[GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_ITEM_MONITOR_NUM_SIGNALS] = {0};
enum  {
	GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_ITEM_UPDATED_SIGNAL,
	GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_NUM_SIGNALS
};
static guint granite_widgets_source_list_data_model_signals[GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_NUM_SIGNALS] = {0};

#define GRANITE_WIDGETS_SOURCE_LIST_TYPE_CELL_RENDERER_ICON (granite_widgets_source_list_cell_renderer_icon_get_type ())
#define GRANITE_WIDGETS_SOURCE_LIST_CELL_RENDERER_ICON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_WIDGETS_SOURCE_LIST_TYPE_CELL_RENDERER_ICON, GraniteWidgetsSourceListCellRendererIcon))
#define GRANITE_WIDGETS_SOURCE_LIST_CELL_RENDERER_ICON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_WIDGETS_SOURCE_LIST_TYPE_CELL_RENDERER_ICON, GraniteWidgetsSourceListCellRendererIconClass))
#define GRANITE_WIDGETS_SOURCE_LIST_IS_CELL_RENDERER_ICON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_WIDGETS_SOURCE_LIST_TYPE_CELL_RENDERER_ICON))
#define GRANITE_WIDGETS_SOURCE_LIST_IS_CELL_RENDERER_ICON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_WIDGETS_SOURCE_LIST_TYPE_CELL_RENDERER_ICON))
#define GRANITE_WIDGETS_SOURCE_LIST_CELL_RENDERER_ICON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_WIDGETS_SOURCE_LIST_TYPE_CELL_RENDERER_ICON, GraniteWidgetsSourceListCellRendererIconClass))

typedef struct _GraniteWidgetsSourceListCellRendererIcon GraniteWidgetsSourceListCellRendererIcon;
typedef struct _GraniteWidgetsSourceListCellRendererIconClass GraniteWidgetsSourceListCellRendererIconClass;
typedef struct _GraniteWidgetsSourceListCellRendererIconPrivate GraniteWidgetsSourceListCellRendererIconPrivate;
enum  {
	GRANITE_WIDGETS_SOURCE_LIST_CELL_RENDERER_ICON_0_PROPERTY,
	GRANITE_WIDGETS_SOURCE_LIST_CELL_RENDERER_ICON_NUM_PROPERTIES
};
static GParamSpec* granite_widgets_source_list_cell_renderer_icon_properties[GRANITE_WIDGETS_SOURCE_LIST_CELL_RENDERER_ICON_NUM_PROPERTIES];
enum  {
	GRANITE_WIDGETS_SOURCE_LIST_CELL_RENDERER_ICON_ACTIVATED_SIGNAL,
	GRANITE_WIDGETS_SOURCE_LIST_CELL_RENDERER_ICON_NUM_SIGNALS
};
static guint granite_widgets_source_list_cell_renderer_icon_signals[GRANITE_WIDGETS_SOURCE_LIST_CELL_RENDERER_ICON_NUM_SIGNALS] = {0};

#define GRANITE_WIDGETS_SOURCE_LIST_TYPE_CELL_RENDERER_SPACER (granite_widgets_source_list_cell_renderer_spacer_get_type ())
#define GRANITE_WIDGETS_SOURCE_LIST_CELL_RENDERER_SPACER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_WIDGETS_SOURCE_LIST_TYPE_CELL_RENDERER_SPACER, GraniteWidgetsSourceListCellRendererSpacer))
#define GRANITE_WIDGETS_SOURCE_LIST_CELL_RENDERER_SPACER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_WIDGETS_SOURCE_LIST_TYPE_CELL_RENDERER_SPACER, GraniteWidgetsSourceListCellRendererSpacerClass))
#define GRANITE_WIDGETS_SOURCE_LIST_IS_CELL_RENDERER_SPACER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_WIDGETS_SOURCE_LIST_TYPE_CELL_RENDERER_SPACER))
#define GRANITE_WIDGETS_SOURCE_LIST_IS_CELL_RENDERER_SPACER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_WIDGETS_SOURCE_LIST_TYPE_CELL_RENDERER_SPACER))
#define GRANITE_WIDGETS_SOURCE_LIST_CELL_RENDERER_SPACER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_WIDGETS_SOURCE_LIST_TYPE_CELL_RENDERER_SPACER, GraniteWidgetsSourceListCellRendererSpacerClass))

typedef struct _GraniteWidgetsSourceListCellRendererSpacer GraniteWidgetsSourceListCellRendererSpacer;
typedef struct _GraniteWidgetsSourceListCellRendererSpacerClass GraniteWidgetsSourceListCellRendererSpacerClass;
typedef struct _GraniteWidgetsSourceListCellRendererSpacerPrivate GraniteWidgetsSourceListCellRendererSpacerPrivate;
enum  {
	GRANITE_WIDGETS_SOURCE_LIST_CELL_RENDERER_SPACER_0_PROPERTY,
	GRANITE_WIDGETS_SOURCE_LIST_CELL_RENDERER_SPACER_LEVEL_PROPERTY,
	GRANITE_WIDGETS_SOURCE_LIST_CELL_RENDERER_SPACER_NUM_PROPERTIES
};
static GParamSpec* granite_widgets_source_list_cell_renderer_spacer_properties[GRANITE_WIDGETS_SOURCE_LIST_CELL_RENDERER_SPACER_NUM_PROPERTIES];
typedef struct _GraniteWidgetsSourceListTreePrivate GraniteWidgetsSourceListTreePrivate;
enum  {
	GRANITE_WIDGETS_SOURCE_LIST_TREE_0_PROPERTY,
	GRANITE_WIDGETS_SOURCE_LIST_TREE_DATA_MODEL_PROPERTY,
	GRANITE_WIDGETS_SOURCE_LIST_TREE_SELECTED_ITEM_PROPERTY,
	GRANITE_WIDGETS_SOURCE_LIST_TREE_EDITING_PROPERTY,
	GRANITE_WIDGETS_SOURCE_LIST_TREE_ELLIPSIZE_MODE_PROPERTY,
	GRANITE_WIDGETS_SOURCE_LIST_TREE_NUM_PROPERTIES
};
static GParamSpec* granite_widgets_source_list_tree_properties[GRANITE_WIDGETS_SOURCE_LIST_TREE_NUM_PROPERTIES];
typedef enum  {
	GRANITE_WIDGETS_SOURCE_LIST_TREE_COLUMN_ITEM,
	GRANITE_WIDGETS_SOURCE_LIST_TREE_COLUMN_N_COLS
} GraniteWidgetsSourceListTreeColumn;

#define GRANITE_WIDGETS_SOURCE_LIST_TREE_TYPE_COLUMN (granite_widgets_source_list_tree_column_get_type ())
#define _gtk_target_list_unref0(var) ((var == NULL) ? NULL : (var = (gtk_target_list_unref (var), NULL)))
#define _g_string_free0(var) ((var == NULL) ? NULL : (var = (g_string_free (var, TRUE), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _g_param_spec_unref0(var) ((var == NULL) ? NULL : (var = (g_param_spec_unref (var), NULL)))
enum  {
	GRANITE_WIDGETS_SOURCE_LIST_TREE_ITEM_SELECTED_SIGNAL,
	GRANITE_WIDGETS_SOURCE_LIST_TREE_NUM_SIGNALS
};
static guint granite_widgets_source_list_tree_signals[GRANITE_WIDGETS_SOURCE_LIST_TREE_NUM_SIGNALS] = {0};
enum  {
	GRANITE_WIDGETS_SOURCE_LIST_ITEM_SELECTED_SIGNAL,
	GRANITE_WIDGETS_SOURCE_LIST_NUM_SIGNALS
};
static guint granite_widgets_source_list_signals[GRANITE_WIDGETS_SOURCE_LIST_NUM_SIGNALS] = {0};
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _GraniteWidgetsSourceListPrivate {
	GraniteWidgetsSourceListTree* tree;
	GraniteWidgetsSourceListDataModel* data_model;
};

struct _GraniteWidgetsSourceListItemPrivate {
	GraniteWidgetsSourceListExpandableItem* _parent;
	gchar* _name;
	gchar* _tooltip;
	gchar* _markup;
	gchar* _badge;
	gboolean _editable;
	gboolean _visible;
	gboolean _selectable;
	GIcon* _icon;
	GIcon* _activatable;
	gchar* _activatable_tooltip;
};

struct _GraniteWidgetsSourceListExpandableItemPrivate {
	gboolean _collapsible;
	gboolean _expanded;
	GeeCollection* children_list;
};

struct _GraniteWidgetsSourceListDataModel {
	GtkTreeModelFilter parent_instance;
	GraniteWidgetsSourceListDataModelPrivate * priv;
};

struct _GraniteWidgetsSourceListDataModelClass {
	GtkTreeModelFilterClass parent_class;
};

struct _GraniteWidgetsSourceListDataModelPrivate {
	GraniteWidgetsSourceListExpandableItem* _root;
	GeeHashMap* items;
	GeeHashMap* monitors;
	GtkTreeStore* child_tree;
	GraniteWidgetsSourceListVisibleFunc filter_func;
	gpointer filter_func_target;
};

struct _Block12Data {
	int _ref_count_;
	GraniteWidgetsSourceListDataModel* self;
	GraniteWidgetsSourceListExpandableItem* parent;
};

struct _GraniteWidgetsSourceListDataModelNodeWrapper {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GraniteWidgetsSourceListDataModelNodeWrapperPrivate * priv;
};

struct _GraniteWidgetsSourceListDataModelNodeWrapperClass {
	GTypeClass parent_class;
	void (*finalize) (GraniteWidgetsSourceListDataModelNodeWrapper *self);
};

struct _GraniteWidgetsSourceListDataModelNodeWrapperPrivate {
	GtkTreeRowReference* row_reference;
};

struct _GraniteWidgetsSourceListDataModelParamSpecNodeWrapper {
	GParamSpec parent_instance;
};

struct _GraniteWidgetsSourceListDataModelItemMonitor {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GraniteWidgetsSourceListDataModelItemMonitorPrivate * priv;
};

struct _GraniteWidgetsSourceListDataModelItemMonitorClass {
	GTypeClass parent_class;
	void (*finalize) (GraniteWidgetsSourceListDataModelItemMonitor *self);
};

struct _GraniteWidgetsSourceListDataModelItemMonitorPrivate {
	GraniteWidgetsSourceListItem* item;
};

struct _GraniteWidgetsSourceListDataModelParamSpecItemMonitor {
	GParamSpec parent_instance;
};

struct _GraniteWidgetsSourceListCellRendererIcon {
	GtkCellRendererPixbuf parent_instance;
	GraniteWidgetsSourceListCellRendererIconPrivate * priv;
};

struct _GraniteWidgetsSourceListCellRendererIconClass {
	GtkCellRendererPixbufClass parent_class;
};

struct _GraniteWidgetsSourceListCellRendererSpacer {
	GtkCellRenderer parent_instance;
	GraniteWidgetsSourceListCellRendererSpacerPrivate * priv;
};

struct _GraniteWidgetsSourceListCellRendererSpacerClass {
	GtkCellRendererClass parent_class;
};

struct _GraniteWidgetsSourceListCellRendererSpacerPrivate {
	gint _level;
};

struct _GraniteWidgetsSourceListTree {
	GtkTreeView parent_instance;
	GraniteWidgetsSourceListTreePrivate * priv;
};

struct _GraniteWidgetsSourceListTreeClass {
	GtkTreeViewClass parent_class;
};

struct _GraniteWidgetsSourceListTreePrivate {
	GraniteWidgetsSourceListDataModel* _data_model;
	GraniteWidgetsSourceListItem* selected;
	GraniteWidgetsSourceListItem* edited;
	GtkEntry* editable_entry;
	GtkCellRendererText* text_cell;
	GraniteWidgetsSourceListCellRendererIcon* icon_cell;
	GraniteWidgetsSourceListCellRendererIcon* activatable_cell;
	GraniteWidgetsCellRendererBadge* badge_cell;
	GraniteWidgetsCellRendererExpander* primary_expander_cell;
	GraniteWidgetsCellRendererExpander* secondary_expander_cell;
	GeeHashMap* spacer_cells;
	gboolean unselectable_item_clicked;
};

static gint GraniteWidgetsSourceList_private_offset;
static gpointer granite_widgets_source_list_parent_class = NULL;
static gint GraniteWidgetsSourceListItem_private_offset;
static gpointer granite_widgets_source_list_item_parent_class = NULL;
static gint GraniteWidgetsSourceListExpandableItem_private_offset;
static gpointer granite_widgets_source_list_expandable_item_parent_class = NULL;
static gint GraniteWidgetsSourceListDataModel_private_offset;
static gpointer granite_widgets_source_list_data_model_parent_class = NULL;
static gint GraniteWidgetsSourceListDataModelNodeWrapper_private_offset;
static gpointer granite_widgets_source_list_data_model_node_wrapper_parent_class = NULL;
static gint GraniteWidgetsSourceListDataModelItemMonitor_private_offset;
static gpointer granite_widgets_source_list_data_model_item_monitor_parent_class = NULL;
static GtkTreeDragSourceIface * granite_widgets_source_list_data_model_gtk_tree_drag_source_parent_iface = NULL;
static GtkTreeDragDestIface * granite_widgets_source_list_data_model_gtk_tree_drag_dest_parent_iface = NULL;
static gpointer granite_widgets_source_list_cell_renderer_icon_parent_class = NULL;
static gint GraniteWidgetsSourceListCellRendererSpacer_private_offset;
static gpointer granite_widgets_source_list_cell_renderer_spacer_parent_class = NULL;
static gint GraniteWidgetsSourceListTree_private_offset;
static gpointer granite_widgets_source_list_tree_parent_class = NULL;

static GType granite_widgets_source_list_sortable_get_type_once (void);
static GType granite_widgets_source_list_drag_source_get_type_once (void);
static GType granite_widgets_source_list_drag_dest_get_type_once (void);
static GType granite_widgets_source_list_tree_get_type (void) G_GNUC_CONST  G_GNUC_UNUSED ;
static GType granite_widgets_source_list_data_model_get_type (void) G_GNUC_CONST  G_GNUC_UNUSED ;
static void granite_widgets_source_list_real_item_selected (GraniteWidgetsSourceList* self,
                                                     GraniteWidgetsSourceListItem* item);
static GraniteWidgetsSourceListExpandableItem* granite_widgets_source_list_data_model_get_root (GraniteWidgetsSourceListDataModel* self);
static void granite_widgets_source_list_data_model_set_root (GraniteWidgetsSourceListDataModel* self,
                                                      GraniteWidgetsSourceListExpandableItem* value);
static GraniteWidgetsSourceListItem* granite_widgets_source_list_tree_get_selected_item (GraniteWidgetsSourceListTree* self);
static void granite_widgets_source_list_tree_set_selected_item (GraniteWidgetsSourceListTree* self,
                                                         GraniteWidgetsSourceListItem* value);
static PangoEllipsizeMode granite_widgets_source_list_tree_get_ellipsize_mode (GraniteWidgetsSourceListTree* self);
static void granite_widgets_source_list_tree_set_ellipsize_mode (GraniteWidgetsSourceListTree* self,
                                                          PangoEllipsizeMode value);
static gboolean granite_widgets_source_list_tree_get_editing (GraniteWidgetsSourceListTree* self);
static GraniteWidgetsSourceListDataModel* granite_widgets_source_list_data_model_new (void);
static GraniteWidgetsSourceListDataModel* granite_widgets_source_list_data_model_construct (GType object_type);
static gboolean granite_widgets_source_list_data_model_has_item (GraniteWidgetsSourceListDataModel* self,
                                                          GraniteWidgetsSourceListItem* item);
static void granite_widgets_source_list_data_model_set_filter_func (GraniteWidgetsSourceListDataModel* self,
                                                             GraniteWidgetsSourceListVisibleFunc visible_func,
                                                             gpointer visible_func_target);
static GtkTreePath* granite_widgets_source_list_data_model_get_item_path (GraniteWidgetsSourceListDataModel* self,
                                                                   GraniteWidgetsSourceListItem* item);
static void _vala_GtkTreePath_free (GtkTreePath* self);
static gboolean granite_widgets_source_list_tree_start_editing_item (GraniteWidgetsSourceListTree* self,
                                                              GraniteWidgetsSourceListItem* item);
static void granite_widgets_source_list_tree_stop_editing (GraniteWidgetsSourceListTree* self);
static void granite_widgets_source_list_tree_configure_drag_source (GraniteWidgetsSourceListTree* self,
                                                             GtkTargetEntry* src_entries,
                                                             gint src_entries_length1);
static void granite_widgets_source_list_tree_configure_drag_dest (GraniteWidgetsSourceListTree* self,
                                                           GtkTargetEntry* dest_entries,
                                                           gint dest_entries_length1,
                                                           GdkDragAction actions);
static gboolean granite_widgets_source_list_tree_scroll_to_item (GraniteWidgetsSourceListTree* self,
                                                          GraniteWidgetsSourceListItem* item,
                                                          gboolean use_align,
                                                          gfloat row_align);
static GtkTreeIter* granite_widgets_source_list_data_model_get_item_iter (GraniteWidgetsSourceListDataModel* self,
                                                                   GraniteWidgetsSourceListItem* item);
static GraniteWidgetsSourceListItem* granite_widgets_source_list_data_model_get_item (GraniteWidgetsSourceListDataModel* self,
                                                                               GtkTreeIter* iter);
static void _vala_GtkTreeIter_free (GtkTreeIter* self);
static GraniteWidgetsSourceListItem* granite_widgets_source_list_get_nth_child (GraniteWidgetsSourceList* self,
                                                                         GraniteWidgetsSourceListExpandableItem* parent,
                                                                         gint index);
static void granite_widgets_source_list_item_real_edited (GraniteWidgetsSourceListItem* self,
                                                   const gchar* new_name);
static void granite_widgets_source_list_item_real_action_activated (GraniteWidgetsSourceListItem* self);
static void granite_widgets_source_list_item_real_activated (GraniteWidgetsSourceListItem* self);
 G_GNUC_INTERNAL void granite_widgets_source_list_item_set_parent (GraniteWidgetsSourceListItem* self,
                                                  GraniteWidgetsSourceListExpandableItem* value);
static GtkMenu* granite_widgets_source_list_item_real_get_context_menu (GraniteWidgetsSourceListItem* self);
static void granite_widgets_source_list_item_finalize (GObject * obj);
static GType granite_widgets_source_list_item_get_type_once (void);
static void _vala_granite_widgets_source_list_item_get_property (GObject * object,
                                                          guint property_id,
                                                          GValue * value,
                                                          GParamSpec * pspec);
static void _vala_granite_widgets_source_list_item_set_property (GObject * object,
                                                          guint property_id,
                                                          const GValue * value,
                                                          GParamSpec * pspec);
static void granite_widgets_source_list_expandable_item_real_toggled (GraniteWidgetsSourceListExpandableItem* self);
static void granite_widgets_source_list_expandable_item_set_expansion (GraniteWidgetsSourceListExpandableItem* item,
                                                                gboolean inclusive,
                                                                gboolean recursive,
                                                                gboolean expanded);
static GObject * granite_widgets_source_list_expandable_item_constructor (GType type,
                                                                   guint n_construct_properties,
                                                                   GObjectConstructParam * construct_properties);
static void granite_widgets_source_list_expandable_item_finalize (GObject * obj);
static GType granite_widgets_source_list_expandable_item_get_type_once (void);
static void _vala_granite_widgets_source_list_expandable_item_get_property (GObject * object,
                                                                     guint property_id,
                                                                     GValue * value,
                                                                     GParamSpec * pspec);
static void _vala_granite_widgets_source_list_expandable_item_set_property (GObject * object,
                                                                     guint property_id,
                                                                     const GValue * value,
                                                                     GParamSpec * pspec);
static gpointer granite_widgets_source_list_data_model_node_wrapper_ref (gpointer instance);
static void granite_widgets_source_list_data_model_node_wrapper_unref (gpointer instance);
static GParamSpec* granite_widgets_source_list_data_model_param_spec_node_wrapper (const gchar* name,
                                                                            const gchar* nick,
                                                                            const gchar* blurb,
                                                                            GType object_type,
                                                                            GParamFlags flags) G_GNUC_UNUSED ;
static void granite_widgets_source_list_data_model_value_set_node_wrapper (GValue* value,
                                                                    gpointer v_object) G_GNUC_UNUSED ;
static void granite_widgets_source_list_data_model_value_take_node_wrapper (GValue* value,
                                                                     gpointer v_object) G_GNUC_UNUSED ;
static gpointer granite_widgets_source_list_data_model_value_get_node_wrapper (const GValue* value) G_GNUC_UNUSED ;
static GType granite_widgets_source_list_data_model_node_wrapper_get_type (void) G_GNUC_CONST  G_GNUC_UNUSED ;
static gpointer granite_widgets_source_list_data_model_item_monitor_ref (gpointer instance);
static void granite_widgets_source_list_data_model_item_monitor_unref (gpointer instance);
static GParamSpec* granite_widgets_source_list_data_model_param_spec_item_monitor (const gchar* name,
                                                                            const gchar* nick,
                                                                            const gchar* blurb,
                                                                            GType object_type,
                                                                            GParamFlags flags) G_GNUC_UNUSED ;
static void granite_widgets_source_list_data_model_value_set_item_monitor (GValue* value,
                                                                    gpointer v_object) G_GNUC_UNUSED ;
static void granite_widgets_source_list_data_model_value_take_item_monitor (GValue* value,
                                                                     gpointer v_object) G_GNUC_UNUSED ;
static gpointer granite_widgets_source_list_data_model_value_get_item_monitor (const GValue* value) G_GNUC_UNUSED ;
static GType granite_widgets_source_list_data_model_item_monitor_get_type (void) G_GNUC_CONST  G_GNUC_UNUSED ;
static GType granite_widgets_source_list_data_model_column_get_type (void) G_GNUC_CONST  G_GNUC_UNUSED ;
static GType granite_widgets_source_list_data_model_column_type (GraniteWidgetsSourceListDataModelColumn self);
static void granite_widgets_source_list_data_model_remove_children_monitor (GraniteWidgetsSourceListDataModel* self,
                                                                     GraniteWidgetsSourceListExpandableItem* item);
static void granite_widgets_source_list_data_model_remove_item (GraniteWidgetsSourceListDataModel* self,
                                                         GraniteWidgetsSourceListItem* item);
static void granite_widgets_source_list_data_model_add_children_monitor (GraniteWidgetsSourceListDataModel* self,
                                                                  GraniteWidgetsSourceListExpandableItem* item);
static void granite_widgets_source_list_data_model_add_item (GraniteWidgetsSourceListDataModel* self,
                                                      GraniteWidgetsSourceListItem* item);
static void granite_widgets_source_list_data_model_update_item (GraniteWidgetsSourceListDataModel* self,
                                                         GraniteWidgetsSourceListItem* item);
static GtkTreePath* granite_widgets_source_list_data_model_node_wrapper_get_path (GraniteWidgetsSourceListDataModelNodeWrapper* self);
static GtkTreeIter* granite_widgets_source_list_data_model_node_wrapper_get_iter (GraniteWidgetsSourceListDataModelNodeWrapper* self);
static GtkTreeIter* granite_widgets_source_list_data_model_get_item_child_iter (GraniteWidgetsSourceListDataModel* self,
                                                                         GraniteWidgetsSourceListItem* item);
static GtkTreeIter* _vala_GtkTreeIter_copy (GtkTreeIter* self);
static GraniteWidgetsSourceListDataModelNodeWrapper* granite_widgets_source_list_data_model_node_wrapper_new (GtkTreeModel* model,
                                                                                                       GtkTreeIter* iter);
static GraniteWidgetsSourceListDataModelNodeWrapper* granite_widgets_source_list_data_model_node_wrapper_construct (GType object_type,
                                                                                                             GtkTreeModel* model,
                                                                                                             GtkTreeIter* iter);
static void granite_widgets_source_list_data_model_add_property_monitor (GraniteWidgetsSourceListDataModel* self,
                                                                  GraniteWidgetsSourceListItem* item);
static void granite_widgets_source_list_data_model_push_parent_update (GraniteWidgetsSourceListDataModel* self,
                                                                GraniteWidgetsSourceListExpandableItem* parent);
static void granite_widgets_source_list_data_model_remove_property_monitor (GraniteWidgetsSourceListDataModel* self,
                                                                     GraniteWidgetsSourceListItem* item);
static GraniteWidgetsSourceListDataModelItemMonitor* granite_widgets_source_list_data_model_item_monitor_new (GraniteWidgetsSourceListItem* item);
static GraniteWidgetsSourceListDataModelItemMonitor* granite_widgets_source_list_data_model_item_monitor_construct (GType object_type,
                                                                                                             GraniteWidgetsSourceListItem* item);
static void granite_widgets_source_list_data_model_on_item_prop_changed (GraniteWidgetsSourceListDataModel* self,
                                                                  GraniteWidgetsSourceListItem* item,
                                                                  const gchar* prop_name);
static void _granite_widgets_source_list_data_model_on_item_prop_changed_granite_widgets_source_list_data_model_item_monitor_changed (GraniteWidgetsSourceListDataModelItemMonitor* _sender,
                                                                                                                               GraniteWidgetsSourceListItem* _self_,
                                                                                                                               const gchar* prop_name,
                                                                                                                               gpointer self);
static void granite_widgets_source_list_data_model_on_item_child_added (GraniteWidgetsSourceListDataModel* self,
                                                                 GraniteWidgetsSourceListItem* item);
static void _granite_widgets_source_list_data_model_on_item_child_added_granite_widgets_source_list_expandable_item_child_added (GraniteWidgetsSourceListExpandableItem* _sender,
                                                                                                                          GraniteWidgetsSourceListItem* item,
                                                                                                                          gpointer self);
static void granite_widgets_source_list_data_model_on_item_child_removed (GraniteWidgetsSourceListDataModel* self,
                                                                   GraniteWidgetsSourceListItem* item);
static void _granite_widgets_source_list_data_model_on_item_child_removed_granite_widgets_source_list_expandable_item_child_removed (GraniteWidgetsSourceListExpandableItem* _sender,
                                                                                                                              GraniteWidgetsSourceListItem* item,
                                                                                                                              gpointer self);
static Block12Data* block12_data_ref (Block12Data* _data12_);
static void block12_data_unref (void * _userdata_);
static gboolean ___lambda80_ (Block12Data* _data12_);
static gboolean ____lambda80__gsource_func (gpointer self);
static GraniteWidgetsSourceListItem* granite_widgets_source_list_data_model_get_item_from_path (GraniteWidgetsSourceListDataModel* self,
                                                                                         GtkTreePath* path);
static GtkTreePath* granite_widgets_source_list_data_model_get_item_child_path (GraniteWidgetsSourceListDataModel* self,
                                                                         GraniteWidgetsSourceListItem* item);
static gboolean granite_widgets_source_list_data_model_is_category (GraniteWidgetsSourceListDataModel* self,
                                                             GraniteWidgetsSourceListItem* item,
                                                             GtkTreeIter* iter,
                                                             GtkTreePath* path);
static gboolean granite_widgets_source_list_data_model_is_iter_at_root_level (GraniteWidgetsSourceListDataModel* self,
                                                                       GtkTreeIter* iter);
static gboolean granite_widgets_source_list_data_model_is_path_at_root_level (GraniteWidgetsSourceListDataModel* self,
                                                                       GtkTreePath* path);
static void granite_widgets_source_list_data_model_resort (GraniteWidgetsSourceListDataModel* self);
static gint granite_widgets_source_list_data_model_child_model_sort_func (GraniteWidgetsSourceListDataModel* self,
                                                                   GtkTreeModel* model,
                                                                   GtkTreeIter* a,
                                                                   GtkTreeIter* b);
static gboolean granite_widgets_source_list_data_model_filter_visible_func (GraniteWidgetsSourceListDataModel* self,
                                                                     GtkTreeModel* child_model,
                                                                     GtkTreeIter* iter);
static gboolean granite_widgets_source_list_data_model_real_drag_data_received (GtkTreeDragDest* base,
                                                                         GtkTreePath* dest,
                                                                         GtkSelectionData* selection_data);
static gboolean granite_widgets_source_list_data_model_child_tree_drag_data_received (GraniteWidgetsSourceListDataModel* self,
                                                                               GtkTreePath* dest,
                                                                               GtkTreePath* src_path);
static GtkTreePath* _vala_GtkTreePath_copy (GtkTreePath* self);
static void granite_widgets_source_list_data_model_recursive_node_copy (GraniteWidgetsSourceListDataModel* self,
                                                                 GtkTreeIter* src_iter,
                                                                 GtkTreeIter* dest_iter);
static void granite_widgets_source_list_data_model_move_item (GraniteWidgetsSourceListDataModel* self,
                                                       GtkTreeIter* src_iter,
                                                       GtkTreeIter* dest_iter);
static gboolean granite_widgets_source_list_data_model_real_row_drop_possible (GtkTreeDragDest* base,
                                                                        GtkTreePath* dest,
                                                                        GtkSelectionData* selection_data);
static gint* _vala_array_dup1 (gint* self,
                        gssize length);
static gint* _vala_array_dup2 (gint* self,
                        gssize length);
static gboolean granite_widgets_source_list_data_model_real_drag_data_get (GtkTreeDragSource* base,
                                                                    GtkTreePath* path,
                                                                    GtkSelectionData* selection_data);
static gboolean granite_widgets_source_list_data_model_real_row_draggable (GtkTreeDragSource* base,
                                                                    GtkTreePath* path);
static void _vala_GtkTreeRowReference_free (GtkTreeRowReference* self);
static gboolean granite_widgets_source_list_data_model_node_wrapper_get_valid (GraniteWidgetsSourceListDataModelNodeWrapper* self);
static void granite_widgets_source_list_data_model_node_wrapper_finalize (GraniteWidgetsSourceListDataModelNodeWrapper * obj);
static GType granite_widgets_source_list_data_model_node_wrapper_get_type_once (void);
static void granite_widgets_source_list_data_model_item_monitor_on_notify (GraniteWidgetsSourceListDataModelItemMonitor* self,
                                                                    GParamSpec* prop);
static void _granite_widgets_source_list_data_model_item_monitor_on_notify_g_object_notify (GObject* _sender,
                                                                                     GParamSpec* pspec,
                                                                                     gpointer self);
static void g_cclosure_user_marshal_VOID__OBJECT_STRING (GClosure * closure,
                                                  GValue * return_value,
                                                  guint n_param_values,
                                                  const GValue * param_values,
                                                  gpointer invocation_hint,
                                                  gpointer marshal_data);
static void granite_widgets_source_list_data_model_item_monitor_finalize (GraniteWidgetsSourceListDataModelItemMonitor * obj);
static GType granite_widgets_source_list_data_model_item_monitor_get_type_once (void);
static GObject * granite_widgets_source_list_data_model_constructor (GType type,
                                                              guint n_construct_properties,
                                                              GObjectConstructParam * construct_properties);
static gint _granite_widgets_source_list_data_model_child_model_sort_func_gtk_tree_iter_compare_func (GtkTreeModel* model,
                                                                                               GtkTreeIter* a,
                                                                                               GtkTreeIter* b,
                                                                                               gpointer self);
static gboolean _granite_widgets_source_list_data_model_filter_visible_func_gtk_tree_model_filter_visible_func (GtkTreeModel* model,
                                                                                                         GtkTreeIter* iter,
                                                                                                         gpointer self);
static void granite_widgets_source_list_data_model_finalize (GObject * obj);
static GType granite_widgets_source_list_data_model_get_type_once (void);
static void _vala_granite_widgets_source_list_data_model_get_property (GObject * object,
                                                                guint property_id,
                                                                GValue * value,
                                                                GParamSpec * pspec);
static void _vala_granite_widgets_source_list_data_model_set_property (GObject * object,
                                                                guint property_id,
                                                                const GValue * value,
                                                                GParamSpec * pspec);
static GType granite_widgets_source_list_cell_renderer_icon_get_type (void) G_GNUC_CONST  G_GNUC_UNUSED ;
static GraniteWidgetsSourceListCellRendererIcon* granite_widgets_source_list_cell_renderer_icon_new (void);
static GraniteWidgetsSourceListCellRendererIcon* granite_widgets_source_list_cell_renderer_icon_construct (GType object_type);
static gboolean granite_widgets_source_list_cell_renderer_icon_real_activate (GtkCellRenderer* base,
                                                                       GdkEvent* event,
                                                                       GtkWidget* widget,
                                                                       const gchar* path,
                                                                       GdkRectangle* background_area,
                                                                       GdkRectangle* cell_area,
                                                                       GtkCellRendererState flags);
static GObject * granite_widgets_source_list_cell_renderer_icon_constructor (GType type,
                                                                      guint n_construct_properties,
                                                                      GObjectConstructParam * construct_properties);
static GType granite_widgets_source_list_cell_renderer_icon_get_type_once (void);
static GType granite_widgets_source_list_cell_renderer_spacer_get_type (void) G_GNUC_CONST  G_GNUC_UNUSED ;
static gint granite_widgets_source_list_cell_renderer_spacer_get_level (GraniteWidgetsSourceListCellRendererSpacer* self);
static void granite_widgets_source_list_cell_renderer_spacer_set_level (GraniteWidgetsSourceListCellRendererSpacer* self,
                                                                 gint value);
static GtkSizeRequestMode granite_widgets_source_list_cell_renderer_spacer_real_get_request_mode (GtkCellRenderer* base);
static void granite_widgets_source_list_cell_renderer_spacer_real_get_preferred_width (GtkCellRenderer* base,
                                                                                GtkWidget* widget,
                                                                                gint* min_size,
                                                                                gint* natural_size);
static void granite_widgets_source_list_cell_renderer_spacer_real_get_preferred_height_for_width (GtkCellRenderer* base,
                                                                                           GtkWidget* widget,
                                                                                           gint width,
                                                                                           gint* min_height,
                                                                                           gint* natural_height);
static void granite_widgets_source_list_cell_renderer_spacer_real_render (GtkCellRenderer* base,
                                                                   cairo_t* context,
                                                                   GtkWidget* widget,
                                                                   GdkRectangle* bg_area,
                                                                   GdkRectangle* cell_area,
                                                                   GtkCellRendererState flags);
static GraniteWidgetsSourceListCellRendererSpacer* granite_widgets_source_list_cell_renderer_spacer_new (void);
static GraniteWidgetsSourceListCellRendererSpacer* granite_widgets_source_list_cell_renderer_spacer_construct (GType object_type);
static void granite_widgets_source_list_cell_renderer_spacer_finalize (GObject * obj);
static GType granite_widgets_source_list_cell_renderer_spacer_get_type_once (void);
static void _vala_granite_widgets_source_list_cell_renderer_spacer_get_property (GObject * object,
                                                                          guint property_id,
                                                                          GValue * value,
                                                                          GParamSpec * pspec);
static void _vala_granite_widgets_source_list_cell_renderer_spacer_set_property (GObject * object,
                                                                          guint property_id,
                                                                          const GValue * value,
                                                                          GParamSpec * pspec);
static void granite_widgets_source_list_tree_disable_item_property_monitor (GraniteWidgetsSourceListTree* self);
static GType granite_widgets_source_list_tree_column_get_type (void) G_GNUC_CONST  G_GNUC_UNUSED ;
static GraniteWidgetsSourceListDataModel* granite_widgets_source_list_tree_get_data_model (GraniteWidgetsSourceListTree* self);
static void granite_widgets_source_list_tree_set_data_model (GraniteWidgetsSourceListTree* self,
                                                      GraniteWidgetsSourceListDataModel* value);
static void granite_widgets_source_list_tree_set_selected (GraniteWidgetsSourceListTree* self,
                                                    GraniteWidgetsSourceListItem* item,
                                                    gboolean scroll_to_item);
static GraniteWidgetsSourceListTree* granite_widgets_source_list_tree_new (GraniteWidgetsSourceListDataModel* data_model);
static GraniteWidgetsSourceListTree* granite_widgets_source_list_tree_construct (GType object_type,
                                                                          GraniteWidgetsSourceListDataModel* data_model);
static gboolean granite_widgets_source_list_tree_real_drag_motion (GtkWidget* base,
                                                            GdkDragContext* context,
                                                            gint x,
                                                            gint y,
                                                            guint time);
static void granite_widgets_source_list_tree_real_drag_data_received (GtkWidget* base,
                                                               GdkDragContext* context,
                                                               gint x,
                                                               gint y,
                                                               GtkSelectionData* selection_data,
                                                               guint info,
                                                               guint time);
static GtkTargetEntry* granite_widgets_source_list_tree_append_row_target_entry (GtkTargetEntry* orig,
                                                                          gint orig_length1,
                                                                          gint* result_length1);
static gboolean granite_widgets_source_list_tree_on_query_tooltip (GraniteWidgetsSourceListTree* self,
                                                            gint x,
                                                            gint y,
                                                            gboolean keyboard_tooltip,
                                                            GtkTooltip* tooltip);
static gboolean granite_widgets_source_list_tree_over_cell (GraniteWidgetsSourceListTree* self,
                                                     GtkTreeViewColumn* col,
                                                     GtkTreePath* path,
                                                     GtkCellRenderer* cell,
                                                     gint x);
static void _vala_array_add2 (GtkTargetEntry* * array,
                       gint* length,
                       gint* size,
                       const GtkTargetEntry* value);
static void _vala_array_add3 (GtkTargetEntry* * array,
                       gint* length,
                       gint* size,
                       const GtkTargetEntry* value);
static void granite_widgets_source_list_tree_enable_item_property_monitor (GraniteWidgetsSourceListTree* self);
static void granite_widgets_source_list_tree_on_model_item_updated (GraniteWidgetsSourceListTree* self,
                                                             GraniteWidgetsSourceListItem* item);
static void _granite_widgets_source_list_tree_on_model_item_updated_granite_widgets_source_list_data_model_item_updated (GraniteWidgetsSourceListDataModel* _sender,
                                                                                                                  GraniteWidgetsSourceListItem* item,
                                                                                                                  gpointer self);
static void granite_widgets_source_list_tree_update_expansion (GraniteWidgetsSourceListTree* self,
                                                        GraniteWidgetsSourceListExpandableItem* expandable_item);
static void granite_widgets_source_list_tree_add_spacer_cell_for_level (GraniteWidgetsSourceListTree* self,
                                                                 gint level,
                                                                 gboolean check_previous);
static void granite_widgets_source_list_tree_spacer_cell_data_func (GtkCellLayout* layout,
                                                             GtkCellRenderer* renderer,
                                                             GtkTreeModel* model,
                                                             GtkTreeIter* iter);
static void _granite_widgets_source_list_tree_spacer_cell_data_func_gtk_cell_layout_data_func (GtkCellLayout* cell_layout,
                                                                                        GtkCellRenderer* cell,
                                                                                        GtkTreeModel* tree_model,
                                                                                        GtkTreeIter* iter,
                                                                                        gpointer self);
static gboolean granite_widgets_source_list_tree_select_func (GraniteWidgetsSourceListTree* self,
                                                       GtkTreeSelection* selection,
                                                       GtkTreeModel* model,
                                                       GtkTreePath* path,
                                                       gboolean path_currently_selected);
static GtkTreePath* granite_widgets_source_list_tree_get_selected_path (GraniteWidgetsSourceListTree* self);
static void __vala_GtkTreePath_free0_ (gpointer var);
static inline void _g_list_free___vala_GtkTreePath_free0_ (GList* self);
static void granite_widgets_source_list_tree_real_cursor_changed (GtkTreeView* base);
static void granite_widgets_source_list_tree_on_editing_started (GraniteWidgetsSourceListTree* self,
                                                          GtkCellEditable* editable,
                                                          const gchar* path);
static void granite_widgets_source_list_tree_on_editing_done (GraniteWidgetsSourceListTree* self);
static void _granite_widgets_source_list_tree_on_editing_done_gtk_cell_editable_editing_done (GtkCellEditable* _sender,
                                                                                       gpointer self);
static void granite_widgets_source_list_tree_on_editing_canceled (GraniteWidgetsSourceListTree* self);
static void granite_widgets_source_list_tree_on_activatable_activated (GraniteWidgetsSourceListTree* self,
                                                                const gchar* item_path_str);
static GraniteWidgetsSourceListItem* granite_widgets_source_list_tree_get_item_from_path_string (GraniteWidgetsSourceListTree* self,
                                                                                          const gchar* item_path_str);
static gboolean granite_widgets_source_list_tree_toggle_expansion (GraniteWidgetsSourceListTree* self,
                                                            GraniteWidgetsSourceListExpandableItem* item);
static void granite_widgets_source_list_tree_real_row_expanded (GtkTreeView* base,
                                                         GtkTreeIter* iter,
                                                         GtkTreePath* path);
static void granite_widgets_source_list_tree_real_row_collapsed (GtkTreeView* base,
                                                          GtkTreeIter* iter,
                                                          GtkTreePath* path);
static void granite_widgets_source_list_tree_real_row_activated (GtkTreeView* base,
                                                          GtkTreePath* path,
                                                          GtkTreeViewColumn* column);
static gboolean granite_widgets_source_list_tree_real_key_release_event (GtkWidget* base,
                                                                  GdkEventKey* event);
static gboolean granite_widgets_source_list_tree_real_button_release_event (GtkWidget* base,
                                                                     GdkEventButton* event);
static gboolean granite_widgets_source_list_tree_real_button_press_event (GtkWidget* base,
                                                                   GdkEventButton* event);
static gboolean granite_widgets_source_list_tree_popup_context_menu (GraniteWidgetsSourceListTree* self,
                                                              GraniteWidgetsSourceListItem* item,
                                                              GdkEventButton* event);
static gboolean granite_widgets_source_list_tree_over_primary_expander (GraniteWidgetsSourceListTree* self,
                                                                 GtkTreeViewColumn* col,
                                                                 GtkTreePath* path,
                                                                 gint x);
static void granite_widgets_source_list_tree_expander_cell_data_func (GraniteWidgetsSourceListTree* self,
                                                               GtkCellLayout* layout,
                                                               GtkCellRenderer* renderer,
                                                               GtkTreeModel* model,
                                                               GtkTreeIter* iter);
static gint granite_widgets_source_list_tree_get_cell_width (GraniteWidgetsSourceListTree* self,
                                                      GtkCellRenderer* cell_renderer);
static gboolean granite_widgets_source_list_tree_real_popup_menu (GtkWidget* base);
static GraniteWidgetsSourceListItem* granite_widgets_source_list_tree_get_item_from_model (GtkTreeModel* model,
                                                                                    GtkTreeIter* iter);
static void granite_widgets_source_list_tree_name_cell_data_func (GraniteWidgetsSourceListTree* self,
                                                           GtkCellLayout* layout,
                                                           GtkCellRenderer* renderer,
                                                           GtkTreeModel* model,
                                                           GtkTreeIter* iter);
static void granite_widgets_source_list_tree_badge_cell_data_func (GraniteWidgetsSourceListTree* self,
                                                            GtkCellLayout* layout,
                                                            GtkCellRenderer* renderer,
                                                            GtkTreeModel* model,
                                                            GtkTreeIter* iter);
static void granite_widgets_source_list_tree_icon_cell_data_func (GraniteWidgetsSourceListTree* self,
                                                           GtkCellLayout* layout,
                                                           GtkCellRenderer* renderer,
                                                           GtkTreeModel* model,
                                                           GtkTreeIter* iter);
static GObject * granite_widgets_source_list_tree_constructor (GType type,
                                                        guint n_construct_properties,
                                                        GObjectConstructParam * construct_properties);
static void _granite_widgets_source_list_tree_expander_cell_data_func_gtk_cell_layout_data_func (GtkCellLayout* cell_layout,
                                                                                          GtkCellRenderer* cell,
                                                                                          GtkTreeModel* tree_model,
                                                                                          GtkTreeIter* iter,
                                                                                          gpointer self);
static void _granite_widgets_source_list_tree_on_activatable_activated_granite_widgets_source_list_cell_renderer_icon_activated (GraniteWidgetsSourceListCellRendererIcon* _sender,
                                                                                                                          const gchar* path,
                                                                                                                          gpointer self);
static void _granite_widgets_source_list_tree_icon_cell_data_func_gtk_cell_layout_data_func (GtkCellLayout* cell_layout,
                                                                                      GtkCellRenderer* cell,
                                                                                      GtkTreeModel* tree_model,
                                                                                      GtkTreeIter* iter,
                                                                                      gpointer self);
static void _granite_widgets_source_list_tree_badge_cell_data_func_gtk_cell_layout_data_func (GtkCellLayout* cell_layout,
                                                                                       GtkCellRenderer* cell,
                                                                                       GtkTreeModel* tree_model,
                                                                                       GtkTreeIter* iter,
                                                                                       gpointer self);
static void _granite_widgets_source_list_tree_on_editing_started_gtk_cell_renderer_editing_started (GtkCellRenderer* _sender,
                                                                                             GtkCellEditable* editable,
                                                                                             const gchar* path,
                                                                                             gpointer self);
static void _granite_widgets_source_list_tree_on_editing_canceled_gtk_cell_renderer_editing_canceled (GtkCellRenderer* _sender,
                                                                                               gpointer self);
static void _granite_widgets_source_list_tree_name_cell_data_func_gtk_cell_layout_data_func (GtkCellLayout* cell_layout,
                                                                                      GtkCellRenderer* cell,
                                                                                      GtkTreeModel* tree_model,
                                                                                      GtkTreeIter* iter,
                                                                                      gpointer self);
static gboolean _granite_widgets_source_list_tree_select_func_gtk_tree_selection_func (GtkTreeSelection* selection,
                                                                                GtkTreeModel* model,
                                                                                GtkTreePath* path,
                                                                                gboolean path_currently_selected,
                                                                                gpointer self);
static gboolean _granite_widgets_source_list_tree_on_query_tooltip_gtk_widget_query_tooltip (GtkWidget* _sender,
                                                                                      gint x,
                                                                                      gint y,
                                                                                      gboolean keyboard_tooltip,
                                                                                      GtkTooltip* tooltip,
                                                                                      gpointer self);
static void granite_widgets_source_list_tree_finalize (GObject * obj);
static GType granite_widgets_source_list_tree_get_type_once (void);
static void _vala_granite_widgets_source_list_tree_get_property (GObject * object,
                                                          guint property_id,
                                                          GValue * value,
                                                          GParamSpec * pspec);
static void _vala_granite_widgets_source_list_tree_set_property (GObject * object,
                                                          guint property_id,
                                                          const GValue * value,
                                                          GParamSpec * pspec);
static GObject * granite_widgets_source_list_constructor (GType type,
                                                   guint n_construct_properties,
                                                   GObjectConstructParam * construct_properties);
static void _granite_widgets_source_list___lambda81_ (GraniteWidgetsSourceList* self,
                                               GraniteWidgetsSourceListItem* item);
static void __granite_widgets_source_list___lambda81__granite_widgets_source_list_tree_item_selected (GraniteWidgetsSourceListTree* _sender,
                                                                                               GraniteWidgetsSourceListItem* item,
                                                                                               gpointer self);
static void granite_widgets_source_list_finalize (GObject * obj);
static GType granite_widgets_source_list_get_type_once (void);
static void _vala_granite_widgets_source_list_get_property (GObject * object,
                                                     guint property_id,
                                                     GValue * value,
                                                     GParamSpec * pspec);
static void _vala_granite_widgets_source_list_set_property (GObject * object,
                                                     guint property_id,
                                                     const GValue * value,
                                                     GParamSpec * pspec);
static inline gpointer _vala_memdup2 (gconstpointer mem,
                        gsize byte_size);

/**
     * Whether this item will allow users to re-arrange its children via DnD.
     *
     * This feature can co-exist with a sort algorithm (implemented
     * by {@link Granite.Widgets.SourceListSortable.compare}), but
     * the actual order of the items in the list will always
     * honor that method. The sort function has to be compatible with
     * the kind of DnD reordering the item wants to allow, since the user can
     * only reorder those items for which //compare// returns 0.
     *
     * @return Whether the item's children can be re-arranged by users.
     * @since 0.3
     */
gboolean
granite_widgets_source_list_sortable_allow_dnd_sorting (GraniteWidgetsSourceListSortable* self)
{
	GraniteWidgetsSourceListSortableIface* _iface_;
#line 36 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 36 "../lib/Widgets/SourceList.vala"
	_iface_ = GRANITE_WIDGETS_SOURCE_LIST_SORTABLE_GET_INTERFACE (self);
#line 36 "../lib/Widgets/SourceList.vala"
	if (_iface_->allow_dnd_sorting) {
#line 36 "../lib/Widgets/SourceList.vala"
		return _iface_->allow_dnd_sorting (self);
#line 943 "SourceList.c"
	}
#line 36 "../lib/Widgets/SourceList.vala"
	return FALSE;
#line 947 "SourceList.c"
}

/**
     * Should return a negative integer, zero, or a positive integer if ''a''
     * sorts //before// ''b'', ''a'' sorts //with// ''b'', or ''a'' sorts
     * //after// ''b'' respectively. If two items compare as equal, their
     * order in the sorted source list is undefined.
     *
     * In order to ensure that the source list behaves as expected, this
     * method must define a partial order on the source list tree; i.e. it
     * must be reflexive, antisymmetric and transitive. Not complying with
     * those requirements could make the program fall into an infinite loop
     * and freeze the user interface.
     *
     * Should return //0// to allow any pair of items to be sortable via DnD.
     *
     * @param a First item.
     * @param b Second item.
     * @return A //negative// integer if //a// sorts before //b//,
     *         //zero// if //a// equals //b//, or a //positive//
     *         integer if //a// sorts after //b//.
     * @since 0.3
     */
gint
granite_widgets_source_list_sortable_compare (GraniteWidgetsSourceListSortable* self,
                                              GraniteWidgetsSourceListItem* a,
                                              GraniteWidgetsSourceListItem* b)
{
	GraniteWidgetsSourceListSortableIface* _iface_;
#line 59 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 59 "../lib/Widgets/SourceList.vala"
	_iface_ = GRANITE_WIDGETS_SOURCE_LIST_SORTABLE_GET_INTERFACE (self);
#line 59 "../lib/Widgets/SourceList.vala"
	if (_iface_->compare) {
#line 59 "../lib/Widgets/SourceList.vala"
		return _iface_->compare (self, a, b);
#line 985 "SourceList.c"
	}
#line 59 "../lib/Widgets/SourceList.vala"
	return -1;
#line 989 "SourceList.c"
}

static void
granite_widgets_source_list_sortable_default_init (GraniteWidgetsSourceListSortableIface * iface,
                                                   gpointer iface_data)
{
	/**
	     * Emitted after a user has re-ordered an item via DnD.
	     *
	     * @param moved The item that was moved to a different position by the user.
	     * @since 0.3
	     */
#line 14 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_sortable_signals[GRANITE_WIDGETS_SOURCE_LIST_SORTABLE_USER_MOVED_ITEM_SIGNAL] = g_signal_new ("user-moved-item", GRANITE_WIDGETS_TYPE_SOURCE_LIST_SORTABLE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, GRANITE_WIDGETS_SOURCE_LIST_TYPE_ITEM);
#line 1004 "SourceList.c"
}

/**
 * An interface for sorting items.
 *
 * @since 0.3
 */
static GType
granite_widgets_source_list_sortable_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (GraniteWidgetsSourceListSortableIface), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) granite_widgets_source_list_sortable_default_init, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
	GType granite_widgets_source_list_sortable_type_id;
	granite_widgets_source_list_sortable_type_id = g_type_register_static (G_TYPE_INTERFACE, "GraniteWidgetsSourceListSortable", &g_define_type_info, 0);
	g_type_interface_add_prerequisite (granite_widgets_source_list_sortable_type_id, GRANITE_WIDGETS_SOURCE_LIST_TYPE_EXPANDABLE_ITEM);
	return granite_widgets_source_list_sortable_type_id;
}

GType
granite_widgets_source_list_sortable_get_type (void)
{
	static volatile gsize granite_widgets_source_list_sortable_type_id__once = 0;
	if (g_once_init_enter (&granite_widgets_source_list_sortable_type_id__once)) {
		GType granite_widgets_source_list_sortable_type_id;
		granite_widgets_source_list_sortable_type_id = granite_widgets_source_list_sortable_get_type_once ();
		g_once_init_leave (&granite_widgets_source_list_sortable_type_id__once, granite_widgets_source_list_sortable_type_id);
	}
	return granite_widgets_source_list_sortable_type_id__once;
}

/**
     * Determines whether this item can be dragged outside the source list widget.
     *
     * Even if this method returns //false//, the item could still be dragged around
     * within the source list if its parent allows DnD reordering. This only happens
     * when the parent implements {@link Granite.Widgets.SourceListSortable}.
     *
     * @return //true// if the item can be dragged; //false// otherwise.
     * @since 0.3
     * @see Granite.Widgets.SourceListSortable
     */
gboolean
granite_widgets_source_list_drag_source_draggable (GraniteWidgetsSourceListDragSource* self)
{
	GraniteWidgetsSourceListDragSourceIface* _iface_;
#line 79 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 79 "../lib/Widgets/SourceList.vala"
	_iface_ = GRANITE_WIDGETS_SOURCE_LIST_DRAG_SOURCE_GET_INTERFACE (self);
#line 79 "../lib/Widgets/SourceList.vala"
	if (_iface_->draggable) {
#line 79 "../lib/Widgets/SourceList.vala"
		return _iface_->draggable (self);
#line 1057 "SourceList.c"
	}
#line 79 "../lib/Widgets/SourceList.vala"
	return FALSE;
#line 1061 "SourceList.c"
}

/**
     * This method is called when the drop site requests the data which is dragged.
     *
     * It is the responsibility of this method to fill //selection_data// with the
     * data in the format which is indicated by {@link Gtk.SelectionData.get_target}.
     *
     * @param selection_data {@link Gtk.SelectionData} containing source data.
     * @since 0.3
     * @see Gtk.SelectionData.set
     * @see Gtk.SelectionData.set_uris
     * @see Gtk.SelectionData.set_text
     */
void
granite_widgets_source_list_drag_source_prepare_selection_data (GraniteWidgetsSourceListDragSource* self,
                                                                GtkSelectionData* selection_data)
{
	GraniteWidgetsSourceListDragSourceIface* _iface_;
#line 93 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 93 "../lib/Widgets/SourceList.vala"
	_iface_ = GRANITE_WIDGETS_SOURCE_LIST_DRAG_SOURCE_GET_INTERFACE (self);
#line 93 "../lib/Widgets/SourceList.vala"
	if (_iface_->prepare_selection_data) {
#line 93 "../lib/Widgets/SourceList.vala"
		_iface_->prepare_selection_data (self, selection_data);
#line 1089 "SourceList.c"
	}
}

static void
granite_widgets_source_list_drag_source_default_init (GraniteWidgetsSourceListDragSourceIface * iface,
                                                      gpointer iface_data)
{
}

/**
 * An interface for dragging items out of the source list widget.
 *
 * @since 0.3
 */
static GType
granite_widgets_source_list_drag_source_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (GraniteWidgetsSourceListDragSourceIface), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) granite_widgets_source_list_drag_source_default_init, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
	GType granite_widgets_source_list_drag_source_type_id;
	granite_widgets_source_list_drag_source_type_id = g_type_register_static (G_TYPE_INTERFACE, "GraniteWidgetsSourceListDragSource", &g_define_type_info, 0);
	g_type_interface_add_prerequisite (granite_widgets_source_list_drag_source_type_id, GRANITE_WIDGETS_SOURCE_LIST_TYPE_ITEM);
	return granite_widgets_source_list_drag_source_type_id;
}

GType
granite_widgets_source_list_drag_source_get_type (void)
{
	static volatile gsize granite_widgets_source_list_drag_source_type_id__once = 0;
	if (g_once_init_enter (&granite_widgets_source_list_drag_source_type_id__once)) {
		GType granite_widgets_source_list_drag_source_type_id;
		granite_widgets_source_list_drag_source_type_id = granite_widgets_source_list_drag_source_get_type_once ();
		g_once_init_leave (&granite_widgets_source_list_drag_source_type_id__once, granite_widgets_source_list_drag_source_type_id);
	}
	return granite_widgets_source_list_drag_source_type_id__once;
}

/**
     * Determines whether //data// can be dropped into this item.
     *
     * @param context The drag context.
     * @param data {@link Gtk.SelectionData} containing source data.
     * @return //true// if the drop is possible; //false// otherwise.
     * @since 0.3
     */
gboolean
granite_widgets_source_list_drag_dest_data_drop_possible (GraniteWidgetsSourceListDragDest* self,
                                                          GdkDragContext* context,
                                                          GtkSelectionData* data)
{
	GraniteWidgetsSourceListDragDestIface* _iface_;
#line 110 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 110 "../lib/Widgets/SourceList.vala"
	_iface_ = GRANITE_WIDGETS_SOURCE_LIST_DRAG_DEST_GET_INTERFACE (self);
#line 110 "../lib/Widgets/SourceList.vala"
	if (_iface_->data_drop_possible) {
#line 110 "../lib/Widgets/SourceList.vala"
		return _iface_->data_drop_possible (self, context, data);
#line 1148 "SourceList.c"
	}
#line 110 "../lib/Widgets/SourceList.vala"
	return FALSE;
#line 1152 "SourceList.c"
}

/**
     * If a data drop is deemed possible, then this method is called
     * when the data is actually dropped into this item. Any actions
     * consequence of the data received should be handled here.
     *
     * @param context The drag context.
     * @param data {@link Gtk.SelectionData} containing source data.
     * @return The action taken, or //0// to indicate that the dropped data was not accepted.
     * @since 0.3
     */
GdkDragAction
granite_widgets_source_list_drag_dest_data_received (GraniteWidgetsSourceListDragDest* self,
                                                     GdkDragContext* context,
                                                     GtkSelectionData* data)
{
	GraniteWidgetsSourceListDragDestIface* _iface_;
#line 122 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, 0U);
#line 122 "../lib/Widgets/SourceList.vala"
	_iface_ = GRANITE_WIDGETS_SOURCE_LIST_DRAG_DEST_GET_INTERFACE (self);
#line 122 "../lib/Widgets/SourceList.vala"
	if (_iface_->data_received) {
#line 122 "../lib/Widgets/SourceList.vala"
		return _iface_->data_received (self, context, data);
#line 1179 "SourceList.c"
	}
#line 122 "../lib/Widgets/SourceList.vala"
	return 0U;
#line 1183 "SourceList.c"
}

static void
granite_widgets_source_list_drag_dest_default_init (GraniteWidgetsSourceListDragDestIface * iface,
                                                    gpointer iface_data)
{
}

/**
 * An interface for receiving data from other widgets via drag-and-drop.
 *
 * @since 0.3
 */
static GType
granite_widgets_source_list_drag_dest_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (GraniteWidgetsSourceListDragDestIface), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) granite_widgets_source_list_drag_dest_default_init, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
	GType granite_widgets_source_list_drag_dest_type_id;
	granite_widgets_source_list_drag_dest_type_id = g_type_register_static (G_TYPE_INTERFACE, "GraniteWidgetsSourceListDragDest", &g_define_type_info, 0);
	g_type_interface_add_prerequisite (granite_widgets_source_list_drag_dest_type_id, GRANITE_WIDGETS_SOURCE_LIST_TYPE_ITEM);
	return granite_widgets_source_list_drag_dest_type_id;
}

GType
granite_widgets_source_list_drag_dest_get_type (void)
{
	static volatile gsize granite_widgets_source_list_drag_dest_type_id__once = 0;
	if (g_once_init_enter (&granite_widgets_source_list_drag_dest_type_id__once)) {
		GType granite_widgets_source_list_drag_dest_type_id;
		granite_widgets_source_list_drag_dest_type_id = granite_widgets_source_list_drag_dest_get_type_once ();
		g_once_init_leave (&granite_widgets_source_list_drag_dest_type_id__once, granite_widgets_source_list_drag_dest_type_id);
	}
	return granite_widgets_source_list_drag_dest_type_id__once;
}

static inline gpointer
granite_widgets_source_list_get_instance_private (GraniteWidgetsSourceList* self)
{
	return G_STRUCT_MEMBER_P (self, GraniteWidgetsSourceList_private_offset);
}

static void
granite_widgets_source_list_real_item_selected (GraniteWidgetsSourceList* self,
                                                GraniteWidgetsSourceListItem* item)
{
}

GraniteWidgetsSourceListExpandableItem*
granite_widgets_source_list_get_root (GraniteWidgetsSourceList* self)
{
	GraniteWidgetsSourceListExpandableItem* result;
	GraniteWidgetsSourceListDataModel* _tmp0_;
	GraniteWidgetsSourceListExpandableItem* _tmp1_;
	GraniteWidgetsSourceListExpandableItem* _tmp2_;
#line 2607 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 2607 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->data_model;
#line 2607 "../lib/Widgets/SourceList.vala"
	_tmp1_ = granite_widgets_source_list_data_model_get_root (_tmp0_);
#line 2607 "../lib/Widgets/SourceList.vala"
	_tmp2_ = _tmp1_;
#line 2607 "../lib/Widgets/SourceList.vala"
	result = _tmp2_;
#line 2607 "../lib/Widgets/SourceList.vala"
	return result;
#line 1250 "SourceList.c"
}

void
granite_widgets_source_list_set_root (GraniteWidgetsSourceList* self,
                                      GraniteWidgetsSourceListExpandableItem* value)
{
	GraniteWidgetsSourceListDataModel* _tmp0_;
#line 2608 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 2608 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->data_model;
#line 2608 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_data_model_set_root (_tmp0_, value);
#line 2608 "../lib/Widgets/SourceList.vala"
	g_object_notify_by_pspec ((GObject *) self, granite_widgets_source_list_properties[GRANITE_WIDGETS_SOURCE_LIST_ROOT_PROPERTY]);
#line 1266 "SourceList.c"
}

GraniteWidgetsSourceListItem*
granite_widgets_source_list_get_selected (GraniteWidgetsSourceList* self)
{
	GraniteWidgetsSourceListItem* result;
	GraniteWidgetsSourceListTree* _tmp0_;
	GraniteWidgetsSourceListItem* _tmp1_;
	GraniteWidgetsSourceListItem* _tmp2_;
#line 2621 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 2621 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->tree;
#line 2621 "../lib/Widgets/SourceList.vala"
	_tmp1_ = granite_widgets_source_list_tree_get_selected_item (_tmp0_);
#line 2621 "../lib/Widgets/SourceList.vala"
	_tmp2_ = _tmp1_;
#line 2621 "../lib/Widgets/SourceList.vala"
	result = _tmp2_;
#line 2621 "../lib/Widgets/SourceList.vala"
	return result;
#line 1288 "SourceList.c"
}

void
granite_widgets_source_list_set_selected (GraniteWidgetsSourceList* self,
                                          GraniteWidgetsSourceListItem* value)
{
	gboolean _tmp0_ = FALSE;
	GraniteWidgetsSourceListTree* _tmp5_;
#line 2622 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 2623 "../lib/Widgets/SourceList.vala"
	if (value != NULL) {
#line 1301 "SourceList.c"
		GraniteWidgetsSourceListExpandableItem* _tmp1_;
		GraniteWidgetsSourceListExpandableItem* _tmp2_;
#line 2623 "../lib/Widgets/SourceList.vala"
		_tmp1_ = granite_widgets_source_list_item_get_parent (value);
#line 2623 "../lib/Widgets/SourceList.vala"
		_tmp2_ = _tmp1_;
#line 2623 "../lib/Widgets/SourceList.vala"
		_tmp0_ = _tmp2_ != NULL;
#line 1310 "SourceList.c"
	} else {
#line 2623 "../lib/Widgets/SourceList.vala"
		_tmp0_ = FALSE;
#line 1314 "SourceList.c"
	}
#line 2623 "../lib/Widgets/SourceList.vala"
	if (_tmp0_) {
#line 1318 "SourceList.c"
		GraniteWidgetsSourceListExpandableItem* _tmp3_;
		GraniteWidgetsSourceListExpandableItem* _tmp4_;
#line 2624 "../lib/Widgets/SourceList.vala"
		_tmp3_ = granite_widgets_source_list_item_get_parent (value);
#line 2624 "../lib/Widgets/SourceList.vala"
		_tmp4_ = _tmp3_;
#line 2624 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_expandable_item_expand_with_parents (_tmp4_);
#line 1327 "SourceList.c"
	}
#line 2625 "../lib/Widgets/SourceList.vala"
	_tmp5_ = self->priv->tree;
#line 2625 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_tree_set_selected_item (_tmp5_, value);
#line 2622 "../lib/Widgets/SourceList.vala"
	g_object_notify_by_pspec ((GObject *) self, granite_widgets_source_list_properties[GRANITE_WIDGETS_SOURCE_LIST_SELECTED_PROPERTY]);
#line 1335 "SourceList.c"
}

PangoEllipsizeMode
granite_widgets_source_list_get_ellipsize_mode (GraniteWidgetsSourceList* self)
{
	PangoEllipsizeMode result;
	GraniteWidgetsSourceListTree* _tmp0_;
	PangoEllipsizeMode _tmp1_;
	PangoEllipsizeMode _tmp2_;
#line 2635 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 2635 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->tree;
#line 2635 "../lib/Widgets/SourceList.vala"
	_tmp1_ = granite_widgets_source_list_tree_get_ellipsize_mode (_tmp0_);
#line 2635 "../lib/Widgets/SourceList.vala"
	_tmp2_ = _tmp1_;
#line 2635 "../lib/Widgets/SourceList.vala"
	result = _tmp2_;
#line 2635 "../lib/Widgets/SourceList.vala"
	return result;
#line 1357 "SourceList.c"
}

void
granite_widgets_source_list_set_ellipsize_mode (GraniteWidgetsSourceList* self,
                                                PangoEllipsizeMode value)
{
	GraniteWidgetsSourceListTree* _tmp0_;
#line 2636 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 2636 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->tree;
#line 2636 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_tree_set_ellipsize_mode (_tmp0_, value);
#line 2636 "../lib/Widgets/SourceList.vala"
	g_object_notify_by_pspec ((GObject *) self, granite_widgets_source_list_properties[GRANITE_WIDGETS_SOURCE_LIST_ELLIPSIZE_MODE_PROPERTY]);
#line 1373 "SourceList.c"
}

gboolean
granite_widgets_source_list_get_editing (GraniteWidgetsSourceList* self)
{
	gboolean result;
	GraniteWidgetsSourceListTree* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
#line 2646 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 2646 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->tree;
#line 2646 "../lib/Widgets/SourceList.vala"
	_tmp1_ = granite_widgets_source_list_tree_get_editing (_tmp0_);
#line 2646 "../lib/Widgets/SourceList.vala"
	_tmp2_ = _tmp1_;
#line 2646 "../lib/Widgets/SourceList.vala"
	result = _tmp2_;
#line 2646 "../lib/Widgets/SourceList.vala"
	return result;
#line 1395 "SourceList.c"
}

/**
     * Creates a new {@link Granite.Widgets.SourceList}.
     *
     * @return A new {@link Granite.Widgets.SourceList}.
     * @since 0.2
     */
GraniteWidgetsSourceList*
granite_widgets_source_list_construct (GType object_type,
                                       GraniteWidgetsSourceListExpandableItem* root)
{
	GraniteWidgetsSourceList * self = NULL;
#line 2658 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (root != NULL, NULL);
#line 2658 "../lib/Widgets/SourceList.vala"
	self = (GraniteWidgetsSourceList*) g_object_new (object_type, NULL);
#line 2659 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_set_root (self, root);
#line 2658 "../lib/Widgets/SourceList.vala"
	return self;
#line 1417 "SourceList.c"
}

GraniteWidgetsSourceList*
granite_widgets_source_list_new (GraniteWidgetsSourceListExpandableItem* root)
{
#line 2658 "../lib/Widgets/SourceList.vala"
	return granite_widgets_source_list_construct (GRANITE_WIDGETS_TYPE_SOURCE_LIST, root);
#line 1425 "SourceList.c"
}

/**
     * Checks whether //item// is part of the source list.
     *
     * @param item The item to query.
     * @return //true// if the item belongs to the source list; //false// otherwise.
     * @since 0.2
     */
gboolean
granite_widgets_source_list_has_item (GraniteWidgetsSourceList* self,
                                      GraniteWidgetsSourceListItem* item)
{
	GraniteWidgetsSourceListDataModel* _tmp0_;
	gboolean result;
#line 2679 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 2679 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (item != NULL, FALSE);
#line 2680 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->data_model;
#line 2680 "../lib/Widgets/SourceList.vala"
	result = granite_widgets_source_list_data_model_has_item (_tmp0_, item);
#line 2680 "../lib/Widgets/SourceList.vala"
	return result;
#line 1451 "SourceList.c"
}

/**
     * Sets the method used for filtering out items.
     *
     * @param visible_func The method to use for filtering items.
     * @param refilter Whether to call {@link Granite.Widgets.SourceList.refilter} using the new function.
     * @see Granite.Widgets.SourceList.VisibleFunc
     * @see Granite.Widgets.SourceList.refilter
     * @since 0.2
     */
void
granite_widgets_source_list_set_filter_func (GraniteWidgetsSourceList* self,
                                             GraniteWidgetsSourceListVisibleFunc visible_func,
                                             gpointer visible_func_target,
                                             gboolean refilter)
{
	GraniteWidgetsSourceListDataModel* _tmp0_;
#line 2692 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 2693 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->data_model;
#line 2693 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_data_model_set_filter_func (_tmp0_, visible_func, visible_func_target);
#line 2694 "../lib/Widgets/SourceList.vala"
	if (refilter) {
#line 2695 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_refilter (self);
#line 1480 "SourceList.c"
	}
}

/**
     * Applies the filter method set by {@link Granite.Widgets.SourceList.set_filter_func}
     * to all the items that are part of the current tree.
     *
     * @see Granite.Widgets.SourceList.VisibleFunc
     * @see Granite.Widgets.SourceList.set_filter_func
     * @since 0.2
     */
void
granite_widgets_source_list_refilter (GraniteWidgetsSourceList* self)
{
	GraniteWidgetsSourceListDataModel* _tmp0_;
#line 2706 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 2707 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->data_model;
#line 2707 "../lib/Widgets/SourceList.vala"
	gtk_tree_model_filter_refilter ((GtkTreeModelFilter*) _tmp0_);
#line 1502 "SourceList.c"
}

/**
     * Queries the actual expansion state of //item//.
     *
     * @see Granite.Widgets.SourceList.ExpandableItem.expanded
     * @return Whether //item// is expanded or not.
     * @since 0.2
     */
static void
_vala_GtkTreePath_free (GtkTreePath* self)
{
#line 2719 "../lib/Widgets/SourceList.vala"
	g_boxed_free (gtk_tree_path_get_type (), self);
#line 1517 "SourceList.c"
}

gboolean
granite_widgets_source_list_is_item_expanded (GraniteWidgetsSourceList* self,
                                              GraniteWidgetsSourceListItem* item)
{
	GtkTreePath* path = NULL;
	GraniteWidgetsSourceListDataModel* _tmp0_;
	GtkTreePath* _tmp1_;
	gboolean _tmp2_ = FALSE;
	GtkTreePath* _tmp3_;
	gboolean result;
#line 2717 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 2717 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (item != NULL, FALSE);
#line 2717 "../lib/Widgets/SourceList.vala"
	_vala_return_val_if_fail (granite_widgets_source_list_has_item (self, item), "has_item (item)", FALSE);
#line 2718 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->data_model;
#line 2718 "../lib/Widgets/SourceList.vala"
	_tmp1_ = granite_widgets_source_list_data_model_get_item_path (_tmp0_, item);
#line 2718 "../lib/Widgets/SourceList.vala"
	path = _tmp1_;
#line 2719 "../lib/Widgets/SourceList.vala"
	_tmp3_ = path;
#line 2719 "../lib/Widgets/SourceList.vala"
	if (_tmp3_ != NULL) {
#line 1546 "SourceList.c"
		GraniteWidgetsSourceListTree* _tmp4_;
		GtkTreePath* _tmp5_;
#line 2719 "../lib/Widgets/SourceList.vala"
		_tmp4_ = self->priv->tree;
#line 2719 "../lib/Widgets/SourceList.vala"
		_tmp5_ = path;
#line 2719 "../lib/Widgets/SourceList.vala"
		_tmp2_ = gtk_tree_view_row_expanded ((GtkTreeView*) _tmp4_, _tmp5_);
#line 1555 "SourceList.c"
	} else {
#line 2719 "../lib/Widgets/SourceList.vala"
		_tmp2_ = FALSE;
#line 1559 "SourceList.c"
	}
#line 2719 "../lib/Widgets/SourceList.vala"
	result = _tmp2_;
#line 2719 "../lib/Widgets/SourceList.vala"
	__vala_GtkTreePath_free0 (path);
#line 2719 "../lib/Widgets/SourceList.vala"
	return result;
#line 1567 "SourceList.c"
}

/**
     * If //item// is editable, this activates the editor; otherwise, it does nothing.
     * If an item was already being edited, this will fail.
     *
     * @param item Item to edit.
     * @see Granite.Widgets.SourceList.Item.editable
     * @see Granite.Widgets.SourceList.editing
     * @see Granite.Widgets.SourceList.stop_editing
     * @return true if the editing started successfully; false otherwise.
     * @since 0.2
     */
gboolean
granite_widgets_source_list_start_editing_item (GraniteWidgetsSourceList* self,
                                                GraniteWidgetsSourceListItem* item)
{
	GraniteWidgetsSourceListTree* _tmp0_;
	gboolean result;
#line 2733 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 2733 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (item != NULL, FALSE);
#line 2733 "../lib/Widgets/SourceList.vala"
	_vala_return_val_if_fail (granite_widgets_source_list_has_item (self, item), "has_item (item)", FALSE);
#line 2734 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->tree;
#line 2734 "../lib/Widgets/SourceList.vala"
	result = granite_widgets_source_list_tree_start_editing_item (_tmp0_, item);
#line 2734 "../lib/Widgets/SourceList.vala"
	return result;
#line 1599 "SourceList.c"
}

/**
     * Cancels any editing operation going on.
     *
     * @see Granite.Widgets.SourceList.editing
     * @see Granite.Widgets.SourceList.start_editing_item
     * @since 0.2
     */
void
granite_widgets_source_list_stop_editing (GraniteWidgetsSourceList* self)
{
	gboolean _tmp0_;
	gboolean _tmp1_;
#line 2744 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 2745 "../lib/Widgets/SourceList.vala"
	_tmp0_ = granite_widgets_source_list_get_editing (self);
#line 2745 "../lib/Widgets/SourceList.vala"
	_tmp1_ = _tmp0_;
#line 2745 "../lib/Widgets/SourceList.vala"
	if (_tmp1_) {
#line 1622 "SourceList.c"
		GraniteWidgetsSourceListTree* _tmp2_;
#line 2746 "../lib/Widgets/SourceList.vala"
		_tmp2_ = self->priv->tree;
#line 2746 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_tree_stop_editing (_tmp2_);
#line 1628 "SourceList.c"
	}
}

/**
     * Turns Source List into a //drag source//.
     *
     * This enables items that implement {@link Granite.Widgets.SourceListDragSource}
     * to be dragged outside the Source List and drop data into external widgets.
     *
     * @param src_entries an array of {@link Gtk.TargetEntry}s indicating the targets
     * that the drag will support.
     * @see Granite.Widgets.SourceListDragSource
     * @see Granite.Widgets.SourceList.disable_drag_source
     * @since 0.3
     */
void
granite_widgets_source_list_enable_drag_source (GraniteWidgetsSourceList* self,
                                                GtkTargetEntry* src_entries,
                                                gint src_entries_length1)
{
	GraniteWidgetsSourceListTree* _tmp0_;
#line 2761 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 2762 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->tree;
#line 2762 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_tree_configure_drag_source (_tmp0_, src_entries, (gint) src_entries_length1);
#line 1656 "SourceList.c"
}

/**
     * Undoes the effect of {@link Granite.Widgets.SourceList.enable_drag_source}
     *
     * @see Granite.Widgets.SourceList.enable_drag_source
     * @since 0.3
     */
void
granite_widgets_source_list_disable_drag_source (GraniteWidgetsSourceList* self)
{
	GraniteWidgetsSourceListTree* _tmp0_;
#line 2771 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 2772 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->tree;
#line 2772 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_tree_configure_drag_source (_tmp0_, NULL, (gint) 0);
#line 1675 "SourceList.c"
}

/**
     * Turns Source List into a //drop destination//.
     *
     * This enables items that implement {@link Granite.Widgets.SourceListDragDest}
     * to receive data from external widgets via drag-and-drop.
     *
     * @param dest_entries an array of {@link Gtk.TargetEntry}s indicating the drop
     * types that Source List items will accept.
     * @param actions a bitmask of possible actions for a drop onto Source List items.
     * @see Granite.Widgets.SourceListDragDest
     * @see Granite.Widgets.SourceList.disable_drag_dest
     * @since 0.3
     */
void
granite_widgets_source_list_enable_drag_dest (GraniteWidgetsSourceList* self,
                                              GtkTargetEntry* dest_entries,
                                              gint dest_entries_length1,
                                              GdkDragAction actions)
{
	GraniteWidgetsSourceListTree* _tmp0_;
#line 2788 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 2789 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->tree;
#line 2789 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_tree_configure_drag_dest (_tmp0_, dest_entries, (gint) dest_entries_length1, actions);
#line 1704 "SourceList.c"
}

/**
     * Undoes the effect of {@link Granite.Widgets.SourceList.enable_drag_dest}
     *
     * @see Granite.Widgets.SourceList.enable_drag_dest
     * @since 0.3
     */
void
granite_widgets_source_list_disable_drag_dest (GraniteWidgetsSourceList* self)
{
	GraniteWidgetsSourceListTree* _tmp0_;
#line 2798 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 2799 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->tree;
#line 2799 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_tree_configure_drag_dest (_tmp0_, NULL, (gint) 0, 0);
#line 1723 "SourceList.c"
}

/**
     * Scrolls the source list tree to make //item// visible.
     *
     * {@link Granite.Widgets.SourceList.ExpandableItem.expand_with_parents} is called
     * for the item's parent if //expand_parents// is //true//, to make sure it's not
     * hidden behind a collapsed row.
     *
     * If use_align is //false//, then the row_align argument is ignored, and the tree
     * does the minimum amount of work to scroll the item onto the screen. This means that
     * the item will be scrolled to the edge closest to its current position. If the item
     * is currently visible on the screen, nothing is done.
     *
     * @param item Item to scroll to.
     * @param expand_parents Whether to recursively expand item's parent in case they are collapsed.
     * @param use_align Whether to use the //row_align// argument.
     * @param row_align The vertical alignment of //item//. 0.0 means top, 0.5 center, and 1.0 bottom.
     * @return //true// if successful; //false// otherwise.
     * @since 0.2
     */
gboolean
granite_widgets_source_list_scroll_to_item (GraniteWidgetsSourceList* self,
                                            GraniteWidgetsSourceListItem* item,
                                            gboolean expand_parents,
                                            gboolean use_align,
                                            gfloat row_align)
{
	gboolean _tmp0_ = FALSE;
	GraniteWidgetsSourceListTree* _tmp5_;
	gboolean result;
#line 2821 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 2821 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (item != NULL, FALSE);
#line 2821 "../lib/Widgets/SourceList.vala"
	_vala_return_val_if_fail (granite_widgets_source_list_has_item (self, item), "has_item (item)", FALSE);
#line 2827 "../lib/Widgets/SourceList.vala"
	if (expand_parents) {
#line 1763 "SourceList.c"
		GraniteWidgetsSourceListExpandableItem* _tmp1_;
		GraniteWidgetsSourceListExpandableItem* _tmp2_;
#line 2827 "../lib/Widgets/SourceList.vala"
		_tmp1_ = granite_widgets_source_list_item_get_parent (item);
#line 2827 "../lib/Widgets/SourceList.vala"
		_tmp2_ = _tmp1_;
#line 2827 "../lib/Widgets/SourceList.vala"
		_tmp0_ = _tmp2_ != NULL;
#line 1772 "SourceList.c"
	} else {
#line 2827 "../lib/Widgets/SourceList.vala"
		_tmp0_ = FALSE;
#line 1776 "SourceList.c"
	}
#line 2827 "../lib/Widgets/SourceList.vala"
	if (_tmp0_) {
#line 1780 "SourceList.c"
		GraniteWidgetsSourceListExpandableItem* _tmp3_;
		GraniteWidgetsSourceListExpandableItem* _tmp4_;
#line 2828 "../lib/Widgets/SourceList.vala"
		_tmp3_ = granite_widgets_source_list_item_get_parent (item);
#line 2828 "../lib/Widgets/SourceList.vala"
		_tmp4_ = _tmp3_;
#line 2828 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_expandable_item_expand_with_parents (_tmp4_);
#line 1789 "SourceList.c"
	}
#line 2830 "../lib/Widgets/SourceList.vala"
	_tmp5_ = self->priv->tree;
#line 2830 "../lib/Widgets/SourceList.vala"
	result = granite_widgets_source_list_tree_scroll_to_item (_tmp5_, item, use_align, row_align);
#line 2830 "../lib/Widgets/SourceList.vala"
	return result;
#line 1797 "SourceList.c"
}

/**
     * Gets the previous item with respect to //reference//.
     *
     * @param reference Item to use as reference.
     * @return The item that appears before //reference//, or //null// if there's none.
     * @since 0.2
     */
static void
_vala_GtkTreeIter_free (GtkTreeIter* self)
{
#line 2846 "../lib/Widgets/SourceList.vala"
	g_boxed_free (gtk_tree_iter_get_type (), self);
#line 1812 "SourceList.c"
}

GraniteWidgetsSourceListItem*
granite_widgets_source_list_get_previous_item (GraniteWidgetsSourceList* self,
                                               GraniteWidgetsSourceListItem* reference)
{
	GtkTreeIter* iter = NULL;
	GraniteWidgetsSourceListDataModel* _tmp0_;
	GtkTreeIter* _tmp1_;
	GtkTreeIter* _tmp2_;
	GraniteWidgetsSourceListItem* result;
#line 2840 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 2840 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (reference != NULL, NULL);
#line 2840 "../lib/Widgets/SourceList.vala"
	_vala_return_val_if_fail (granite_widgets_source_list_has_item (self, reference), "has_item (reference)", NULL);
#line 2842 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->data_model;
#line 2842 "../lib/Widgets/SourceList.vala"
	_tmp1_ = granite_widgets_source_list_data_model_get_item_iter (_tmp0_, reference);
#line 2842 "../lib/Widgets/SourceList.vala"
	iter = _tmp1_;
#line 2843 "../lib/Widgets/SourceList.vala"
	_tmp2_ = iter;
#line 2843 "../lib/Widgets/SourceList.vala"
	if (_tmp2_ != NULL) {
#line 1840 "SourceList.c"
		GtkTreeIter new_iter = {0};
		GtkTreeIter* _tmp3_;
		GraniteWidgetsSourceListDataModel* _tmp4_;
		gboolean _tmp5_;
#line 2844 "../lib/Widgets/SourceList.vala"
		_tmp3_ = iter;
#line 2844 "../lib/Widgets/SourceList.vala"
		new_iter = *_tmp3_;
#line 2845 "../lib/Widgets/SourceList.vala"
		_tmp4_ = self->priv->data_model;
#line 2845 "../lib/Widgets/SourceList.vala"
		_tmp5_ = gtk_tree_model_iter_previous ((GtkTreeModel*) _tmp4_, &new_iter);
#line 2845 "../lib/Widgets/SourceList.vala"
		if (_tmp5_) {
#line 1855 "SourceList.c"
			GraniteWidgetsSourceListDataModel* _tmp6_;
			GtkTreeIter _tmp7_;
			GraniteWidgetsSourceListItem* _tmp8_;
#line 2846 "../lib/Widgets/SourceList.vala"
			_tmp6_ = self->priv->data_model;
#line 2846 "../lib/Widgets/SourceList.vala"
			_tmp7_ = new_iter;
#line 2846 "../lib/Widgets/SourceList.vala"
			_tmp8_ = granite_widgets_source_list_data_model_get_item (_tmp6_, &_tmp7_);
#line 2846 "../lib/Widgets/SourceList.vala"
			result = _tmp8_;
#line 2846 "../lib/Widgets/SourceList.vala"
			__vala_GtkTreeIter_free0 (iter);
#line 2846 "../lib/Widgets/SourceList.vala"
			return result;
#line 1871 "SourceList.c"
		}
	}
#line 2849 "../lib/Widgets/SourceList.vala"
	result = NULL;
#line 2849 "../lib/Widgets/SourceList.vala"
	__vala_GtkTreeIter_free0 (iter);
#line 2849 "../lib/Widgets/SourceList.vala"
	return result;
#line 1880 "SourceList.c"
}

/**
     * Gets the next item with respect to //reference//.
     *
     * @param reference Item to use as reference.
     * @return The item that appears after //reference//, or //null// if there's none.
     * @since 0.2
     */
GraniteWidgetsSourceListItem*
granite_widgets_source_list_get_next_item (GraniteWidgetsSourceList* self,
                                           GraniteWidgetsSourceListItem* reference)
{
	GtkTreeIter* iter = NULL;
	GraniteWidgetsSourceListDataModel* _tmp0_;
	GtkTreeIter* _tmp1_;
	GtkTreeIter* _tmp2_;
	GraniteWidgetsSourceListItem* result;
#line 2859 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 2859 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (reference != NULL, NULL);
#line 2859 "../lib/Widgets/SourceList.vala"
	_vala_return_val_if_fail (granite_widgets_source_list_has_item (self, reference), "has_item (reference)", NULL);
#line 2861 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->data_model;
#line 2861 "../lib/Widgets/SourceList.vala"
	_tmp1_ = granite_widgets_source_list_data_model_get_item_iter (_tmp0_, reference);
#line 2861 "../lib/Widgets/SourceList.vala"
	iter = _tmp1_;
#line 2862 "../lib/Widgets/SourceList.vala"
	_tmp2_ = iter;
#line 2862 "../lib/Widgets/SourceList.vala"
	if (_tmp2_ != NULL) {
#line 1915 "SourceList.c"
		GtkTreeIter new_iter = {0};
		GtkTreeIter* _tmp3_;
		GraniteWidgetsSourceListDataModel* _tmp4_;
		gboolean _tmp5_;
#line 2863 "../lib/Widgets/SourceList.vala"
		_tmp3_ = iter;
#line 2863 "../lib/Widgets/SourceList.vala"
		new_iter = *_tmp3_;
#line 2864 "../lib/Widgets/SourceList.vala"
		_tmp4_ = self->priv->data_model;
#line 2864 "../lib/Widgets/SourceList.vala"
		_tmp5_ = gtk_tree_model_iter_next ((GtkTreeModel*) _tmp4_, &new_iter);
#line 2864 "../lib/Widgets/SourceList.vala"
		if (_tmp5_) {
#line 1930 "SourceList.c"
			GraniteWidgetsSourceListDataModel* _tmp6_;
			GtkTreeIter _tmp7_;
			GraniteWidgetsSourceListItem* _tmp8_;
#line 2865 "../lib/Widgets/SourceList.vala"
			_tmp6_ = self->priv->data_model;
#line 2865 "../lib/Widgets/SourceList.vala"
			_tmp7_ = new_iter;
#line 2865 "../lib/Widgets/SourceList.vala"
			_tmp8_ = granite_widgets_source_list_data_model_get_item (_tmp6_, &_tmp7_);
#line 2865 "../lib/Widgets/SourceList.vala"
			result = _tmp8_;
#line 2865 "../lib/Widgets/SourceList.vala"
			__vala_GtkTreeIter_free0 (iter);
#line 2865 "../lib/Widgets/SourceList.vala"
			return result;
#line 1946 "SourceList.c"
		}
	}
#line 2868 "../lib/Widgets/SourceList.vala"
	result = NULL;
#line 2868 "../lib/Widgets/SourceList.vala"
	__vala_GtkTreeIter_free0 (iter);
#line 2868 "../lib/Widgets/SourceList.vala"
	return result;
#line 1955 "SourceList.c"
}

/**
     * Gets the first visible child of an expandable item.
     *
     * @param parent Parent of the child to look up.
     * @return The first visible child of //parent//, or null if it was not found.
     * @since 0.2
     */
GraniteWidgetsSourceListItem*
granite_widgets_source_list_get_first_child (GraniteWidgetsSourceList* self,
                                             GraniteWidgetsSourceListExpandableItem* parent)
{
	GraniteWidgetsSourceListItem* _tmp0_;
	GraniteWidgetsSourceListItem* result;
#line 2878 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 2878 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (parent != NULL, NULL);
#line 2879 "../lib/Widgets/SourceList.vala"
	_tmp0_ = granite_widgets_source_list_get_nth_child (self, parent, 0);
#line 2879 "../lib/Widgets/SourceList.vala"
	result = _tmp0_;
#line 2879 "../lib/Widgets/SourceList.vala"
	return result;
#line 1981 "SourceList.c"
}

/**
     * Gets the last visible child of an expandable item.
     *
     * @param parent Parent of the child to look up.
     * @return The last visible child of //parent//, or null if it was not found.
     * @since 0.2
     */
GraniteWidgetsSourceListItem*
granite_widgets_source_list_get_last_child (GraniteWidgetsSourceList* self,
                                            GraniteWidgetsSourceListExpandableItem* parent)
{
	GraniteWidgetsSourceListItem* _tmp0_;
	GraniteWidgetsSourceListItem* result;
#line 2889 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 2889 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (parent != NULL, NULL);
#line 2890 "../lib/Widgets/SourceList.vala"
	_tmp0_ = granite_widgets_source_list_get_nth_child (self, parent, ((gint) granite_widgets_source_list_get_n_visible_children (self, parent)) - 1);
#line 2890 "../lib/Widgets/SourceList.vala"
	result = _tmp0_;
#line 2890 "../lib/Widgets/SourceList.vala"
	return result;
#line 2007 "SourceList.c"
}

/**
     * Gets the number of visible children of an expandable item.
     *
     * @param parent Item to query.
     * @return Number of visible children of //parent//.
     * @since 0.2
     */
guint
granite_widgets_source_list_get_n_visible_children (GraniteWidgetsSourceList* self,
                                                    GraniteWidgetsSourceListExpandableItem* parent)
{
	GtkTreeIter* parent_iter = NULL;
	GraniteWidgetsSourceListDataModel* _tmp0_;
	GtkTreeIter* _tmp1_;
	GraniteWidgetsSourceListDataModel* _tmp2_;
	guint result;
#line 2900 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, 0U);
#line 2900 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (parent != NULL, 0U);
#line 2902 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->data_model;
#line 2902 "../lib/Widgets/SourceList.vala"
	_tmp1_ = granite_widgets_source_list_data_model_get_item_iter (_tmp0_, (GraniteWidgetsSourceListItem*) parent);
#line 2902 "../lib/Widgets/SourceList.vala"
	parent_iter = _tmp1_;
#line 2903 "../lib/Widgets/SourceList.vala"
	_tmp2_ = self->priv->data_model;
#line 2903 "../lib/Widgets/SourceList.vala"
	result = (guint) gtk_tree_model_iter_n_children ((GtkTreeModel*) _tmp2_, parent_iter);
#line 2903 "../lib/Widgets/SourceList.vala"
	__vala_GtkTreeIter_free0 (parent_iter);
#line 2903 "../lib/Widgets/SourceList.vala"
	return result;
#line 2044 "SourceList.c"
}

static GraniteWidgetsSourceListItem*
granite_widgets_source_list_get_nth_child (GraniteWidgetsSourceList* self,
                                           GraniteWidgetsSourceListExpandableItem* parent,
                                           gint index)
{
	GtkTreeIter* parent_iter = NULL;
	GraniteWidgetsSourceListDataModel* _tmp0_;
	GtkTreeIter* _tmp1_;
	GtkTreeIter child_iter = {0};
	GraniteWidgetsSourceListDataModel* _tmp2_;
	GtkTreeIter* _tmp3_;
	GtkTreeIter _tmp4_ = {0};
	gboolean _tmp5_;
	GraniteWidgetsSourceListItem* result;
#line 2906 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 2906 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (parent != NULL, NULL);
#line 2907 "../lib/Widgets/SourceList.vala"
	if (index < 0) {
#line 2908 "../lib/Widgets/SourceList.vala"
		result = NULL;
#line 2908 "../lib/Widgets/SourceList.vala"
		return result;
#line 2071 "SourceList.c"
	}
#line 2911 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->data_model;
#line 2911 "../lib/Widgets/SourceList.vala"
	_tmp1_ = granite_widgets_source_list_data_model_get_item_iter (_tmp0_, (GraniteWidgetsSourceListItem*) parent);
#line 2911 "../lib/Widgets/SourceList.vala"
	parent_iter = _tmp1_;
#line 2914 "../lib/Widgets/SourceList.vala"
	_tmp2_ = self->priv->data_model;
#line 2914 "../lib/Widgets/SourceList.vala"
	_tmp3_ = parent_iter;
#line 2914 "../lib/Widgets/SourceList.vala"
	_tmp5_ = gtk_tree_model_iter_nth_child ((GtkTreeModel*) _tmp2_, &_tmp4_, _tmp3_, index);
#line 2914 "../lib/Widgets/SourceList.vala"
	child_iter = _tmp4_;
#line 2914 "../lib/Widgets/SourceList.vala"
	if (_tmp5_) {
#line 2089 "SourceList.c"
		GraniteWidgetsSourceListDataModel* _tmp6_;
		GtkTreeIter _tmp7_;
		GraniteWidgetsSourceListItem* _tmp8_;
#line 2915 "../lib/Widgets/SourceList.vala"
		_tmp6_ = self->priv->data_model;
#line 2915 "../lib/Widgets/SourceList.vala"
		_tmp7_ = child_iter;
#line 2915 "../lib/Widgets/SourceList.vala"
		_tmp8_ = granite_widgets_source_list_data_model_get_item (_tmp6_, &_tmp7_);
#line 2915 "../lib/Widgets/SourceList.vala"
		result = _tmp8_;
#line 2915 "../lib/Widgets/SourceList.vala"
		__vala_GtkTreeIter_free0 (parent_iter);
#line 2915 "../lib/Widgets/SourceList.vala"
		return result;
#line 2105 "SourceList.c"
	}
#line 2917 "../lib/Widgets/SourceList.vala"
	result = NULL;
#line 2917 "../lib/Widgets/SourceList.vala"
	__vala_GtkTreeIter_free0 (parent_iter);
#line 2917 "../lib/Widgets/SourceList.vala"
	return result;
#line 2113 "SourceList.c"
}

static inline gpointer
granite_widgets_source_list_item_get_instance_private (GraniteWidgetsSourceListItem* self)
{
	return G_STRUCT_MEMBER_P (self, GraniteWidgetsSourceListItem_private_offset);
}

static gchar*
string_strip (const gchar* self)
{
	gchar* _result_ = NULL;
	gchar* _tmp0_;
	gchar* result;
#line 1367 "glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1368 "glib-2.0.vapi"
	_tmp0_ = g_strdup (self);
#line 1368 "glib-2.0.vapi"
	_result_ = _tmp0_;
#line 1369 "glib-2.0.vapi"
	g_strstrip (_result_);
#line 1370 "glib-2.0.vapi"
	result = _result_;
#line 1370 "glib-2.0.vapi"
	return result;
#line 2140 "SourceList.c"
}

static void
granite_widgets_source_list_item_real_edited (GraniteWidgetsSourceListItem* self,
                                              const gchar* new_name)
{
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_;
#line 278 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (new_name != NULL);
#line 279 "../lib/Widgets/SourceList.vala"
	_tmp1_ = self->priv->_editable;
#line 279 "../lib/Widgets/SourceList.vala"
	if (_tmp1_) {
#line 2155 "SourceList.c"
		gchar* _tmp2_;
		gchar* _tmp3_;
#line 279 "../lib/Widgets/SourceList.vala"
		_tmp2_ = string_strip (new_name);
#line 279 "../lib/Widgets/SourceList.vala"
		_tmp3_ = _tmp2_;
#line 279 "../lib/Widgets/SourceList.vala"
		_tmp0_ = g_strcmp0 (_tmp3_, "") != 0;
#line 279 "../lib/Widgets/SourceList.vala"
		_g_free0 (_tmp3_);
#line 2166 "SourceList.c"
	} else {
#line 279 "../lib/Widgets/SourceList.vala"
		_tmp0_ = FALSE;
#line 2170 "SourceList.c"
	}
#line 279 "../lib/Widgets/SourceList.vala"
	if (_tmp0_) {
#line 280 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_item_set_name (self, new_name);
#line 2176 "SourceList.c"
	}
}

static void
granite_widgets_source_list_item_real_action_activated (GraniteWidgetsSourceListItem* self)
{
}

static void
granite_widgets_source_list_item_real_activated (GraniteWidgetsSourceListItem* self)
{
}

GraniteWidgetsSourceListExpandableItem*
granite_widgets_source_list_item_get_parent (GraniteWidgetsSourceListItem* self)
{
	GraniteWidgetsSourceListExpandableItem* result;
	GraniteWidgetsSourceListExpandableItem* _tmp0_;
#line 306 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 306 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->_parent;
#line 306 "../lib/Widgets/SourceList.vala"
	result = _tmp0_;
#line 306 "../lib/Widgets/SourceList.vala"
	return result;
#line 2203 "SourceList.c"
}

static gpointer
_g_object_ref0 (gpointer self)
{
#line 306 "../lib/Widgets/SourceList.vala"
	return self ? g_object_ref (self) : NULL;
#line 2211 "SourceList.c"
}

 G_GNUC_INTERNAL void
granite_widgets_source_list_item_set_parent (GraniteWidgetsSourceListItem* self,
                                             GraniteWidgetsSourceListExpandableItem* value)
{
	GraniteWidgetsSourceListExpandableItem* old_value;
#line 306 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 306 "../lib/Widgets/SourceList.vala"
	old_value = granite_widgets_source_list_item_get_parent (self);
#line 306 "../lib/Widgets/SourceList.vala"
	if (old_value != value) {
#line 2225 "SourceList.c"
		GraniteWidgetsSourceListExpandableItem* _tmp0_;
#line 306 "../lib/Widgets/SourceList.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 306 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (self->priv->_parent);
#line 306 "../lib/Widgets/SourceList.vala"
		self->priv->_parent = _tmp0_;
#line 306 "../lib/Widgets/SourceList.vala"
		g_object_notify_by_pspec ((GObject *) self, granite_widgets_source_list_item_properties[GRANITE_WIDGETS_SOURCE_LIST_ITEM_PARENT_PROPERTY]);
#line 2235 "SourceList.c"
	}
}

const gchar*
granite_widgets_source_list_item_get_name (GraniteWidgetsSourceListItem* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 313 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 313 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->_name;
#line 313 "../lib/Widgets/SourceList.vala"
	result = _tmp0_;
#line 313 "../lib/Widgets/SourceList.vala"
	return result;
#line 2252 "SourceList.c"
}

void
granite_widgets_source_list_item_set_name (GraniteWidgetsSourceListItem* self,
                                           const gchar* value)
{
	gchar* old_value;
#line 313 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 313 "../lib/Widgets/SourceList.vala"
	old_value = granite_widgets_source_list_item_get_name (self);
#line 313 "../lib/Widgets/SourceList.vala"
	if (g_strcmp0 (value, old_value) != 0) {
#line 2266 "SourceList.c"
		gchar* _tmp0_;
#line 313 "../lib/Widgets/SourceList.vala"
		_tmp0_ = g_strdup (value);
#line 313 "../lib/Widgets/SourceList.vala"
		_g_free0 (self->priv->_name);
#line 313 "../lib/Widgets/SourceList.vala"
		self->priv->_name = _tmp0_;
#line 313 "../lib/Widgets/SourceList.vala"
		g_object_notify_by_pspec ((GObject *) self, granite_widgets_source_list_item_properties[GRANITE_WIDGETS_SOURCE_LIST_ITEM_NAME_PROPERTY]);
#line 2276 "SourceList.c"
	}
}

const gchar*
granite_widgets_source_list_item_get_tooltip (GraniteWidgetsSourceListItem* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 321 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 321 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->_tooltip;
#line 321 "../lib/Widgets/SourceList.vala"
	result = _tmp0_;
#line 321 "../lib/Widgets/SourceList.vala"
	return result;
#line 2293 "SourceList.c"
}

void
granite_widgets_source_list_item_set_tooltip (GraniteWidgetsSourceListItem* self,
                                              const gchar* value)
{
	gchar* old_value;
#line 321 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 321 "../lib/Widgets/SourceList.vala"
	old_value = granite_widgets_source_list_item_get_tooltip (self);
#line 321 "../lib/Widgets/SourceList.vala"
	if (g_strcmp0 (value, old_value) != 0) {
#line 2307 "SourceList.c"
		gchar* _tmp0_;
#line 321 "../lib/Widgets/SourceList.vala"
		_tmp0_ = g_strdup (value);
#line 321 "../lib/Widgets/SourceList.vala"
		_g_free0 (self->priv->_tooltip);
#line 321 "../lib/Widgets/SourceList.vala"
		self->priv->_tooltip = _tmp0_;
#line 321 "../lib/Widgets/SourceList.vala"
		g_object_notify_by_pspec ((GObject *) self, granite_widgets_source_list_item_properties[GRANITE_WIDGETS_SOURCE_LIST_ITEM_TOOLTIP_PROPERTY]);
#line 2317 "SourceList.c"
	}
}

const gchar*
granite_widgets_source_list_item_get_markup (GraniteWidgetsSourceListItem* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 334 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 334 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->_markup;
#line 334 "../lib/Widgets/SourceList.vala"
	result = _tmp0_;
#line 334 "../lib/Widgets/SourceList.vala"
	return result;
#line 2334 "SourceList.c"
}

void
granite_widgets_source_list_item_set_markup (GraniteWidgetsSourceListItem* self,
                                             const gchar* value)
{
	gchar* old_value;
#line 334 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 334 "../lib/Widgets/SourceList.vala"
	old_value = granite_widgets_source_list_item_get_markup (self);
#line 334 "../lib/Widgets/SourceList.vala"
	if (g_strcmp0 (value, old_value) != 0) {
#line 2348 "SourceList.c"
		gchar* _tmp0_;
#line 334 "../lib/Widgets/SourceList.vala"
		_tmp0_ = g_strdup (value);
#line 334 "../lib/Widgets/SourceList.vala"
		_g_free0 (self->priv->_markup);
#line 334 "../lib/Widgets/SourceList.vala"
		self->priv->_markup = _tmp0_;
#line 334 "../lib/Widgets/SourceList.vala"
		g_object_notify_by_pspec ((GObject *) self, granite_widgets_source_list_item_properties[GRANITE_WIDGETS_SOURCE_LIST_ITEM_MARKUP_PROPERTY]);
#line 2358 "SourceList.c"
	}
}

const gchar*
granite_widgets_source_list_item_get_badge (GraniteWidgetsSourceListItem* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 344 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 344 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->_badge;
#line 344 "../lib/Widgets/SourceList.vala"
	result = _tmp0_;
#line 344 "../lib/Widgets/SourceList.vala"
	return result;
#line 2375 "SourceList.c"
}

void
granite_widgets_source_list_item_set_badge (GraniteWidgetsSourceListItem* self,
                                            const gchar* value)
{
	gchar* old_value;
#line 344 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 344 "../lib/Widgets/SourceList.vala"
	old_value = granite_widgets_source_list_item_get_badge (self);
#line 344 "../lib/Widgets/SourceList.vala"
	if (g_strcmp0 (value, old_value) != 0) {
#line 2389 "SourceList.c"
		gchar* _tmp0_;
#line 344 "../lib/Widgets/SourceList.vala"
		_tmp0_ = g_strdup (value);
#line 344 "../lib/Widgets/SourceList.vala"
		_g_free0 (self->priv->_badge);
#line 344 "../lib/Widgets/SourceList.vala"
		self->priv->_badge = _tmp0_;
#line 344 "../lib/Widgets/SourceList.vala"
		g_object_notify_by_pspec ((GObject *) self, granite_widgets_source_list_item_properties[GRANITE_WIDGETS_SOURCE_LIST_ITEM_BADGE_PROPERTY]);
#line 2399 "SourceList.c"
	}
}

gboolean
granite_widgets_source_list_item_get_editable (GraniteWidgetsSourceListItem* self)
{
	gboolean result;
#line 358 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 358 "../lib/Widgets/SourceList.vala"
	result = self->priv->_editable;
#line 358 "../lib/Widgets/SourceList.vala"
	return result;
#line 2413 "SourceList.c"
}

void
granite_widgets_source_list_item_set_editable (GraniteWidgetsSourceListItem* self,
                                               gboolean value)
{
	gboolean old_value;
#line 358 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 358 "../lib/Widgets/SourceList.vala"
	old_value = granite_widgets_source_list_item_get_editable (self);
#line 358 "../lib/Widgets/SourceList.vala"
	if (old_value != value) {
#line 358 "../lib/Widgets/SourceList.vala"
		self->priv->_editable = value;
#line 358 "../lib/Widgets/SourceList.vala"
		g_object_notify_by_pspec ((GObject *) self, granite_widgets_source_list_item_properties[GRANITE_WIDGETS_SOURCE_LIST_ITEM_EDITABLE_PROPERTY]);
#line 2431 "SourceList.c"
	}
}

gboolean
granite_widgets_source_list_item_get_visible (GraniteWidgetsSourceListItem* self)
{
	gboolean result;
#line 365 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 365 "../lib/Widgets/SourceList.vala"
	result = self->priv->_visible;
#line 365 "../lib/Widgets/SourceList.vala"
	return result;
#line 2445 "SourceList.c"
}

void
granite_widgets_source_list_item_set_visible (GraniteWidgetsSourceListItem* self,
                                              gboolean value)
{
	gboolean old_value;
#line 365 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 365 "../lib/Widgets/SourceList.vala"
	old_value = granite_widgets_source_list_item_get_visible (self);
#line 365 "../lib/Widgets/SourceList.vala"
	if (old_value != value) {
#line 365 "../lib/Widgets/SourceList.vala"
		self->priv->_visible = value;
#line 365 "../lib/Widgets/SourceList.vala"
		g_object_notify_by_pspec ((GObject *) self, granite_widgets_source_list_item_properties[GRANITE_WIDGETS_SOURCE_LIST_ITEM_VISIBLE_PROPERTY]);
#line 2463 "SourceList.c"
	}
}

gboolean
granite_widgets_source_list_item_get_selectable (GraniteWidgetsSourceListItem* self)
{
	gboolean result;
#line 378 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 378 "../lib/Widgets/SourceList.vala"
	result = self->priv->_selectable;
#line 378 "../lib/Widgets/SourceList.vala"
	return result;
#line 2477 "SourceList.c"
}

void
granite_widgets_source_list_item_set_selectable (GraniteWidgetsSourceListItem* self,
                                                 gboolean value)
{
	gboolean old_value;
#line 378 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 378 "../lib/Widgets/SourceList.vala"
	old_value = granite_widgets_source_list_item_get_selectable (self);
#line 378 "../lib/Widgets/SourceList.vala"
	if (old_value != value) {
#line 378 "../lib/Widgets/SourceList.vala"
		self->priv->_selectable = value;
#line 378 "../lib/Widgets/SourceList.vala"
		g_object_notify_by_pspec ((GObject *) self, granite_widgets_source_list_item_properties[GRANITE_WIDGETS_SOURCE_LIST_ITEM_SELECTABLE_PROPERTY]);
#line 2495 "SourceList.c"
	}
}

GIcon*
granite_widgets_source_list_item_get_icon (GraniteWidgetsSourceListItem* self)
{
	GIcon* result;
	GIcon* _tmp0_;
#line 388 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 388 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->_icon;
#line 388 "../lib/Widgets/SourceList.vala"
	result = _tmp0_;
#line 388 "../lib/Widgets/SourceList.vala"
	return result;
#line 2512 "SourceList.c"
}

void
granite_widgets_source_list_item_set_icon (GraniteWidgetsSourceListItem* self,
                                           GIcon* value)
{
	GIcon* old_value;
#line 388 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 388 "../lib/Widgets/SourceList.vala"
	old_value = granite_widgets_source_list_item_get_icon (self);
#line 388 "../lib/Widgets/SourceList.vala"
	if (old_value != value) {
#line 2526 "SourceList.c"
		GIcon* _tmp0_;
#line 388 "../lib/Widgets/SourceList.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 388 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (self->priv->_icon);
#line 388 "../lib/Widgets/SourceList.vala"
		self->priv->_icon = _tmp0_;
#line 388 "../lib/Widgets/SourceList.vala"
		g_object_notify_by_pspec ((GObject *) self, granite_widgets_source_list_item_properties[GRANITE_WIDGETS_SOURCE_LIST_ITEM_ICON_PROPERTY]);
#line 2536 "SourceList.c"
	}
}

GIcon*
granite_widgets_source_list_item_get_activatable (GraniteWidgetsSourceListItem* self)
{
	GIcon* result;
	GIcon* _tmp0_;
#line 398 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 398 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->_activatable;
#line 398 "../lib/Widgets/SourceList.vala"
	result = _tmp0_;
#line 398 "../lib/Widgets/SourceList.vala"
	return result;
#line 2553 "SourceList.c"
}

void
granite_widgets_source_list_item_set_activatable (GraniteWidgetsSourceListItem* self,
                                                  GIcon* value)
{
	GIcon* old_value;
#line 398 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 398 "../lib/Widgets/SourceList.vala"
	old_value = granite_widgets_source_list_item_get_activatable (self);
#line 398 "../lib/Widgets/SourceList.vala"
	if (old_value != value) {
#line 2567 "SourceList.c"
		GIcon* _tmp0_;
#line 398 "../lib/Widgets/SourceList.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 398 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (self->priv->_activatable);
#line 398 "../lib/Widgets/SourceList.vala"
		self->priv->_activatable = _tmp0_;
#line 398 "../lib/Widgets/SourceList.vala"
		g_object_notify_by_pspec ((GObject *) self, granite_widgets_source_list_item_properties[GRANITE_WIDGETS_SOURCE_LIST_ITEM_ACTIVATABLE_PROPERTY]);
#line 2577 "SourceList.c"
	}
}

const gchar*
granite_widgets_source_list_item_get_activatable_tooltip (GraniteWidgetsSourceListItem* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 405 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 405 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->_activatable_tooltip;
#line 405 "../lib/Widgets/SourceList.vala"
	result = _tmp0_;
#line 405 "../lib/Widgets/SourceList.vala"
	return result;
#line 2594 "SourceList.c"
}

void
granite_widgets_source_list_item_set_activatable_tooltip (GraniteWidgetsSourceListItem* self,
                                                          const gchar* value)
{
	gchar* old_value;
#line 405 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 405 "../lib/Widgets/SourceList.vala"
	old_value = granite_widgets_source_list_item_get_activatable_tooltip (self);
#line 405 "../lib/Widgets/SourceList.vala"
	if (g_strcmp0 (value, old_value) != 0) {
#line 2608 "SourceList.c"
		gchar* _tmp0_;
#line 405 "../lib/Widgets/SourceList.vala"
		_tmp0_ = g_strdup (value);
#line 405 "../lib/Widgets/SourceList.vala"
		_g_free0 (self->priv->_activatable_tooltip);
#line 405 "../lib/Widgets/SourceList.vala"
		self->priv->_activatable_tooltip = _tmp0_;
#line 405 "../lib/Widgets/SourceList.vala"
		g_object_notify_by_pspec ((GObject *) self, granite_widgets_source_list_item_properties[GRANITE_WIDGETS_SOURCE_LIST_ITEM_ACTIVATABLE_TOOLTIP_PROPERTY]);
#line 2618 "SourceList.c"
	}
}

/**
         * Creates a new {@link Granite.Widgets.SourceList.Item}.
         *
         * @param name Name of the item.
         * @return (transfer full) A new {@link Granite.Widgets.SourceList.Item}.
         * @since 0.2
         */
GraniteWidgetsSourceListItem*
granite_widgets_source_list_item_construct (GType object_type,
                                            const gchar* name)
{
	GraniteWidgetsSourceListItem * self = NULL;
#line 414 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 414 "../lib/Widgets/SourceList.vala"
	self = (GraniteWidgetsSourceListItem*) g_object_new (object_type, NULL);
#line 415 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_item_set_name (self, name);
#line 414 "../lib/Widgets/SourceList.vala"
	return self;
#line 2642 "SourceList.c"
}

GraniteWidgetsSourceListItem*
granite_widgets_source_list_item_new (const gchar* name)
{
#line 414 "../lib/Widgets/SourceList.vala"
	return granite_widgets_source_list_item_construct (GRANITE_WIDGETS_SOURCE_LIST_TYPE_ITEM, name);
#line 2650 "SourceList.c"
}

/**
         * Invoked when the item is secondary-clicked or when the usual menu keys are pressed.
         *
         * Note that since Granite 5.0, right clicking on an item no longer selects/activates it, so
         * any context menu items should be actioned on the item instance rather than the selected item
         * in the SourceList
         *
         * @return A {@link Gtk.Menu} or //null// if nothing should be displayed.
         * @since 0.2
         */
static GtkMenu*
granite_widgets_source_list_item_real_get_context_menu (GraniteWidgetsSourceListItem* self)
{
	GtkMenu* result;
#line 429 "../lib/Widgets/SourceList.vala"
	result = NULL;
#line 429 "../lib/Widgets/SourceList.vala"
	return result;
#line 2671 "SourceList.c"
}

GtkMenu*
granite_widgets_source_list_item_get_context_menu (GraniteWidgetsSourceListItem* self)
{
	GraniteWidgetsSourceListItemClass* _klass_;
#line 428 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 428 "../lib/Widgets/SourceList.vala"
	_klass_ = GRANITE_WIDGETS_SOURCE_LIST_ITEM_GET_CLASS (self);
#line 428 "../lib/Widgets/SourceList.vala"
	if (_klass_->get_context_menu) {
#line 428 "../lib/Widgets/SourceList.vala"
		return _klass_->get_context_menu (self);
#line 2686 "SourceList.c"
	}
#line 428 "../lib/Widgets/SourceList.vala"
	return NULL;
#line 2690 "SourceList.c"
}

static void
granite_widgets_source_list_item_class_init (GraniteWidgetsSourceListItemClass * klass,
                                             gpointer klass_data)
{
#line 267 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_item_parent_class = g_type_class_peek_parent (klass);
#line 267 "../lib/Widgets/SourceList.vala"
	g_type_class_adjust_private_offset (klass, &GraniteWidgetsSourceListItem_private_offset);
#line 267 "../lib/Widgets/SourceList.vala"
	((GraniteWidgetsSourceListItemClass *) klass)->get_context_menu = (GtkMenu* (*) (GraniteWidgetsSourceListItem*)) granite_widgets_source_list_item_real_get_context_menu;
#line 267 "../lib/Widgets/SourceList.vala"
	((GraniteWidgetsSourceListItemClass *) klass)->edited = granite_widgets_source_list_item_real_edited;
#line 267 "../lib/Widgets/SourceList.vala"
	((GraniteWidgetsSourceListItemClass *) klass)->action_activated = granite_widgets_source_list_item_real_action_activated;
#line 267 "../lib/Widgets/SourceList.vala"
	((GraniteWidgetsSourceListItemClass *) klass)->activated = granite_widgets_source_list_item_real_activated;
#line 267 "../lib/Widgets/SourceList.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_granite_widgets_source_list_item_get_property;
#line 267 "../lib/Widgets/SourceList.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_granite_widgets_source_list_item_set_property;
#line 267 "../lib/Widgets/SourceList.vala"
	G_OBJECT_CLASS (klass)->finalize = granite_widgets_source_list_item_finalize;
#line 2715 "SourceList.c"
	/**
	         * Parent {@link Granite.Widgets.SourceList.ExpandableItem} of the item.
	         * ''Must not'' be modified.
	         *
	         * @since 0.2
	         */
#line 267 "../lib/Widgets/SourceList.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GRANITE_WIDGETS_SOURCE_LIST_ITEM_PARENT_PROPERTY, granite_widgets_source_list_item_properties[GRANITE_WIDGETS_SOURCE_LIST_ITEM_PARENT_PROPERTY] = g_param_spec_object ("parent", "parent", "parent", GRANITE_WIDGETS_SOURCE_LIST_TYPE_EXPANDABLE_ITEM, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 2724 "SourceList.c"
	/**
	         * The item's name. Primary and most important information.
	         *
	         * @since 0.2
	         */
#line 267 "../lib/Widgets/SourceList.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GRANITE_WIDGETS_SOURCE_LIST_ITEM_NAME_PROPERTY, granite_widgets_source_list_item_properties[GRANITE_WIDGETS_SOURCE_LIST_ITEM_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 2732 "SourceList.c"
	/**
	         * The item's tooltip. If set to null (default), the tooltip for the item will be the
	         * contents of the {@link Granite.Widgets.SourceList.Item.name} property.
	         *
	         * @since 5.3
	         */
#line 267 "../lib/Widgets/SourceList.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GRANITE_WIDGETS_SOURCE_LIST_ITEM_TOOLTIP_PROPERTY, granite_widgets_source_list_item_properties[GRANITE_WIDGETS_SOURCE_LIST_ITEM_TOOLTIP_PROPERTY] = g_param_spec_string ("tooltip", "tooltip", "tooltip", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 2741 "SourceList.c"
	/**
	         * Markup to be used instead of {@link Granite.Widgets.SourceList.ExpandableItem.name}
	         * This would mean that &, <, etc have to be escaped in the text, but basic formatting
	         * can be done on the item with HTML style tags.
	         *
	         * Note: Only the {@link Granite.Widgets.SourceList.ExpandableItem.name} property
	         * is modified for editable items. So this property will be need to updated and
	         * reformatted with editable items.
	         *
	         * @since 5.0
	         */
#line 267 "../lib/Widgets/SourceList.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GRANITE_WIDGETS_SOURCE_LIST_ITEM_MARKUP_PROPERTY, granite_widgets_source_list_item_properties[GRANITE_WIDGETS_SOURCE_LIST_ITEM_MARKUP_PROPERTY] = g_param_spec_string ("markup", "markup", "markup", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 2755 "SourceList.c"
	/**
	         * A badge shown next to the item's name.
	         *
	         * It can be used for displaying the number of unread messages in the "Inbox" item,
	         * for instance.
	         *
	         * @since 0.2
	         */
#line 267 "../lib/Widgets/SourceList.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GRANITE_WIDGETS_SOURCE_LIST_ITEM_BADGE_PROPERTY, granite_widgets_source_list_item_properties[GRANITE_WIDGETS_SOURCE_LIST_ITEM_BADGE_PROPERTY] = g_param_spec_string ("badge", "badge", "badge", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 2766 "SourceList.c"
	/**
	         * Whether the item's name can be edited from within the source list.
	         *
	         * When this property is set to //true//, users can edit the item by pressing
	         * the F2 key, or by double-clicking its name.
	         *
	         * ''This property only works for selectable items''.
	         *
	         * @see Granite.Widgets.SourceList.Item.selectable
	         * @see Granite.Widgets.SourceList.start_editing_item
	         * @since 0.2
	         */
#line 267 "../lib/Widgets/SourceList.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GRANITE_WIDGETS_SOURCE_LIST_ITEM_EDITABLE_PROPERTY, granite_widgets_source_list_item_properties[GRANITE_WIDGETS_SOURCE_LIST_ITEM_EDITABLE_PROPERTY] = g_param_spec_boolean ("editable", "editable", "editable", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 2781 "SourceList.c"
	/**
	         * Whether the item should appear in the source list's tree or not.
	         *
	         * @since 0.2
	         */
#line 267 "../lib/Widgets/SourceList.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GRANITE_WIDGETS_SOURCE_LIST_ITEM_VISIBLE_PROPERTY, granite_widgets_source_list_item_properties[GRANITE_WIDGETS_SOURCE_LIST_ITEM_VISIBLE_PROPERTY] = g_param_spec_boolean ("visible", "visible", "visible", TRUE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 2789 "SourceList.c"
	/**
	         * Whether the item can be selected or not.
	         *
	         * Setting this property to true doesn't guarantee that the item will actually be
	         * selectable, since there are other external factors to take into account, like the
	         * item's {@link Granite.Widgets.SourceList.Item.visible} property; whether the item is
	         * a category; the parent item is collapsed, etc.
	         *
	         * @see Granite.Widgets.SourceList.Item.visible
	         * @since 0.2
	         */
#line 267 "../lib/Widgets/SourceList.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GRANITE_WIDGETS_SOURCE_LIST_ITEM_SELECTABLE_PROPERTY, granite_widgets_source_list_item_properties[GRANITE_WIDGETS_SOURCE_LIST_ITEM_SELECTABLE_PROPERTY] = g_param_spec_boolean ("selectable", "selectable", "selectable", TRUE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 2803 "SourceList.c"
	/**
	         * Primary icon.
	         *
	         * This property should be used to give the user an idea of what the item represents
	         * (i.e. content type.)
	         *
	         * @since 0.2
	         */
#line 267 "../lib/Widgets/SourceList.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GRANITE_WIDGETS_SOURCE_LIST_ITEM_ICON_PROPERTY, granite_widgets_source_list_item_properties[GRANITE_WIDGETS_SOURCE_LIST_ITEM_ICON_PROPERTY] = g_param_spec_object ("icon", "icon", "icon", g_icon_get_type (), G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 2814 "SourceList.c"
	/**
	         * An activatable icon that works like a button.
	         *
	         * It can be used for e.g. showing an //"eject"// icon on a device's item.
	         *
	         * @see Granite.Widgets.SourceList.Item.action_activated
	         * @since 0.2
	         */
#line 267 "../lib/Widgets/SourceList.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GRANITE_WIDGETS_SOURCE_LIST_ITEM_ACTIVATABLE_PROPERTY, granite_widgets_source_list_item_properties[GRANITE_WIDGETS_SOURCE_LIST_ITEM_ACTIVATABLE_PROPERTY] = g_param_spec_object ("activatable", "activatable", "activatable", g_icon_get_type (), G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 2825 "SourceList.c"
	/**
	         * The tooltip for the activatable icon.
	         *
	         * @since 5.0
	         */
#line 267 "../lib/Widgets/SourceList.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GRANITE_WIDGETS_SOURCE_LIST_ITEM_ACTIVATABLE_TOOLTIP_PROPERTY, granite_widgets_source_list_item_properties[GRANITE_WIDGETS_SOURCE_LIST_ITEM_ACTIVATABLE_TOOLTIP_PROPERTY] = g_param_spec_string ("activatable-tooltip", "activatable-tooltip", "activatable-tooltip", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 2833 "SourceList.c"
	/**
	         * Emitted when the user has finished editing the item's name.
	         *
	         * By default, if the name doesn't consist of white space, it is automatically assigned
	         * to the {@link Granite.Widgets.SourceList.Item.name} property. The default behavior can
	         * be changed by overriding this signal.
	         * @param new_name The item's new name (result of editing.)
	         * @since 0.2
	         */
#line 267 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_item_signals[GRANITE_WIDGETS_SOURCE_LIST_ITEM_EDITED_SIGNAL] = g_signal_new ("edited", GRANITE_WIDGETS_SOURCE_LIST_TYPE_ITEM, G_SIGNAL_RUN_LAST, G_STRUCT_OFFSET (GraniteWidgetsSourceListItemClass, edited), NULL, NULL, g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, 1, G_TYPE_STRING);
#line 2845 "SourceList.c"
	/**
	         * The {@link Granite.Widgets.SourceList.Item.activatable} icon was activated.
	         *
	         * @see Granite.Widgets.SourceList.Item.activatable
	         * @since 0.2
	         */
#line 267 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_item_signals[GRANITE_WIDGETS_SOURCE_LIST_ITEM_ACTION_ACTIVATED_SIGNAL] = g_signal_new ("action-activated", GRANITE_WIDGETS_SOURCE_LIST_TYPE_ITEM, G_SIGNAL_RUN_LAST, G_STRUCT_OFFSET (GraniteWidgetsSourceListItemClass, action_activated), NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 2854 "SourceList.c"
	/**
	         * Emitted when the item is double-clicked or when it is selected and one of the keys:
	         * Space, Shift+Space, Return or Enter is pressed. This signal is //also// for
	         * editable items.
	         *
	         * @since 0.2
	         */
#line 267 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_item_signals[GRANITE_WIDGETS_SOURCE_LIST_ITEM_ACTIVATED_SIGNAL] = g_signal_new ("activated", GRANITE_WIDGETS_SOURCE_LIST_TYPE_ITEM, G_SIGNAL_RUN_LAST, G_STRUCT_OFFSET (GraniteWidgetsSourceListItemClass, activated), NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 2864 "SourceList.c"
}

static void
granite_widgets_source_list_item_instance_init (GraniteWidgetsSourceListItem * self,
                                                gpointer klass)
{
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
#line 267 "../lib/Widgets/SourceList.vala"
	self->priv = granite_widgets_source_list_item_get_instance_private (self);
#line 313 "../lib/Widgets/SourceList.vala"
	_tmp0_ = g_strdup ("");
#line 313 "../lib/Widgets/SourceList.vala"
	self->priv->_name = _tmp0_;
#line 321 "../lib/Widgets/SourceList.vala"
	self->priv->_tooltip = NULL;
#line 334 "../lib/Widgets/SourceList.vala"
	self->priv->_markup = NULL;
#line 344 "../lib/Widgets/SourceList.vala"
	_tmp1_ = g_strdup ("");
#line 344 "../lib/Widgets/SourceList.vala"
	self->priv->_badge = _tmp1_;
#line 358 "../lib/Widgets/SourceList.vala"
	self->priv->_editable = FALSE;
#line 365 "../lib/Widgets/SourceList.vala"
	self->priv->_visible = TRUE;
#line 378 "../lib/Widgets/SourceList.vala"
	self->priv->_selectable = TRUE;
#line 405 "../lib/Widgets/SourceList.vala"
	_tmp2_ = g_strdup ("");
#line 405 "../lib/Widgets/SourceList.vala"
	self->priv->_activatable_tooltip = _tmp2_;
#line 2898 "SourceList.c"
}

static void
granite_widgets_source_list_item_finalize (GObject * obj)
{
	GraniteWidgetsSourceListItem * self;
#line 267 "../lib/Widgets/SourceList.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GRANITE_WIDGETS_SOURCE_LIST_TYPE_ITEM, GraniteWidgetsSourceListItem);
#line 306 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (self->priv->_parent);
#line 313 "../lib/Widgets/SourceList.vala"
	_g_free0 (self->priv->_name);
#line 321 "../lib/Widgets/SourceList.vala"
	_g_free0 (self->priv->_tooltip);
#line 334 "../lib/Widgets/SourceList.vala"
	_g_free0 (self->priv->_markup);
#line 344 "../lib/Widgets/SourceList.vala"
	_g_free0 (self->priv->_badge);
#line 388 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (self->priv->_icon);
#line 398 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (self->priv->_activatable);
#line 405 "../lib/Widgets/SourceList.vala"
	_g_free0 (self->priv->_activatable_tooltip);
#line 267 "../lib/Widgets/SourceList.vala"
	G_OBJECT_CLASS (granite_widgets_source_list_item_parent_class)->finalize (obj);
#line 2925 "SourceList.c"
}

/**
     * A source list entry.
     *
     * Any change made to any of its properties will be ''automatically'' reflected
     * by the {@link Granite.Widgets.SourceList} widget.
     *
     * @since 0.2
     */
static GType
granite_widgets_source_list_item_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (GraniteWidgetsSourceListItemClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) granite_widgets_source_list_item_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GraniteWidgetsSourceListItem), 0, (GInstanceInitFunc) granite_widgets_source_list_item_instance_init, NULL };
	GType granite_widgets_source_list_item_type_id;
	granite_widgets_source_list_item_type_id = g_type_register_static (G_TYPE_OBJECT, "GraniteWidgetsSourceListItem", &g_define_type_info, 0);
	GraniteWidgetsSourceListItem_private_offset = g_type_add_instance_private (granite_widgets_source_list_item_type_id, sizeof (GraniteWidgetsSourceListItemPrivate));
	return granite_widgets_source_list_item_type_id;
}

GType
granite_widgets_source_list_item_get_type (void)
{
	static volatile gsize granite_widgets_source_list_item_type_id__once = 0;
	if (g_once_init_enter (&granite_widgets_source_list_item_type_id__once)) {
		GType granite_widgets_source_list_item_type_id;
		granite_widgets_source_list_item_type_id = granite_widgets_source_list_item_get_type_once ();
		g_once_init_leave (&granite_widgets_source_list_item_type_id__once, granite_widgets_source_list_item_type_id);
	}
	return granite_widgets_source_list_item_type_id__once;
}

static void
_vala_granite_widgets_source_list_item_get_property (GObject * object,
                                                     guint property_id,
                                                     GValue * value,
                                                     GParamSpec * pspec)
{
	GraniteWidgetsSourceListItem * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GRANITE_WIDGETS_SOURCE_LIST_TYPE_ITEM, GraniteWidgetsSourceListItem);
#line 267 "../lib/Widgets/SourceList.vala"
	switch (property_id) {
#line 267 "../lib/Widgets/SourceList.vala"
		case GRANITE_WIDGETS_SOURCE_LIST_ITEM_PARENT_PROPERTY:
#line 267 "../lib/Widgets/SourceList.vala"
		g_value_set_object (value, granite_widgets_source_list_item_get_parent (self));
#line 267 "../lib/Widgets/SourceList.vala"
		break;
#line 267 "../lib/Widgets/SourceList.vala"
		case GRANITE_WIDGETS_SOURCE_LIST_ITEM_NAME_PROPERTY:
#line 267 "../lib/Widgets/SourceList.vala"
		g_value_set_string (value, granite_widgets_source_list_item_get_name (self));
#line 267 "../lib/Widgets/SourceList.vala"
		break;
#line 267 "../lib/Widgets/SourceList.vala"
		case GRANITE_WIDGETS_SOURCE_LIST_ITEM_TOOLTIP_PROPERTY:
#line 267 "../lib/Widgets/SourceList.vala"
		g_value_set_string (value, granite_widgets_source_list_item_get_tooltip (self));
#line 267 "../lib/Widgets/SourceList.vala"
		break;
#line 267 "../lib/Widgets/SourceList.vala"
		case GRANITE_WIDGETS_SOURCE_LIST_ITEM_MARKUP_PROPERTY:
#line 267 "../lib/Widgets/SourceList.vala"
		g_value_set_string (value, granite_widgets_source_list_item_get_markup (self));
#line 267 "../lib/Widgets/SourceList.vala"
		break;
#line 267 "../lib/Widgets/SourceList.vala"
		case GRANITE_WIDGETS_SOURCE_LIST_ITEM_BADGE_PROPERTY:
#line 267 "../lib/Widgets/SourceList.vala"
		g_value_set_string (value, granite_widgets_source_list_item_get_badge (self));
#line 267 "../lib/Widgets/SourceList.vala"
		break;
#line 267 "../lib/Widgets/SourceList.vala"
		case GRANITE_WIDGETS_SOURCE_LIST_ITEM_EDITABLE_PROPERTY:
#line 267 "../lib/Widgets/SourceList.vala"
		g_value_set_boolean (value, granite_widgets_source_list_item_get_editable (self));
#line 267 "../lib/Widgets/SourceList.vala"
		break;
#line 267 "../lib/Widgets/SourceList.vala"
		case GRANITE_WIDGETS_SOURCE_LIST_ITEM_VISIBLE_PROPERTY:
#line 267 "../lib/Widgets/SourceList.vala"
		g_value_set_boolean (value, granite_widgets_source_list_item_get_visible (self));
#line 267 "../lib/Widgets/SourceList.vala"
		break;
#line 267 "../lib/Widgets/SourceList.vala"
		case GRANITE_WIDGETS_SOURCE_LIST_ITEM_SELECTABLE_PROPERTY:
#line 267 "../lib/Widgets/SourceList.vala"
		g_value_set_boolean (value, granite_widgets_source_list_item_get_selectable (self));
#line 267 "../lib/Widgets/SourceList.vala"
		break;
#line 267 "../lib/Widgets/SourceList.vala"
		case GRANITE_WIDGETS_SOURCE_LIST_ITEM_ICON_PROPERTY:
#line 267 "../lib/Widgets/SourceList.vala"
		g_value_set_object (value, granite_widgets_source_list_item_get_icon (self));
#line 267 "../lib/Widgets/SourceList.vala"
		break;
#line 267 "../lib/Widgets/SourceList.vala"
		case GRANITE_WIDGETS_SOURCE_LIST_ITEM_ACTIVATABLE_PROPERTY:
#line 267 "../lib/Widgets/SourceList.vala"
		g_value_set_object (value, granite_widgets_source_list_item_get_activatable (self));
#line 267 "../lib/Widgets/SourceList.vala"
		break;
#line 267 "../lib/Widgets/SourceList.vala"
		case GRANITE_WIDGETS_SOURCE_LIST_ITEM_ACTIVATABLE_TOOLTIP_PROPERTY:
#line 267 "../lib/Widgets/SourceList.vala"
		g_value_set_string (value, granite_widgets_source_list_item_get_activatable_tooltip (self));
#line 267 "../lib/Widgets/SourceList.vala"
		break;
#line 3034 "SourceList.c"
		default:
#line 267 "../lib/Widgets/SourceList.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 267 "../lib/Widgets/SourceList.vala"
		break;
#line 3040 "SourceList.c"
	}
}

static void
_vala_granite_widgets_source_list_item_set_property (GObject * object,
                                                     guint property_id,
                                                     const GValue * value,
                                                     GParamSpec * pspec)
{
	GraniteWidgetsSourceListItem * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GRANITE_WIDGETS_SOURCE_LIST_TYPE_ITEM, GraniteWidgetsSourceListItem);
#line 267 "../lib/Widgets/SourceList.vala"
	switch (property_id) {
#line 267 "../lib/Widgets/SourceList.vala"
		case GRANITE_WIDGETS_SOURCE_LIST_ITEM_PARENT_PROPERTY:
#line 267 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_item_set_parent (self, g_value_get_object (value));
#line 267 "../lib/Widgets/SourceList.vala"
		break;
#line 267 "../lib/Widgets/SourceList.vala"
		case GRANITE_WIDGETS_SOURCE_LIST_ITEM_NAME_PROPERTY:
#line 267 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_item_set_name (self, g_value_get_string (value));
#line 267 "../lib/Widgets/SourceList.vala"
		break;
#line 267 "../lib/Widgets/SourceList.vala"
		case GRANITE_WIDGETS_SOURCE_LIST_ITEM_TOOLTIP_PROPERTY:
#line 267 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_item_set_tooltip (self, g_value_get_string (value));
#line 267 "../lib/Widgets/SourceList.vala"
		break;
#line 267 "../lib/Widgets/SourceList.vala"
		case GRANITE_WIDGETS_SOURCE_LIST_ITEM_MARKUP_PROPERTY:
#line 267 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_item_set_markup (self, g_value_get_string (value));
#line 267 "../lib/Widgets/SourceList.vala"
		break;
#line 267 "../lib/Widgets/SourceList.vala"
		case GRANITE_WIDGETS_SOURCE_LIST_ITEM_BADGE_PROPERTY:
#line 267 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_item_set_badge (self, g_value_get_string (value));
#line 267 "../lib/Widgets/SourceList.vala"
		break;
#line 267 "../lib/Widgets/SourceList.vala"
		case GRANITE_WIDGETS_SOURCE_LIST_ITEM_EDITABLE_PROPERTY:
#line 267 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_item_set_editable (self, g_value_get_boolean (value));
#line 267 "../lib/Widgets/SourceList.vala"
		break;
#line 267 "../lib/Widgets/SourceList.vala"
		case GRANITE_WIDGETS_SOURCE_LIST_ITEM_VISIBLE_PROPERTY:
#line 267 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_item_set_visible (self, g_value_get_boolean (value));
#line 267 "../lib/Widgets/SourceList.vala"
		break;
#line 267 "../lib/Widgets/SourceList.vala"
		case GRANITE_WIDGETS_SOURCE_LIST_ITEM_SELECTABLE_PROPERTY:
#line 267 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_item_set_selectable (self, g_value_get_boolean (value));
#line 267 "../lib/Widgets/SourceList.vala"
		break;
#line 267 "../lib/Widgets/SourceList.vala"
		case GRANITE_WIDGETS_SOURCE_LIST_ITEM_ICON_PROPERTY:
#line 267 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_item_set_icon (self, g_value_get_object (value));
#line 267 "../lib/Widgets/SourceList.vala"
		break;
#line 267 "../lib/Widgets/SourceList.vala"
		case GRANITE_WIDGETS_SOURCE_LIST_ITEM_ACTIVATABLE_PROPERTY:
#line 267 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_item_set_activatable (self, g_value_get_object (value));
#line 267 "../lib/Widgets/SourceList.vala"
		break;
#line 267 "../lib/Widgets/SourceList.vala"
		case GRANITE_WIDGETS_SOURCE_LIST_ITEM_ACTIVATABLE_TOOLTIP_PROPERTY:
#line 267 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_item_set_activatable_tooltip (self, g_value_get_string (value));
#line 267 "../lib/Widgets/SourceList.vala"
		break;
#line 3120 "SourceList.c"
		default:
#line 267 "../lib/Widgets/SourceList.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 267 "../lib/Widgets/SourceList.vala"
		break;
#line 3126 "SourceList.c"
	}
}

static inline gpointer
granite_widgets_source_list_expandable_item_get_instance_private (GraniteWidgetsSourceListExpandableItem* self)
{
	return G_STRUCT_MEMBER_P (self, GraniteWidgetsSourceListExpandableItem_private_offset);
}

static void
granite_widgets_source_list_expandable_item_real_toggled (GraniteWidgetsSourceListExpandableItem* self)
{
}

gboolean
granite_widgets_source_list_expandable_item_get_collapsible (GraniteWidgetsSourceListExpandableItem* self)
{
	gboolean result;
#line 490 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 490 "../lib/Widgets/SourceList.vala"
	result = self->priv->_collapsible;
#line 490 "../lib/Widgets/SourceList.vala"
	return result;
#line 3151 "SourceList.c"
}

void
granite_widgets_source_list_expandable_item_set_collapsible (GraniteWidgetsSourceListExpandableItem* self,
                                                             gboolean value)
{
	gboolean old_value;
#line 490 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 490 "../lib/Widgets/SourceList.vala"
	old_value = granite_widgets_source_list_expandable_item_get_collapsible (self);
#line 490 "../lib/Widgets/SourceList.vala"
	if (old_value != value) {
#line 490 "../lib/Widgets/SourceList.vala"
		self->priv->_collapsible = value;
#line 490 "../lib/Widgets/SourceList.vala"
		g_object_notify_by_pspec ((GObject *) self, granite_widgets_source_list_expandable_item_properties[GRANITE_WIDGETS_SOURCE_LIST_EXPANDABLE_ITEM_COLLAPSIBLE_PROPERTY]);
#line 3169 "SourceList.c"
	}
}

gboolean
granite_widgets_source_list_expandable_item_get_expanded (GraniteWidgetsSourceListExpandableItem* self)
{
	gboolean result;
	gboolean _tmp0_ = FALSE;
#line 514 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 514 "../lib/Widgets/SourceList.vala"
	if (self->priv->_expanded) {
#line 514 "../lib/Widgets/SourceList.vala"
		_tmp0_ = TRUE;
#line 3184 "SourceList.c"
	} else {
		gboolean _tmp1_;
#line 514 "../lib/Widgets/SourceList.vala"
		_tmp1_ = self->priv->_collapsible;
#line 514 "../lib/Widgets/SourceList.vala"
		_tmp0_ = !_tmp1_;
#line 3191 "SourceList.c"
	}
#line 514 "../lib/Widgets/SourceList.vala"
	result = _tmp0_;
#line 514 "../lib/Widgets/SourceList.vala"
	return result;
#line 3197 "SourceList.c"
}

void
granite_widgets_source_list_expandable_item_set_expanded (GraniteWidgetsSourceListExpandableItem* self,
                                                          gboolean value)
{
#line 515 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 516 "../lib/Widgets/SourceList.vala"
	if (value != self->priv->_expanded) {
#line 517 "../lib/Widgets/SourceList.vala"
		self->priv->_expanded = value;
#line 518 "../lib/Widgets/SourceList.vala"
		g_signal_emit (self, granite_widgets_source_list_expandable_item_signals[GRANITE_WIDGETS_SOURCE_LIST_EXPANDABLE_ITEM_TOGGLED_SIGNAL], 0);
#line 3212 "SourceList.c"
	}
#line 515 "../lib/Widgets/SourceList.vala"
	g_object_notify_by_pspec ((GObject *) self, granite_widgets_source_list_expandable_item_properties[GRANITE_WIDGETS_SOURCE_LIST_EXPANDABLE_ITEM_EXPANDED_PROPERTY]);
#line 3216 "SourceList.c"
}

guint
granite_widgets_source_list_expandable_item_get_n_children (GraniteWidgetsSourceListExpandableItem* self)
{
	guint result;
	GeeCollection* _tmp0_;
	gint _tmp1_;
	gint _tmp2_;
#line 529 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, 0U);
#line 529 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->children_list;
#line 529 "../lib/Widgets/SourceList.vala"
	_tmp1_ = gee_collection_get_size (_tmp0_);
#line 529 "../lib/Widgets/SourceList.vala"
	_tmp2_ = _tmp1_;
#line 529 "../lib/Widgets/SourceList.vala"
	result = (guint) _tmp2_;
#line 529 "../lib/Widgets/SourceList.vala"
	return result;
#line 3238 "SourceList.c"
}

GeeCollection*
granite_widgets_source_list_expandable_item_get_children (GraniteWidgetsSourceListExpandableItem* self)
{
	GeeCollection* result;
	GeeArrayList* children_list_copy = NULL;
	GeeArrayList* _tmp0_;
	GeeCollection* _tmp1_;
#line 542 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 545 "../lib/Widgets/SourceList.vala"
	_tmp0_ = gee_array_list_new (GRANITE_WIDGETS_SOURCE_LIST_TYPE_ITEM, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
#line 545 "../lib/Widgets/SourceList.vala"
	children_list_copy = _tmp0_;
#line 546 "../lib/Widgets/SourceList.vala"
	_tmp1_ = self->priv->children_list;
#line 546 "../lib/Widgets/SourceList.vala"
	gee_array_list_add_all (children_list_copy, _tmp1_);
#line 547 "../lib/Widgets/SourceList.vala"
	result = (GeeCollection*) children_list_copy;
#line 547 "../lib/Widgets/SourceList.vala"
	return result;
#line 3262 "SourceList.c"
}

/**
         * Creates a new {@link Granite.Widgets.SourceList.ExpandableItem}
         *
         * @param name Title of the item.
         * @return (transfer full) A new {@link Granite.Widgets.SourceList.ExpandableItem}.
         * @since 0.2
         */
GraniteWidgetsSourceListExpandableItem*
granite_widgets_source_list_expandable_item_construct (GType object_type,
                                                       const gchar* name)
{
	GraniteWidgetsSourceListExpandableItem * self = NULL;
#line 560 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 561 "../lib/Widgets/SourceList.vala"
	self = (GraniteWidgetsSourceListExpandableItem*) granite_widgets_source_list_item_construct (object_type, name);
#line 560 "../lib/Widgets/SourceList.vala"
	return self;
#line 3283 "SourceList.c"
}

GraniteWidgetsSourceListExpandableItem*
granite_widgets_source_list_expandable_item_new (const gchar* name)
{
#line 560 "../lib/Widgets/SourceList.vala"
	return granite_widgets_source_list_expandable_item_construct (GRANITE_WIDGETS_SOURCE_LIST_TYPE_EXPANDABLE_ITEM, name);
#line 3291 "SourceList.c"
}

/**
         * Checks whether the item contains the specified child.
         *
         * This method only considers the item's immediate children.
         *
         * @param item Item to search.
         * @return Whether the item was found or not.
         * @since 0.2
         */
gboolean
granite_widgets_source_list_expandable_item_contains (GraniteWidgetsSourceListExpandableItem* self,
                                                      GraniteWidgetsSourceListItem* item)
{
	GeeCollection* _tmp0_;
	gboolean result;
#line 577 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 577 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (item != NULL, FALSE);
#line 578 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->children_list;
#line 578 "../lib/Widgets/SourceList.vala"
	result = gee_collection_contains (_tmp0_, item);
#line 578 "../lib/Widgets/SourceList.vala"
	return result;
#line 3319 "SourceList.c"
}

/**
         * Adds an item.
         *
         * {@link Granite.Widgets.SourceList.ExpandableItem.child_added} is fired after the item is added.
         *
         * While adding a child item, //the item it's being added to will set itself as the parent//.
         * Please note that items are required to have their //parent// property set to //null// before
         * being added, so make sure the item is removed from its previous parent before attempting
         * to add it to another item. For instance:
         * {{{
         * if (item.parent != null)
         *     item.parent.remove (item); // this will set item's parent to null
         * new_parent.add (item);
         * }}}
         *
         * @param item The item to add. Its parent __must__ be //null//.
         * @see Granite.Widgets.SourceList.ExpandableItem.child_added
         * @see Granite.Widgets.SourceList.ExpandableItem.remove
         * @since 0.2
         */
void
granite_widgets_source_list_expandable_item_add (GraniteWidgetsSourceListExpandableItem* self,
                                                 GraniteWidgetsSourceListItem* item)
{
	GraniteWidgetsSourceListExpandableItem* _tmp0_;
	GraniteWidgetsSourceListExpandableItem* _tmp1_;
	GeeCollection* _tmp2_;
#line 601 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 601 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (item != NULL);
#line 601 "../lib/Widgets/SourceList.vala"
	_tmp0_ = granite_widgets_source_list_item_get_parent (item);
#line 601 "../lib/Widgets/SourceList.vala"
	_tmp1_ = _tmp0_;
#line 601 "../lib/Widgets/SourceList.vala"
	_vala_return_if_fail (_tmp1_ == NULL, "item.parent == null");
#line 602 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_item_set_parent (item, self);
#line 603 "../lib/Widgets/SourceList.vala"
	_tmp2_ = self->priv->children_list;
#line 603 "../lib/Widgets/SourceList.vala"
	gee_collection_add (_tmp2_, item);
#line 604 "../lib/Widgets/SourceList.vala"
	g_signal_emit (self, granite_widgets_source_list_expandable_item_signals[GRANITE_WIDGETS_SOURCE_LIST_EXPANDABLE_ITEM_CHILD_ADDED_SIGNAL], 0, item);
#line 3367 "SourceList.c"
}

/**
         * Removes an item.
         *
         * The {@link Granite.Widgets.SourceList.ExpandableItem.child_removed} signal is fired
         * //after removing the item//. Finally (i.e. after all the handlers have been invoked),
         * the item's {@link Granite.Widgets.SourceList.Item.parent} property is set to //null//.
         * This has the advantage of letting signal handlers know the parent from which //item//
         * is being removed.
         *
         * @param item The item to remove. This will fail if item has a different parent.
         * @see Granite.Widgets.SourceList.ExpandableItem.child_removed
         * @see Granite.Widgets.SourceList.ExpandableItem.clear
         * @since 0.2
         */
void
granite_widgets_source_list_expandable_item_remove (GraniteWidgetsSourceListExpandableItem* self,
                                                    GraniteWidgetsSourceListItem* item)
{
	GraniteWidgetsSourceListExpandableItem* _tmp0_;
	GraniteWidgetsSourceListExpandableItem* _tmp1_;
	GeeCollection* _tmp2_;
#line 621 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 621 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (item != NULL);
#line 621 "../lib/Widgets/SourceList.vala"
	_tmp0_ = granite_widgets_source_list_item_get_parent (item);
#line 621 "../lib/Widgets/SourceList.vala"
	_tmp1_ = _tmp0_;
#line 621 "../lib/Widgets/SourceList.vala"
	_vala_return_if_fail (_tmp1_ == self, "item.parent == this");
#line 622 "../lib/Widgets/SourceList.vala"
	_tmp2_ = self->priv->children_list;
#line 622 "../lib/Widgets/SourceList.vala"
	gee_collection_remove (_tmp2_, item);
#line 623 "../lib/Widgets/SourceList.vala"
	g_signal_emit (self, granite_widgets_source_list_expandable_item_signals[GRANITE_WIDGETS_SOURCE_LIST_EXPANDABLE_ITEM_CHILD_REMOVED_SIGNAL], 0, item);
#line 624 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_item_set_parent (item, NULL);
#line 3409 "SourceList.c"
}

/**
         * Removes all the items contained by the item. It works similarly to
         * {@link Granite.Widgets.SourceList.ExpandableItem.remove}.
         *
         * @see Granite.Widgets.SourceList.ExpandableItem.remove
         * @see Granite.Widgets.SourceList.ExpandableItem.child_removed
         * @since 0.2
         */
void
granite_widgets_source_list_expandable_item_clear (GraniteWidgetsSourceListExpandableItem* self)
{
#line 635 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 3425 "SourceList.c"
	{
		GeeIterator* _item_it = NULL;
		GeeCollection* _tmp0_;
		GeeCollection* _tmp1_;
		GeeCollection* _tmp2_;
		GeeIterator* _tmp3_;
		GeeIterator* _tmp4_;
#line 636 "../lib/Widgets/SourceList.vala"
		_tmp0_ = granite_widgets_source_list_expandable_item_get_children (self);
#line 636 "../lib/Widgets/SourceList.vala"
		_tmp1_ = _tmp0_;
#line 636 "../lib/Widgets/SourceList.vala"
		_tmp2_ = _tmp1_;
#line 636 "../lib/Widgets/SourceList.vala"
		_tmp3_ = gee_iterable_iterator ((GeeIterable*) _tmp2_);
#line 636 "../lib/Widgets/SourceList.vala"
		_tmp4_ = _tmp3_;
#line 636 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (_tmp2_);
#line 636 "../lib/Widgets/SourceList.vala"
		_item_it = _tmp4_;
#line 636 "../lib/Widgets/SourceList.vala"
		while (TRUE) {
#line 3449 "SourceList.c"
			GeeIterator* _tmp5_;
			GraniteWidgetsSourceListItem* item = NULL;
			GeeIterator* _tmp6_;
			gpointer _tmp7_;
			GraniteWidgetsSourceListItem* _tmp8_;
#line 636 "../lib/Widgets/SourceList.vala"
			_tmp5_ = _item_it;
#line 636 "../lib/Widgets/SourceList.vala"
			if (!gee_iterator_next (_tmp5_)) {
#line 636 "../lib/Widgets/SourceList.vala"
				break;
#line 3461 "SourceList.c"
			}
#line 636 "../lib/Widgets/SourceList.vala"
			_tmp6_ = _item_it;
#line 636 "../lib/Widgets/SourceList.vala"
			_tmp7_ = gee_iterator_get (_tmp6_);
#line 636 "../lib/Widgets/SourceList.vala"
			item = (GraniteWidgetsSourceListItem*) _tmp7_;
#line 637 "../lib/Widgets/SourceList.vala"
			_tmp8_ = item;
#line 637 "../lib/Widgets/SourceList.vala"
			granite_widgets_source_list_expandable_item_remove (self, _tmp8_);
#line 636 "../lib/Widgets/SourceList.vala"
			_g_object_unref0 (item);
#line 3475 "SourceList.c"
		}
#line 636 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (_item_it);
#line 3479 "SourceList.c"
	}
}

/**
         * Expands the item and/or its children.
         *
         * @param inclusive Whether to also expand this item (true), or only its children (false).
         * @param recursive Whether to recursively expand all the children (true), or only
         * immediate children (false).
         * @see Granite.Widgets.SourceList.ExpandableItem.expanded
         * @since 0.2
         */
void
granite_widgets_source_list_expandable_item_expand_all (GraniteWidgetsSourceListExpandableItem* self,
                                                        gboolean inclusive,
                                                        gboolean recursive)
{
#line 649 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 650 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_expandable_item_set_expansion (self, inclusive, recursive, TRUE);
#line 3501 "SourceList.c"
}

/**
         * Collapses the item and/or its children.
         *
         * @param inclusive Whether to also collapse this item (true), or only its children (false).
         * @param recursive Whether to recursively collapse all the children (true), or only
         * immediate children (false).
         * @see Granite.Widgets.SourceList.ExpandableItem.expanded
         * @since 0.2
         */
void
granite_widgets_source_list_expandable_item_collapse_all (GraniteWidgetsSourceListExpandableItem* self,
                                                          gboolean inclusive,
                                                          gboolean recursive)
{
#line 662 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 663 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_expandable_item_set_expansion (self, inclusive, recursive, FALSE);
#line 3522 "SourceList.c"
}

static void
granite_widgets_source_list_expandable_item_set_expansion (GraniteWidgetsSourceListExpandableItem* item,
                                                           gboolean inclusive,
                                                           gboolean recursive,
                                                           gboolean expanded)
{
#line 666 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (item != NULL);
#line 667 "../lib/Widgets/SourceList.vala"
	if (inclusive) {
#line 668 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_expandable_item_set_expanded (item, expanded);
#line 3537 "SourceList.c"
	}
	{
		GeeIterator* _child_item_it = NULL;
		GeeCollection* _tmp0_;
		GeeCollection* _tmp1_;
		GeeCollection* _tmp2_;
		GeeIterator* _tmp3_;
		GeeIterator* _tmp4_;
#line 670 "../lib/Widgets/SourceList.vala"
		_tmp0_ = granite_widgets_source_list_expandable_item_get_children (item);
#line 670 "../lib/Widgets/SourceList.vala"
		_tmp1_ = _tmp0_;
#line 670 "../lib/Widgets/SourceList.vala"
		_tmp2_ = _tmp1_;
#line 670 "../lib/Widgets/SourceList.vala"
		_tmp3_ = gee_iterable_iterator ((GeeIterable*) _tmp2_);
#line 670 "../lib/Widgets/SourceList.vala"
		_tmp4_ = _tmp3_;
#line 670 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (_tmp2_);
#line 670 "../lib/Widgets/SourceList.vala"
		_child_item_it = _tmp4_;
#line 670 "../lib/Widgets/SourceList.vala"
		while (TRUE) {
#line 3562 "SourceList.c"
			GeeIterator* _tmp5_;
			GraniteWidgetsSourceListItem* child_item = NULL;
			GeeIterator* _tmp6_;
			gpointer _tmp7_;
			GraniteWidgetsSourceListExpandableItem* child_expandable_item = NULL;
			GraniteWidgetsSourceListItem* _tmp8_;
			GraniteWidgetsSourceListExpandableItem* _tmp9_;
			GraniteWidgetsSourceListExpandableItem* _tmp10_;
#line 670 "../lib/Widgets/SourceList.vala"
			_tmp5_ = _child_item_it;
#line 670 "../lib/Widgets/SourceList.vala"
			if (!gee_iterator_next (_tmp5_)) {
#line 670 "../lib/Widgets/SourceList.vala"
				break;
#line 3577 "SourceList.c"
			}
#line 670 "../lib/Widgets/SourceList.vala"
			_tmp6_ = _child_item_it;
#line 670 "../lib/Widgets/SourceList.vala"
			_tmp7_ = gee_iterator_get (_tmp6_);
#line 670 "../lib/Widgets/SourceList.vala"
			child_item = (GraniteWidgetsSourceListItem*) _tmp7_;
#line 671 "../lib/Widgets/SourceList.vala"
			_tmp8_ = child_item;
#line 671 "../lib/Widgets/SourceList.vala"
			_tmp9_ = _g_object_ref0 (GRANITE_WIDGETS_SOURCE_LIST_IS_EXPANDABLE_ITEM (_tmp8_) ? ((GraniteWidgetsSourceListExpandableItem*) _tmp8_) : NULL);
#line 671 "../lib/Widgets/SourceList.vala"
			child_expandable_item = _tmp9_;
#line 672 "../lib/Widgets/SourceList.vala"
			_tmp10_ = child_expandable_item;
#line 672 "../lib/Widgets/SourceList.vala"
			if (_tmp10_ != NULL) {
#line 673 "../lib/Widgets/SourceList.vala"
				if (recursive) {
#line 3597 "SourceList.c"
					GraniteWidgetsSourceListExpandableItem* _tmp11_;
#line 674 "../lib/Widgets/SourceList.vala"
					_tmp11_ = child_expandable_item;
#line 674 "../lib/Widgets/SourceList.vala"
					granite_widgets_source_list_expandable_item_set_expansion (_tmp11_, TRUE, TRUE, expanded);
#line 3603 "SourceList.c"
				} else {
					GraniteWidgetsSourceListExpandableItem* _tmp12_;
#line 676 "../lib/Widgets/SourceList.vala"
					_tmp12_ = child_expandable_item;
#line 676 "../lib/Widgets/SourceList.vala"
					granite_widgets_source_list_expandable_item_set_expanded (_tmp12_, expanded);
#line 3610 "SourceList.c"
				}
			}
#line 670 "../lib/Widgets/SourceList.vala"
			_g_object_unref0 (child_expandable_item);
#line 670 "../lib/Widgets/SourceList.vala"
			_g_object_unref0 (child_item);
#line 3617 "SourceList.c"
		}
#line 670 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (_child_item_it);
#line 3621 "SourceList.c"
	}
}

/**
         * Recursively expands the item along with its parent(s).
         *
         * @see Granite.Widgets.SourceList.ExpandableItem.expanded
         * @since 0.2
         */
void
granite_widgets_source_list_expandable_item_expand_with_parents (GraniteWidgetsSourceListExpandableItem* self)
{
	GraniteWidgetsSourceListExpandableItem* _tmp0_;
	GraniteWidgetsSourceListExpandableItem* _tmp1_;
#line 687 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 692 "../lib/Widgets/SourceList.vala"
	_tmp0_ = granite_widgets_source_list_item_get_parent ((GraniteWidgetsSourceListItem*) self);
#line 692 "../lib/Widgets/SourceList.vala"
	_tmp1_ = _tmp0_;
#line 692 "../lib/Widgets/SourceList.vala"
	if (_tmp1_ != NULL) {
#line 3644 "SourceList.c"
		GraniteWidgetsSourceListExpandableItem* _tmp2_;
		GraniteWidgetsSourceListExpandableItem* _tmp3_;
#line 693 "../lib/Widgets/SourceList.vala"
		_tmp2_ = granite_widgets_source_list_item_get_parent ((GraniteWidgetsSourceListItem*) self);
#line 693 "../lib/Widgets/SourceList.vala"
		_tmp3_ = _tmp2_;
#line 693 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_expandable_item_expand_with_parents (_tmp3_);
#line 3653 "SourceList.c"
	}
#line 694 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_expandable_item_set_expanded (self, TRUE);
#line 3657 "SourceList.c"
}

/**
         * Recursively collapses the item along with its parent(s).
         *
         * @see Granite.Widgets.SourceList.ExpandableItem.expanded
         * @since 0.2
         */
void
granite_widgets_source_list_expandable_item_collapse_with_parents (GraniteWidgetsSourceListExpandableItem* self)
{
	GraniteWidgetsSourceListExpandableItem* _tmp0_;
	GraniteWidgetsSourceListExpandableItem* _tmp1_;
#line 703 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 704 "../lib/Widgets/SourceList.vala"
	_tmp0_ = granite_widgets_source_list_item_get_parent ((GraniteWidgetsSourceListItem*) self);
#line 704 "../lib/Widgets/SourceList.vala"
	_tmp1_ = _tmp0_;
#line 704 "../lib/Widgets/SourceList.vala"
	if (_tmp1_ != NULL) {
#line 3679 "SourceList.c"
		GraniteWidgetsSourceListExpandableItem* _tmp2_;
		GraniteWidgetsSourceListExpandableItem* _tmp3_;
#line 705 "../lib/Widgets/SourceList.vala"
		_tmp2_ = granite_widgets_source_list_item_get_parent ((GraniteWidgetsSourceListItem*) self);
#line 705 "../lib/Widgets/SourceList.vala"
		_tmp3_ = _tmp2_;
#line 705 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_expandable_item_collapse_with_parents (_tmp3_);
#line 3688 "SourceList.c"
	}
#line 706 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_expandable_item_set_expanded (self, FALSE);
#line 3692 "SourceList.c"
}

static GObject *
granite_widgets_source_list_expandable_item_constructor (GType type,
                                                         guint n_construct_properties,
                                                         GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GraniteWidgetsSourceListExpandableItem * self;
#line 564 "../lib/Widgets/SourceList.vala"
	parent_class = G_OBJECT_CLASS (granite_widgets_source_list_expandable_item_parent_class);
#line 564 "../lib/Widgets/SourceList.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 564 "../lib/Widgets/SourceList.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GRANITE_WIDGETS_SOURCE_LIST_TYPE_EXPANDABLE_ITEM, GraniteWidgetsSourceListExpandableItem);
#line 565 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_item_set_editable ((GraniteWidgetsSourceListItem*) self, FALSE);
#line 564 "../lib/Widgets/SourceList.vala"
	return obj;
#line 3713 "SourceList.c"
}

static void
granite_widgets_source_list_expandable_item_class_init (GraniteWidgetsSourceListExpandableItemClass * klass,
                                                        gpointer klass_data)
{
#line 453 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_expandable_item_parent_class = g_type_class_peek_parent (klass);
#line 453 "../lib/Widgets/SourceList.vala"
	g_type_class_adjust_private_offset (klass, &GraniteWidgetsSourceListExpandableItem_private_offset);
#line 453 "../lib/Widgets/SourceList.vala"
	((GraniteWidgetsSourceListExpandableItemClass *) klass)->toggled = granite_widgets_source_list_expandable_item_real_toggled;
#line 453 "../lib/Widgets/SourceList.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_granite_widgets_source_list_expandable_item_get_property;
#line 453 "../lib/Widgets/SourceList.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_granite_widgets_source_list_expandable_item_set_property;
#line 453 "../lib/Widgets/SourceList.vala"
	G_OBJECT_CLASS (klass)->constructor = granite_widgets_source_list_expandable_item_constructor;
#line 453 "../lib/Widgets/SourceList.vala"
	G_OBJECT_CLASS (klass)->finalize = granite_widgets_source_list_expandable_item_finalize;
#line 3734 "SourceList.c"
	/**
	         * Whether the item is collapsible or not.
	         *
	         * When set to //false//, the item is //always// expanded and the expander is
	         * not shown. Please note that this will also affect the value returned by the
	         * {@link Granite.Widgets.SourceList.ExpandableItem.expanded} property.
	         *
	         * @see Granite.Widgets.SourceList.ExpandableItem.expanded
	         * @since 0.2
	         */
#line 453 "../lib/Widgets/SourceList.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GRANITE_WIDGETS_SOURCE_LIST_EXPANDABLE_ITEM_COLLAPSIBLE_PROPERTY, granite_widgets_source_list_expandable_item_properties[GRANITE_WIDGETS_SOURCE_LIST_EXPANDABLE_ITEM_COLLAPSIBLE_PROPERTY] = g_param_spec_boolean ("collapsible", "collapsible", "collapsible", TRUE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 453 "../lib/Widgets/SourceList.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GRANITE_WIDGETS_SOURCE_LIST_EXPANDABLE_ITEM_EXPANDED_PROPERTY, granite_widgets_source_list_expandable_item_properties[GRANITE_WIDGETS_SOURCE_LIST_EXPANDABLE_ITEM_EXPANDED_PROPERTY] = g_param_spec_boolean ("expanded", "expanded", "expanded", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 3749 "SourceList.c"
	/**
	         * Number of children contained by the item.
	         *
	         * @since 0.2
	         */
#line 453 "../lib/Widgets/SourceList.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GRANITE_WIDGETS_SOURCE_LIST_EXPANDABLE_ITEM_N_CHILDREN_PROPERTY, granite_widgets_source_list_expandable_item_properties[GRANITE_WIDGETS_SOURCE_LIST_EXPANDABLE_ITEM_N_CHILDREN_PROPERTY] = g_param_spec_uint ("n-children", "n-children", "n-children", 0, G_MAXUINT, 0U, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
#line 3757 "SourceList.c"
	/**
	         * The item's children.
	         *
	         * This returns a newly-created list containing the children.
	         * It's safe to iterate it while removing items with
	         * {@link Granite.Widgets.SourceList.ExpandableItem.remove}
	         *
	         * @since 0.2
	         */
#line 453 "../lib/Widgets/SourceList.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GRANITE_WIDGETS_SOURCE_LIST_EXPANDABLE_ITEM_CHILDREN_PROPERTY, granite_widgets_source_list_expandable_item_properties[GRANITE_WIDGETS_SOURCE_LIST_EXPANDABLE_ITEM_CHILDREN_PROPERTY] = g_param_spec_object ("children", "children", "children", GEE_TYPE_COLLECTION, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
#line 3769 "SourceList.c"
	/**
	         * Emitted when an item is added.
	         *
	         * @param item Item added.
	         * @see Granite.Widgets.SourceList.ExpandableItem.add
	         * @since 0.2
	         */
#line 453 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_expandable_item_signals[GRANITE_WIDGETS_SOURCE_LIST_EXPANDABLE_ITEM_CHILD_ADDED_SIGNAL] = g_signal_new ("child-added", GRANITE_WIDGETS_SOURCE_LIST_TYPE_EXPANDABLE_ITEM, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, GRANITE_WIDGETS_SOURCE_LIST_TYPE_ITEM);
#line 3779 "SourceList.c"
	/**
	         * Emitted when an item is removed.
	         *
	         * @param item Item removed.
	         * @see Granite.Widgets.SourceList.ExpandableItem.remove
	         * @since 0.2
	         */
#line 453 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_expandable_item_signals[GRANITE_WIDGETS_SOURCE_LIST_EXPANDABLE_ITEM_CHILD_REMOVED_SIGNAL] = g_signal_new ("child-removed", GRANITE_WIDGETS_SOURCE_LIST_TYPE_EXPANDABLE_ITEM, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, GRANITE_WIDGETS_SOURCE_LIST_TYPE_ITEM);
#line 3789 "SourceList.c"
	/**
	         * Emitted when the item is expanded or collapsed.
	         *
	         * @since 0.2
	         */
#line 453 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_expandable_item_signals[GRANITE_WIDGETS_SOURCE_LIST_EXPANDABLE_ITEM_TOGGLED_SIGNAL] = g_signal_new ("toggled", GRANITE_WIDGETS_SOURCE_LIST_TYPE_EXPANDABLE_ITEM, G_SIGNAL_RUN_LAST, G_STRUCT_OFFSET (GraniteWidgetsSourceListExpandableItemClass, toggled), NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 3797 "SourceList.c"
}

static void
granite_widgets_source_list_expandable_item_instance_init (GraniteWidgetsSourceListExpandableItem * self,
                                                           gpointer klass)
{
	GeeArrayList* _tmp0_;
#line 453 "../lib/Widgets/SourceList.vala"
	self->priv = granite_widgets_source_list_expandable_item_get_instance_private (self);
#line 490 "../lib/Widgets/SourceList.vala"
	self->priv->_collapsible = TRUE;
#line 512 "../lib/Widgets/SourceList.vala"
	self->priv->_expanded = FALSE;
#line 551 "../lib/Widgets/SourceList.vala"
	_tmp0_ = gee_array_list_new (GRANITE_WIDGETS_SOURCE_LIST_TYPE_ITEM, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
#line 551 "../lib/Widgets/SourceList.vala"
	self->priv->children_list = (GeeCollection*) _tmp0_;
#line 3815 "SourceList.c"
}

static void
granite_widgets_source_list_expandable_item_finalize (GObject * obj)
{
	GraniteWidgetsSourceListExpandableItem * self;
#line 453 "../lib/Widgets/SourceList.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GRANITE_WIDGETS_SOURCE_LIST_TYPE_EXPANDABLE_ITEM, GraniteWidgetsSourceListExpandableItem);
#line 551 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (self->priv->children_list);
#line 453 "../lib/Widgets/SourceList.vala"
	G_OBJECT_CLASS (granite_widgets_source_list_expandable_item_parent_class)->finalize (obj);
#line 3828 "SourceList.c"
}

/**
     * An item that can contain more items.
     *
     * It supports all the properties inherited from {@link Granite.Widgets.SourceList.Item},
     * and behaves like a normal item, except when it is located at the root level; in that case,
     * the following properties are ignored by the widget:
     *
     * * {@link Granite.Widgets.SourceList.Item.selectable}
     * * {@link Granite.Widgets.SourceList.Item.editable}
     * * {@link Granite.Widgets.SourceList.Item.icon}
     * * {@link Granite.Widgets.SourceList.Item.activatable}
     * * {@link Granite.Widgets.SourceList.Item.badge}
     *
     * Root-level expandable items (i.e. Main Categories) are ''not'' displayed when they contain
     * zero visible children.
     *
     * @since 0.2
     */
static GType
granite_widgets_source_list_expandable_item_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (GraniteWidgetsSourceListExpandableItemClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) granite_widgets_source_list_expandable_item_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GraniteWidgetsSourceListExpandableItem), 0, (GInstanceInitFunc) granite_widgets_source_list_expandable_item_instance_init, NULL };
	GType granite_widgets_source_list_expandable_item_type_id;
	granite_widgets_source_list_expandable_item_type_id = g_type_register_static (GRANITE_WIDGETS_SOURCE_LIST_TYPE_ITEM, "GraniteWidgetsSourceListExpandableItem", &g_define_type_info, 0);
	GraniteWidgetsSourceListExpandableItem_private_offset = g_type_add_instance_private (granite_widgets_source_list_expandable_item_type_id, sizeof (GraniteWidgetsSourceListExpandableItemPrivate));
	return granite_widgets_source_list_expandable_item_type_id;
}

GType
granite_widgets_source_list_expandable_item_get_type (void)
{
	static volatile gsize granite_widgets_source_list_expandable_item_type_id__once = 0;
	if (g_once_init_enter (&granite_widgets_source_list_expandable_item_type_id__once)) {
		GType granite_widgets_source_list_expandable_item_type_id;
		granite_widgets_source_list_expandable_item_type_id = granite_widgets_source_list_expandable_item_get_type_once ();
		g_once_init_leave (&granite_widgets_source_list_expandable_item_type_id__once, granite_widgets_source_list_expandable_item_type_id);
	}
	return granite_widgets_source_list_expandable_item_type_id__once;
}

static void
_vala_granite_widgets_source_list_expandable_item_get_property (GObject * object,
                                                                guint property_id,
                                                                GValue * value,
                                                                GParamSpec * pspec)
{
	GraniteWidgetsSourceListExpandableItem * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GRANITE_WIDGETS_SOURCE_LIST_TYPE_EXPANDABLE_ITEM, GraniteWidgetsSourceListExpandableItem);
#line 453 "../lib/Widgets/SourceList.vala"
	switch (property_id) {
#line 453 "../lib/Widgets/SourceList.vala"
		case GRANITE_WIDGETS_SOURCE_LIST_EXPANDABLE_ITEM_COLLAPSIBLE_PROPERTY:
#line 453 "../lib/Widgets/SourceList.vala"
		g_value_set_boolean (value, granite_widgets_source_list_expandable_item_get_collapsible (self));
#line 453 "../lib/Widgets/SourceList.vala"
		break;
#line 453 "../lib/Widgets/SourceList.vala"
		case GRANITE_WIDGETS_SOURCE_LIST_EXPANDABLE_ITEM_EXPANDED_PROPERTY:
#line 453 "../lib/Widgets/SourceList.vala"
		g_value_set_boolean (value, granite_widgets_source_list_expandable_item_get_expanded (self));
#line 453 "../lib/Widgets/SourceList.vala"
		break;
#line 453 "../lib/Widgets/SourceList.vala"
		case GRANITE_WIDGETS_SOURCE_LIST_EXPANDABLE_ITEM_N_CHILDREN_PROPERTY:
#line 453 "../lib/Widgets/SourceList.vala"
		g_value_set_uint (value, granite_widgets_source_list_expandable_item_get_n_children (self));
#line 453 "../lib/Widgets/SourceList.vala"
		break;
#line 453 "../lib/Widgets/SourceList.vala"
		case GRANITE_WIDGETS_SOURCE_LIST_EXPANDABLE_ITEM_CHILDREN_PROPERTY:
#line 453 "../lib/Widgets/SourceList.vala"
		g_value_take_object (value, granite_widgets_source_list_expandable_item_get_children (self));
#line 453 "../lib/Widgets/SourceList.vala"
		break;
#line 3905 "SourceList.c"
		default:
#line 453 "../lib/Widgets/SourceList.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 453 "../lib/Widgets/SourceList.vala"
		break;
#line 3911 "SourceList.c"
	}
}

static void
_vala_granite_widgets_source_list_expandable_item_set_property (GObject * object,
                                                                guint property_id,
                                                                const GValue * value,
                                                                GParamSpec * pspec)
{
	GraniteWidgetsSourceListExpandableItem * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GRANITE_WIDGETS_SOURCE_LIST_TYPE_EXPANDABLE_ITEM, GraniteWidgetsSourceListExpandableItem);
#line 453 "../lib/Widgets/SourceList.vala"
	switch (property_id) {
#line 453 "../lib/Widgets/SourceList.vala"
		case GRANITE_WIDGETS_SOURCE_LIST_EXPANDABLE_ITEM_COLLAPSIBLE_PROPERTY:
#line 453 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_expandable_item_set_collapsible (self, g_value_get_boolean (value));
#line 453 "../lib/Widgets/SourceList.vala"
		break;
#line 453 "../lib/Widgets/SourceList.vala"
		case GRANITE_WIDGETS_SOURCE_LIST_EXPANDABLE_ITEM_EXPANDED_PROPERTY:
#line 453 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_expandable_item_set_expanded (self, g_value_get_boolean (value));
#line 453 "../lib/Widgets/SourceList.vala"
		break;
#line 3937 "SourceList.c"
		default:
#line 453 "../lib/Widgets/SourceList.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 453 "../lib/Widgets/SourceList.vala"
		break;
#line 3943 "SourceList.c"
	}
}

static inline gpointer
granite_widgets_source_list_data_model_get_instance_private (GraniteWidgetsSourceListDataModel* self)
{
	return G_STRUCT_MEMBER_P (self, GraniteWidgetsSourceListDataModel_private_offset);
}

static GType
granite_widgets_source_list_data_model_column_type (GraniteWidgetsSourceListDataModelColumn self)
{
	GType result;
#line 802 "../lib/Widgets/SourceList.vala"
	switch (self) {
#line 802 "../lib/Widgets/SourceList.vala"
		case GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_COLUMN_ITEM:
#line 3961 "SourceList.c"
		{
#line 804 "../lib/Widgets/SourceList.vala"
			result = GRANITE_WIDGETS_SOURCE_LIST_TYPE_ITEM;
#line 804 "../lib/Widgets/SourceList.vala"
			return result;
#line 3967 "SourceList.c"
		}
		default:
		{
#line 807 "../lib/Widgets/SourceList.vala"
			g_assert_not_reached ();
#line 3973 "SourceList.c"
		}
	}
}

static GType
granite_widgets_source_list_data_model_column_get_type_once (void)
{
	static const GEnumValue values[] = {{GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_COLUMN_ITEM, "GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_COLUMN_ITEM", "item"}, {GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_COLUMN_N_COLUMNS, "GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_COLUMN_N_COLUMNS", "n-columns"}, {0, NULL, NULL}};
	GType granite_widgets_source_list_data_model_column_type_id;
	granite_widgets_source_list_data_model_column_type_id = g_enum_register_static ("GraniteWidgetsSourceListDataModelColumn", values);
	return granite_widgets_source_list_data_model_column_type_id;
}

static GType
granite_widgets_source_list_data_model_column_get_type (void)
{
	static volatile gsize granite_widgets_source_list_data_model_column_type_id__once = 0;
	if (g_once_init_enter (&granite_widgets_source_list_data_model_column_type_id__once)) {
		GType granite_widgets_source_list_data_model_column_type_id;
		granite_widgets_source_list_data_model_column_type_id = granite_widgets_source_list_data_model_column_get_type_once ();
		g_once_init_leave (&granite_widgets_source_list_data_model_column_type_id__once, granite_widgets_source_list_data_model_column_type_id);
	}
	return granite_widgets_source_list_data_model_column_type_id__once;
}

static GraniteWidgetsSourceListExpandableItem*
granite_widgets_source_list_data_model_get_root (GraniteWidgetsSourceListDataModel* self)
{
	GraniteWidgetsSourceListExpandableItem* result;
	GraniteWidgetsSourceListExpandableItem* _tmp0_;
#line 828 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 828 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->_root;
#line 828 "../lib/Widgets/SourceList.vala"
	result = _tmp0_;
#line 828 "../lib/Widgets/SourceList.vala"
	return result;
#line 4012 "SourceList.c"
}

static void
granite_widgets_source_list_data_model_set_root (GraniteWidgetsSourceListDataModel* self,
                                                 GraniteWidgetsSourceListExpandableItem* value)
{
	GraniteWidgetsSourceListExpandableItem* _tmp0_;
	GraniteWidgetsSourceListExpandableItem* _tmp12_;
	GraniteWidgetsSourceListExpandableItem* _tmp13_;
#line 829 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 830 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->_root;
#line 830 "../lib/Widgets/SourceList.vala"
	if (_tmp0_ != NULL) {
#line 4028 "SourceList.c"
		GraniteWidgetsSourceListExpandableItem* _tmp1_;
#line 831 "../lib/Widgets/SourceList.vala"
		_tmp1_ = self->priv->_root;
#line 831 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_data_model_remove_children_monitor (self, _tmp1_);
#line 4034 "SourceList.c"
		{
			GeeIterator* _item_it = NULL;
			GraniteWidgetsSourceListExpandableItem* _tmp2_;
			GeeCollection* _tmp3_;
			GeeCollection* _tmp4_;
			GeeCollection* _tmp5_;
			GeeIterator* _tmp6_;
			GeeIterator* _tmp7_;
#line 832 "../lib/Widgets/SourceList.vala"
			_tmp2_ = self->priv->_root;
#line 832 "../lib/Widgets/SourceList.vala"
			_tmp3_ = granite_widgets_source_list_expandable_item_get_children (_tmp2_);
#line 832 "../lib/Widgets/SourceList.vala"
			_tmp4_ = _tmp3_;
#line 832 "../lib/Widgets/SourceList.vala"
			_tmp5_ = _tmp4_;
#line 832 "../lib/Widgets/SourceList.vala"
			_tmp6_ = gee_iterable_iterator ((GeeIterable*) _tmp5_);
#line 832 "../lib/Widgets/SourceList.vala"
			_tmp7_ = _tmp6_;
#line 832 "../lib/Widgets/SourceList.vala"
			_g_object_unref0 (_tmp5_);
#line 832 "../lib/Widgets/SourceList.vala"
			_item_it = _tmp7_;
#line 832 "../lib/Widgets/SourceList.vala"
			while (TRUE) {
#line 4061 "SourceList.c"
				GeeIterator* _tmp8_;
				GraniteWidgetsSourceListItem* item = NULL;
				GeeIterator* _tmp9_;
				gpointer _tmp10_;
				GraniteWidgetsSourceListItem* _tmp11_;
#line 832 "../lib/Widgets/SourceList.vala"
				_tmp8_ = _item_it;
#line 832 "../lib/Widgets/SourceList.vala"
				if (!gee_iterator_next (_tmp8_)) {
#line 832 "../lib/Widgets/SourceList.vala"
					break;
#line 4073 "SourceList.c"
				}
#line 832 "../lib/Widgets/SourceList.vala"
				_tmp9_ = _item_it;
#line 832 "../lib/Widgets/SourceList.vala"
				_tmp10_ = gee_iterator_get (_tmp9_);
#line 832 "../lib/Widgets/SourceList.vala"
				item = (GraniteWidgetsSourceListItem*) _tmp10_;
#line 833 "../lib/Widgets/SourceList.vala"
				_tmp11_ = item;
#line 833 "../lib/Widgets/SourceList.vala"
				granite_widgets_source_list_data_model_remove_item (self, _tmp11_);
#line 832 "../lib/Widgets/SourceList.vala"
				_g_object_unref0 (item);
#line 4087 "SourceList.c"
			}
#line 832 "../lib/Widgets/SourceList.vala"
			_g_object_unref0 (_item_it);
#line 4091 "SourceList.c"
		}
	}
#line 836 "../lib/Widgets/SourceList.vala"
	_tmp12_ = _g_object_ref0 (value);
#line 836 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (self->priv->_root);
#line 836 "../lib/Widgets/SourceList.vala"
	self->priv->_root = _tmp12_;
#line 838 "../lib/Widgets/SourceList.vala"
	_tmp13_ = self->priv->_root;
#line 838 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_data_model_add_children_monitor (self, _tmp13_);
#line 4104 "SourceList.c"
	{
		GeeIterator* _item_it = NULL;
		GraniteWidgetsSourceListExpandableItem* _tmp14_;
		GeeCollection* _tmp15_;
		GeeCollection* _tmp16_;
		GeeCollection* _tmp17_;
		GeeIterator* _tmp18_;
		GeeIterator* _tmp19_;
#line 839 "../lib/Widgets/SourceList.vala"
		_tmp14_ = self->priv->_root;
#line 839 "../lib/Widgets/SourceList.vala"
		_tmp15_ = granite_widgets_source_list_expandable_item_get_children (_tmp14_);
#line 839 "../lib/Widgets/SourceList.vala"
		_tmp16_ = _tmp15_;
#line 839 "../lib/Widgets/SourceList.vala"
		_tmp17_ = _tmp16_;
#line 839 "../lib/Widgets/SourceList.vala"
		_tmp18_ = gee_iterable_iterator ((GeeIterable*) _tmp17_);
#line 839 "../lib/Widgets/SourceList.vala"
		_tmp19_ = _tmp18_;
#line 839 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (_tmp17_);
#line 839 "../lib/Widgets/SourceList.vala"
		_item_it = _tmp19_;
#line 839 "../lib/Widgets/SourceList.vala"
		while (TRUE) {
#line 4131 "SourceList.c"
			GeeIterator* _tmp20_;
			GraniteWidgetsSourceListItem* item = NULL;
			GeeIterator* _tmp21_;
			gpointer _tmp22_;
			GraniteWidgetsSourceListItem* _tmp23_;
#line 839 "../lib/Widgets/SourceList.vala"
			_tmp20_ = _item_it;
#line 839 "../lib/Widgets/SourceList.vala"
			if (!gee_iterator_next (_tmp20_)) {
#line 839 "../lib/Widgets/SourceList.vala"
				break;
#line 4143 "SourceList.c"
			}
#line 839 "../lib/Widgets/SourceList.vala"
			_tmp21_ = _item_it;
#line 839 "../lib/Widgets/SourceList.vala"
			_tmp22_ = gee_iterator_get (_tmp21_);
#line 839 "../lib/Widgets/SourceList.vala"
			item = (GraniteWidgetsSourceListItem*) _tmp22_;
#line 840 "../lib/Widgets/SourceList.vala"
			_tmp23_ = item;
#line 840 "../lib/Widgets/SourceList.vala"
			granite_widgets_source_list_data_model_add_item (self, _tmp23_);
#line 839 "../lib/Widgets/SourceList.vala"
			_g_object_unref0 (item);
#line 4157 "SourceList.c"
		}
#line 839 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (_item_it);
#line 4161 "SourceList.c"
	}
#line 829 "../lib/Widgets/SourceList.vala"
	g_object_notify_by_pspec ((GObject *) self, granite_widgets_source_list_data_model_properties[GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_ROOT_PROPERTY]);
#line 4165 "SourceList.c"
}

static GraniteWidgetsSourceListDataModel*
granite_widgets_source_list_data_model_construct (GType object_type)
{
	GraniteWidgetsSourceListDataModel * self = NULL;
#line 854 "../lib/Widgets/SourceList.vala"
	self = (GraniteWidgetsSourceListDataModel*) g_object_new (object_type, NULL);
#line 854 "../lib/Widgets/SourceList.vala"
	return self;
#line 4176 "SourceList.c"
}

static GraniteWidgetsSourceListDataModel*
granite_widgets_source_list_data_model_new (void)
{
#line 854 "../lib/Widgets/SourceList.vala"
	return granite_widgets_source_list_data_model_construct (GRANITE_WIDGETS_SOURCE_LIST_TYPE_DATA_MODEL);
#line 4184 "SourceList.c"
}

static gboolean
granite_widgets_source_list_data_model_has_item (GraniteWidgetsSourceListDataModel* self,
                                                 GraniteWidgetsSourceListItem* item)
{
	GeeHashMap* _tmp0_;
	gboolean result;
#line 869 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 869 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (item != NULL, FALSE);
#line 870 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->items;
#line 870 "../lib/Widgets/SourceList.vala"
	result = gee_abstract_map_has_key ((GeeAbstractMap*) _tmp0_, item);
#line 870 "../lib/Widgets/SourceList.vala"
	return result;
#line 4203 "SourceList.c"
}

static void
granite_widgets_source_list_data_model_update_item (GraniteWidgetsSourceListDataModel* self,
                                                    GraniteWidgetsSourceListItem* item)
{
	GraniteWidgetsSourceListExpandableItem* _tmp0_;
	GraniteWidgetsSourceListExpandableItem* _tmp1_;
	GraniteWidgetsSourceListDataModelNodeWrapper* node_reference = NULL;
	GeeHashMap* _tmp2_;
	gpointer _tmp3_;
	GraniteWidgetsSourceListDataModelNodeWrapper* _tmp4_;
#line 873 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 873 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (item != NULL);
#line 873 "../lib/Widgets/SourceList.vala"
	_vala_return_if_fail (granite_widgets_source_list_data_model_has_item (self, item), "has_item (item)");
#line 874 "../lib/Widgets/SourceList.vala"
	_tmp0_ = granite_widgets_source_list_data_model_get_root (self);
#line 874 "../lib/Widgets/SourceList.vala"
	_tmp1_ = _tmp0_;
#line 874 "../lib/Widgets/SourceList.vala"
	_vala_assert (_tmp1_ != NULL, "root != null");
#line 879 "../lib/Widgets/SourceList.vala"
	_tmp2_ = self->priv->items;
#line 879 "../lib/Widgets/SourceList.vala"
	_tmp3_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp2_, item);
#line 879 "../lib/Widgets/SourceList.vala"
	node_reference = (GraniteWidgetsSourceListDataModelNodeWrapper*) _tmp3_;
#line 880 "../lib/Widgets/SourceList.vala"
	_tmp4_ = node_reference;
#line 880 "../lib/Widgets/SourceList.vala"
	if (_tmp4_ != NULL) {
#line 4238 "SourceList.c"
		GtkTreePath* path = NULL;
		GraniteWidgetsSourceListDataModelNodeWrapper* _tmp5_;
		GtkTreePath* _tmp6_;
		GtkTreePath* _tmp7_;
		GtkTreeIter* iter = NULL;
		GraniteWidgetsSourceListDataModelNodeWrapper* _tmp8_;
		GtkTreeIter* _tmp9_;
		GtkTreeIter* _tmp10_;
		gboolean _tmp11_ = FALSE;
		GtkTreePath* _tmp12_;
#line 881 "../lib/Widgets/SourceList.vala"
		_tmp5_ = node_reference;
#line 881 "../lib/Widgets/SourceList.vala"
		_tmp6_ = granite_widgets_source_list_data_model_node_wrapper_get_path (_tmp5_);
#line 881 "../lib/Widgets/SourceList.vala"
		_tmp7_ = _tmp6_;
#line 881 "../lib/Widgets/SourceList.vala"
		path = _tmp7_;
#line 882 "../lib/Widgets/SourceList.vala"
		_tmp8_ = node_reference;
#line 882 "../lib/Widgets/SourceList.vala"
		_tmp9_ = granite_widgets_source_list_data_model_node_wrapper_get_iter (_tmp8_);
#line 882 "../lib/Widgets/SourceList.vala"
		_tmp10_ = _tmp9_;
#line 882 "../lib/Widgets/SourceList.vala"
		iter = _tmp10_;
#line 883 "../lib/Widgets/SourceList.vala"
		_tmp12_ = path;
#line 883 "../lib/Widgets/SourceList.vala"
		if (_tmp12_ != NULL) {
#line 4269 "SourceList.c"
			GtkTreeIter* _tmp13_;
#line 883 "../lib/Widgets/SourceList.vala"
			_tmp13_ = iter;
#line 883 "../lib/Widgets/SourceList.vala"
			_tmp11_ = _tmp13_ != NULL;
#line 4275 "SourceList.c"
		} else {
#line 883 "../lib/Widgets/SourceList.vala"
			_tmp11_ = FALSE;
#line 4279 "SourceList.c"
		}
#line 883 "../lib/Widgets/SourceList.vala"
		if (_tmp11_) {
#line 4283 "SourceList.c"
			GtkTreeStore* _tmp14_;
			GtkTreePath* _tmp15_;
			GtkTreeIter* _tmp16_;
			GtkTreeIter _tmp17_;
#line 884 "../lib/Widgets/SourceList.vala"
			_tmp14_ = self->priv->child_tree;
#line 884 "../lib/Widgets/SourceList.vala"
			_tmp15_ = path;
#line 884 "../lib/Widgets/SourceList.vala"
			_tmp16_ = iter;
#line 884 "../lib/Widgets/SourceList.vala"
			_tmp17_ = *_tmp16_;
#line 884 "../lib/Widgets/SourceList.vala"
			gtk_tree_model_row_changed ((GtkTreeModel*) _tmp14_, _tmp15_, &_tmp17_);
#line 885 "../lib/Widgets/SourceList.vala"
			g_signal_emit (self, granite_widgets_source_list_data_model_signals[GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_ITEM_UPDATED_SIGNAL], 0, item);
#line 4300 "SourceList.c"
		}
#line 880 "../lib/Widgets/SourceList.vala"
		__vala_GtkTreeIter_free0 (iter);
#line 880 "../lib/Widgets/SourceList.vala"
		__vala_GtkTreePath_free0 (path);
#line 4306 "SourceList.c"
	}
#line 873 "../lib/Widgets/SourceList.vala"
	_granite_widgets_source_list_data_model_node_wrapper_unref0 (node_reference);
#line 4310 "SourceList.c"
}

static GtkTreeIter*
_vala_GtkTreeIter_copy (GtkTreeIter* self)
{
#line 909 "../lib/Widgets/SourceList.vala"
	return g_boxed_copy (gtk_tree_iter_get_type (), self);
#line 4318 "SourceList.c"
}

static gpointer
__vala_GtkTreeIter_copy0 (gpointer self)
{
#line 909 "../lib/Widgets/SourceList.vala"
	return self ? _vala_GtkTreeIter_copy (self) : NULL;
#line 4326 "SourceList.c"
}

static void
granite_widgets_source_list_data_model_add_item (GraniteWidgetsSourceListDataModel* self,
                                                 GraniteWidgetsSourceListItem* item)
{
	GraniteWidgetsSourceListExpandableItem* _tmp0_;
	GraniteWidgetsSourceListExpandableItem* _tmp1_;
	GtkTreeIter* parent_child_iter = NULL;
	GtkTreeIter* child_iter = NULL;
	GraniteWidgetsSourceListExpandableItem* parent = NULL;
	GraniteWidgetsSourceListExpandableItem* _tmp2_;
	GraniteWidgetsSourceListExpandableItem* _tmp3_;
	GraniteWidgetsSourceListExpandableItem* _tmp4_;
	gboolean _tmp5_ = FALSE;
	GraniteWidgetsSourceListExpandableItem* _tmp6_;
	GtkTreeStore* _tmp15_;
	GtkTreeIter* _tmp16_;
	GtkTreeIter _tmp17_ = {0};
	GtkTreeIter _tmp18_;
	GtkTreeIter* _tmp19_;
	GtkTreeStore* _tmp20_;
	GtkTreeIter* _tmp21_;
	GtkTreeIter _tmp22_;
	GeeHashMap* _tmp23_;
	GtkTreeStore* _tmp24_;
	GtkTreeIter* _tmp25_;
	GtkTreeIter _tmp26_;
	GraniteWidgetsSourceListDataModelNodeWrapper* _tmp27_;
	GraniteWidgetsSourceListDataModelNodeWrapper* _tmp28_;
	GraniteWidgetsSourceListExpandableItem* _tmp29_;
	GraniteWidgetsSourceListExpandableItem* expandable = NULL;
	GraniteWidgetsSourceListExpandableItem* _tmp30_;
	GraniteWidgetsSourceListExpandableItem* _tmp31_;
#line 890 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 890 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (item != NULL);
#line 890 "../lib/Widgets/SourceList.vala"
	_vala_return_if_fail (!granite_widgets_source_list_data_model_has_item (self, item), "!has_item (item)");
#line 891 "../lib/Widgets/SourceList.vala"
	_tmp0_ = granite_widgets_source_list_data_model_get_root (self);
#line 891 "../lib/Widgets/SourceList.vala"
	_tmp1_ = _tmp0_;
#line 891 "../lib/Widgets/SourceList.vala"
	_vala_assert (_tmp1_ != NULL, "root != null");
#line 894 "../lib/Widgets/SourceList.vala"
	parent_child_iter = NULL;
#line 895 "../lib/Widgets/SourceList.vala"
	_tmp2_ = granite_widgets_source_list_item_get_parent (item);
#line 895 "../lib/Widgets/SourceList.vala"
	_tmp3_ = _tmp2_;
#line 895 "../lib/Widgets/SourceList.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 895 "../lib/Widgets/SourceList.vala"
	parent = _tmp4_;
#line 897 "../lib/Widgets/SourceList.vala"
	_tmp6_ = parent;
#line 897 "../lib/Widgets/SourceList.vala"
	if (_tmp6_ != NULL) {
#line 4387 "SourceList.c"
		GraniteWidgetsSourceListExpandableItem* _tmp7_;
		GraniteWidgetsSourceListExpandableItem* _tmp8_;
		GraniteWidgetsSourceListExpandableItem* _tmp9_;
#line 897 "../lib/Widgets/SourceList.vala"
		_tmp7_ = parent;
#line 897 "../lib/Widgets/SourceList.vala"
		_tmp8_ = granite_widgets_source_list_data_model_get_root (self);
#line 897 "../lib/Widgets/SourceList.vala"
		_tmp9_ = _tmp8_;
#line 897 "../lib/Widgets/SourceList.vala"
		_tmp5_ = _tmp7_ != _tmp9_;
#line 4399 "SourceList.c"
	} else {
#line 897 "../lib/Widgets/SourceList.vala"
		_tmp5_ = FALSE;
#line 4403 "SourceList.c"
	}
#line 897 "../lib/Widgets/SourceList.vala"
	if (_tmp5_) {
#line 4407 "SourceList.c"
		GraniteWidgetsSourceListExpandableItem* _tmp10_;
		GraniteWidgetsSourceListExpandableItem* _tmp12_;
		GtkTreeIter* _tmp13_;
		GtkTreeIter* _tmp14_;
#line 899 "../lib/Widgets/SourceList.vala"
		_tmp10_ = parent;
#line 899 "../lib/Widgets/SourceList.vala"
		if (!granite_widgets_source_list_data_model_has_item (self, (GraniteWidgetsSourceListItem*) _tmp10_)) {
#line 4416 "SourceList.c"
			GraniteWidgetsSourceListExpandableItem* _tmp11_;
#line 900 "../lib/Widgets/SourceList.vala"
			_tmp11_ = parent;
#line 900 "../lib/Widgets/SourceList.vala"
			granite_widgets_source_list_data_model_add_item (self, (GraniteWidgetsSourceListItem*) _tmp11_);
#line 4422 "SourceList.c"
		}
#line 903 "../lib/Widgets/SourceList.vala"
		_tmp12_ = parent;
#line 903 "../lib/Widgets/SourceList.vala"
		_tmp13_ = granite_widgets_source_list_data_model_get_item_child_iter (self, (GraniteWidgetsSourceListItem*) _tmp12_);
#line 903 "../lib/Widgets/SourceList.vala"
		__vala_GtkTreeIter_free0 (parent_child_iter);
#line 903 "../lib/Widgets/SourceList.vala"
		parent_child_iter = _tmp13_;
#line 906 "../lib/Widgets/SourceList.vala"
		_tmp14_ = parent_child_iter;
#line 906 "../lib/Widgets/SourceList.vala"
		_vala_assert (_tmp14_ != NULL, "parent_child_iter != null");
#line 4436 "SourceList.c"
	}
#line 909 "../lib/Widgets/SourceList.vala"
	_tmp15_ = self->priv->child_tree;
#line 909 "../lib/Widgets/SourceList.vala"
	_tmp16_ = parent_child_iter;
#line 909 "../lib/Widgets/SourceList.vala"
	gtk_tree_store_append (_tmp15_, &_tmp17_, _tmp16_);
#line 909 "../lib/Widgets/SourceList.vala"
	__vala_GtkTreeIter_free0 (child_iter);
#line 909 "../lib/Widgets/SourceList.vala"
	_tmp18_ = _tmp17_;
#line 909 "../lib/Widgets/SourceList.vala"
	_tmp19_ = __vala_GtkTreeIter_copy0 (&_tmp18_);
#line 909 "../lib/Widgets/SourceList.vala"
	child_iter = _tmp19_;
#line 910 "../lib/Widgets/SourceList.vala"
	_tmp20_ = self->priv->child_tree;
#line 910 "../lib/Widgets/SourceList.vala"
	_tmp21_ = child_iter;
#line 910 "../lib/Widgets/SourceList.vala"
	_tmp22_ = *_tmp21_;
#line 910 "../lib/Widgets/SourceList.vala"
	gtk_tree_store_set (_tmp20_, &_tmp22_, GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_COLUMN_ITEM, item, -1, -1);
#line 912 "../lib/Widgets/SourceList.vala"
	_tmp23_ = self->priv->items;
#line 912 "../lib/Widgets/SourceList.vala"
	_tmp24_ = self->priv->child_tree;
#line 912 "../lib/Widgets/SourceList.vala"
	_tmp25_ = child_iter;
#line 912 "../lib/Widgets/SourceList.vala"
	_tmp26_ = *_tmp25_;
#line 912 "../lib/Widgets/SourceList.vala"
	_tmp27_ = granite_widgets_source_list_data_model_node_wrapper_new ((GtkTreeModel*) _tmp24_, &_tmp26_);
#line 912 "../lib/Widgets/SourceList.vala"
	_tmp28_ = _tmp27_;
#line 912 "../lib/Widgets/SourceList.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp23_, item, _tmp28_);
#line 912 "../lib/Widgets/SourceList.vala"
	_granite_widgets_source_list_data_model_node_wrapper_unref0 (_tmp28_);
#line 916 "../lib/Widgets/SourceList.vala"
	g_signal_emit (self, granite_widgets_source_list_data_model_signals[GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_ITEM_UPDATED_SIGNAL], 0, item);
#line 918 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_data_model_add_property_monitor (self, item);
#line 920 "../lib/Widgets/SourceList.vala"
	_tmp29_ = parent;
#line 920 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_data_model_push_parent_update (self, _tmp29_);
#line 923 "../lib/Widgets/SourceList.vala"
	_tmp30_ = _g_object_ref0 (GRANITE_WIDGETS_SOURCE_LIST_IS_EXPANDABLE_ITEM (item) ? ((GraniteWidgetsSourceListExpandableItem*) item) : NULL);
#line 923 "../lib/Widgets/SourceList.vala"
	expandable = _tmp30_;
#line 924 "../lib/Widgets/SourceList.vala"
	_tmp31_ = expandable;
#line 924 "../lib/Widgets/SourceList.vala"
	if (_tmp31_ != NULL) {
#line 4492 "SourceList.c"
		GraniteWidgetsSourceListExpandableItem* _tmp42_;
		{
			GeeIterator* _child_item_it = NULL;
			GraniteWidgetsSourceListExpandableItem* _tmp32_;
			GeeCollection* _tmp33_;
			GeeCollection* _tmp34_;
			GeeCollection* _tmp35_;
			GeeIterator* _tmp36_;
			GeeIterator* _tmp37_;
#line 925 "../lib/Widgets/SourceList.vala"
			_tmp32_ = expandable;
#line 925 "../lib/Widgets/SourceList.vala"
			_tmp33_ = granite_widgets_source_list_expandable_item_get_children (_tmp32_);
#line 925 "../lib/Widgets/SourceList.vala"
			_tmp34_ = _tmp33_;
#line 925 "../lib/Widgets/SourceList.vala"
			_tmp35_ = _tmp34_;
#line 925 "../lib/Widgets/SourceList.vala"
			_tmp36_ = gee_iterable_iterator ((GeeIterable*) _tmp35_);
#line 925 "../lib/Widgets/SourceList.vala"
			_tmp37_ = _tmp36_;
#line 925 "../lib/Widgets/SourceList.vala"
			_g_object_unref0 (_tmp35_);
#line 925 "../lib/Widgets/SourceList.vala"
			_child_item_it = _tmp37_;
#line 925 "../lib/Widgets/SourceList.vala"
			while (TRUE) {
#line 4520 "SourceList.c"
				GeeIterator* _tmp38_;
				GraniteWidgetsSourceListItem* child_item = NULL;
				GeeIterator* _tmp39_;
				gpointer _tmp40_;
				GraniteWidgetsSourceListItem* _tmp41_;
#line 925 "../lib/Widgets/SourceList.vala"
				_tmp38_ = _child_item_it;
#line 925 "../lib/Widgets/SourceList.vala"
				if (!gee_iterator_next (_tmp38_)) {
#line 925 "../lib/Widgets/SourceList.vala"
					break;
#line 4532 "SourceList.c"
				}
#line 925 "../lib/Widgets/SourceList.vala"
				_tmp39_ = _child_item_it;
#line 925 "../lib/Widgets/SourceList.vala"
				_tmp40_ = gee_iterator_get (_tmp39_);
#line 925 "../lib/Widgets/SourceList.vala"
				child_item = (GraniteWidgetsSourceListItem*) _tmp40_;
#line 926 "../lib/Widgets/SourceList.vala"
				_tmp41_ = child_item;
#line 926 "../lib/Widgets/SourceList.vala"
				granite_widgets_source_list_data_model_add_item (self, _tmp41_);
#line 925 "../lib/Widgets/SourceList.vala"
				_g_object_unref0 (child_item);
#line 4546 "SourceList.c"
			}
#line 925 "../lib/Widgets/SourceList.vala"
			_g_object_unref0 (_child_item_it);
#line 4550 "SourceList.c"
		}
#line 929 "../lib/Widgets/SourceList.vala"
		_tmp42_ = expandable;
#line 929 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_data_model_add_children_monitor (self, _tmp42_);
#line 4556 "SourceList.c"
	}
#line 890 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (expandable);
#line 890 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (parent);
#line 890 "../lib/Widgets/SourceList.vala"
	__vala_GtkTreeIter_free0 (child_iter);
#line 890 "../lib/Widgets/SourceList.vala"
	__vala_GtkTreeIter_free0 (parent_child_iter);
#line 4566 "SourceList.c"
}

static void
granite_widgets_source_list_data_model_remove_item (GraniteWidgetsSourceListDataModel* self,
                                                    GraniteWidgetsSourceListItem* item)
{
	GraniteWidgetsSourceListExpandableItem* _tmp0_;
	GraniteWidgetsSourceListExpandableItem* _tmp1_;
	GtkTreeIter* child_iter = NULL;
	GtkTreeIter* _tmp2_;
	GeeHashMap* _tmp3_;
	GtkTreeIter* _tmp4_;
	GraniteWidgetsSourceListExpandableItem* _tmp6_;
	GraniteWidgetsSourceListExpandableItem* _tmp7_;
	GraniteWidgetsSourceListExpandableItem* expandable = NULL;
	GraniteWidgetsSourceListExpandableItem* _tmp8_;
	GraniteWidgetsSourceListExpandableItem* _tmp9_;
#line 933 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 933 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (item != NULL);
#line 933 "../lib/Widgets/SourceList.vala"
	_vala_return_if_fail (granite_widgets_source_list_data_model_has_item (self, item), "has_item (item)");
#line 934 "../lib/Widgets/SourceList.vala"
	_tmp0_ = granite_widgets_source_list_data_model_get_root (self);
#line 934 "../lib/Widgets/SourceList.vala"
	_tmp1_ = _tmp0_;
#line 934 "../lib/Widgets/SourceList.vala"
	_vala_assert (_tmp1_ != NULL, "root != null");
#line 936 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_data_model_remove_property_monitor (self, item);
#line 941 "../lib/Widgets/SourceList.vala"
	_tmp2_ = granite_widgets_source_list_data_model_get_item_child_iter (self, item);
#line 941 "../lib/Widgets/SourceList.vala"
	child_iter = _tmp2_;
#line 947 "../lib/Widgets/SourceList.vala"
	_tmp3_ = self->priv->items;
#line 947 "../lib/Widgets/SourceList.vala"
	gee_abstract_map_unset ((GeeAbstractMap*) _tmp3_, item, NULL);
#line 949 "../lib/Widgets/SourceList.vala"
	_tmp4_ = child_iter;
#line 949 "../lib/Widgets/SourceList.vala"
	if (_tmp4_ != NULL) {
#line 4610 "SourceList.c"
		GtkTreeStore* _tmp5_;
#line 950 "../lib/Widgets/SourceList.vala"
		_tmp5_ = self->priv->child_tree;
#line 950 "../lib/Widgets/SourceList.vala"
		gtk_tree_store_remove (_tmp5_, child_iter);
#line 4616 "SourceList.c"
	}
#line 952 "../lib/Widgets/SourceList.vala"
	_tmp6_ = granite_widgets_source_list_item_get_parent (item);
#line 952 "../lib/Widgets/SourceList.vala"
	_tmp7_ = _tmp6_;
#line 952 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_data_model_push_parent_update (self, _tmp7_);
#line 955 "../lib/Widgets/SourceList.vala"
	_tmp8_ = _g_object_ref0 (GRANITE_WIDGETS_SOURCE_LIST_IS_EXPANDABLE_ITEM (item) ? ((GraniteWidgetsSourceListExpandableItem*) item) : NULL);
#line 955 "../lib/Widgets/SourceList.vala"
	expandable = _tmp8_;
#line 956 "../lib/Widgets/SourceList.vala"
	_tmp9_ = expandable;
#line 956 "../lib/Widgets/SourceList.vala"
	if (_tmp9_ != NULL) {
#line 4632 "SourceList.c"
		GraniteWidgetsSourceListExpandableItem* _tmp10_;
#line 958 "../lib/Widgets/SourceList.vala"
		_tmp10_ = expandable;
#line 958 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_data_model_remove_children_monitor (self, _tmp10_);
#line 4638 "SourceList.c"
		{
			GeeIterator* _child_item_it = NULL;
			GraniteWidgetsSourceListExpandableItem* _tmp11_;
			GeeCollection* _tmp12_;
			GeeCollection* _tmp13_;
			GeeCollection* _tmp14_;
			GeeIterator* _tmp15_;
			GeeIterator* _tmp16_;
#line 960 "../lib/Widgets/SourceList.vala"
			_tmp11_ = expandable;
#line 960 "../lib/Widgets/SourceList.vala"
			_tmp12_ = granite_widgets_source_list_expandable_item_get_children (_tmp11_);
#line 960 "../lib/Widgets/SourceList.vala"
			_tmp13_ = _tmp12_;
#line 960 "../lib/Widgets/SourceList.vala"
			_tmp14_ = _tmp13_;
#line 960 "../lib/Widgets/SourceList.vala"
			_tmp15_ = gee_iterable_iterator ((GeeIterable*) _tmp14_);
#line 960 "../lib/Widgets/SourceList.vala"
			_tmp16_ = _tmp15_;
#line 960 "../lib/Widgets/SourceList.vala"
			_g_object_unref0 (_tmp14_);
#line 960 "../lib/Widgets/SourceList.vala"
			_child_item_it = _tmp16_;
#line 960 "../lib/Widgets/SourceList.vala"
			while (TRUE) {
#line 4665 "SourceList.c"
				GeeIterator* _tmp17_;
				GraniteWidgetsSourceListItem* child_item = NULL;
				GeeIterator* _tmp18_;
				gpointer _tmp19_;
				GraniteWidgetsSourceListItem* _tmp20_;
#line 960 "../lib/Widgets/SourceList.vala"
				_tmp17_ = _child_item_it;
#line 960 "../lib/Widgets/SourceList.vala"
				if (!gee_iterator_next (_tmp17_)) {
#line 960 "../lib/Widgets/SourceList.vala"
					break;
#line 4677 "SourceList.c"
				}
#line 960 "../lib/Widgets/SourceList.vala"
				_tmp18_ = _child_item_it;
#line 960 "../lib/Widgets/SourceList.vala"
				_tmp19_ = gee_iterator_get (_tmp18_);
#line 960 "../lib/Widgets/SourceList.vala"
				child_item = (GraniteWidgetsSourceListItem*) _tmp19_;
#line 961 "../lib/Widgets/SourceList.vala"
				_tmp20_ = child_item;
#line 961 "../lib/Widgets/SourceList.vala"
				granite_widgets_source_list_data_model_remove_item (self, _tmp20_);
#line 960 "../lib/Widgets/SourceList.vala"
				_g_object_unref0 (child_item);
#line 4691 "SourceList.c"
			}
#line 960 "../lib/Widgets/SourceList.vala"
			_g_object_unref0 (_child_item_it);
#line 4695 "SourceList.c"
		}
	}
#line 933 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (expandable);
#line 933 "../lib/Widgets/SourceList.vala"
	__vala_GtkTreeIter_free0 (child_iter);
#line 4702 "SourceList.c"
}

static void
_granite_widgets_source_list_data_model_on_item_prop_changed_granite_widgets_source_list_data_model_item_monitor_changed (GraniteWidgetsSourceListDataModelItemMonitor* _sender,
                                                                                                                          GraniteWidgetsSourceListItem* _self_,
                                                                                                                          const gchar* prop_name,
                                                                                                                          gpointer self)
{
#line 968 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_data_model_on_item_prop_changed ((GraniteWidgetsSourceListDataModel*) self, _self_, prop_name);
#line 4713 "SourceList.c"
}

static void
granite_widgets_source_list_data_model_add_property_monitor (GraniteWidgetsSourceListDataModel* self,
                                                             GraniteWidgetsSourceListItem* item)
{
	GraniteWidgetsSourceListDataModelItemMonitor* wrapper = NULL;
	GraniteWidgetsSourceListDataModelItemMonitor* _tmp0_;
	GeeHashMap* _tmp1_;
#line 965 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 965 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (item != NULL);
#line 966 "../lib/Widgets/SourceList.vala"
	_tmp0_ = granite_widgets_source_list_data_model_item_monitor_new (item);
#line 966 "../lib/Widgets/SourceList.vala"
	wrapper = _tmp0_;
#line 967 "../lib/Widgets/SourceList.vala"
	_tmp1_ = self->priv->monitors;
#line 967 "../lib/Widgets/SourceList.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp1_, item, wrapper);
#line 968 "../lib/Widgets/SourceList.vala"
	g_signal_connect_object (wrapper, "changed", (GCallback) _granite_widgets_source_list_data_model_on_item_prop_changed_granite_widgets_source_list_data_model_item_monitor_changed, self, 0);
#line 965 "../lib/Widgets/SourceList.vala"
	_granite_widgets_source_list_data_model_item_monitor_unref0 (wrapper);
#line 4739 "SourceList.c"
}

static void
granite_widgets_source_list_data_model_remove_property_monitor (GraniteWidgetsSourceListDataModel* self,
                                                                GraniteWidgetsSourceListItem* item)
{
	GraniteWidgetsSourceListDataModelItemMonitor* wrapper = NULL;
	GeeHashMap* _tmp0_;
	gpointer _tmp1_;
	GraniteWidgetsSourceListDataModelItemMonitor* _tmp2_;
	GeeHashMap* _tmp5_;
#line 971 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 971 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (item != NULL);
#line 972 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->monitors;
#line 972 "../lib/Widgets/SourceList.vala"
	_tmp1_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp0_, item);
#line 972 "../lib/Widgets/SourceList.vala"
	wrapper = (GraniteWidgetsSourceListDataModelItemMonitor*) _tmp1_;
#line 973 "../lib/Widgets/SourceList.vala"
	_tmp2_ = wrapper;
#line 973 "../lib/Widgets/SourceList.vala"
	if (_tmp2_ != NULL) {
#line 4765 "SourceList.c"
		GraniteWidgetsSourceListDataModelItemMonitor* _tmp3_;
		guint _tmp4_;
#line 974 "../lib/Widgets/SourceList.vala"
		_tmp3_ = wrapper;
#line 974 "../lib/Widgets/SourceList.vala"
		g_signal_parse_name ("changed", GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_TYPE_ITEM_MONITOR, &_tmp4_, NULL, FALSE);
#line 974 "../lib/Widgets/SourceList.vala"
		g_signal_handlers_disconnect_matched (_tmp3_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp4_, 0, NULL, (GCallback) _granite_widgets_source_list_data_model_on_item_prop_changed_granite_widgets_source_list_data_model_item_monitor_changed, self);
#line 4774 "SourceList.c"
	}
#line 975 "../lib/Widgets/SourceList.vala"
	_tmp5_ = self->priv->monitors;
#line 975 "../lib/Widgets/SourceList.vala"
	gee_abstract_map_unset ((GeeAbstractMap*) _tmp5_, item, NULL);
#line 971 "../lib/Widgets/SourceList.vala"
	_granite_widgets_source_list_data_model_item_monitor_unref0 (wrapper);
#line 4782 "SourceList.c"
}

static void
_granite_widgets_source_list_data_model_on_item_child_added_granite_widgets_source_list_expandable_item_child_added (GraniteWidgetsSourceListExpandableItem* _sender,
                                                                                                                     GraniteWidgetsSourceListItem* item,
                                                                                                                     gpointer self)
{
#line 979 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_data_model_on_item_child_added ((GraniteWidgetsSourceListDataModel*) self, item);
#line 4792 "SourceList.c"
}

static void
_granite_widgets_source_list_data_model_on_item_child_removed_granite_widgets_source_list_expandable_item_child_removed (GraniteWidgetsSourceListExpandableItem* _sender,
                                                                                                                         GraniteWidgetsSourceListItem* item,
                                                                                                                         gpointer self)
{
#line 980 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_data_model_on_item_child_removed ((GraniteWidgetsSourceListDataModel*) self, item);
#line 4802 "SourceList.c"
}

static void
granite_widgets_source_list_data_model_add_children_monitor (GraniteWidgetsSourceListDataModel* self,
                                                             GraniteWidgetsSourceListExpandableItem* item)
{
#line 978 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 978 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (item != NULL);
#line 979 "../lib/Widgets/SourceList.vala"
	g_signal_connect_object (item, "child-added", (GCallback) _granite_widgets_source_list_data_model_on_item_child_added_granite_widgets_source_list_expandable_item_child_added, self, G_CONNECT_AFTER);
#line 980 "../lib/Widgets/SourceList.vala"
	g_signal_connect_object (item, "child-removed", (GCallback) _granite_widgets_source_list_data_model_on_item_child_removed_granite_widgets_source_list_expandable_item_child_removed, self, G_CONNECT_AFTER);
#line 4817 "SourceList.c"
}

static void
granite_widgets_source_list_data_model_remove_children_monitor (GraniteWidgetsSourceListDataModel* self,
                                                                GraniteWidgetsSourceListExpandableItem* item)
{
	guint _tmp0_;
	guint _tmp1_;
#line 983 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 983 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (item != NULL);
#line 984 "../lib/Widgets/SourceList.vala"
	g_signal_parse_name ("child-added", GRANITE_WIDGETS_SOURCE_LIST_TYPE_EXPANDABLE_ITEM, &_tmp0_, NULL, FALSE);
#line 984 "../lib/Widgets/SourceList.vala"
	g_signal_handlers_disconnect_matched (item, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp0_, 0, NULL, (GCallback) _granite_widgets_source_list_data_model_on_item_child_added_granite_widgets_source_list_expandable_item_child_added, self);
#line 985 "../lib/Widgets/SourceList.vala"
	g_signal_parse_name ("child-removed", GRANITE_WIDGETS_SOURCE_LIST_TYPE_EXPANDABLE_ITEM, &_tmp1_, NULL, FALSE);
#line 985 "../lib/Widgets/SourceList.vala"
	g_signal_handlers_disconnect_matched (item, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _granite_widgets_source_list_data_model_on_item_child_removed_granite_widgets_source_list_expandable_item_child_removed, self);
#line 4838 "SourceList.c"
}

static void
granite_widgets_source_list_data_model_on_item_child_added (GraniteWidgetsSourceListDataModel* self,
                                                            GraniteWidgetsSourceListItem* item)
{
#line 988 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 988 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (item != NULL);
#line 989 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_data_model_add_item (self, item);
#line 4851 "SourceList.c"
}

static void
granite_widgets_source_list_data_model_on_item_child_removed (GraniteWidgetsSourceListDataModel* self,
                                                              GraniteWidgetsSourceListItem* item)
{
#line 992 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 992 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (item != NULL);
#line 993 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_data_model_remove_item (self, item);
#line 4864 "SourceList.c"
}

static void
granite_widgets_source_list_data_model_on_item_prop_changed (GraniteWidgetsSourceListDataModel* self,
                                                             GraniteWidgetsSourceListItem* item,
                                                             const gchar* prop_name)
{
#line 996 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 996 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (item != NULL);
#line 996 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (prop_name != NULL);
#line 997 "../lib/Widgets/SourceList.vala"
	if (g_strcmp0 (prop_name, "parent") != 0) {
#line 998 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_data_model_update_item (self, item);
#line 4882 "SourceList.c"
	}
}

/**
         * Pushes a call to update_item() if //parent// is not //null//.
         *
         * This is needed because the visibility of categories depends on their n_children property,
         * and also because item expansion should be updated after adding or removing items.
         * If many updates are pushed, and the item has still not been updated, only one is processed.
         * This guarantees efficiency as updating a category item could trigger expensive actions.
         */
static Block12Data*
block12_data_ref (Block12Data* _data12_)
{
#line 1009 "../lib/Widgets/SourceList.vala"
	g_atomic_int_inc (&_data12_->_ref_count_);
#line 1009 "../lib/Widgets/SourceList.vala"
	return _data12_;
#line 4901 "SourceList.c"
}

static void
block12_data_unref (void * _userdata_)
{
	Block12Data* _data12_;
	_data12_ = (Block12Data*) _userdata_;
#line 1009 "../lib/Widgets/SourceList.vala"
	if (g_atomic_int_dec_and_test (&_data12_->_ref_count_)) {
#line 4911 "SourceList.c"
		GraniteWidgetsSourceListDataModel* self;
#line 1009 "../lib/Widgets/SourceList.vala"
		self = _data12_->self;
#line 1009 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (_data12_->parent);
#line 1009 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (self);
#line 1009 "../lib/Widgets/SourceList.vala"
		g_slice_free (Block12Data, _data12_);
#line 4921 "SourceList.c"
	}
}

static gboolean
___lambda80_ (Block12Data* _data12_)
{
	GraniteWidgetsSourceListDataModel* self;
	gboolean result;
#line 1026 "../lib/Widgets/SourceList.vala"
	self = _data12_->self;
#line 1027 "../lib/Widgets/SourceList.vala"
	if (_data12_->parent != NULL) {
#line 1028 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_data_model_update_item (self, (GraniteWidgetsSourceListItem*) _data12_->parent);
#line 1031 "../lib/Widgets/SourceList.vala"
		g_object_set_data_full ((GObject*) _data12_->parent, GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_ITEM_PARENT_NEEDS_UPDATE, (gpointer) ((gintptr) FALSE), NULL);
#line 4938 "SourceList.c"
	}
#line 1034 "../lib/Widgets/SourceList.vala"
	result = FALSE;
#line 1034 "../lib/Widgets/SourceList.vala"
	return result;
#line 4944 "SourceList.c"
}

static gboolean
____lambda80__gsource_func (gpointer self)
{
	gboolean result;
	result = ___lambda80_ (self);
#line 1026 "../lib/Widgets/SourceList.vala"
	return result;
#line 4954 "SourceList.c"
}

static void
granite_widgets_source_list_data_model_push_parent_update (GraniteWidgetsSourceListDataModel* self,
                                                           GraniteWidgetsSourceListExpandableItem* parent)
{
	Block12Data* _data12_;
	GraniteWidgetsSourceListExpandableItem* _tmp0_;
	gboolean needs_update = FALSE;
	gconstpointer _tmp1_;
	GtkTreePath* path = NULL;
	GtkTreePath* _tmp2_;
	GtkTreePath* _tmp3_;
#line 1009 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 1009 "../lib/Widgets/SourceList.vala"
	_data12_ = g_slice_new0 (Block12Data);
#line 1009 "../lib/Widgets/SourceList.vala"
	_data12_->_ref_count_ = 1;
#line 1009 "../lib/Widgets/SourceList.vala"
	_data12_->self = g_object_ref (self);
#line 1009 "../lib/Widgets/SourceList.vala"
	_tmp0_ = _g_object_ref0 (parent);
#line 1009 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (_data12_->parent);
#line 1009 "../lib/Widgets/SourceList.vala"
	_data12_->parent = _tmp0_;
#line 1010 "../lib/Widgets/SourceList.vala"
	if (_data12_->parent == NULL) {
#line 1011 "../lib/Widgets/SourceList.vala"
		block12_data_unref (_data12_);
#line 1011 "../lib/Widgets/SourceList.vala"
		_data12_ = NULL;
#line 1011 "../lib/Widgets/SourceList.vala"
		return;
#line 4990 "SourceList.c"
	}
#line 1013 "../lib/Widgets/SourceList.vala"
	_tmp1_ = g_object_get_data ((GObject*) _data12_->parent, GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_ITEM_PARENT_NEEDS_UPDATE);
#line 1013 "../lib/Widgets/SourceList.vala"
	needs_update = (gboolean) ((gintptr) _tmp1_);
#line 1017 "../lib/Widgets/SourceList.vala"
	if (needs_update) {
#line 1018 "../lib/Widgets/SourceList.vala"
		block12_data_unref (_data12_);
#line 1018 "../lib/Widgets/SourceList.vala"
		_data12_ = NULL;
#line 1018 "../lib/Widgets/SourceList.vala"
		return;
#line 5004 "SourceList.c"
	}
#line 1020 "../lib/Widgets/SourceList.vala"
	_tmp2_ = granite_widgets_source_list_data_model_get_item_path (self, (GraniteWidgetsSourceListItem*) _data12_->parent);
#line 1020 "../lib/Widgets/SourceList.vala"
	path = _tmp2_;
#line 1022 "../lib/Widgets/SourceList.vala"
	_tmp3_ = path;
#line 1022 "../lib/Widgets/SourceList.vala"
	if (_tmp3_ != NULL) {
#line 1024 "../lib/Widgets/SourceList.vala"
		g_object_set_data_full ((GObject*) _data12_->parent, GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_ITEM_PARENT_NEEDS_UPDATE, (gpointer) ((gintptr) TRUE), NULL);
#line 1026 "../lib/Widgets/SourceList.vala"
		g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ____lambda80__gsource_func, block12_data_ref (_data12_), block12_data_unref);
#line 5018 "SourceList.c"
	}
#line 1009 "../lib/Widgets/SourceList.vala"
	__vala_GtkTreePath_free0 (path);
#line 1009 "../lib/Widgets/SourceList.vala"
	block12_data_unref (_data12_);
#line 1009 "../lib/Widgets/SourceList.vala"
	_data12_ = NULL;
#line 5026 "SourceList.c"
}

/**
         * Returns the Item pointed by iter, or null if the iter doesn't refer to a valid item.
         */
static GraniteWidgetsSourceListItem*
granite_widgets_source_list_data_model_get_item (GraniteWidgetsSourceListDataModel* self,
                                                 GtkTreeIter* iter)
{
	GraniteWidgetsSourceListItem* item = NULL;
	GtkTreeIter _tmp0_;
	GraniteWidgetsSourceListItem* _tmp1_ = NULL;
	GraniteWidgetsSourceListItem* result;
#line 1042 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 1042 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (iter != NULL, NULL);
#line 1044 "../lib/Widgets/SourceList.vala"
	_tmp0_ = *iter;
#line 1044 "../lib/Widgets/SourceList.vala"
	gtk_tree_model_get ((GtkTreeModel*) self, &_tmp0_, GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_COLUMN_ITEM, &_tmp1_, -1, -1);
#line 1044 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (item);
#line 1044 "../lib/Widgets/SourceList.vala"
	item = _tmp1_;
#line 1045 "../lib/Widgets/SourceList.vala"
	result = item;
#line 1045 "../lib/Widgets/SourceList.vala"
	return result;
#line 5056 "SourceList.c"
}

/**
         * Returns the Item pointed by path, or null if the path doesn't refer to a valid item.
         */
static GraniteWidgetsSourceListItem*
granite_widgets_source_list_data_model_get_item_from_path (GraniteWidgetsSourceListDataModel* self,
                                                           GtkTreePath* path)
{
	GtkTreeIter iter = {0};
	GtkTreeIter _tmp0_ = {0};
	gboolean _tmp1_;
	GraniteWidgetsSourceListItem* result;
#line 1051 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 1051 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (path != NULL, NULL);
#line 1053 "../lib/Widgets/SourceList.vala"
	_tmp1_ = gtk_tree_model_get_iter ((GtkTreeModel*) self, &_tmp0_, path);
#line 1053 "../lib/Widgets/SourceList.vala"
	iter = _tmp0_;
#line 1053 "../lib/Widgets/SourceList.vala"
	if (_tmp1_) {
#line 5080 "SourceList.c"
		GtkTreeIter _tmp2_;
		GraniteWidgetsSourceListItem* _tmp3_;
#line 1054 "../lib/Widgets/SourceList.vala"
		_tmp2_ = iter;
#line 1054 "../lib/Widgets/SourceList.vala"
		_tmp3_ = granite_widgets_source_list_data_model_get_item (self, &_tmp2_);
#line 1054 "../lib/Widgets/SourceList.vala"
		result = _tmp3_;
#line 1054 "../lib/Widgets/SourceList.vala"
		return result;
#line 5091 "SourceList.c"
	}
#line 1056 "../lib/Widgets/SourceList.vala"
	result = NULL;
#line 1056 "../lib/Widgets/SourceList.vala"
	return result;
#line 5097 "SourceList.c"
}

/**
         * Returns a newly-created path pointing to the item, or null in case a valid path
         * is not found.
         */
static GtkTreePath*
granite_widgets_source_list_data_model_get_item_path (GraniteWidgetsSourceListDataModel* self,
                                                      GraniteWidgetsSourceListItem* item)
{
	GtkTreePath* path = NULL;
	GtkTreePath* child_path = NULL;
	GtkTreePath* _tmp0_;
	GtkTreePath* _tmp1_;
	GtkTreePath* result;
#line 1063 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 1063 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (item != NULL, NULL);
#line 1064 "../lib/Widgets/SourceList.vala"
	path = NULL;
#line 1064 "../lib/Widgets/SourceList.vala"
	_tmp0_ = granite_widgets_source_list_data_model_get_item_child_path (self, item);
#line 1064 "../lib/Widgets/SourceList.vala"
	child_path = _tmp0_;
#line 1067 "../lib/Widgets/SourceList.vala"
	_tmp1_ = child_path;
#line 1067 "../lib/Widgets/SourceList.vala"
	if (_tmp1_ != NULL) {
#line 5127 "SourceList.c"
		GtkTreePath* _tmp2_;
		GtkTreePath* _tmp3_;
#line 1068 "../lib/Widgets/SourceList.vala"
		_tmp2_ = child_path;
#line 1068 "../lib/Widgets/SourceList.vala"
		_tmp3_ = gtk_tree_model_filter_convert_child_path_to_path ((GtkTreeModelFilter*) self, _tmp2_);
#line 1068 "../lib/Widgets/SourceList.vala"
		__vala_GtkTreePath_free0 (path);
#line 1068 "../lib/Widgets/SourceList.vala"
		path = _tmp3_;
#line 5138 "SourceList.c"
	}
#line 1070 "../lib/Widgets/SourceList.vala"
	result = path;
#line 1070 "../lib/Widgets/SourceList.vala"
	__vala_GtkTreePath_free0 (child_path);
#line 1070 "../lib/Widgets/SourceList.vala"
	return result;
#line 5146 "SourceList.c"
}

/**
         * Returns a newly-created iterator pointing to the item, or null in case a valid iter
         * was not found.
         */
static GtkTreeIter*
granite_widgets_source_list_data_model_get_item_iter (GraniteWidgetsSourceListDataModel* self,
                                                      GraniteWidgetsSourceListItem* item)
{
	GtkTreeIter* child_iter = NULL;
	GtkTreeIter* _tmp0_;
	GtkTreeIter* _tmp1_;
	GtkTreeIter* result;
#line 1077 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 1077 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (item != NULL, NULL);
#line 1078 "../lib/Widgets/SourceList.vala"
	_tmp0_ = granite_widgets_source_list_data_model_get_item_child_iter (self, item);
#line 1078 "../lib/Widgets/SourceList.vala"
	child_iter = _tmp0_;
#line 1080 "../lib/Widgets/SourceList.vala"
	_tmp1_ = child_iter;
#line 1080 "../lib/Widgets/SourceList.vala"
	if (_tmp1_ != NULL) {
#line 5173 "SourceList.c"
		GtkTreeIter iter = {0};
		GtkTreeIter* _tmp2_;
		GtkTreeIter _tmp3_ = {0};
		GtkTreeIter _tmp4_;
		gboolean _tmp5_;
#line 1082 "../lib/Widgets/SourceList.vala"
		_tmp2_ = child_iter;
#line 1082 "../lib/Widgets/SourceList.vala"
		_tmp4_ = *_tmp2_;
#line 1082 "../lib/Widgets/SourceList.vala"
		_tmp5_ = gtk_tree_model_filter_convert_child_iter_to_iter ((GtkTreeModelFilter*) self, &_tmp3_, &_tmp4_);
#line 1082 "../lib/Widgets/SourceList.vala"
		iter = _tmp3_;
#line 1082 "../lib/Widgets/SourceList.vala"
		if (_tmp5_) {
#line 5189 "SourceList.c"
			GtkTreeIter* _tmp6_;
#line 1083 "../lib/Widgets/SourceList.vala"
			_tmp6_ = __vala_GtkTreeIter_copy0 (&iter);
#line 1083 "../lib/Widgets/SourceList.vala"
			result = _tmp6_;
#line 1083 "../lib/Widgets/SourceList.vala"
			__vala_GtkTreeIter_free0 (child_iter);
#line 1083 "../lib/Widgets/SourceList.vala"
			return result;
#line 5199 "SourceList.c"
		}
	}
#line 1086 "../lib/Widgets/SourceList.vala"
	result = NULL;
#line 1086 "../lib/Widgets/SourceList.vala"
	__vala_GtkTreeIter_free0 (child_iter);
#line 1086 "../lib/Widgets/SourceList.vala"
	return result;
#line 5208 "SourceList.c"
}

/**
         * External "extra" filter method.
         */
static void
granite_widgets_source_list_data_model_set_filter_func (GraniteWidgetsSourceListDataModel* self,
                                                        GraniteWidgetsSourceListVisibleFunc visible_func,
                                                        gpointer visible_func_target)
{
#line 1092 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 1093 "../lib/Widgets/SourceList.vala"
	self->priv->filter_func = visible_func;
#line 1093 "../lib/Widgets/SourceList.vala"
	self->priv->filter_func_target = visible_func_target;
#line 5225 "SourceList.c"
}

/**
         * Checks whether an item is a category (i.e. a root-level expandable item).
         * The caller must pass an iter or path pointing to the item, but not both
         * (one of them must be null.)
         *
         * TODO: instead of checking the position of the iter or path, we should simply
         * check whether the item's parent is the root item and whether the item is
         * expandable. We don't do so right now because vala still allows client code
         * to access the Item.parent property, even though its setter is defined as internal.
         */
static gboolean
granite_widgets_source_list_data_model_is_category (GraniteWidgetsSourceListDataModel* self,
                                                    GraniteWidgetsSourceListItem* item,
                                                    GtkTreeIter* iter,
                                                    GtkTreePath* path)
{
	gboolean is_category = FALSE;
	gboolean result;
#line 1106 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 1106 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (item != NULL, FALSE);
#line 1107 "../lib/Widgets/SourceList.vala"
	is_category = FALSE;
#line 1109 "../lib/Widgets/SourceList.vala"
	if (GRANITE_WIDGETS_SOURCE_LIST_IS_EXPANDABLE_ITEM (item)) {
#line 1110 "../lib/Widgets/SourceList.vala"
		if (iter != NULL) {
#line 5256 "SourceList.c"
			GtkTreeIter _tmp0_;
#line 1111 "../lib/Widgets/SourceList.vala"
			_vala_assert (path == NULL, "path == null");
#line 1112 "../lib/Widgets/SourceList.vala"
			_tmp0_ = *iter;
#line 1112 "../lib/Widgets/SourceList.vala"
			is_category = granite_widgets_source_list_data_model_is_iter_at_root_level (self, &_tmp0_);
#line 5264 "SourceList.c"
		} else {
#line 1114 "../lib/Widgets/SourceList.vala"
			_vala_assert (iter == NULL, "iter == null");
#line 1115 "../lib/Widgets/SourceList.vala"
			is_category = granite_widgets_source_list_data_model_is_path_at_root_level (self, path);
#line 5270 "SourceList.c"
		}
	}
#line 1118 "../lib/Widgets/SourceList.vala"
	result = is_category;
#line 1118 "../lib/Widgets/SourceList.vala"
	return result;
#line 5277 "SourceList.c"
}

static gboolean
granite_widgets_source_list_data_model_is_iter_at_root_level (GraniteWidgetsSourceListDataModel* self,
                                                              GtkTreeIter* iter)
{
	GtkTreeIter _tmp0_;
	GtkTreePath* _tmp1_;
	GtkTreePath* _tmp2_;
	gboolean _tmp3_;
	gboolean result;
#line 1121 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 1121 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (iter != NULL, FALSE);
#line 1122 "../lib/Widgets/SourceList.vala"
	_tmp0_ = *iter;
#line 1122 "../lib/Widgets/SourceList.vala"
	_tmp1_ = gtk_tree_model_get_path ((GtkTreeModel*) self, &_tmp0_);
#line 1122 "../lib/Widgets/SourceList.vala"
	_tmp2_ = _tmp1_;
#line 1122 "../lib/Widgets/SourceList.vala"
	_tmp3_ = granite_widgets_source_list_data_model_is_path_at_root_level (self, _tmp2_);
#line 1122 "../lib/Widgets/SourceList.vala"
	__vala_GtkTreePath_free0 (_tmp2_);
#line 1122 "../lib/Widgets/SourceList.vala"
	result = _tmp3_;
#line 1122 "../lib/Widgets/SourceList.vala"
	return result;
#line 5307 "SourceList.c"
}

static gboolean
granite_widgets_source_list_data_model_is_path_at_root_level (GraniteWidgetsSourceListDataModel* self,
                                                              GtkTreePath* path)
{
	gboolean result;
#line 1125 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 1125 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (path != NULL, FALSE);
#line 1126 "../lib/Widgets/SourceList.vala"
	result = gtk_tree_path_get_depth (path) == 1;
#line 1126 "../lib/Widgets/SourceList.vala"
	return result;
#line 5323 "SourceList.c"
}

static void
granite_widgets_source_list_data_model_resort (GraniteWidgetsSourceListDataModel* self)
{
	GtkTreeStore* _tmp0_;
	GtkTreeStore* _tmp1_;
#line 1129 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 1130 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->child_tree;
#line 1130 "../lib/Widgets/SourceList.vala"
	gtk_tree_sortable_set_sort_column_id ((GtkTreeSortable*) _tmp0_, GTK_TREE_SORTABLE_UNSORTED_SORT_COLUMN_ID, GTK_SORT_ASCENDING);
#line 1131 "../lib/Widgets/SourceList.vala"
	_tmp1_ = self->priv->child_tree;
#line 1131 "../lib/Widgets/SourceList.vala"
	gtk_tree_sortable_set_sort_column_id ((GtkTreeSortable*) _tmp1_, GTK_TREE_SORTABLE_DEFAULT_SORT_COLUMN_ID, GTK_SORT_ASCENDING);
#line 5341 "SourceList.c"
}

static gint
granite_widgets_source_list_data_model_child_model_sort_func (GraniteWidgetsSourceListDataModel* self,
                                                              GtkTreeModel* model,
                                                              GtkTreeIter* a,
                                                              GtkTreeIter* b)
{
	gint order = 0;
	GraniteWidgetsSourceListItem* item_a = NULL;
	GraniteWidgetsSourceListItem* item_b = NULL;
	GtkTreeStore* _tmp0_;
	GtkTreeIter _tmp1_;
	GraniteWidgetsSourceListItem* _tmp2_ = NULL;
	GtkTreeStore* _tmp3_;
	GtkTreeIter _tmp4_;
	GraniteWidgetsSourceListItem* _tmp5_ = NULL;
	GraniteWidgetsSourceListItem* _tmp6_;
	GraniteWidgetsSourceListExpandableItem* _tmp7_;
	GraniteWidgetsSourceListExpandableItem* _tmp8_;
	GraniteWidgetsSourceListItem* _tmp9_;
	GraniteWidgetsSourceListExpandableItem* _tmp10_;
	GraniteWidgetsSourceListExpandableItem* _tmp11_;
	GraniteWidgetsSourceListSortable* parent = NULL;
	GraniteWidgetsSourceListItem* _tmp12_;
	GraniteWidgetsSourceListExpandableItem* _tmp13_;
	GraniteWidgetsSourceListExpandableItem* _tmp14_;
	GraniteWidgetsSourceListSortable* _tmp15_;
	GraniteWidgetsSourceListSortable* _tmp16_;
	gint result;
#line 1134 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 1134 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (model != NULL, 0);
#line 1134 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (a != NULL, 0);
#line 1134 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (b != NULL, 0);
#line 1135 "../lib/Widgets/SourceList.vala"
	order = 0;
#line 1138 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->child_tree;
#line 1138 "../lib/Widgets/SourceList.vala"
	_tmp1_ = *a;
#line 1138 "../lib/Widgets/SourceList.vala"
	gtk_tree_model_get ((GtkTreeModel*) _tmp0_, &_tmp1_, GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_COLUMN_ITEM, &_tmp2_, -1, -1);
#line 1138 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (item_a);
#line 1138 "../lib/Widgets/SourceList.vala"
	item_a = _tmp2_;
#line 1139 "../lib/Widgets/SourceList.vala"
	_tmp3_ = self->priv->child_tree;
#line 1139 "../lib/Widgets/SourceList.vala"
	_tmp4_ = *b;
#line 1139 "../lib/Widgets/SourceList.vala"
	gtk_tree_model_get ((GtkTreeModel*) _tmp3_, &_tmp4_, GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_COLUMN_ITEM, &_tmp5_, -1, -1);
#line 1139 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (item_b);
#line 1139 "../lib/Widgets/SourceList.vala"
	item_b = _tmp5_;
#line 1142 "../lib/Widgets/SourceList.vala"
	_tmp6_ = item_a;
#line 1142 "../lib/Widgets/SourceList.vala"
	_tmp7_ = granite_widgets_source_list_item_get_parent (_tmp6_);
#line 1142 "../lib/Widgets/SourceList.vala"
	_tmp8_ = _tmp7_;
#line 1142 "../lib/Widgets/SourceList.vala"
	_tmp9_ = item_b;
#line 1142 "../lib/Widgets/SourceList.vala"
	_tmp10_ = granite_widgets_source_list_item_get_parent (_tmp9_);
#line 1142 "../lib/Widgets/SourceList.vala"
	_tmp11_ = _tmp10_;
#line 1142 "../lib/Widgets/SourceList.vala"
	_vala_assert (_tmp8_ == _tmp11_, "item_a.parent == item_b.parent");
#line 1144 "../lib/Widgets/SourceList.vala"
	_tmp12_ = item_a;
#line 1144 "../lib/Widgets/SourceList.vala"
	_tmp13_ = granite_widgets_source_list_item_get_parent (_tmp12_);
#line 1144 "../lib/Widgets/SourceList.vala"
	_tmp14_ = _tmp13_;
#line 1144 "../lib/Widgets/SourceList.vala"
	_tmp15_ = _g_object_ref0 (GRANITE_WIDGETS_IS_SOURCE_LIST_SORTABLE (_tmp14_) ? ((GraniteWidgetsSourceListSortable*) _tmp14_) : NULL);
#line 1144 "../lib/Widgets/SourceList.vala"
	parent = _tmp15_;
#line 1145 "../lib/Widgets/SourceList.vala"
	_tmp16_ = parent;
#line 1145 "../lib/Widgets/SourceList.vala"
	if (_tmp16_ != NULL) {
#line 5430 "SourceList.c"
		GraniteWidgetsSourceListSortable* _tmp17_;
		GraniteWidgetsSourceListItem* _tmp18_;
		GraniteWidgetsSourceListItem* _tmp19_;
#line 1146 "../lib/Widgets/SourceList.vala"
		_tmp17_ = parent;
#line 1146 "../lib/Widgets/SourceList.vala"
		_tmp18_ = item_a;
#line 1146 "../lib/Widgets/SourceList.vala"
		_tmp19_ = item_b;
#line 1146 "../lib/Widgets/SourceList.vala"
		order = granite_widgets_source_list_sortable_compare (_tmp17_, _tmp18_, _tmp19_);
#line 5442 "SourceList.c"
	}
#line 1148 "../lib/Widgets/SourceList.vala"
	result = order;
#line 1148 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (parent);
#line 1148 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (item_b);
#line 1148 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (item_a);
#line 1148 "../lib/Widgets/SourceList.vala"
	return result;
#line 5454 "SourceList.c"
}

static GtkTreeIter*
granite_widgets_source_list_data_model_get_item_child_iter (GraniteWidgetsSourceListDataModel* self,
                                                            GraniteWidgetsSourceListItem* item)
{
	GtkTreeIter* child_iter = NULL;
	GraniteWidgetsSourceListDataModelNodeWrapper* child_node_wrapper = NULL;
	GeeHashMap* _tmp0_;
	gpointer _tmp1_;
	GraniteWidgetsSourceListDataModelNodeWrapper* _tmp2_;
	GtkTreeIter* result;
#line 1151 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 1151 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (item != NULL, NULL);
#line 1152 "../lib/Widgets/SourceList.vala"
	child_iter = NULL;
#line 1154 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->items;
#line 1154 "../lib/Widgets/SourceList.vala"
	_tmp1_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp0_, item);
#line 1154 "../lib/Widgets/SourceList.vala"
	child_node_wrapper = (GraniteWidgetsSourceListDataModelNodeWrapper*) _tmp1_;
#line 1155 "../lib/Widgets/SourceList.vala"
	_tmp2_ = child_node_wrapper;
#line 1155 "../lib/Widgets/SourceList.vala"
	if (_tmp2_ != NULL) {
#line 5483 "SourceList.c"
		GraniteWidgetsSourceListDataModelNodeWrapper* _tmp3_;
		GtkTreeIter* _tmp4_;
		GtkTreeIter* _tmp5_;
#line 1156 "../lib/Widgets/SourceList.vala"
		_tmp3_ = child_node_wrapper;
#line 1156 "../lib/Widgets/SourceList.vala"
		_tmp4_ = granite_widgets_source_list_data_model_node_wrapper_get_iter (_tmp3_);
#line 1156 "../lib/Widgets/SourceList.vala"
		_tmp5_ = _tmp4_;
#line 1156 "../lib/Widgets/SourceList.vala"
		__vala_GtkTreeIter_free0 (child_iter);
#line 1156 "../lib/Widgets/SourceList.vala"
		child_iter = _tmp5_;
#line 5497 "SourceList.c"
	}
#line 1158 "../lib/Widgets/SourceList.vala"
	result = child_iter;
#line 1158 "../lib/Widgets/SourceList.vala"
	_granite_widgets_source_list_data_model_node_wrapper_unref0 (child_node_wrapper);
#line 1158 "../lib/Widgets/SourceList.vala"
	return result;
#line 5505 "SourceList.c"
}

static GtkTreePath*
granite_widgets_source_list_data_model_get_item_child_path (GraniteWidgetsSourceListDataModel* self,
                                                            GraniteWidgetsSourceListItem* item)
{
	GtkTreePath* child_path = NULL;
	GraniteWidgetsSourceListDataModelNodeWrapper* child_node_wrapper = NULL;
	GeeHashMap* _tmp0_;
	gpointer _tmp1_;
	GraniteWidgetsSourceListDataModelNodeWrapper* _tmp2_;
	GtkTreePath* result;
#line 1161 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 1161 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (item != NULL, NULL);
#line 1162 "../lib/Widgets/SourceList.vala"
	child_path = NULL;
#line 1164 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->items;
#line 1164 "../lib/Widgets/SourceList.vala"
	_tmp1_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp0_, item);
#line 1164 "../lib/Widgets/SourceList.vala"
	child_node_wrapper = (GraniteWidgetsSourceListDataModelNodeWrapper*) _tmp1_;
#line 1165 "../lib/Widgets/SourceList.vala"
	_tmp2_ = child_node_wrapper;
#line 1165 "../lib/Widgets/SourceList.vala"
	if (_tmp2_ != NULL) {
#line 5534 "SourceList.c"
		GraniteWidgetsSourceListDataModelNodeWrapper* _tmp3_;
		GtkTreePath* _tmp4_;
		GtkTreePath* _tmp5_;
#line 1166 "../lib/Widgets/SourceList.vala"
		_tmp3_ = child_node_wrapper;
#line 1166 "../lib/Widgets/SourceList.vala"
		_tmp4_ = granite_widgets_source_list_data_model_node_wrapper_get_path (_tmp3_);
#line 1166 "../lib/Widgets/SourceList.vala"
		_tmp5_ = _tmp4_;
#line 1166 "../lib/Widgets/SourceList.vala"
		__vala_GtkTreePath_free0 (child_path);
#line 1166 "../lib/Widgets/SourceList.vala"
		child_path = _tmp5_;
#line 5548 "SourceList.c"
	}
#line 1168 "../lib/Widgets/SourceList.vala"
	result = child_path;
#line 1168 "../lib/Widgets/SourceList.vala"
	_granite_widgets_source_list_data_model_node_wrapper_unref0 (child_node_wrapper);
#line 1168 "../lib/Widgets/SourceList.vala"
	return result;
#line 5556 "SourceList.c"
}

/**
         * Filters the child-tree items based on their "visible" property.
         */
static gboolean
granite_widgets_source_list_data_model_filter_visible_func (GraniteWidgetsSourceListDataModel* self,
                                                            GtkTreeModel* child_model,
                                                            GtkTreeIter* iter)
{
	gboolean item_visible = FALSE;
	GraniteWidgetsSourceListItem* item = NULL;
	GtkTreeStore* _tmp0_;
	GtkTreeIter _tmp1_;
	GraniteWidgetsSourceListItem* _tmp2_ = NULL;
	GraniteWidgetsSourceListItem* _tmp3_;
	GraniteWidgetsSourceListVisibleFunc _tmp27_;
	gpointer _tmp27__target;
	gboolean result;
#line 1174 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 1174 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (child_model != NULL, FALSE);
#line 1174 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (iter != NULL, FALSE);
#line 1175 "../lib/Widgets/SourceList.vala"
	item_visible = FALSE;
#line 1178 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->child_tree;
#line 1178 "../lib/Widgets/SourceList.vala"
	_tmp1_ = *iter;
#line 1178 "../lib/Widgets/SourceList.vala"
	gtk_tree_model_get ((GtkTreeModel*) _tmp0_, &_tmp1_, GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_COLUMN_ITEM, &_tmp2_, -1, -1);
#line 1178 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (item);
#line 1178 "../lib/Widgets/SourceList.vala"
	item = _tmp2_;
#line 1180 "../lib/Widgets/SourceList.vala"
	_tmp3_ = item;
#line 1180 "../lib/Widgets/SourceList.vala"
	if (_tmp3_ != NULL) {
#line 5598 "SourceList.c"
		GraniteWidgetsSourceListItem* _tmp4_;
		gboolean _tmp5_;
		gboolean _tmp6_;
		GraniteWidgetsSourceListExpandableItem* expandable = NULL;
		GraniteWidgetsSourceListItem* _tmp7_;
		GraniteWidgetsSourceListExpandableItem* _tmp8_;
		gboolean _tmp9_ = FALSE;
		GraniteWidgetsSourceListExpandableItem* _tmp10_;
#line 1181 "../lib/Widgets/SourceList.vala"
		_tmp4_ = item;
#line 1181 "../lib/Widgets/SourceList.vala"
		_tmp5_ = granite_widgets_source_list_item_get_visible (_tmp4_);
#line 1181 "../lib/Widgets/SourceList.vala"
		_tmp6_ = _tmp5_;
#line 1181 "../lib/Widgets/SourceList.vala"
		item_visible = _tmp6_;
#line 1185 "../lib/Widgets/SourceList.vala"
		_tmp7_ = item;
#line 1185 "../lib/Widgets/SourceList.vala"
		_tmp8_ = _g_object_ref0 (GRANITE_WIDGETS_SOURCE_LIST_IS_EXPANDABLE_ITEM (_tmp7_) ? ((GraniteWidgetsSourceListExpandableItem*) _tmp7_) : NULL);
#line 1185 "../lib/Widgets/SourceList.vala"
		expandable = _tmp8_;
#line 1186 "../lib/Widgets/SourceList.vala"
		_tmp10_ = expandable;
#line 1186 "../lib/Widgets/SourceList.vala"
		if (_tmp10_ != NULL) {
#line 5625 "SourceList.c"
			GtkTreeStore* _tmp11_;
			GtkTreeIter _tmp12_;
#line 1186 "../lib/Widgets/SourceList.vala"
			_tmp11_ = self->priv->child_tree;
#line 1186 "../lib/Widgets/SourceList.vala"
			_tmp12_ = *iter;
#line 1186 "../lib/Widgets/SourceList.vala"
			_tmp9_ = gtk_tree_store_iter_depth (_tmp11_, &_tmp12_) == 0;
#line 5634 "SourceList.c"
		} else {
#line 1186 "../lib/Widgets/SourceList.vala"
			_tmp9_ = FALSE;
#line 5638 "SourceList.c"
		}
#line 1186 "../lib/Widgets/SourceList.vala"
		if (_tmp9_) {
#line 5642 "SourceList.c"
			guint n_visible_children = 0U;
			gboolean _tmp26_ = FALSE;
#line 1187 "../lib/Widgets/SourceList.vala"
			n_visible_children = (guint) 0;
#line 5647 "SourceList.c"
			{
				GeeIterator* _child_item_it = NULL;
				GraniteWidgetsSourceListExpandableItem* _tmp13_;
				GeeCollection* _tmp14_;
				GeeCollection* _tmp15_;
				GeeCollection* _tmp16_;
				GeeIterator* _tmp17_;
				GeeIterator* _tmp18_;
#line 1188 "../lib/Widgets/SourceList.vala"
				_tmp13_ = expandable;
#line 1188 "../lib/Widgets/SourceList.vala"
				_tmp14_ = granite_widgets_source_list_expandable_item_get_children (_tmp13_);
#line 1188 "../lib/Widgets/SourceList.vala"
				_tmp15_ = _tmp14_;
#line 1188 "../lib/Widgets/SourceList.vala"
				_tmp16_ = _tmp15_;
#line 1188 "../lib/Widgets/SourceList.vala"
				_tmp17_ = gee_iterable_iterator ((GeeIterable*) _tmp16_);
#line 1188 "../lib/Widgets/SourceList.vala"
				_tmp18_ = _tmp17_;
#line 1188 "../lib/Widgets/SourceList.vala"
				_g_object_unref0 (_tmp16_);
#line 1188 "../lib/Widgets/SourceList.vala"
				_child_item_it = _tmp18_;
#line 1188 "../lib/Widgets/SourceList.vala"
				while (TRUE) {
#line 5674 "SourceList.c"
					GeeIterator* _tmp19_;
					GraniteWidgetsSourceListItem* child_item = NULL;
					GeeIterator* _tmp20_;
					gpointer _tmp21_;
					GraniteWidgetsSourceListItem* _tmp22_;
					gboolean _tmp23_;
					gboolean _tmp24_;
#line 1188 "../lib/Widgets/SourceList.vala"
					_tmp19_ = _child_item_it;
#line 1188 "../lib/Widgets/SourceList.vala"
					if (!gee_iterator_next (_tmp19_)) {
#line 1188 "../lib/Widgets/SourceList.vala"
						break;
#line 5688 "SourceList.c"
					}
#line 1188 "../lib/Widgets/SourceList.vala"
					_tmp20_ = _child_item_it;
#line 1188 "../lib/Widgets/SourceList.vala"
					_tmp21_ = gee_iterator_get (_tmp20_);
#line 1188 "../lib/Widgets/SourceList.vala"
					child_item = (GraniteWidgetsSourceListItem*) _tmp21_;
#line 1189 "../lib/Widgets/SourceList.vala"
					_tmp22_ = child_item;
#line 1189 "../lib/Widgets/SourceList.vala"
					_tmp23_ = granite_widgets_source_list_item_get_visible (_tmp22_);
#line 1189 "../lib/Widgets/SourceList.vala"
					_tmp24_ = _tmp23_;
#line 1189 "../lib/Widgets/SourceList.vala"
					if (_tmp24_) {
#line 5704 "SourceList.c"
						guint _tmp25_;
#line 1190 "../lib/Widgets/SourceList.vala"
						_tmp25_ = n_visible_children;
#line 1190 "../lib/Widgets/SourceList.vala"
						n_visible_children = _tmp25_ + 1;
#line 5710 "SourceList.c"
					}
#line 1188 "../lib/Widgets/SourceList.vala"
					_g_object_unref0 (child_item);
#line 5714 "SourceList.c"
				}
#line 1188 "../lib/Widgets/SourceList.vala"
				_g_object_unref0 (_child_item_it);
#line 5718 "SourceList.c"
			}
#line 1192 "../lib/Widgets/SourceList.vala"
			if (item_visible) {
#line 1192 "../lib/Widgets/SourceList.vala"
				_tmp26_ = n_visible_children > ((guint) 0);
#line 5724 "SourceList.c"
			} else {
#line 1192 "../lib/Widgets/SourceList.vala"
				_tmp26_ = FALSE;
#line 5728 "SourceList.c"
			}
#line 1192 "../lib/Widgets/SourceList.vala"
			item_visible = _tmp26_;
#line 5732 "SourceList.c"
		}
#line 1180 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (expandable);
#line 5736 "SourceList.c"
	}
#line 1196 "../lib/Widgets/SourceList.vala"
	_tmp27_ = self->priv->filter_func;
#line 1196 "../lib/Widgets/SourceList.vala"
	_tmp27__target = self->priv->filter_func_target;
#line 1196 "../lib/Widgets/SourceList.vala"
	if (_tmp27_ != NULL) {
#line 5744 "SourceList.c"
		gboolean _tmp28_ = FALSE;
#line 1197 "../lib/Widgets/SourceList.vala"
		if (item_visible) {
#line 5748 "SourceList.c"
			GraniteWidgetsSourceListVisibleFunc _tmp29_;
			gpointer _tmp29__target;
			GraniteWidgetsSourceListItem* _tmp30_;
#line 1197 "../lib/Widgets/SourceList.vala"
			_tmp29_ = self->priv->filter_func;
#line 1197 "../lib/Widgets/SourceList.vala"
			_tmp29__target = self->priv->filter_func_target;
#line 1197 "../lib/Widgets/SourceList.vala"
			_tmp30_ = item;
#line 1197 "../lib/Widgets/SourceList.vala"
			_tmp28_ = _tmp29_ (_tmp30_, _tmp29__target);
#line 5760 "SourceList.c"
		} else {
#line 1197 "../lib/Widgets/SourceList.vala"
			_tmp28_ = FALSE;
#line 5764 "SourceList.c"
		}
#line 1197 "../lib/Widgets/SourceList.vala"
		item_visible = _tmp28_;
#line 5768 "SourceList.c"
	}
#line 1199 "../lib/Widgets/SourceList.vala"
	result = item_visible;
#line 1199 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (item);
#line 1199 "../lib/Widgets/SourceList.vala"
	return result;
#line 5776 "SourceList.c"
}

/**
         * TreeDragDest implementation
         */
static gboolean
granite_widgets_source_list_data_model_real_drag_data_received (GtkTreeDragDest* base,
                                                                GtkTreePath* dest,
                                                                GtkSelectionData* selection_data)
{
	GraniteWidgetsSourceListDataModel * self;
	GtkTreeModel* model = NULL;
	GtkTreePath* src_path = NULL;
	gboolean _tmp0_ = FALSE;
	GtkTreeModel* _tmp1_ = NULL;
	GtkTreePath* _tmp2_ = NULL;
	gboolean _tmp3_;
	GtkTreeModel* _tmp4_;
	gboolean result;
#line 1206 "../lib/Widgets/SourceList.vala"
	self = (GraniteWidgetsSourceListDataModel*) base;
#line 1206 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (dest != NULL, FALSE);
#line 1206 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (selection_data != NULL, FALSE);
#line 1214 "../lib/Widgets/SourceList.vala"
	_tmp3_ = gtk_tree_get_row_drag_data (selection_data, &_tmp1_, &_tmp2_);
#line 1214 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (model);
#line 1214 "../lib/Widgets/SourceList.vala"
	_tmp4_ = _g_object_ref0 (_tmp1_);
#line 1214 "../lib/Widgets/SourceList.vala"
	model = _tmp4_;
#line 1214 "../lib/Widgets/SourceList.vala"
	__vala_GtkTreePath_free0 (src_path);
#line 1214 "../lib/Widgets/SourceList.vala"
	src_path = _tmp2_;
#line 1214 "../lib/Widgets/SourceList.vala"
	if (_tmp3_) {
#line 5816 "SourceList.c"
		GtkTreeModel* _tmp5_;
		GtkTreeStore* _tmp6_;
#line 1214 "../lib/Widgets/SourceList.vala"
		_tmp5_ = model;
#line 1214 "../lib/Widgets/SourceList.vala"
		_tmp6_ = self->priv->child_tree;
#line 1214 "../lib/Widgets/SourceList.vala"
		_tmp0_ = _tmp5_ == G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, gtk_tree_model_get_type (), GtkTreeModel);
#line 5825 "SourceList.c"
	} else {
#line 1214 "../lib/Widgets/SourceList.vala"
		_tmp0_ = FALSE;
#line 5829 "SourceList.c"
	}
#line 1214 "../lib/Widgets/SourceList.vala"
	if (_tmp0_) {
#line 5833 "SourceList.c"
		GtkTreePath* child_dest = NULL;
		GtkTreePath* _tmp7_;
		GtkTreePath* _tmp8_;
#line 1216 "../lib/Widgets/SourceList.vala"
		_tmp7_ = gtk_tree_model_filter_convert_path_to_child_path ((GtkTreeModelFilter*) self, dest);
#line 1216 "../lib/Widgets/SourceList.vala"
		child_dest = _tmp7_;
#line 1218 "../lib/Widgets/SourceList.vala"
		_tmp8_ = child_dest;
#line 1218 "../lib/Widgets/SourceList.vala"
		if (_tmp8_ != NULL) {
#line 5845 "SourceList.c"
			GtkTreePath* _tmp9_;
			GtkTreePath* _tmp10_;
#line 1220 "../lib/Widgets/SourceList.vala"
			_tmp9_ = child_dest;
#line 1220 "../lib/Widgets/SourceList.vala"
			_tmp10_ = src_path;
#line 1220 "../lib/Widgets/SourceList.vala"
			if (granite_widgets_source_list_data_model_child_tree_drag_data_received (self, _tmp9_, _tmp10_)) {
#line 1221 "../lib/Widgets/SourceList.vala"
				result = TRUE;
#line 1221 "../lib/Widgets/SourceList.vala"
				__vala_GtkTreePath_free0 (child_dest);
#line 1221 "../lib/Widgets/SourceList.vala"
				__vala_GtkTreePath_free0 (src_path);
#line 1221 "../lib/Widgets/SourceList.vala"
				_g_object_unref0 (model);
#line 1221 "../lib/Widgets/SourceList.vala"
				return result;
#line 5864 "SourceList.c"
			}
		}
#line 1214 "../lib/Widgets/SourceList.vala"
		__vala_GtkTreePath_free0 (child_dest);
#line 5869 "SourceList.c"
	}
#line 1226 "../lib/Widgets/SourceList.vala"
	result = FALSE;
#line 1226 "../lib/Widgets/SourceList.vala"
	__vala_GtkTreePath_free0 (src_path);
#line 1226 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (model);
#line 1226 "../lib/Widgets/SourceList.vala"
	return result;
#line 5879 "SourceList.c"
}

static GtkTreePath*
_vala_GtkTreePath_copy (GtkTreePath* self)
{
#line 1236 "../lib/Widgets/SourceList.vala"
	return g_boxed_copy (gtk_tree_path_get_type (), self);
#line 5887 "SourceList.c"
}

static gpointer
__vala_GtkTreePath_copy0 (gpointer self)
{
#line 1236 "../lib/Widgets/SourceList.vala"
	return self ? _vala_GtkTreePath_copy (self) : NULL;
#line 5895 "SourceList.c"
}

static gboolean
granite_widgets_source_list_data_model_child_tree_drag_data_received (GraniteWidgetsSourceListDataModel* self,
                                                                      GtkTreePath* dest,
                                                                      GtkTreePath* src_path)
{
	gboolean retval = FALSE;
	GtkTreeIter src_iter = {0};
	GtkTreeIter dest_iter = {0};
	GtkTreeStore* _tmp0_;
	GtkTreeIter _tmp1_ = {0};
	gboolean _tmp2_;
	GtkTreePath* prev = NULL;
	GtkTreePath* _tmp3_;
	GtkTreePath* _tmp4_;
	gboolean result;
#line 1229 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 1229 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (dest != NULL, FALSE);
#line 1229 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (src_path != NULL, FALSE);
#line 1230 "../lib/Widgets/SourceList.vala"
	retval = FALSE;
#line 1233 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->child_tree;
#line 1233 "../lib/Widgets/SourceList.vala"
	_tmp2_ = gtk_tree_model_get_iter ((GtkTreeModel*) _tmp0_, &_tmp1_, src_path);
#line 1233 "../lib/Widgets/SourceList.vala"
	src_iter = _tmp1_;
#line 1233 "../lib/Widgets/SourceList.vala"
	if (!_tmp2_) {
#line 1234 "../lib/Widgets/SourceList.vala"
		result = FALSE;
#line 1234 "../lib/Widgets/SourceList.vala"
		return result;
#line 5933 "SourceList.c"
	}
#line 1236 "../lib/Widgets/SourceList.vala"
	_tmp3_ = __vala_GtkTreePath_copy0 (dest);
#line 1236 "../lib/Widgets/SourceList.vala"
	prev = _tmp3_;
#line 1239 "../lib/Widgets/SourceList.vala"
	_tmp4_ = prev;
#line 1239 "../lib/Widgets/SourceList.vala"
	if (!gtk_tree_path_prev (_tmp4_)) {
#line 5943 "SourceList.c"
		GtkTreePath* parent = NULL;
		GtkTreePath* _tmp5_;
		GtkTreeIter* dest_parent = NULL;
		gboolean _tmp6_ = FALSE;
		GtkTreePath* _tmp7_;
		GtkTreeStore* _tmp14_;
		GtkTreeIter* _tmp15_;
		GtkTreeIter _tmp16_ = {0};
#line 1243 "../lib/Widgets/SourceList.vala"
		_tmp5_ = __vala_GtkTreePath_copy0 (dest);
#line 1243 "../lib/Widgets/SourceList.vala"
		parent = _tmp5_;
#line 1244 "../lib/Widgets/SourceList.vala"
		dest_parent = NULL;
#line 1246 "../lib/Widgets/SourceList.vala"
		_tmp7_ = parent;
#line 1246 "../lib/Widgets/SourceList.vala"
		if (gtk_tree_path_up (_tmp7_)) {
#line 5962 "SourceList.c"
			GtkTreePath* _tmp8_;
#line 1246 "../lib/Widgets/SourceList.vala"
			_tmp8_ = parent;
#line 1246 "../lib/Widgets/SourceList.vala"
			_tmp6_ = gtk_tree_path_get_depth (_tmp8_) > 0;
#line 5968 "SourceList.c"
		} else {
#line 1246 "../lib/Widgets/SourceList.vala"
			_tmp6_ = FALSE;
#line 5972 "SourceList.c"
		}
#line 1246 "../lib/Widgets/SourceList.vala"
		if (_tmp6_) {
#line 5976 "SourceList.c"
			GtkTreeStore* _tmp9_;
			GtkTreePath* _tmp10_;
			GtkTreeIter _tmp11_ = {0};
			GtkTreeIter _tmp12_;
			GtkTreeIter* _tmp13_;
#line 1247 "../lib/Widgets/SourceList.vala"
			_tmp9_ = self->priv->child_tree;
#line 1247 "../lib/Widgets/SourceList.vala"
			_tmp10_ = parent;
#line 1247 "../lib/Widgets/SourceList.vala"
			gtk_tree_model_get_iter ((GtkTreeModel*) _tmp9_, &_tmp11_, _tmp10_);
#line 1247 "../lib/Widgets/SourceList.vala"
			__vala_GtkTreeIter_free0 (dest_parent);
#line 1247 "../lib/Widgets/SourceList.vala"
			_tmp12_ = _tmp11_;
#line 1247 "../lib/Widgets/SourceList.vala"
			_tmp13_ = __vala_GtkTreeIter_copy0 (&_tmp12_);
#line 1247 "../lib/Widgets/SourceList.vala"
			dest_parent = _tmp13_;
#line 5996 "SourceList.c"
		}
#line 1249 "../lib/Widgets/SourceList.vala"
		_tmp14_ = self->priv->child_tree;
#line 1249 "../lib/Widgets/SourceList.vala"
		_tmp15_ = dest_parent;
#line 1249 "../lib/Widgets/SourceList.vala"
		gtk_tree_store_prepend (_tmp14_, &_tmp16_, _tmp15_);
#line 1249 "../lib/Widgets/SourceList.vala"
		dest_iter = _tmp16_;
#line 1250 "../lib/Widgets/SourceList.vala"
		retval = TRUE;
#line 1239 "../lib/Widgets/SourceList.vala"
		__vala_GtkTreeIter_free0 (dest_parent);
#line 1239 "../lib/Widgets/SourceList.vala"
		__vala_GtkTreePath_free0 (parent);
#line 6012 "SourceList.c"
	} else {
		GtkTreeStore* _tmp17_;
		GtkTreePath* _tmp18_;
		GtkTreeIter _tmp19_ = {0};
		gboolean _tmp20_;
#line 1251 "../lib/Widgets/SourceList.vala"
		_tmp17_ = self->priv->child_tree;
#line 1251 "../lib/Widgets/SourceList.vala"
		_tmp18_ = prev;
#line 1251 "../lib/Widgets/SourceList.vala"
		_tmp20_ = gtk_tree_model_get_iter ((GtkTreeModel*) _tmp17_, &_tmp19_, _tmp18_);
#line 1251 "../lib/Widgets/SourceList.vala"
		dest_iter = _tmp19_;
#line 1251 "../lib/Widgets/SourceList.vala"
		if (_tmp20_) {
#line 6028 "SourceList.c"
			GtkTreeIter tmp_iter = {0};
			GtkTreeIter _tmp21_;
			GtkTreeStore* _tmp22_;
			GtkTreeIter _tmp23_;
			GtkTreeIter _tmp24_ = {0};
#line 1252 "../lib/Widgets/SourceList.vala"
			_tmp21_ = dest_iter;
#line 1252 "../lib/Widgets/SourceList.vala"
			tmp_iter = _tmp21_;
#line 1253 "../lib/Widgets/SourceList.vala"
			_tmp22_ = self->priv->child_tree;
#line 1253 "../lib/Widgets/SourceList.vala"
			_tmp23_ = tmp_iter;
#line 1253 "../lib/Widgets/SourceList.vala"
			gtk_tree_store_insert_after (_tmp22_, &_tmp24_, NULL, &_tmp23_);
#line 1253 "../lib/Widgets/SourceList.vala"
			dest_iter = _tmp24_;
#line 1254 "../lib/Widgets/SourceList.vala"
			retval = TRUE;
#line 6048 "SourceList.c"
		}
	}
#line 1259 "../lib/Widgets/SourceList.vala"
	if (retval) {
#line 6053 "SourceList.c"
		GtkTreeIter _tmp25_;
		GtkTreeIter _tmp26_;
		GraniteWidgetsSourceListItem* item = NULL;
		GtkTreeStore* _tmp27_;
		GtkTreeIter _tmp28_;
		GraniteWidgetsSourceListItem* _tmp29_ = NULL;
		GraniteWidgetsSourceListItem* _tmp30_;
		GraniteWidgetsSourceListItem* _tmp31_;
		GraniteWidgetsSourceListSortable* parent = NULL;
		GraniteWidgetsSourceListItem* _tmp32_;
		GraniteWidgetsSourceListExpandableItem* _tmp33_;
		GraniteWidgetsSourceListExpandableItem* _tmp34_;
		GraniteWidgetsSourceListSortable* _tmp35_;
		GraniteWidgetsSourceListSortable* _tmp36_;
		GraniteWidgetsSourceListSortable* _tmp37_;
		GraniteWidgetsSourceListItem* _tmp38_;
#line 1260 "../lib/Widgets/SourceList.vala"
		_tmp25_ = src_iter;
#line 1260 "../lib/Widgets/SourceList.vala"
		_tmp26_ = dest_iter;
#line 1260 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_data_model_recursive_node_copy (self, &_tmp25_, &_tmp26_);
#line 1264 "../lib/Widgets/SourceList.vala"
		_tmp27_ = self->priv->child_tree;
#line 1264 "../lib/Widgets/SourceList.vala"
		_tmp28_ = src_iter;
#line 1264 "../lib/Widgets/SourceList.vala"
		gtk_tree_model_get ((GtkTreeModel*) _tmp27_, &_tmp28_, GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_COLUMN_ITEM, &_tmp29_, -1, -1);
#line 1264 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (item);
#line 1264 "../lib/Widgets/SourceList.vala"
		item = _tmp29_;
#line 1265 "../lib/Widgets/SourceList.vala"
		_tmp30_ = item;
#line 1265 "../lib/Widgets/SourceList.vala"
		g_return_val_if_fail (_tmp30_ != NULL, retval);
#line 1274 "../lib/Widgets/SourceList.vala"
		_tmp31_ = item;
#line 1274 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_data_model_update_item (self, _tmp31_);
#line 1276 "../lib/Widgets/SourceList.vala"
		_tmp32_ = item;
#line 1276 "../lib/Widgets/SourceList.vala"
		_tmp33_ = granite_widgets_source_list_item_get_parent (_tmp32_);
#line 1276 "../lib/Widgets/SourceList.vala"
		_tmp34_ = _tmp33_;
#line 1276 "../lib/Widgets/SourceList.vala"
		_tmp35_ = _g_object_ref0 (GRANITE_WIDGETS_IS_SOURCE_LIST_SORTABLE (_tmp34_) ? ((GraniteWidgetsSourceListSortable*) _tmp34_) : NULL);
#line 1276 "../lib/Widgets/SourceList.vala"
		parent = _tmp35_;
#line 1277 "../lib/Widgets/SourceList.vala"
		_tmp36_ = parent;
#line 1277 "../lib/Widgets/SourceList.vala"
		g_return_val_if_fail (_tmp36_ != NULL, retval);
#line 1279 "../lib/Widgets/SourceList.vala"
		_tmp37_ = parent;
#line 1279 "../lib/Widgets/SourceList.vala"
		_tmp38_ = item;
#line 1279 "../lib/Widgets/SourceList.vala"
		g_signal_emit (_tmp37_, granite_widgets_source_list_sortable_signals[GRANITE_WIDGETS_SOURCE_LIST_SORTABLE_USER_MOVED_ITEM_SIGNAL], 0, _tmp38_);
#line 1259 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (parent);
#line 1259 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (item);
#line 6118 "SourceList.c"
	}
#line 1282 "../lib/Widgets/SourceList.vala"
	result = retval;
#line 1282 "../lib/Widgets/SourceList.vala"
	__vala_GtkTreePath_free0 (prev);
#line 1282 "../lib/Widgets/SourceList.vala"
	return result;
#line 6126 "SourceList.c"
}

static void
granite_widgets_source_list_data_model_recursive_node_copy (GraniteWidgetsSourceListDataModel* self,
                                                            GtkTreeIter* src_iter,
                                                            GtkTreeIter* dest_iter)
{
	GtkTreeIter _tmp0_;
	GtkTreeIter _tmp1_;
	GtkTreeIter child = {0};
	GtkTreeStore* _tmp2_;
	GtkTreeIter _tmp3_;
	GtkTreeIter _tmp4_ = {0};
	gboolean _tmp5_;
#line 1285 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 1285 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (src_iter != NULL);
#line 1285 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (dest_iter != NULL);
#line 1286 "../lib/Widgets/SourceList.vala"
	_tmp0_ = *src_iter;
#line 1286 "../lib/Widgets/SourceList.vala"
	_tmp1_ = *dest_iter;
#line 1286 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_data_model_move_item (self, &_tmp0_, &_tmp1_);
#line 1289 "../lib/Widgets/SourceList.vala"
	_tmp2_ = self->priv->child_tree;
#line 1289 "../lib/Widgets/SourceList.vala"
	_tmp3_ = *src_iter;
#line 1289 "../lib/Widgets/SourceList.vala"
	_tmp5_ = gtk_tree_model_iter_children ((GtkTreeModel*) _tmp2_, &_tmp4_, &_tmp3_);
#line 1289 "../lib/Widgets/SourceList.vala"
	child = _tmp4_;
#line 1289 "../lib/Widgets/SourceList.vala"
	if (_tmp5_) {
#line 6163 "SourceList.c"
		{
			gboolean _tmp6_ = FALSE;
#line 1292 "../lib/Widgets/SourceList.vala"
			_tmp6_ = TRUE;
#line 1292 "../lib/Widgets/SourceList.vala"
			while (TRUE) {
#line 6170 "SourceList.c"
				GtkTreeIter copy = {0};
				GtkTreeStore* _tmp9_;
				GtkTreeIter _tmp10_;
				GtkTreeIter _tmp11_ = {0};
				GtkTreeIter _tmp12_;
				GtkTreeIter _tmp13_;
#line 1292 "../lib/Widgets/SourceList.vala"
				if (!_tmp6_) {
#line 6179 "SourceList.c"
					GtkTreeStore* _tmp7_;
					gboolean _tmp8_;
#line 1296 "../lib/Widgets/SourceList.vala"
					_tmp7_ = self->priv->child_tree;
#line 1296 "../lib/Widgets/SourceList.vala"
					_tmp8_ = gtk_tree_model_iter_next ((GtkTreeModel*) _tmp7_, &child);
#line 1296 "../lib/Widgets/SourceList.vala"
					if (!_tmp8_) {
#line 1296 "../lib/Widgets/SourceList.vala"
						break;
#line 6190 "SourceList.c"
					}
				}
#line 1292 "../lib/Widgets/SourceList.vala"
				_tmp6_ = FALSE;
#line 1294 "../lib/Widgets/SourceList.vala"
				_tmp9_ = self->priv->child_tree;
#line 1294 "../lib/Widgets/SourceList.vala"
				_tmp10_ = *dest_iter;
#line 1294 "../lib/Widgets/SourceList.vala"
				gtk_tree_store_append (_tmp9_, &_tmp11_, &_tmp10_);
#line 1294 "../lib/Widgets/SourceList.vala"
				copy = _tmp11_;
#line 1295 "../lib/Widgets/SourceList.vala"
				_tmp12_ = child;
#line 1295 "../lib/Widgets/SourceList.vala"
				_tmp13_ = copy;
#line 1295 "../lib/Widgets/SourceList.vala"
				granite_widgets_source_list_data_model_recursive_node_copy (self, &_tmp12_, &_tmp13_);
#line 6209 "SourceList.c"
			}
		}
	}
}

static void
granite_widgets_source_list_data_model_move_item (GraniteWidgetsSourceListDataModel* self,
                                                  GtkTreeIter* src_iter,
                                                  GtkTreeIter* dest_iter)
{
	GraniteWidgetsSourceListItem* item = NULL;
	GtkTreeStore* _tmp0_;
	GtkTreeIter _tmp1_;
	GraniteWidgetsSourceListItem* _tmp2_ = NULL;
	GtkTreeStore* _tmp3_;
	GtkTreeIter _tmp4_;
	GeeHashMap* _tmp5_;
	GtkTreeStore* _tmp6_;
	GtkTreeIter _tmp7_;
	GraniteWidgetsSourceListDataModelNodeWrapper* _tmp8_;
	GraniteWidgetsSourceListDataModelNodeWrapper* _tmp9_;
#line 1300 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 1300 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (src_iter != NULL);
#line 1300 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (dest_iter != NULL);
#line 1302 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->child_tree;
#line 1302 "../lib/Widgets/SourceList.vala"
	_tmp1_ = *src_iter;
#line 1302 "../lib/Widgets/SourceList.vala"
	gtk_tree_model_get ((GtkTreeModel*) _tmp0_, &_tmp1_, GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_COLUMN_ITEM, &_tmp2_, -1, -1);
#line 1302 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (item);
#line 1302 "../lib/Widgets/SourceList.vala"
	item = _tmp2_;
#line 1303 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (item != NULL);
#line 1306 "../lib/Widgets/SourceList.vala"
	_tmp3_ = self->priv->child_tree;
#line 1306 "../lib/Widgets/SourceList.vala"
	_tmp4_ = *dest_iter;
#line 1306 "../lib/Widgets/SourceList.vala"
	gtk_tree_store_set (_tmp3_, &_tmp4_, GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_COLUMN_ITEM, item, -1, -1);
#line 1307 "../lib/Widgets/SourceList.vala"
	_tmp5_ = self->priv->items;
#line 1307 "../lib/Widgets/SourceList.vala"
	_tmp6_ = self->priv->child_tree;
#line 1307 "../lib/Widgets/SourceList.vala"
	_tmp7_ = *dest_iter;
#line 1307 "../lib/Widgets/SourceList.vala"
	_tmp8_ = granite_widgets_source_list_data_model_node_wrapper_new ((GtkTreeModel*) _tmp6_, &_tmp7_);
#line 1307 "../lib/Widgets/SourceList.vala"
	_tmp9_ = _tmp8_;
#line 1307 "../lib/Widgets/SourceList.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp5_, item, _tmp9_);
#line 1307 "../lib/Widgets/SourceList.vala"
	_granite_widgets_source_list_data_model_node_wrapper_unref0 (_tmp9_);
#line 1300 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (item);
#line 6271 "SourceList.c"
}

static gint*
_vala_array_dup1 (gint* self,
                  gssize length)
{
#line 1354 "../lib/Widgets/SourceList.vala"
	if (length > 0) {
#line 1354 "../lib/Widgets/SourceList.vala"
		return _vala_memdup2 (self, length * sizeof (gint));
#line 6282 "SourceList.c"
	}
#line 1354 "../lib/Widgets/SourceList.vala"
	return NULL;
#line 6286 "SourceList.c"
}

static gint*
_vala_array_dup2 (gint* self,
                  gssize length)
{
#line 1355 "../lib/Widgets/SourceList.vala"
	if (length > 0) {
#line 1355 "../lib/Widgets/SourceList.vala"
		return _vala_memdup2 (self, length * sizeof (gint));
#line 6297 "SourceList.c"
	}
#line 1355 "../lib/Widgets/SourceList.vala"
	return NULL;
#line 6301 "SourceList.c"
}

static gboolean
granite_widgets_source_list_data_model_real_row_drop_possible (GtkTreeDragDest* base,
                                                               GtkTreePath* dest,
                                                               GtkSelectionData* selection_data)
{
	GraniteWidgetsSourceListDataModel * self;
	GtkTreeModel* model = NULL;
	GtkTreePath* src_path = NULL;
	gboolean _tmp0_ = FALSE;
	GtkTreeModel* _tmp1_ = NULL;
	GtkTreePath* _tmp2_ = NULL;
	gboolean _tmp3_;
	GtkTreeModel* _tmp4_;
	GtkTreePath* child_dest = NULL;
	GtkTreePath* _tmp7_;
	gboolean _tmp8_ = FALSE;
	GtkTreePath* _tmp9_;
	gint src_depth = 0;
	GtkTreePath* _tmp12_;
	gint dest_depth = 0;
	GtkTreePath* _tmp13_;
	GraniteWidgetsSourceListItem* parent = NULL;
	GraniteWidgetsSourceListSortable* sortable = NULL;
	GraniteWidgetsSourceListItem* _tmp35_;
	GraniteWidgetsSourceListSortable* _tmp36_;
	gboolean _tmp37_ = FALSE;
	GraniteWidgetsSourceListSortable* _tmp38_;
	GraniteWidgetsSourceListItem* dest_item = NULL;
	GraniteWidgetsSourceListItem* _tmp40_;
	GraniteWidgetsSourceListItem* _tmp41_;
	GraniteWidgetsSourceListItem* source_item = NULL;
	GtkTreePath* filter_src_path = NULL;
	GtkTreePath* _tmp42_;
	GtkTreePath* _tmp43_;
	GtkTreePath* _tmp44_;
	GraniteWidgetsSourceListItem* _tmp47_;
	GraniteWidgetsSourceListSortable* _tmp48_;
	GraniteWidgetsSourceListItem* _tmp49_;
	GraniteWidgetsSourceListItem* _tmp50_;
	gboolean result;
#line 1310 "../lib/Widgets/SourceList.vala"
	self = (GraniteWidgetsSourceListDataModel*) base;
#line 1310 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (dest != NULL, FALSE);
#line 1310 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (selection_data != NULL, FALSE);
#line 1317 "../lib/Widgets/SourceList.vala"
	_tmp3_ = gtk_tree_get_row_drag_data (selection_data, &_tmp1_, &_tmp2_);
#line 1317 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (model);
#line 1317 "../lib/Widgets/SourceList.vala"
	_tmp4_ = _g_object_ref0 (_tmp1_);
#line 1317 "../lib/Widgets/SourceList.vala"
	model = _tmp4_;
#line 1317 "../lib/Widgets/SourceList.vala"
	__vala_GtkTreePath_free0 (src_path);
#line 1317 "../lib/Widgets/SourceList.vala"
	src_path = _tmp2_;
#line 1317 "../lib/Widgets/SourceList.vala"
	if (!_tmp3_) {
#line 1317 "../lib/Widgets/SourceList.vala"
		_tmp0_ = TRUE;
#line 6366 "SourceList.c"
	} else {
		GtkTreeModel* _tmp5_;
		GtkTreeStore* _tmp6_;
#line 1317 "../lib/Widgets/SourceList.vala"
		_tmp5_ = model;
#line 1317 "../lib/Widgets/SourceList.vala"
		_tmp6_ = self->priv->child_tree;
#line 1317 "../lib/Widgets/SourceList.vala"
		_tmp0_ = _tmp5_ != G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, gtk_tree_model_get_type (), GtkTreeModel);
#line 6376 "SourceList.c"
	}
#line 1317 "../lib/Widgets/SourceList.vala"
	if (_tmp0_) {
#line 1318 "../lib/Widgets/SourceList.vala"
		result = FALSE;
#line 1318 "../lib/Widgets/SourceList.vala"
		__vala_GtkTreePath_free0 (src_path);
#line 1318 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (model);
#line 1318 "../lib/Widgets/SourceList.vala"
		return result;
#line 6388 "SourceList.c"
	}
#line 1321 "../lib/Widgets/SourceList.vala"
	_tmp7_ = gtk_tree_model_filter_convert_path_to_child_path ((GtkTreeModelFilter*) self, dest);
#line 1321 "../lib/Widgets/SourceList.vala"
	child_dest = _tmp7_;
#line 1324 "../lib/Widgets/SourceList.vala"
	_tmp9_ = child_dest;
#line 1324 "../lib/Widgets/SourceList.vala"
	if (_tmp9_ == NULL) {
#line 1324 "../lib/Widgets/SourceList.vala"
		_tmp8_ = TRUE;
#line 6400 "SourceList.c"
	} else {
		GtkTreePath* _tmp10_;
		GtkTreePath* _tmp11_;
#line 1324 "../lib/Widgets/SourceList.vala"
		_tmp10_ = src_path;
#line 1324 "../lib/Widgets/SourceList.vala"
		_tmp11_ = child_dest;
#line 1324 "../lib/Widgets/SourceList.vala"
		_tmp8_ = gtk_tree_path_compare (_tmp10_, _tmp11_) == 0;
#line 6410 "SourceList.c"
	}
#line 1324 "../lib/Widgets/SourceList.vala"
	if (_tmp8_) {
#line 1325 "../lib/Widgets/SourceList.vala"
		result = FALSE;
#line 1325 "../lib/Widgets/SourceList.vala"
		__vala_GtkTreePath_free0 (child_dest);
#line 1325 "../lib/Widgets/SourceList.vala"
		__vala_GtkTreePath_free0 (src_path);
#line 1325 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (model);
#line 1325 "../lib/Widgets/SourceList.vala"
		return result;
#line 6424 "SourceList.c"
	}
#line 1329 "../lib/Widgets/SourceList.vala"
	_tmp12_ = src_path;
#line 1329 "../lib/Widgets/SourceList.vala"
	src_depth = gtk_tree_path_get_depth (_tmp12_);
#line 1330 "../lib/Widgets/SourceList.vala"
	_tmp13_ = child_dest;
#line 1330 "../lib/Widgets/SourceList.vala"
	dest_depth = gtk_tree_path_get_depth (_tmp13_);
#line 1332 "../lib/Widgets/SourceList.vala"
	if (src_depth != dest_depth) {
#line 1333 "../lib/Widgets/SourceList.vala"
		result = FALSE;
#line 1333 "../lib/Widgets/SourceList.vala"
		__vala_GtkTreePath_free0 (child_dest);
#line 1333 "../lib/Widgets/SourceList.vala"
		__vala_GtkTreePath_free0 (src_path);
#line 1333 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (model);
#line 1333 "../lib/Widgets/SourceList.vala"
		return result;
#line 6446 "SourceList.c"
	}
#line 1336 "../lib/Widgets/SourceList.vala"
	if (src_depth < 1) {
#line 1337 "../lib/Widgets/SourceList.vala"
		result = FALSE;
#line 1337 "../lib/Widgets/SourceList.vala"
		__vala_GtkTreePath_free0 (child_dest);
#line 1337 "../lib/Widgets/SourceList.vala"
		__vala_GtkTreePath_free0 (src_path);
#line 1337 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (model);
#line 1337 "../lib/Widgets/SourceList.vala"
		return result;
#line 6460 "SourceList.c"
	}
#line 1339 "../lib/Widgets/SourceList.vala"
	parent = NULL;
#line 1344 "../lib/Widgets/SourceList.vala"
	if (src_depth == 1) {
#line 6466 "SourceList.c"
		GraniteWidgetsSourceListExpandableItem* _tmp14_;
		GraniteWidgetsSourceListExpandableItem* _tmp15_;
		GraniteWidgetsSourceListItem* _tmp16_;
#line 1345 "../lib/Widgets/SourceList.vala"
		_tmp14_ = granite_widgets_source_list_data_model_get_root (self);
#line 1345 "../lib/Widgets/SourceList.vala"
		_tmp15_ = _tmp14_;
#line 1345 "../lib/Widgets/SourceList.vala"
		_tmp16_ = _g_object_ref0 ((GraniteWidgetsSourceListItem*) _tmp15_);
#line 1345 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (parent);
#line 1345 "../lib/Widgets/SourceList.vala"
		parent = _tmp16_;
#line 6480 "SourceList.c"
	} else {
		gint* src_indices = NULL;
		GtkTreePath* _tmp17_;
		gint _tmp18_ = 0;
		gint* _tmp19_;
		gint* _tmp20_;
		gint _tmp20__length1;
		gint src_indices_length1;
		gint _src_indices_size_;
		gint* dest_indices = NULL;
		GtkTreePath* _tmp21_;
		gint _tmp22_ = 0;
		gint* _tmp23_;
		gint* _tmp24_;
		gint _tmp24__length1;
		gint dest_indices_length1;
		gint _dest_indices_size_;
		gint src_parent_index = 0;
		gint* _tmp25_;
		gint _tmp25__length1;
		gint _tmp26_;
		gint dest_parent_index = 0;
		gint* _tmp27_;
		gint _tmp27__length1;
		gint _tmp28_;
		GtkTreePath* dest_parent = NULL;
		GtkTreePath* _tmp29_;
		gboolean _tmp30_ = FALSE;
		GtkTreePath* _tmp31_;
		GtkTreePath* _tmp33_;
		GraniteWidgetsSourceListItem* _tmp34_;
#line 1348 "../lib/Widgets/SourceList.vala"
		_vala_assert (dest_depth > 1, "dest_depth > 1");
#line 1354 "../lib/Widgets/SourceList.vala"
		_tmp17_ = src_path;
#line 1354 "../lib/Widgets/SourceList.vala"
		_tmp19_ = gtk_tree_path_get_indices_with_depth (_tmp17_, &_tmp18_);
#line 1354 "../lib/Widgets/SourceList.vala"
		_tmp20_ = (_tmp19_ != NULL) ? _vala_array_dup1 (_tmp19_, _tmp18_) : _tmp19_;
#line 1354 "../lib/Widgets/SourceList.vala"
		_tmp20__length1 = _tmp18_;
#line 1354 "../lib/Widgets/SourceList.vala"
		src_indices = _tmp20_;
#line 1354 "../lib/Widgets/SourceList.vala"
		src_indices_length1 = _tmp20__length1;
#line 1354 "../lib/Widgets/SourceList.vala"
		_src_indices_size_ = src_indices_length1;
#line 1355 "../lib/Widgets/SourceList.vala"
		_tmp21_ = child_dest;
#line 1355 "../lib/Widgets/SourceList.vala"
		_tmp23_ = gtk_tree_path_get_indices_with_depth (_tmp21_, &_tmp22_);
#line 1355 "../lib/Widgets/SourceList.vala"
		_tmp24_ = (_tmp23_ != NULL) ? _vala_array_dup2 (_tmp23_, _tmp22_) : _tmp23_;
#line 1355 "../lib/Widgets/SourceList.vala"
		_tmp24__length1 = _tmp22_;
#line 1355 "../lib/Widgets/SourceList.vala"
		dest_indices = _tmp24_;
#line 1355 "../lib/Widgets/SourceList.vala"
		dest_indices_length1 = _tmp24__length1;
#line 1355 "../lib/Widgets/SourceList.vala"
		_dest_indices_size_ = dest_indices_length1;
#line 1358 "../lib/Widgets/SourceList.vala"
		_tmp25_ = src_indices;
#line 1358 "../lib/Widgets/SourceList.vala"
		_tmp25__length1 = src_indices_length1;
#line 1358 "../lib/Widgets/SourceList.vala"
		_tmp26_ = _tmp25_[src_depth - 2];
#line 1358 "../lib/Widgets/SourceList.vala"
		src_parent_index = _tmp26_;
#line 1359 "../lib/Widgets/SourceList.vala"
		_tmp27_ = dest_indices;
#line 1359 "../lib/Widgets/SourceList.vala"
		_tmp27__length1 = dest_indices_length1;
#line 1359 "../lib/Widgets/SourceList.vala"
		_tmp28_ = _tmp27_[dest_depth - 2];
#line 1359 "../lib/Widgets/SourceList.vala"
		dest_parent_index = _tmp28_;
#line 1361 "../lib/Widgets/SourceList.vala"
		if (src_parent_index != dest_parent_index) {
#line 1362 "../lib/Widgets/SourceList.vala"
			result = FALSE;
#line 1362 "../lib/Widgets/SourceList.vala"
			dest_indices = (g_free (dest_indices), NULL);
#line 1362 "../lib/Widgets/SourceList.vala"
			src_indices = (g_free (src_indices), NULL);
#line 1362 "../lib/Widgets/SourceList.vala"
			_g_object_unref0 (parent);
#line 1362 "../lib/Widgets/SourceList.vala"
			__vala_GtkTreePath_free0 (child_dest);
#line 1362 "../lib/Widgets/SourceList.vala"
			__vala_GtkTreePath_free0 (src_path);
#line 1362 "../lib/Widgets/SourceList.vala"
			_g_object_unref0 (model);
#line 1362 "../lib/Widgets/SourceList.vala"
			return result;
#line 6576 "SourceList.c"
		}
#line 1365 "../lib/Widgets/SourceList.vala"
		_tmp29_ = __vala_GtkTreePath_copy0 (dest);
#line 1365 "../lib/Widgets/SourceList.vala"
		dest_parent = _tmp29_;
#line 1367 "../lib/Widgets/SourceList.vala"
		_tmp31_ = dest_parent;
#line 1367 "../lib/Widgets/SourceList.vala"
		if (!gtk_tree_path_up (_tmp31_)) {
#line 1367 "../lib/Widgets/SourceList.vala"
			_tmp30_ = TRUE;
#line 6588 "SourceList.c"
		} else {
			GtkTreePath* _tmp32_;
#line 1367 "../lib/Widgets/SourceList.vala"
			_tmp32_ = dest_parent;
#line 1367 "../lib/Widgets/SourceList.vala"
			_tmp30_ = gtk_tree_path_get_depth (_tmp32_) < 1;
#line 6595 "SourceList.c"
		}
#line 1367 "../lib/Widgets/SourceList.vala"
		if (_tmp30_) {
#line 1368 "../lib/Widgets/SourceList.vala"
			result = FALSE;
#line 1368 "../lib/Widgets/SourceList.vala"
			__vala_GtkTreePath_free0 (dest_parent);
#line 1368 "../lib/Widgets/SourceList.vala"
			dest_indices = (g_free (dest_indices), NULL);
#line 1368 "../lib/Widgets/SourceList.vala"
			src_indices = (g_free (src_indices), NULL);
#line 1368 "../lib/Widgets/SourceList.vala"
			_g_object_unref0 (parent);
#line 1368 "../lib/Widgets/SourceList.vala"
			__vala_GtkTreePath_free0 (child_dest);
#line 1368 "../lib/Widgets/SourceList.vala"
			__vala_GtkTreePath_free0 (src_path);
#line 1368 "../lib/Widgets/SourceList.vala"
			_g_object_unref0 (model);
#line 1368 "../lib/Widgets/SourceList.vala"
			return result;
#line 6617 "SourceList.c"
		}
#line 1370 "../lib/Widgets/SourceList.vala"
		_tmp33_ = dest_parent;
#line 1370 "../lib/Widgets/SourceList.vala"
		_tmp34_ = granite_widgets_source_list_data_model_get_item_from_path (self, _tmp33_);
#line 1370 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (parent);
#line 1370 "../lib/Widgets/SourceList.vala"
		parent = _tmp34_;
#line 1344 "../lib/Widgets/SourceList.vala"
		__vala_GtkTreePath_free0 (dest_parent);
#line 1344 "../lib/Widgets/SourceList.vala"
		dest_indices = (g_free (dest_indices), NULL);
#line 1344 "../lib/Widgets/SourceList.vala"
		src_indices = (g_free (src_indices), NULL);
#line 6633 "SourceList.c"
	}
#line 1373 "../lib/Widgets/SourceList.vala"
	_tmp35_ = parent;
#line 1373 "../lib/Widgets/SourceList.vala"
	_tmp36_ = _g_object_ref0 (GRANITE_WIDGETS_IS_SOURCE_LIST_SORTABLE (_tmp35_) ? ((GraniteWidgetsSourceListSortable*) _tmp35_) : NULL);
#line 1373 "../lib/Widgets/SourceList.vala"
	sortable = _tmp36_;
#line 1375 "../lib/Widgets/SourceList.vala"
	_tmp38_ = sortable;
#line 1375 "../lib/Widgets/SourceList.vala"
	if (_tmp38_ == NULL) {
#line 1375 "../lib/Widgets/SourceList.vala"
		_tmp37_ = TRUE;
#line 6647 "SourceList.c"
	} else {
		GraniteWidgetsSourceListSortable* _tmp39_;
#line 1375 "../lib/Widgets/SourceList.vala"
		_tmp39_ = sortable;
#line 1375 "../lib/Widgets/SourceList.vala"
		_tmp37_ = !granite_widgets_source_list_sortable_allow_dnd_sorting (_tmp39_);
#line 6654 "SourceList.c"
	}
#line 1375 "../lib/Widgets/SourceList.vala"
	if (_tmp37_) {
#line 1376 "../lib/Widgets/SourceList.vala"
		result = FALSE;
#line 1376 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (sortable);
#line 1376 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (parent);
#line 1376 "../lib/Widgets/SourceList.vala"
		__vala_GtkTreePath_free0 (child_dest);
#line 1376 "../lib/Widgets/SourceList.vala"
		__vala_GtkTreePath_free0 (src_path);
#line 1376 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (model);
#line 1376 "../lib/Widgets/SourceList.vala"
		return result;
#line 6672 "SourceList.c"
	}
#line 1378 "../lib/Widgets/SourceList.vala"
	_tmp40_ = granite_widgets_source_list_data_model_get_item_from_path (self, dest);
#line 1378 "../lib/Widgets/SourceList.vala"
	dest_item = _tmp40_;
#line 1380 "../lib/Widgets/SourceList.vala"
	_tmp41_ = dest_item;
#line 1380 "../lib/Widgets/SourceList.vala"
	if (_tmp41_ == NULL) {
#line 1381 "../lib/Widgets/SourceList.vala"
		result = TRUE;
#line 1381 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (dest_item);
#line 1381 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (sortable);
#line 1381 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (parent);
#line 1381 "../lib/Widgets/SourceList.vala"
		__vala_GtkTreePath_free0 (child_dest);
#line 1381 "../lib/Widgets/SourceList.vala"
		__vala_GtkTreePath_free0 (src_path);
#line 1381 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (model);
#line 1381 "../lib/Widgets/SourceList.vala"
		return result;
#line 6698 "SourceList.c"
	}
#line 1383 "../lib/Widgets/SourceList.vala"
	source_item = NULL;
#line 1384 "../lib/Widgets/SourceList.vala"
	_tmp42_ = src_path;
#line 1384 "../lib/Widgets/SourceList.vala"
	_tmp43_ = gtk_tree_model_filter_convert_child_path_to_path ((GtkTreeModelFilter*) self, _tmp42_);
#line 1384 "../lib/Widgets/SourceList.vala"
	filter_src_path = _tmp43_;
#line 1386 "../lib/Widgets/SourceList.vala"
	_tmp44_ = filter_src_path;
#line 1386 "../lib/Widgets/SourceList.vala"
	if (_tmp44_ != NULL) {
#line 6712 "SourceList.c"
		GtkTreePath* _tmp45_;
		GraniteWidgetsSourceListItem* _tmp46_;
#line 1387 "../lib/Widgets/SourceList.vala"
		_tmp45_ = filter_src_path;
#line 1387 "../lib/Widgets/SourceList.vala"
		_tmp46_ = granite_widgets_source_list_data_model_get_item_from_path (self, _tmp45_);
#line 1387 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (source_item);
#line 1387 "../lib/Widgets/SourceList.vala"
		source_item = _tmp46_;
#line 6723 "SourceList.c"
	}
#line 1389 "../lib/Widgets/SourceList.vala"
	_tmp47_ = source_item;
#line 1389 "../lib/Widgets/SourceList.vala"
	if (_tmp47_ == NULL) {
#line 1390 "../lib/Widgets/SourceList.vala"
		result = FALSE;
#line 1390 "../lib/Widgets/SourceList.vala"
		__vala_GtkTreePath_free0 (filter_src_path);
#line 1390 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (source_item);
#line 1390 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (dest_item);
#line 1390 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (sortable);
#line 1390 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (parent);
#line 1390 "../lib/Widgets/SourceList.vala"
		__vala_GtkTreePath_free0 (child_dest);
#line 1390 "../lib/Widgets/SourceList.vala"
		__vala_GtkTreePath_free0 (src_path);
#line 1390 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (model);
#line 1390 "../lib/Widgets/SourceList.vala"
		return result;
#line 6749 "SourceList.c"
	}
#line 1398 "../lib/Widgets/SourceList.vala"
	_tmp48_ = sortable;
#line 1398 "../lib/Widgets/SourceList.vala"
	_tmp49_ = dest_item;
#line 1398 "../lib/Widgets/SourceList.vala"
	_tmp50_ = source_item;
#line 1398 "../lib/Widgets/SourceList.vala"
	if (granite_widgets_source_list_sortable_compare (_tmp48_, _tmp49_, _tmp50_) >= 0) {
#line 6759 "SourceList.c"
		GraniteWidgetsSourceListItem* dest_item_prev = NULL;
		GraniteWidgetsSourceListItem* _tmp51_;
		gboolean _tmp52_ = FALSE;
		gboolean _tmp53_ = FALSE;
		GraniteWidgetsSourceListItem* _tmp54_;
#line 1399 "../lib/Widgets/SourceList.vala"
		if (!gtk_tree_path_prev (dest)) {
#line 1400 "../lib/Widgets/SourceList.vala"
			result = TRUE;
#line 1400 "../lib/Widgets/SourceList.vala"
			__vala_GtkTreePath_free0 (filter_src_path);
#line 1400 "../lib/Widgets/SourceList.vala"
			_g_object_unref0 (source_item);
#line 1400 "../lib/Widgets/SourceList.vala"
			_g_object_unref0 (dest_item);
#line 1400 "../lib/Widgets/SourceList.vala"
			_g_object_unref0 (sortable);
#line 1400 "../lib/Widgets/SourceList.vala"
			_g_object_unref0 (parent);
#line 1400 "../lib/Widgets/SourceList.vala"
			__vala_GtkTreePath_free0 (child_dest);
#line 1400 "../lib/Widgets/SourceList.vala"
			__vala_GtkTreePath_free0 (src_path);
#line 1400 "../lib/Widgets/SourceList.vala"
			_g_object_unref0 (model);
#line 1400 "../lib/Widgets/SourceList.vala"
			return result;
#line 6787 "SourceList.c"
		}
#line 1404 "../lib/Widgets/SourceList.vala"
		_tmp51_ = granite_widgets_source_list_data_model_get_item_from_path (self, dest);
#line 1404 "../lib/Widgets/SourceList.vala"
		dest_item_prev = _tmp51_;
#line 1406 "../lib/Widgets/SourceList.vala"
		_tmp54_ = dest_item_prev;
#line 1406 "../lib/Widgets/SourceList.vala"
		if (_tmp54_ != NULL) {
#line 6797 "SourceList.c"
			GraniteWidgetsSourceListItem* _tmp55_;
			GraniteWidgetsSourceListItem* _tmp56_;
#line 1407 "../lib/Widgets/SourceList.vala"
			_tmp55_ = dest_item_prev;
#line 1407 "../lib/Widgets/SourceList.vala"
			_tmp56_ = source_item;
#line 1407 "../lib/Widgets/SourceList.vala"
			_tmp53_ = _tmp55_ != _tmp56_;
#line 6806 "SourceList.c"
		} else {
#line 1406 "../lib/Widgets/SourceList.vala"
			_tmp53_ = FALSE;
#line 6810 "SourceList.c"
		}
#line 1406 "../lib/Widgets/SourceList.vala"
		if (_tmp53_) {
#line 6814 "SourceList.c"
			GraniteWidgetsSourceListSortable* _tmp57_;
			GraniteWidgetsSourceListItem* _tmp58_;
			GraniteWidgetsSourceListItem* _tmp59_;
#line 1408 "../lib/Widgets/SourceList.vala"
			_tmp57_ = sortable;
#line 1408 "../lib/Widgets/SourceList.vala"
			_tmp58_ = dest_item_prev;
#line 1408 "../lib/Widgets/SourceList.vala"
			_tmp59_ = source_item;
#line 1408 "../lib/Widgets/SourceList.vala"
			_tmp52_ = granite_widgets_source_list_sortable_compare (_tmp57_, _tmp58_, _tmp59_) <= 0;
#line 6826 "SourceList.c"
		} else {
#line 1406 "../lib/Widgets/SourceList.vala"
			_tmp52_ = FALSE;
#line 6830 "SourceList.c"
		}
#line 1406 "../lib/Widgets/SourceList.vala"
		result = _tmp52_;
#line 1406 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (dest_item_prev);
#line 1406 "../lib/Widgets/SourceList.vala"
		__vala_GtkTreePath_free0 (filter_src_path);
#line 1406 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (source_item);
#line 1406 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (dest_item);
#line 1406 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (sortable);
#line 1406 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (parent);
#line 1406 "../lib/Widgets/SourceList.vala"
		__vala_GtkTreePath_free0 (child_dest);
#line 1406 "../lib/Widgets/SourceList.vala"
		__vala_GtkTreePath_free0 (src_path);
#line 1406 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (model);
#line 1406 "../lib/Widgets/SourceList.vala"
		return result;
#line 6854 "SourceList.c"
	}
#line 1411 "../lib/Widgets/SourceList.vala"
	result = FALSE;
#line 1411 "../lib/Widgets/SourceList.vala"
	__vala_GtkTreePath_free0 (filter_src_path);
#line 1411 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (source_item);
#line 1411 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (dest_item);
#line 1411 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (sortable);
#line 1411 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (parent);
#line 1411 "../lib/Widgets/SourceList.vala"
	__vala_GtkTreePath_free0 (child_dest);
#line 1411 "../lib/Widgets/SourceList.vala"
	__vala_GtkTreePath_free0 (src_path);
#line 1411 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (model);
#line 1411 "../lib/Widgets/SourceList.vala"
	return result;
#line 6876 "SourceList.c"
}

/**
         * Override default implementation of TreeDragSource
         *
         * drag_data_delete is not overriden because the default implementation
         * does exactly what we need.
         */
static gboolean
granite_widgets_source_list_data_model_real_drag_data_get (GtkTreeDragSource* base,
                                                           GtkTreePath* path,
                                                           GtkSelectionData* selection_data)
{
	GraniteWidgetsSourceListDataModel * self;
	GraniteWidgetsSourceListDragSource* drag_source_item = NULL;
	GraniteWidgetsSourceListItem* _tmp0_;
	GraniteWidgetsSourceListDragSource* _tmp1_;
	gboolean _tmp2_ = FALSE;
	GraniteWidgetsSourceListDragSource* _tmp3_;
	gboolean result;
#line 1421 "../lib/Widgets/SourceList.vala"
	self = (GraniteWidgetsSourceListDataModel*) base;
#line 1421 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (path != NULL, FALSE);
#line 1421 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (selection_data != NULL, FALSE);
#line 1424 "../lib/Widgets/SourceList.vala"
	if (gtk_selection_data_get_target (selection_data) == gdk_atom_intern_static_string ("GTK_TREE_MODEL_ROW")) {
#line 1425 "../lib/Widgets/SourceList.vala"
		result = granite_widgets_source_list_data_model_gtk_tree_drag_source_parent_iface->drag_data_get ((GtkTreeDragSource*) G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_model_filter_get_type (), GtkTreeModelFilter), path, selection_data);
#line 1425 "../lib/Widgets/SourceList.vala"
		return result;
#line 6909 "SourceList.c"
	}
#line 1428 "../lib/Widgets/SourceList.vala"
	_tmp0_ = granite_widgets_source_list_data_model_get_item_from_path (self, path);
#line 1428 "../lib/Widgets/SourceList.vala"
	_tmp1_ = GRANITE_WIDGETS_IS_SOURCE_LIST_DRAG_SOURCE (_tmp0_) ? ((GraniteWidgetsSourceListDragSource*) _tmp0_) : NULL;
#line 1428 "../lib/Widgets/SourceList.vala"
	if (_tmp1_ == NULL) {
#line 1428 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (_tmp0_);
#line 6919 "SourceList.c"
	}
#line 1428 "../lib/Widgets/SourceList.vala"
	drag_source_item = _tmp1_;
#line 1429 "../lib/Widgets/SourceList.vala"
	_tmp3_ = drag_source_item;
#line 1429 "../lib/Widgets/SourceList.vala"
	if (_tmp3_ != NULL) {
#line 6927 "SourceList.c"
		GraniteWidgetsSourceListDragSource* _tmp4_;
#line 1429 "../lib/Widgets/SourceList.vala"
		_tmp4_ = drag_source_item;
#line 1429 "../lib/Widgets/SourceList.vala"
		_tmp2_ = granite_widgets_source_list_drag_source_draggable (_tmp4_);
#line 6933 "SourceList.c"
	} else {
#line 1429 "../lib/Widgets/SourceList.vala"
		_tmp2_ = FALSE;
#line 6937 "SourceList.c"
	}
#line 1429 "../lib/Widgets/SourceList.vala"
	if (_tmp2_) {
#line 6941 "SourceList.c"
		GraniteWidgetsSourceListDragSource* _tmp5_;
#line 1430 "../lib/Widgets/SourceList.vala"
		_tmp5_ = drag_source_item;
#line 1430 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_drag_source_prepare_selection_data (_tmp5_, selection_data);
#line 1431 "../lib/Widgets/SourceList.vala"
		result = TRUE;
#line 1431 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (drag_source_item);
#line 1431 "../lib/Widgets/SourceList.vala"
		return result;
#line 6953 "SourceList.c"
	}
#line 1434 "../lib/Widgets/SourceList.vala"
	result = FALSE;
#line 1434 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (drag_source_item);
#line 1434 "../lib/Widgets/SourceList.vala"
	return result;
#line 6961 "SourceList.c"
}

static gboolean
granite_widgets_source_list_data_model_real_row_draggable (GtkTreeDragSource* base,
                                                           GtkTreePath* path)
{
	GraniteWidgetsSourceListDataModel * self;
	GraniteWidgetsSourceListItem* item = NULL;
	GraniteWidgetsSourceListItem* _tmp0_;
	GraniteWidgetsSourceListItem* _tmp1_;
	gboolean result;
#line 1437 "../lib/Widgets/SourceList.vala"
	self = (GraniteWidgetsSourceListDataModel*) base;
#line 1437 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (path != NULL, FALSE);
#line 1438 "../lib/Widgets/SourceList.vala"
	if (!granite_widgets_source_list_data_model_gtk_tree_drag_source_parent_iface->row_draggable ((GtkTreeDragSource*) G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_model_filter_get_type (), GtkTreeModelFilter), path)) {
#line 1439 "../lib/Widgets/SourceList.vala"
		result = FALSE;
#line 1439 "../lib/Widgets/SourceList.vala"
		return result;
#line 6983 "SourceList.c"
	}
#line 1441 "../lib/Widgets/SourceList.vala"
	_tmp0_ = granite_widgets_source_list_data_model_get_item_from_path (self, path);
#line 1441 "../lib/Widgets/SourceList.vala"
	item = _tmp0_;
#line 1443 "../lib/Widgets/SourceList.vala"
	_tmp1_ = item;
#line 1443 "../lib/Widgets/SourceList.vala"
	if (_tmp1_ != NULL) {
#line 6993 "SourceList.c"
		GraniteWidgetsSourceListSortable* sortable_item = NULL;
		GraniteWidgetsSourceListItem* _tmp2_;
		GraniteWidgetsSourceListExpandableItem* _tmp3_;
		GraniteWidgetsSourceListExpandableItem* _tmp4_;
		GraniteWidgetsSourceListSortable* _tmp5_;
		gboolean _tmp6_ = FALSE;
		GraniteWidgetsSourceListSortable* _tmp7_;
		GraniteWidgetsSourceListDragSource* drag_source_item = NULL;
		GraniteWidgetsSourceListItem* _tmp9_;
		GraniteWidgetsSourceListDragSource* _tmp10_;
		gboolean _tmp11_ = FALSE;
		GraniteWidgetsSourceListDragSource* _tmp12_;
#line 1445 "../lib/Widgets/SourceList.vala"
		_tmp2_ = item;
#line 1445 "../lib/Widgets/SourceList.vala"
		_tmp3_ = granite_widgets_source_list_item_get_parent (_tmp2_);
#line 1445 "../lib/Widgets/SourceList.vala"
		_tmp4_ = _tmp3_;
#line 1445 "../lib/Widgets/SourceList.vala"
		_tmp5_ = _g_object_ref0 (GRANITE_WIDGETS_IS_SOURCE_LIST_SORTABLE (_tmp4_) ? ((GraniteWidgetsSourceListSortable*) _tmp4_) : NULL);
#line 1445 "../lib/Widgets/SourceList.vala"
		sortable_item = _tmp5_;
#line 1447 "../lib/Widgets/SourceList.vala"
		_tmp7_ = sortable_item;
#line 1447 "../lib/Widgets/SourceList.vala"
		if (_tmp7_ != NULL) {
#line 7020 "SourceList.c"
			GraniteWidgetsSourceListSortable* _tmp8_;
#line 1447 "../lib/Widgets/SourceList.vala"
			_tmp8_ = sortable_item;
#line 1447 "../lib/Widgets/SourceList.vala"
			_tmp6_ = granite_widgets_source_list_sortable_allow_dnd_sorting (_tmp8_);
#line 7026 "SourceList.c"
		} else {
#line 1447 "../lib/Widgets/SourceList.vala"
			_tmp6_ = FALSE;
#line 7030 "SourceList.c"
		}
#line 1447 "../lib/Widgets/SourceList.vala"
		if (_tmp6_) {
#line 1448 "../lib/Widgets/SourceList.vala"
			result = TRUE;
#line 1448 "../lib/Widgets/SourceList.vala"
			_g_object_unref0 (sortable_item);
#line 1448 "../lib/Widgets/SourceList.vala"
			_g_object_unref0 (item);
#line 1448 "../lib/Widgets/SourceList.vala"
			return result;
#line 7042 "SourceList.c"
		}
#line 1452 "../lib/Widgets/SourceList.vala"
		_tmp9_ = item;
#line 1452 "../lib/Widgets/SourceList.vala"
		_tmp10_ = _g_object_ref0 (GRANITE_WIDGETS_IS_SOURCE_LIST_DRAG_SOURCE (_tmp9_) ? ((GraniteWidgetsSourceListDragSource*) _tmp9_) : NULL);
#line 1452 "../lib/Widgets/SourceList.vala"
		drag_source_item = _tmp10_;
#line 1454 "../lib/Widgets/SourceList.vala"
		_tmp12_ = drag_source_item;
#line 1454 "../lib/Widgets/SourceList.vala"
		if (_tmp12_ != NULL) {
#line 7054 "SourceList.c"
			GraniteWidgetsSourceListDragSource* _tmp13_;
#line 1454 "../lib/Widgets/SourceList.vala"
			_tmp13_ = drag_source_item;
#line 1454 "../lib/Widgets/SourceList.vala"
			_tmp11_ = granite_widgets_source_list_drag_source_draggable (_tmp13_);
#line 7060 "SourceList.c"
		} else {
#line 1454 "../lib/Widgets/SourceList.vala"
			_tmp11_ = FALSE;
#line 7064 "SourceList.c"
		}
#line 1454 "../lib/Widgets/SourceList.vala"
		if (_tmp11_) {
#line 1455 "../lib/Widgets/SourceList.vala"
			result = TRUE;
#line 1455 "../lib/Widgets/SourceList.vala"
			_g_object_unref0 (drag_source_item);
#line 1455 "../lib/Widgets/SourceList.vala"
			_g_object_unref0 (sortable_item);
#line 1455 "../lib/Widgets/SourceList.vala"
			_g_object_unref0 (item);
#line 1455 "../lib/Widgets/SourceList.vala"
			return result;
#line 7078 "SourceList.c"
		}
#line 1443 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (drag_source_item);
#line 1443 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (sortable_item);
#line 7084 "SourceList.c"
	}
#line 1458 "../lib/Widgets/SourceList.vala"
	result = FALSE;
#line 1458 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (item);
#line 1458 "../lib/Widgets/SourceList.vala"
	return result;
#line 7092 "SourceList.c"
}

static inline gpointer
granite_widgets_source_list_data_model_node_wrapper_get_instance_private (GraniteWidgetsSourceListDataModelNodeWrapper* self)
{
	return G_STRUCT_MEMBER_P (self, GraniteWidgetsSourceListDataModelNodeWrapper_private_offset);
}

static void
_vala_GtkTreeRowReference_free (GtkTreeRowReference* self)
{
#line 734 "../lib/Widgets/SourceList.vala"
	g_boxed_free (gtk_tree_row_reference_get_type (), self);
#line 7106 "SourceList.c"
}

static GtkTreeIter*
granite_widgets_source_list_data_model_node_wrapper_get_iter (GraniteWidgetsSourceListDataModelNodeWrapper* self)
{
	GtkTreeIter* result;
	GtkTreeIter* rv = NULL;
	gboolean _tmp0_;
	gboolean _tmp1_;
#line 740 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 741 "../lib/Widgets/SourceList.vala"
	rv = NULL;
#line 743 "../lib/Widgets/SourceList.vala"
	_tmp0_ = granite_widgets_source_list_data_model_node_wrapper_get_valid (self);
#line 743 "../lib/Widgets/SourceList.vala"
	_tmp1_ = _tmp0_;
#line 743 "../lib/Widgets/SourceList.vala"
	if (_tmp1_) {
#line 7126 "SourceList.c"
		GtkTreePath* _path = NULL;
		GtkTreePath* _tmp2_;
		GtkTreePath* _tmp3_;
		GtkTreePath* _tmp4_;
#line 744 "../lib/Widgets/SourceList.vala"
		_tmp2_ = granite_widgets_source_list_data_model_node_wrapper_get_path (self);
#line 744 "../lib/Widgets/SourceList.vala"
		_tmp3_ = _tmp2_;
#line 744 "../lib/Widgets/SourceList.vala"
		_path = _tmp3_;
#line 745 "../lib/Widgets/SourceList.vala"
		_tmp4_ = _path;
#line 745 "../lib/Widgets/SourceList.vala"
		if (_tmp4_ != NULL) {
#line 7141 "SourceList.c"
			GtkTreeIter _iter = {0};
			GtkTreeRowReference* _tmp5_;
			GtkTreeModel* _tmp6_;
			GtkTreePath* _tmp7_;
			GtkTreeIter _tmp8_ = {0};
			gboolean _tmp9_;
#line 747 "../lib/Widgets/SourceList.vala"
			_tmp5_ = self->priv->row_reference;
#line 747 "../lib/Widgets/SourceList.vala"
			_tmp6_ = gtk_tree_row_reference_get_model (_tmp5_);
#line 747 "../lib/Widgets/SourceList.vala"
			_tmp7_ = _path;
#line 747 "../lib/Widgets/SourceList.vala"
			_tmp9_ = gtk_tree_model_get_iter (_tmp6_, &_tmp8_, _tmp7_);
#line 747 "../lib/Widgets/SourceList.vala"
			_iter = _tmp8_;
#line 747 "../lib/Widgets/SourceList.vala"
			if (_tmp9_) {
#line 7160 "SourceList.c"
				GtkTreeIter _tmp10_;
				GtkTreeIter* _tmp11_;
#line 748 "../lib/Widgets/SourceList.vala"
				_tmp10_ = _iter;
#line 748 "../lib/Widgets/SourceList.vala"
				_tmp11_ = __vala_GtkTreeIter_copy0 (&_tmp10_);
#line 748 "../lib/Widgets/SourceList.vala"
				__vala_GtkTreeIter_free0 (rv);
#line 748 "../lib/Widgets/SourceList.vala"
				rv = _tmp11_;
#line 7171 "SourceList.c"
			}
		}
#line 743 "../lib/Widgets/SourceList.vala"
		__vala_GtkTreePath_free0 (_path);
#line 7176 "SourceList.c"
	}
#line 752 "../lib/Widgets/SourceList.vala"
	result = rv;
#line 752 "../lib/Widgets/SourceList.vala"
	return result;
#line 7182 "SourceList.c"
}

static GtkTreePath*
granite_widgets_source_list_data_model_node_wrapper_get_path (GraniteWidgetsSourceListDataModelNodeWrapper* self)
{
	GtkTreePath* result;
	GtkTreePath* _tmp0_ = NULL;
	gboolean _tmp1_;
	gboolean _tmp2_;
#line 760 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 760 "../lib/Widgets/SourceList.vala"
	_tmp1_ = granite_widgets_source_list_data_model_node_wrapper_get_valid (self);
#line 760 "../lib/Widgets/SourceList.vala"
	_tmp2_ = _tmp1_;
#line 760 "../lib/Widgets/SourceList.vala"
	if (_tmp2_) {
#line 7200 "SourceList.c"
		GtkTreeRowReference* _tmp3_;
		GtkTreePath* _tmp4_;
#line 760 "../lib/Widgets/SourceList.vala"
		_tmp3_ = self->priv->row_reference;
#line 760 "../lib/Widgets/SourceList.vala"
		_tmp4_ = gtk_tree_row_reference_get_path (_tmp3_);
#line 760 "../lib/Widgets/SourceList.vala"
		__vala_GtkTreePath_free0 (_tmp0_);
#line 760 "../lib/Widgets/SourceList.vala"
		_tmp0_ = _tmp4_;
#line 7211 "SourceList.c"
	} else {
#line 760 "../lib/Widgets/SourceList.vala"
		__vala_GtkTreePath_free0 (_tmp0_);
#line 760 "../lib/Widgets/SourceList.vala"
		_tmp0_ = NULL;
#line 7217 "SourceList.c"
	}
#line 760 "../lib/Widgets/SourceList.vala"
	result = _tmp0_;
#line 760 "../lib/Widgets/SourceList.vala"
	return result;
#line 7223 "SourceList.c"
}

static gboolean
granite_widgets_source_list_data_model_node_wrapper_get_valid (GraniteWidgetsSourceListDataModelNodeWrapper* self)
{
	gboolean result;
	gboolean _tmp0_ = FALSE;
	GtkTreeRowReference* _tmp1_;
#line 768 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 768 "../lib/Widgets/SourceList.vala"
	_tmp1_ = self->priv->row_reference;
#line 768 "../lib/Widgets/SourceList.vala"
	if (_tmp1_ != NULL) {
#line 7238 "SourceList.c"
		GtkTreeRowReference* _tmp2_;
#line 768 "../lib/Widgets/SourceList.vala"
		_tmp2_ = self->priv->row_reference;
#line 768 "../lib/Widgets/SourceList.vala"
		_tmp0_ = gtk_tree_row_reference_valid (_tmp2_);
#line 7244 "SourceList.c"
	} else {
#line 768 "../lib/Widgets/SourceList.vala"
		_tmp0_ = FALSE;
#line 7248 "SourceList.c"
	}
#line 768 "../lib/Widgets/SourceList.vala"
	result = _tmp0_;
#line 768 "../lib/Widgets/SourceList.vala"
	return result;
#line 7254 "SourceList.c"
}

static GraniteWidgetsSourceListDataModelNodeWrapper*
granite_widgets_source_list_data_model_node_wrapper_construct (GType object_type,
                                                               GtkTreeModel* model,
                                                               GtkTreeIter* iter)
{
	GraniteWidgetsSourceListDataModelNodeWrapper* self = NULL;
	GtkTreeIter _tmp0_;
	GtkTreePath* _tmp1_;
	GtkTreePath* _tmp2_;
	GtkTreeRowReference* _tmp3_;
#line 771 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (model != NULL, NULL);
#line 771 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (iter != NULL, NULL);
#line 771 "../lib/Widgets/SourceList.vala"
	self = (GraniteWidgetsSourceListDataModelNodeWrapper*) g_type_create_instance (object_type);
#line 772 "../lib/Widgets/SourceList.vala"
	_tmp0_ = *iter;
#line 772 "../lib/Widgets/SourceList.vala"
	_tmp1_ = gtk_tree_model_get_path (model, &_tmp0_);
#line 772 "../lib/Widgets/SourceList.vala"
	_tmp2_ = _tmp1_;
#line 772 "../lib/Widgets/SourceList.vala"
	_tmp3_ = gtk_tree_row_reference_new (model, _tmp2_);
#line 772 "../lib/Widgets/SourceList.vala"
	__vala_GtkTreeRowReference_free0 (self->priv->row_reference);
#line 772 "../lib/Widgets/SourceList.vala"
	self->priv->row_reference = _tmp3_;
#line 772 "../lib/Widgets/SourceList.vala"
	__vala_GtkTreePath_free0 (_tmp2_);
#line 771 "../lib/Widgets/SourceList.vala"
	return self;
#line 7289 "SourceList.c"
}

static GraniteWidgetsSourceListDataModelNodeWrapper*
granite_widgets_source_list_data_model_node_wrapper_new (GtkTreeModel* model,
                                                         GtkTreeIter* iter)
{
#line 771 "../lib/Widgets/SourceList.vala"
	return granite_widgets_source_list_data_model_node_wrapper_construct (GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_TYPE_NODE_WRAPPER, model, iter);
#line 7298 "SourceList.c"
}

static void
granite_widgets_source_list_data_model_value_node_wrapper_init (GValue* value)
{
#line 729 "../lib/Widgets/SourceList.vala"
	value->data[0].v_pointer = NULL;
#line 7306 "SourceList.c"
}

static void
granite_widgets_source_list_data_model_value_node_wrapper_free_value (GValue* value)
{
#line 729 "../lib/Widgets/SourceList.vala"
	if (value->data[0].v_pointer) {
#line 729 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_data_model_node_wrapper_unref (value->data[0].v_pointer);
#line 7316 "SourceList.c"
	}
}

static void
granite_widgets_source_list_data_model_value_node_wrapper_copy_value (const GValue* src_value,
                                                                      GValue* dest_value)
{
#line 729 "../lib/Widgets/SourceList.vala"
	if (src_value->data[0].v_pointer) {
#line 729 "../lib/Widgets/SourceList.vala"
		dest_value->data[0].v_pointer = granite_widgets_source_list_data_model_node_wrapper_ref (src_value->data[0].v_pointer);
#line 7328 "SourceList.c"
	} else {
#line 729 "../lib/Widgets/SourceList.vala"
		dest_value->data[0].v_pointer = NULL;
#line 7332 "SourceList.c"
	}
}

static gpointer
granite_widgets_source_list_data_model_value_node_wrapper_peek_pointer (const GValue* value)
{
#line 729 "../lib/Widgets/SourceList.vala"
	return value->data[0].v_pointer;
#line 7341 "SourceList.c"
}

static gchar*
granite_widgets_source_list_data_model_value_node_wrapper_collect_value (GValue* value,
                                                                         guint n_collect_values,
                                                                         GTypeCValue* collect_values,
                                                                         guint collect_flags)
{
#line 729 "../lib/Widgets/SourceList.vala"
	if (collect_values[0].v_pointer) {
#line 7352 "SourceList.c"
		GraniteWidgetsSourceListDataModelNodeWrapper * object;
		object = collect_values[0].v_pointer;
#line 729 "../lib/Widgets/SourceList.vala"
		if (object->parent_instance.g_class == NULL) {
#line 729 "../lib/Widgets/SourceList.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 7359 "SourceList.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 729 "../lib/Widgets/SourceList.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 7363 "SourceList.c"
		}
#line 729 "../lib/Widgets/SourceList.vala"
		value->data[0].v_pointer = granite_widgets_source_list_data_model_node_wrapper_ref (object);
#line 7367 "SourceList.c"
	} else {
#line 729 "../lib/Widgets/SourceList.vala"
		value->data[0].v_pointer = NULL;
#line 7371 "SourceList.c"
	}
#line 729 "../lib/Widgets/SourceList.vala"
	return NULL;
#line 7375 "SourceList.c"
}

static gchar*
granite_widgets_source_list_data_model_value_node_wrapper_lcopy_value (const GValue* value,
                                                                       guint n_collect_values,
                                                                       GTypeCValue* collect_values,
                                                                       guint collect_flags)
{
	GraniteWidgetsSourceListDataModelNodeWrapper ** object_p;
	object_p = collect_values[0].v_pointer;
#line 729 "../lib/Widgets/SourceList.vala"
	if (!object_p) {
#line 729 "../lib/Widgets/SourceList.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 7390 "SourceList.c"
	}
#line 729 "../lib/Widgets/SourceList.vala"
	if (!value->data[0].v_pointer) {
#line 729 "../lib/Widgets/SourceList.vala"
		*object_p = NULL;
#line 7396 "SourceList.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 729 "../lib/Widgets/SourceList.vala"
		*object_p = value->data[0].v_pointer;
#line 7400 "SourceList.c"
	} else {
#line 729 "../lib/Widgets/SourceList.vala"
		*object_p = granite_widgets_source_list_data_model_node_wrapper_ref (value->data[0].v_pointer);
#line 7404 "SourceList.c"
	}
#line 729 "../lib/Widgets/SourceList.vala"
	return NULL;
#line 7408 "SourceList.c"
}

static GParamSpec*
granite_widgets_source_list_data_model_param_spec_node_wrapper (const gchar* name,
                                                                const gchar* nick,
                                                                const gchar* blurb,
                                                                GType object_type,
                                                                GParamFlags flags)
{
	GraniteWidgetsSourceListDataModelParamSpecNodeWrapper* spec;
#line 729 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (g_type_is_a (object_type, GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_TYPE_NODE_WRAPPER), NULL);
#line 729 "../lib/Widgets/SourceList.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 729 "../lib/Widgets/SourceList.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 729 "../lib/Widgets/SourceList.vala"
	return G_PARAM_SPEC (spec);
#line 7427 "SourceList.c"
}

static gpointer
granite_widgets_source_list_data_model_value_get_node_wrapper (const GValue* value)
{
#line 729 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_TYPE_NODE_WRAPPER), NULL);
#line 729 "../lib/Widgets/SourceList.vala"
	return value->data[0].v_pointer;
#line 7437 "SourceList.c"
}

static void
granite_widgets_source_list_data_model_value_set_node_wrapper (GValue* value,
                                                               gpointer v_object)
{
	GraniteWidgetsSourceListDataModelNodeWrapper * old;
#line 729 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_TYPE_NODE_WRAPPER));
#line 729 "../lib/Widgets/SourceList.vala"
	old = value->data[0].v_pointer;
#line 729 "../lib/Widgets/SourceList.vala"
	if (v_object) {
#line 729 "../lib/Widgets/SourceList.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_TYPE_NODE_WRAPPER));
#line 729 "../lib/Widgets/SourceList.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 729 "../lib/Widgets/SourceList.vala"
		value->data[0].v_pointer = v_object;
#line 729 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_data_model_node_wrapper_ref (value->data[0].v_pointer);
#line 7459 "SourceList.c"
	} else {
#line 729 "../lib/Widgets/SourceList.vala"
		value->data[0].v_pointer = NULL;
#line 7463 "SourceList.c"
	}
#line 729 "../lib/Widgets/SourceList.vala"
	if (old) {
#line 729 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_data_model_node_wrapper_unref (old);
#line 7469 "SourceList.c"
	}
}

static void
granite_widgets_source_list_data_model_value_take_node_wrapper (GValue* value,
                                                                gpointer v_object)
{
	GraniteWidgetsSourceListDataModelNodeWrapper * old;
#line 729 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_TYPE_NODE_WRAPPER));
#line 729 "../lib/Widgets/SourceList.vala"
	old = value->data[0].v_pointer;
#line 729 "../lib/Widgets/SourceList.vala"
	if (v_object) {
#line 729 "../lib/Widgets/SourceList.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_TYPE_NODE_WRAPPER));
#line 729 "../lib/Widgets/SourceList.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 729 "../lib/Widgets/SourceList.vala"
		value->data[0].v_pointer = v_object;
#line 7490 "SourceList.c"
	} else {
#line 729 "../lib/Widgets/SourceList.vala"
		value->data[0].v_pointer = NULL;
#line 7494 "SourceList.c"
	}
#line 729 "../lib/Widgets/SourceList.vala"
	if (old) {
#line 729 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_data_model_node_wrapper_unref (old);
#line 7500 "SourceList.c"
	}
}

static void
granite_widgets_source_list_data_model_node_wrapper_class_init (GraniteWidgetsSourceListDataModelNodeWrapperClass * klass,
                                                                gpointer klass_data)
{
#line 729 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_data_model_node_wrapper_parent_class = g_type_class_peek_parent (klass);
#line 729 "../lib/Widgets/SourceList.vala"
	((GraniteWidgetsSourceListDataModelNodeWrapperClass *) klass)->finalize = granite_widgets_source_list_data_model_node_wrapper_finalize;
#line 729 "../lib/Widgets/SourceList.vala"
	g_type_class_adjust_private_offset (klass, &GraniteWidgetsSourceListDataModelNodeWrapper_private_offset);
#line 7514 "SourceList.c"
}

static void
granite_widgets_source_list_data_model_node_wrapper_instance_init (GraniteWidgetsSourceListDataModelNodeWrapper * self,
                                                                   gpointer klass)
{
#line 729 "../lib/Widgets/SourceList.vala"
	self->priv = granite_widgets_source_list_data_model_node_wrapper_get_instance_private (self);
#line 729 "../lib/Widgets/SourceList.vala"
	self->ref_count = 1;
#line 7525 "SourceList.c"
}

static void
granite_widgets_source_list_data_model_node_wrapper_finalize (GraniteWidgetsSourceListDataModelNodeWrapper * obj)
{
	GraniteWidgetsSourceListDataModelNodeWrapper * self;
#line 729 "../lib/Widgets/SourceList.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_TYPE_NODE_WRAPPER, GraniteWidgetsSourceListDataModelNodeWrapper);
#line 729 "../lib/Widgets/SourceList.vala"
	g_signal_handlers_destroy (self);
#line 734 "../lib/Widgets/SourceList.vala"
	__vala_GtkTreeRowReference_free0 (self->priv->row_reference);
#line 7538 "SourceList.c"
}

/**
         * An object that references a particular row in a model. This class is a wrapper built around
         * Gtk.TreeRowReference, and exists with the purpose of ensuring we never use invalid tree paths
         * or iters in the model, since most of these errors provoke failures due to GTK+ assertions
         * or, even worse, unexpected behavior.
         */
static GType
granite_widgets_source_list_data_model_node_wrapper_get_type_once (void)
{
	static const GTypeValueTable g_define_type_value_table = { granite_widgets_source_list_data_model_value_node_wrapper_init, granite_widgets_source_list_data_model_value_node_wrapper_free_value, granite_widgets_source_list_data_model_value_node_wrapper_copy_value, granite_widgets_source_list_data_model_value_node_wrapper_peek_pointer, "p", granite_widgets_source_list_data_model_value_node_wrapper_collect_value, "p", granite_widgets_source_list_data_model_value_node_wrapper_lcopy_value };
	static const GTypeInfo g_define_type_info = { sizeof (GraniteWidgetsSourceListDataModelNodeWrapperClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) granite_widgets_source_list_data_model_node_wrapper_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GraniteWidgetsSourceListDataModelNodeWrapper), 0, (GInstanceInitFunc) granite_widgets_source_list_data_model_node_wrapper_instance_init, &g_define_type_value_table };
	static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
	GType granite_widgets_source_list_data_model_node_wrapper_type_id;
	granite_widgets_source_list_data_model_node_wrapper_type_id = g_type_register_fundamental (g_type_fundamental_next (), "GraniteWidgetsSourceListDataModelNodeWrapper", &g_define_type_info, &g_define_type_fundamental_info, 0);
	GraniteWidgetsSourceListDataModelNodeWrapper_private_offset = g_type_add_instance_private (granite_widgets_source_list_data_model_node_wrapper_type_id, sizeof (GraniteWidgetsSourceListDataModelNodeWrapperPrivate));
	return granite_widgets_source_list_data_model_node_wrapper_type_id;
}

static GType
granite_widgets_source_list_data_model_node_wrapper_get_type (void)
{
	static volatile gsize granite_widgets_source_list_data_model_node_wrapper_type_id__once = 0;
	if (g_once_init_enter (&granite_widgets_source_list_data_model_node_wrapper_type_id__once)) {
		GType granite_widgets_source_list_data_model_node_wrapper_type_id;
		granite_widgets_source_list_data_model_node_wrapper_type_id = granite_widgets_source_list_data_model_node_wrapper_get_type_once ();
		g_once_init_leave (&granite_widgets_source_list_data_model_node_wrapper_type_id__once, granite_widgets_source_list_data_model_node_wrapper_type_id);
	}
	return granite_widgets_source_list_data_model_node_wrapper_type_id__once;
}

static gpointer
granite_widgets_source_list_data_model_node_wrapper_ref (gpointer instance)
{
	GraniteWidgetsSourceListDataModelNodeWrapper * self;
	self = instance;
#line 729 "../lib/Widgets/SourceList.vala"
	g_atomic_int_inc (&self->ref_count);
#line 729 "../lib/Widgets/SourceList.vala"
	return instance;
#line 7580 "SourceList.c"
}

static void
granite_widgets_source_list_data_model_node_wrapper_unref (gpointer instance)
{
	GraniteWidgetsSourceListDataModelNodeWrapper * self;
	self = instance;
#line 729 "../lib/Widgets/SourceList.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 729 "../lib/Widgets/SourceList.vala"
		GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_NODE_WRAPPER_GET_CLASS (self)->finalize (self);
#line 729 "../lib/Widgets/SourceList.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 7594 "SourceList.c"
	}
}

static inline gpointer
granite_widgets_source_list_data_model_item_monitor_get_instance_private (GraniteWidgetsSourceListDataModelItemMonitor* self)
{
	return G_STRUCT_MEMBER_P (self, GraniteWidgetsSourceListDataModelItemMonitor_private_offset);
}

static void
_granite_widgets_source_list_data_model_item_monitor_on_notify_g_object_notify (GObject* _sender,
                                                                                GParamSpec* pspec,
                                                                                gpointer self)
{
#line 789 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_data_model_item_monitor_on_notify ((GraniteWidgetsSourceListDataModelItemMonitor*) self, pspec);
#line 7611 "SourceList.c"
}

static void
g_cclosure_user_marshal_VOID__OBJECT_STRING (GClosure * closure,
                                             GValue * return_value,
                                             guint n_param_values,
                                             const GValue * param_values,
                                             gpointer invocation_hint,
                                             gpointer marshal_data)
{
	typedef void (*GMarshalFunc_VOID__OBJECT_STRING) (gpointer data1, gpointer arg_1, const char* arg_2, gpointer data2);
	register GMarshalFunc_VOID__OBJECT_STRING callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
#line 779 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (n_param_values == 3);
#line 779 "../lib/Widgets/SourceList.vala"
	if (G_CCLOSURE_SWAP_DATA (closure)) {
#line 779 "../lib/Widgets/SourceList.vala"
		data1 = closure->data;
#line 779 "../lib/Widgets/SourceList.vala"
		data2 = param_values->data[0].v_pointer;
#line 7636 "SourceList.c"
	} else {
#line 779 "../lib/Widgets/SourceList.vala"
		data1 = param_values->data[0].v_pointer;
#line 779 "../lib/Widgets/SourceList.vala"
		data2 = closure->data;
#line 7642 "SourceList.c"
	}
#line 779 "../lib/Widgets/SourceList.vala"
	callback = (GMarshalFunc_VOID__OBJECT_STRING) (marshal_data ? marshal_data : cc->callback);
#line 779 "../lib/Widgets/SourceList.vala"
	callback (data1, g_value_get_object (param_values + 1), g_value_get_string (param_values + 2), data2);
#line 7648 "SourceList.c"
}

static GraniteWidgetsSourceListDataModelItemMonitor*
granite_widgets_source_list_data_model_item_monitor_construct (GType object_type,
                                                               GraniteWidgetsSourceListItem* item)
{
	GraniteWidgetsSourceListDataModelItemMonitor* self = NULL;
	GraniteWidgetsSourceListItem* _tmp0_;
#line 783 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (item != NULL, NULL);
#line 783 "../lib/Widgets/SourceList.vala"
	self = (GraniteWidgetsSourceListDataModelItemMonitor*) g_type_create_instance (object_type);
#line 784 "../lib/Widgets/SourceList.vala"
	_tmp0_ = _g_object_ref0 (item);
#line 784 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (self->priv->item);
#line 784 "../lib/Widgets/SourceList.vala"
	self->priv->item = _tmp0_;
#line 785 "../lib/Widgets/SourceList.vala"
	g_signal_connect_after ((GObject*) item, "notify", (GCallback) _granite_widgets_source_list_data_model_item_monitor_on_notify_g_object_notify, self);
#line 783 "../lib/Widgets/SourceList.vala"
	return self;
#line 7671 "SourceList.c"
}

static GraniteWidgetsSourceListDataModelItemMonitor*
granite_widgets_source_list_data_model_item_monitor_new (GraniteWidgetsSourceListItem* item)
{
#line 783 "../lib/Widgets/SourceList.vala"
	return granite_widgets_source_list_data_model_item_monitor_construct (GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_TYPE_ITEM_MONITOR, item);
#line 7679 "SourceList.c"
}

static void
granite_widgets_source_list_data_model_item_monitor_on_notify (GraniteWidgetsSourceListDataModelItemMonitor* self,
                                                               GParamSpec* prop)
{
	GraniteWidgetsSourceListItem* _tmp0_;
	const gchar* _tmp1_;
#line 792 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 792 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (prop != NULL);
#line 793 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->item;
#line 793 "../lib/Widgets/SourceList.vala"
	_tmp1_ = prop->name;
#line 793 "../lib/Widgets/SourceList.vala"
	g_signal_emit (self, granite_widgets_source_list_data_model_item_monitor_signals[GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_ITEM_MONITOR_CHANGED_SIGNAL], 0, _tmp0_, _tmp1_);
#line 7698 "SourceList.c"
}

static void
granite_widgets_source_list_data_model_value_item_monitor_init (GValue* value)
{
#line 779 "../lib/Widgets/SourceList.vala"
	value->data[0].v_pointer = NULL;
#line 7706 "SourceList.c"
}

static void
granite_widgets_source_list_data_model_value_item_monitor_free_value (GValue* value)
{
#line 779 "../lib/Widgets/SourceList.vala"
	if (value->data[0].v_pointer) {
#line 779 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_data_model_item_monitor_unref (value->data[0].v_pointer);
#line 7716 "SourceList.c"
	}
}

static void
granite_widgets_source_list_data_model_value_item_monitor_copy_value (const GValue* src_value,
                                                                      GValue* dest_value)
{
#line 779 "../lib/Widgets/SourceList.vala"
	if (src_value->data[0].v_pointer) {
#line 779 "../lib/Widgets/SourceList.vala"
		dest_value->data[0].v_pointer = granite_widgets_source_list_data_model_item_monitor_ref (src_value->data[0].v_pointer);
#line 7728 "SourceList.c"
	} else {
#line 779 "../lib/Widgets/SourceList.vala"
		dest_value->data[0].v_pointer = NULL;
#line 7732 "SourceList.c"
	}
}

static gpointer
granite_widgets_source_list_data_model_value_item_monitor_peek_pointer (const GValue* value)
{
#line 779 "../lib/Widgets/SourceList.vala"
	return value->data[0].v_pointer;
#line 7741 "SourceList.c"
}

static gchar*
granite_widgets_source_list_data_model_value_item_monitor_collect_value (GValue* value,
                                                                         guint n_collect_values,
                                                                         GTypeCValue* collect_values,
                                                                         guint collect_flags)
{
#line 779 "../lib/Widgets/SourceList.vala"
	if (collect_values[0].v_pointer) {
#line 7752 "SourceList.c"
		GraniteWidgetsSourceListDataModelItemMonitor * object;
		object = collect_values[0].v_pointer;
#line 779 "../lib/Widgets/SourceList.vala"
		if (object->parent_instance.g_class == NULL) {
#line 779 "../lib/Widgets/SourceList.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 7759 "SourceList.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 779 "../lib/Widgets/SourceList.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 7763 "SourceList.c"
		}
#line 779 "../lib/Widgets/SourceList.vala"
		value->data[0].v_pointer = granite_widgets_source_list_data_model_item_monitor_ref (object);
#line 7767 "SourceList.c"
	} else {
#line 779 "../lib/Widgets/SourceList.vala"
		value->data[0].v_pointer = NULL;
#line 7771 "SourceList.c"
	}
#line 779 "../lib/Widgets/SourceList.vala"
	return NULL;
#line 7775 "SourceList.c"
}

static gchar*
granite_widgets_source_list_data_model_value_item_monitor_lcopy_value (const GValue* value,
                                                                       guint n_collect_values,
                                                                       GTypeCValue* collect_values,
                                                                       guint collect_flags)
{
	GraniteWidgetsSourceListDataModelItemMonitor ** object_p;
	object_p = collect_values[0].v_pointer;
#line 779 "../lib/Widgets/SourceList.vala"
	if (!object_p) {
#line 779 "../lib/Widgets/SourceList.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 7790 "SourceList.c"
	}
#line 779 "../lib/Widgets/SourceList.vala"
	if (!value->data[0].v_pointer) {
#line 779 "../lib/Widgets/SourceList.vala"
		*object_p = NULL;
#line 7796 "SourceList.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 779 "../lib/Widgets/SourceList.vala"
		*object_p = value->data[0].v_pointer;
#line 7800 "SourceList.c"
	} else {
#line 779 "../lib/Widgets/SourceList.vala"
		*object_p = granite_widgets_source_list_data_model_item_monitor_ref (value->data[0].v_pointer);
#line 7804 "SourceList.c"
	}
#line 779 "../lib/Widgets/SourceList.vala"
	return NULL;
#line 7808 "SourceList.c"
}

static GParamSpec*
granite_widgets_source_list_data_model_param_spec_item_monitor (const gchar* name,
                                                                const gchar* nick,
                                                                const gchar* blurb,
                                                                GType object_type,
                                                                GParamFlags flags)
{
	GraniteWidgetsSourceListDataModelParamSpecItemMonitor* spec;
#line 779 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (g_type_is_a (object_type, GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_TYPE_ITEM_MONITOR), NULL);
#line 779 "../lib/Widgets/SourceList.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 779 "../lib/Widgets/SourceList.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 779 "../lib/Widgets/SourceList.vala"
	return G_PARAM_SPEC (spec);
#line 7827 "SourceList.c"
}

static gpointer
granite_widgets_source_list_data_model_value_get_item_monitor (const GValue* value)
{
#line 779 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_TYPE_ITEM_MONITOR), NULL);
#line 779 "../lib/Widgets/SourceList.vala"
	return value->data[0].v_pointer;
#line 7837 "SourceList.c"
}

static void
granite_widgets_source_list_data_model_value_set_item_monitor (GValue* value,
                                                               gpointer v_object)
{
	GraniteWidgetsSourceListDataModelItemMonitor * old;
#line 779 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_TYPE_ITEM_MONITOR));
#line 779 "../lib/Widgets/SourceList.vala"
	old = value->data[0].v_pointer;
#line 779 "../lib/Widgets/SourceList.vala"
	if (v_object) {
#line 779 "../lib/Widgets/SourceList.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_TYPE_ITEM_MONITOR));
#line 779 "../lib/Widgets/SourceList.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 779 "../lib/Widgets/SourceList.vala"
		value->data[0].v_pointer = v_object;
#line 779 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_data_model_item_monitor_ref (value->data[0].v_pointer);
#line 7859 "SourceList.c"
	} else {
#line 779 "../lib/Widgets/SourceList.vala"
		value->data[0].v_pointer = NULL;
#line 7863 "SourceList.c"
	}
#line 779 "../lib/Widgets/SourceList.vala"
	if (old) {
#line 779 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_data_model_item_monitor_unref (old);
#line 7869 "SourceList.c"
	}
}

static void
granite_widgets_source_list_data_model_value_take_item_monitor (GValue* value,
                                                                gpointer v_object)
{
	GraniteWidgetsSourceListDataModelItemMonitor * old;
#line 779 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_TYPE_ITEM_MONITOR));
#line 779 "../lib/Widgets/SourceList.vala"
	old = value->data[0].v_pointer;
#line 779 "../lib/Widgets/SourceList.vala"
	if (v_object) {
#line 779 "../lib/Widgets/SourceList.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_TYPE_ITEM_MONITOR));
#line 779 "../lib/Widgets/SourceList.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 779 "../lib/Widgets/SourceList.vala"
		value->data[0].v_pointer = v_object;
#line 7890 "SourceList.c"
	} else {
#line 779 "../lib/Widgets/SourceList.vala"
		value->data[0].v_pointer = NULL;
#line 7894 "SourceList.c"
	}
#line 779 "../lib/Widgets/SourceList.vala"
	if (old) {
#line 779 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_data_model_item_monitor_unref (old);
#line 7900 "SourceList.c"
	}
}

static void
granite_widgets_source_list_data_model_item_monitor_class_init (GraniteWidgetsSourceListDataModelItemMonitorClass * klass,
                                                                gpointer klass_data)
{
#line 779 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_data_model_item_monitor_parent_class = g_type_class_peek_parent (klass);
#line 779 "../lib/Widgets/SourceList.vala"
	((GraniteWidgetsSourceListDataModelItemMonitorClass *) klass)->finalize = granite_widgets_source_list_data_model_item_monitor_finalize;
#line 779 "../lib/Widgets/SourceList.vala"
	g_type_class_adjust_private_offset (klass, &GraniteWidgetsSourceListDataModelItemMonitor_private_offset);
#line 779 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_data_model_item_monitor_signals[GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_ITEM_MONITOR_CHANGED_SIGNAL] = g_signal_new ("changed", GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_TYPE_ITEM_MONITOR, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__OBJECT_STRING, G_TYPE_NONE, 2, GRANITE_WIDGETS_SOURCE_LIST_TYPE_ITEM, G_TYPE_STRING);
#line 7916 "SourceList.c"
}

static void
granite_widgets_source_list_data_model_item_monitor_instance_init (GraniteWidgetsSourceListDataModelItemMonitor * self,
                                                                   gpointer klass)
{
#line 779 "../lib/Widgets/SourceList.vala"
	self->priv = granite_widgets_source_list_data_model_item_monitor_get_instance_private (self);
#line 779 "../lib/Widgets/SourceList.vala"
	self->ref_count = 1;
#line 7927 "SourceList.c"
}

static void
granite_widgets_source_list_data_model_item_monitor_finalize (GraniteWidgetsSourceListDataModelItemMonitor * obj)
{
	GraniteWidgetsSourceListDataModelItemMonitor * self;
	GraniteWidgetsSourceListItem* _tmp0_;
	guint _tmp1_;
#line 779 "../lib/Widgets/SourceList.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_TYPE_ITEM_MONITOR, GraniteWidgetsSourceListDataModelItemMonitor);
#line 779 "../lib/Widgets/SourceList.vala"
	g_signal_handlers_destroy (self);
#line 789 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->item;
#line 789 "../lib/Widgets/SourceList.vala"
	g_signal_parse_name ("notify", G_TYPE_OBJECT, &_tmp1_, NULL, FALSE);
#line 789 "../lib/Widgets/SourceList.vala"
	g_signal_handlers_disconnect_matched ((GObject*) _tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _granite_widgets_source_list_data_model_item_monitor_on_notify_g_object_notify, self);
#line 781 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (self->priv->item);
#line 7948 "SourceList.c"
}

/**
         * Helper object used to monitor item property changes.
         */
static GType
granite_widgets_source_list_data_model_item_monitor_get_type_once (void)
{
	static const GTypeValueTable g_define_type_value_table = { granite_widgets_source_list_data_model_value_item_monitor_init, granite_widgets_source_list_data_model_value_item_monitor_free_value, granite_widgets_source_list_data_model_value_item_monitor_copy_value, granite_widgets_source_list_data_model_value_item_monitor_peek_pointer, "p", granite_widgets_source_list_data_model_value_item_monitor_collect_value, "p", granite_widgets_source_list_data_model_value_item_monitor_lcopy_value };
	static const GTypeInfo g_define_type_info = { sizeof (GraniteWidgetsSourceListDataModelItemMonitorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) granite_widgets_source_list_data_model_item_monitor_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GraniteWidgetsSourceListDataModelItemMonitor), 0, (GInstanceInitFunc) granite_widgets_source_list_data_model_item_monitor_instance_init, &g_define_type_value_table };
	static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
	GType granite_widgets_source_list_data_model_item_monitor_type_id;
	granite_widgets_source_list_data_model_item_monitor_type_id = g_type_register_fundamental (g_type_fundamental_next (), "GraniteWidgetsSourceListDataModelItemMonitor", &g_define_type_info, &g_define_type_fundamental_info, 0);
	GraniteWidgetsSourceListDataModelItemMonitor_private_offset = g_type_add_instance_private (granite_widgets_source_list_data_model_item_monitor_type_id, sizeof (GraniteWidgetsSourceListDataModelItemMonitorPrivate));
	return granite_widgets_source_list_data_model_item_monitor_type_id;
}

static GType
granite_widgets_source_list_data_model_item_monitor_get_type (void)
{
	static volatile gsize granite_widgets_source_list_data_model_item_monitor_type_id__once = 0;
	if (g_once_init_enter (&granite_widgets_source_list_data_model_item_monitor_type_id__once)) {
		GType granite_widgets_source_list_data_model_item_monitor_type_id;
		granite_widgets_source_list_data_model_item_monitor_type_id = granite_widgets_source_list_data_model_item_monitor_get_type_once ();
		g_once_init_leave (&granite_widgets_source_list_data_model_item_monitor_type_id__once, granite_widgets_source_list_data_model_item_monitor_type_id);
	}
	return granite_widgets_source_list_data_model_item_monitor_type_id__once;
}

static gpointer
granite_widgets_source_list_data_model_item_monitor_ref (gpointer instance)
{
	GraniteWidgetsSourceListDataModelItemMonitor * self;
	self = instance;
#line 779 "../lib/Widgets/SourceList.vala"
	g_atomic_int_inc (&self->ref_count);
#line 779 "../lib/Widgets/SourceList.vala"
	return instance;
#line 7987 "SourceList.c"
}

static void
granite_widgets_source_list_data_model_item_monitor_unref (gpointer instance)
{
	GraniteWidgetsSourceListDataModelItemMonitor * self;
	self = instance;
#line 779 "../lib/Widgets/SourceList.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 779 "../lib/Widgets/SourceList.vala"
		GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_ITEM_MONITOR_GET_CLASS (self)->finalize (self);
#line 779 "../lib/Widgets/SourceList.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 8001 "SourceList.c"
	}
}

static gint
_granite_widgets_source_list_data_model_child_model_sort_func_gtk_tree_iter_compare_func (GtkTreeModel* model,
                                                                                          GtkTreeIter* a,
                                                                                          GtkTreeIter* b,
                                                                                          gpointer self)
{
	gint result;
	result = granite_widgets_source_list_data_model_child_model_sort_func ((GraniteWidgetsSourceListDataModel*) self, model, a, b);
#line 863 "../lib/Widgets/SourceList.vala"
	return result;
#line 8015 "SourceList.c"
}

static gboolean
_granite_widgets_source_list_data_model_filter_visible_func_gtk_tree_model_filter_visible_func (GtkTreeModel* model,
                                                                                                GtkTreeIter* iter,
                                                                                                gpointer self)
{
	gboolean result;
	result = granite_widgets_source_list_data_model_filter_visible_func ((GraniteWidgetsSourceListDataModel*) self, model, iter);
#line 866 "../lib/Widgets/SourceList.vala"
	return result;
#line 8027 "SourceList.c"
}

static GObject *
granite_widgets_source_list_data_model_constructor (GType type,
                                                    guint n_construct_properties,
                                                    GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GraniteWidgetsSourceListDataModel * self;
	GtkTreeStore* _tmp0_;
	GtkTreeStore* _tmp1_;
	GtkTreeStore* _tmp2_;
#line 858 "../lib/Widgets/SourceList.vala"
	parent_class = G_OBJECT_CLASS (granite_widgets_source_list_data_model_parent_class);
#line 858 "../lib/Widgets/SourceList.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 858 "../lib/Widgets/SourceList.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GRANITE_WIDGETS_SOURCE_LIST_TYPE_DATA_MODEL, GraniteWidgetsSourceListDataModel);
#line 859 "../lib/Widgets/SourceList.vala"
	_tmp0_ = gtk_tree_store_new ((gint) GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_COLUMN_N_COLUMNS, granite_widgets_source_list_data_model_column_type (GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_COLUMN_ITEM));
#line 859 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (self->priv->child_tree);
#line 859 "../lib/Widgets/SourceList.vala"
	self->priv->child_tree = _tmp0_;
#line 860 "../lib/Widgets/SourceList.vala"
	_tmp1_ = self->priv->child_tree;
#line 860 "../lib/Widgets/SourceList.vala"
	g_object_set ((GtkTreeModelFilter*) self, "child-model", (GtkTreeModel*) _tmp1_, NULL);
#line 861 "../lib/Widgets/SourceList.vala"
	g_object_set ((GtkTreeModelFilter*) self, "virtual-root", NULL, NULL);
#line 863 "../lib/Widgets/SourceList.vala"
	_tmp2_ = self->priv->child_tree;
#line 863 "../lib/Widgets/SourceList.vala"
	gtk_tree_sortable_set_default_sort_func ((GtkTreeSortable*) _tmp2_, _granite_widgets_source_list_data_model_child_model_sort_func_gtk_tree_iter_compare_func, g_object_ref (self), g_object_unref);
#line 864 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_data_model_resort (self);
#line 866 "../lib/Widgets/SourceList.vala"
	gtk_tree_model_filter_set_visible_func ((GtkTreeModelFilter*) self, _granite_widgets_source_list_data_model_filter_visible_func_gtk_tree_model_filter_visible_func, g_object_ref (self), g_object_unref);
#line 858 "../lib/Widgets/SourceList.vala"
	return obj;
#line 8069 "SourceList.c"
}

static void
granite_widgets_source_list_data_model_class_init (GraniteWidgetsSourceListDataModelClass * klass,
                                                   gpointer klass_data)
{
#line 721 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_data_model_parent_class = g_type_class_peek_parent (klass);
#line 721 "../lib/Widgets/SourceList.vala"
	g_type_class_adjust_private_offset (klass, &GraniteWidgetsSourceListDataModel_private_offset);
#line 721 "../lib/Widgets/SourceList.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_granite_widgets_source_list_data_model_get_property;
#line 721 "../lib/Widgets/SourceList.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_granite_widgets_source_list_data_model_set_property;
#line 721 "../lib/Widgets/SourceList.vala"
	G_OBJECT_CLASS (klass)->constructor = granite_widgets_source_list_data_model_constructor;
#line 721 "../lib/Widgets/SourceList.vala"
	G_OBJECT_CLASS (klass)->finalize = granite_widgets_source_list_data_model_finalize;
#line 8088 "SourceList.c"
	/**
	         * Root item.
	         *
	         * This item is not actually part of the model. It's only used as a proxy
	         * for adding and removing items.
	         */
#line 721 "../lib/Widgets/SourceList.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_ROOT_PROPERTY, granite_widgets_source_list_data_model_properties[GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_ROOT_PROPERTY] = g_param_spec_object ("root", "root", "root", GRANITE_WIDGETS_SOURCE_LIST_TYPE_EXPANDABLE_ITEM, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 721 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_data_model_signals[GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_ITEM_UPDATED_SIGNAL] = g_signal_new ("item-updated", GRANITE_WIDGETS_SOURCE_LIST_TYPE_DATA_MODEL, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, GRANITE_WIDGETS_SOURCE_LIST_TYPE_ITEM);
#line 8099 "SourceList.c"
}

static void
granite_widgets_source_list_data_model_gtk_tree_drag_source_interface_init (GtkTreeDragSourceIface * iface,
                                                                            gpointer iface_data)
{
#line 721 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_data_model_gtk_tree_drag_source_parent_iface = g_type_interface_peek_parent (iface);
#line 721 "../lib/Widgets/SourceList.vala"
	iface->drag_data_get = (gboolean (*) (GtkTreeDragSource*, GtkTreePath*, GtkSelectionData*)) granite_widgets_source_list_data_model_real_drag_data_get;
#line 721 "../lib/Widgets/SourceList.vala"
	iface->row_draggable = (gboolean (*) (GtkTreeDragSource*, GtkTreePath*)) granite_widgets_source_list_data_model_real_row_draggable;
#line 8112 "SourceList.c"
}

static void
granite_widgets_source_list_data_model_gtk_tree_drag_dest_interface_init (GtkTreeDragDestIface * iface,
                                                                          gpointer iface_data)
{
#line 721 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_data_model_gtk_tree_drag_dest_parent_iface = g_type_interface_peek_parent (iface);
#line 721 "../lib/Widgets/SourceList.vala"
	iface->drag_data_received = (gboolean (*) (GtkTreeDragDest*, GtkTreePath*, GtkSelectionData*)) granite_widgets_source_list_data_model_real_drag_data_received;
#line 721 "../lib/Widgets/SourceList.vala"
	iface->row_drop_possible = (gboolean (*) (GtkTreeDragDest*, GtkTreePath*, GtkSelectionData*)) granite_widgets_source_list_data_model_real_row_drop_possible;
#line 8125 "SourceList.c"
}

static void
granite_widgets_source_list_data_model_instance_init (GraniteWidgetsSourceListDataModel * self,
                                                      gpointer klass)
{
	GeeHashMap* _tmp0_;
	GeeHashMap* _tmp1_;
#line 721 "../lib/Widgets/SourceList.vala"
	self->priv = granite_widgets_source_list_data_model_get_instance_private (self);
#line 847 "../lib/Widgets/SourceList.vala"
	_tmp0_ = gee_hash_map_new (GRANITE_WIDGETS_SOURCE_LIST_TYPE_ITEM, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_TYPE_NODE_WRAPPER, (GBoxedCopyFunc) granite_widgets_source_list_data_model_node_wrapper_ref, (GDestroyNotify) granite_widgets_source_list_data_model_node_wrapper_unref, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 847 "../lib/Widgets/SourceList.vala"
	self->priv->items = _tmp0_;
#line 849 "../lib/Widgets/SourceList.vala"
	_tmp1_ = gee_hash_map_new (GRANITE_WIDGETS_SOURCE_LIST_TYPE_ITEM, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_TYPE_ITEM_MONITOR, (GBoxedCopyFunc) granite_widgets_source_list_data_model_item_monitor_ref, (GDestroyNotify) granite_widgets_source_list_data_model_item_monitor_unref, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 849 "../lib/Widgets/SourceList.vala"
	self->priv->monitors = _tmp1_;
#line 8144 "SourceList.c"
}

static void
granite_widgets_source_list_data_model_finalize (GObject * obj)
{
	GraniteWidgetsSourceListDataModel * self;
#line 721 "../lib/Widgets/SourceList.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GRANITE_WIDGETS_SOURCE_LIST_TYPE_DATA_MODEL, GraniteWidgetsSourceListDataModel);
#line 819 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (self->priv->_root);
#line 847 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (self->priv->items);
#line 849 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (self->priv->monitors);
#line 851 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (self->priv->child_tree);
#line 721 "../lib/Widgets/SourceList.vala"
	G_OBJECT_CLASS (granite_widgets_source_list_data_model_parent_class)->finalize (obj);
#line 8163 "SourceList.c"
}

/**
     * The model backing the SourceList tree.
     *
     * It monitors item property changes, and handles children additions and removals. It also controls
     * the visibility of the items based on their "visible" property, and on their number of children,
     * if they happen to be categories. Its main purpose is to provide an easy and practical interface
     * for sorting, adding, removing and updating items, eliminating the need of repeatedly dealing with
     * the Gtk.TreeModel API directly.
     */
static GType
granite_widgets_source_list_data_model_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (GraniteWidgetsSourceListDataModelClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) granite_widgets_source_list_data_model_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GraniteWidgetsSourceListDataModel), 0, (GInstanceInitFunc) granite_widgets_source_list_data_model_instance_init, NULL };
	static const GInterfaceInfo gtk_tree_drag_source_info = { (GInterfaceInitFunc) granite_widgets_source_list_data_model_gtk_tree_drag_source_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	static const GInterfaceInfo gtk_tree_drag_dest_info = { (GInterfaceInitFunc) granite_widgets_source_list_data_model_gtk_tree_drag_dest_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	GType granite_widgets_source_list_data_model_type_id;
	granite_widgets_source_list_data_model_type_id = g_type_register_static (gtk_tree_model_filter_get_type (), "GraniteWidgetsSourceListDataModel", &g_define_type_info, 0);
	g_type_add_interface_static (granite_widgets_source_list_data_model_type_id, gtk_tree_drag_source_get_type (), &gtk_tree_drag_source_info);
	g_type_add_interface_static (granite_widgets_source_list_data_model_type_id, gtk_tree_drag_dest_get_type (), &gtk_tree_drag_dest_info);
	GraniteWidgetsSourceListDataModel_private_offset = g_type_add_instance_private (granite_widgets_source_list_data_model_type_id, sizeof (GraniteWidgetsSourceListDataModelPrivate));
	return granite_widgets_source_list_data_model_type_id;
}

static GType
granite_widgets_source_list_data_model_get_type (void)
{
	static volatile gsize granite_widgets_source_list_data_model_type_id__once = 0;
	if (g_once_init_enter (&granite_widgets_source_list_data_model_type_id__once)) {
		GType granite_widgets_source_list_data_model_type_id;
		granite_widgets_source_list_data_model_type_id = granite_widgets_source_list_data_model_get_type_once ();
		g_once_init_leave (&granite_widgets_source_list_data_model_type_id__once, granite_widgets_source_list_data_model_type_id);
	}
	return granite_widgets_source_list_data_model_type_id__once;
}

static void
_vala_granite_widgets_source_list_data_model_get_property (GObject * object,
                                                           guint property_id,
                                                           GValue * value,
                                                           GParamSpec * pspec)
{
	GraniteWidgetsSourceListDataModel * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GRANITE_WIDGETS_SOURCE_LIST_TYPE_DATA_MODEL, GraniteWidgetsSourceListDataModel);
#line 721 "../lib/Widgets/SourceList.vala"
	switch (property_id) {
#line 721 "../lib/Widgets/SourceList.vala"
		case GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_ROOT_PROPERTY:
#line 721 "../lib/Widgets/SourceList.vala"
		g_value_set_object (value, granite_widgets_source_list_data_model_get_root (self));
#line 721 "../lib/Widgets/SourceList.vala"
		break;
#line 8217 "SourceList.c"
		default:
#line 721 "../lib/Widgets/SourceList.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 721 "../lib/Widgets/SourceList.vala"
		break;
#line 8223 "SourceList.c"
	}
}

static void
_vala_granite_widgets_source_list_data_model_set_property (GObject * object,
                                                           guint property_id,
                                                           const GValue * value,
                                                           GParamSpec * pspec)
{
	GraniteWidgetsSourceListDataModel * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GRANITE_WIDGETS_SOURCE_LIST_TYPE_DATA_MODEL, GraniteWidgetsSourceListDataModel);
#line 721 "../lib/Widgets/SourceList.vala"
	switch (property_id) {
#line 721 "../lib/Widgets/SourceList.vala"
		case GRANITE_WIDGETS_SOURCE_LIST_DATA_MODEL_ROOT_PROPERTY:
#line 721 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_data_model_set_root (self, g_value_get_object (value));
#line 721 "../lib/Widgets/SourceList.vala"
		break;
#line 8243 "SourceList.c"
		default:
#line 721 "../lib/Widgets/SourceList.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 721 "../lib/Widgets/SourceList.vala"
		break;
#line 8249 "SourceList.c"
	}
}

static GraniteWidgetsSourceListCellRendererIcon*
granite_widgets_source_list_cell_renderer_icon_construct (GType object_type)
{
	GraniteWidgetsSourceListCellRendererIcon * self = NULL;
#line 1472 "../lib/Widgets/SourceList.vala"
	self = (GraniteWidgetsSourceListCellRendererIcon*) g_object_new (object_type, NULL);
#line 1472 "../lib/Widgets/SourceList.vala"
	return self;
#line 8261 "SourceList.c"
}

static GraniteWidgetsSourceListCellRendererIcon*
granite_widgets_source_list_cell_renderer_icon_new (void)
{
#line 1472 "../lib/Widgets/SourceList.vala"
	return granite_widgets_source_list_cell_renderer_icon_construct (GRANITE_WIDGETS_SOURCE_LIST_TYPE_CELL_RENDERER_ICON);
#line 8269 "SourceList.c"
}

static gboolean
granite_widgets_source_list_cell_renderer_icon_real_activate (GtkCellRenderer* base,
                                                              GdkEvent* event,
                                                              GtkWidget* widget,
                                                              const gchar* path,
                                                              GdkRectangle* background_area,
                                                              GdkRectangle* cell_area,
                                                              GtkCellRendererState flags)
{
	GraniteWidgetsSourceListCellRendererIcon * self;
	gboolean result;
#line 1481 "../lib/Widgets/SourceList.vala"
	self = (GraniteWidgetsSourceListCellRendererIcon*) base;
#line 1481 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 1481 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (widget != NULL, FALSE);
#line 1481 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (path != NULL, FALSE);
#line 1481 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (background_area != NULL, FALSE);
#line 1481 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (cell_area != NULL, FALSE);
#line 1489 "../lib/Widgets/SourceList.vala"
	g_signal_emit (self, granite_widgets_source_list_cell_renderer_icon_signals[GRANITE_WIDGETS_SOURCE_LIST_CELL_RENDERER_ICON_ACTIVATED_SIGNAL], 0, path);
#line 1490 "../lib/Widgets/SourceList.vala"
	result = TRUE;
#line 1490 "../lib/Widgets/SourceList.vala"
	return result;
#line 8301 "SourceList.c"
}

static GObject *
granite_widgets_source_list_cell_renderer_icon_constructor (GType type,
                                                            guint n_construct_properties,
                                                            GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GraniteWidgetsSourceListCellRendererIcon * self;
#line 1476 "../lib/Widgets/SourceList.vala"
	parent_class = G_OBJECT_CLASS (granite_widgets_source_list_cell_renderer_icon_parent_class);
#line 1476 "../lib/Widgets/SourceList.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 1476 "../lib/Widgets/SourceList.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GRANITE_WIDGETS_SOURCE_LIST_TYPE_CELL_RENDERER_ICON, GraniteWidgetsSourceListCellRendererIcon);
#line 1477 "../lib/Widgets/SourceList.vala"
	g_object_set ((GtkCellRenderer*) self, "mode", GTK_CELL_RENDERER_MODE_ACTIVATABLE, NULL);
#line 1478 "../lib/Widgets/SourceList.vala"
	g_object_set ((GtkCellRendererPixbuf*) self, "stock-size", (guint) GRANITE_WIDGETS_SOURCE_LIST_CELL_RENDERER_ICON_ICON_SIZE, NULL);
#line 1476 "../lib/Widgets/SourceList.vala"
	return obj;
#line 8324 "SourceList.c"
}

static void
granite_widgets_source_list_cell_renderer_icon_class_init (GraniteWidgetsSourceListCellRendererIconClass * klass,
                                                           gpointer klass_data)
{
#line 1467 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_cell_renderer_icon_parent_class = g_type_class_peek_parent (klass);
#line 1467 "../lib/Widgets/SourceList.vala"
	((GtkCellRendererClass *) klass)->activate = (gboolean (*) (GtkCellRenderer*, GdkEvent*, GtkWidget*, const gchar*, GdkRectangle*, GdkRectangle*, GtkCellRendererState)) granite_widgets_source_list_cell_renderer_icon_real_activate;
#line 1467 "../lib/Widgets/SourceList.vala"
	G_OBJECT_CLASS (klass)->constructor = granite_widgets_source_list_cell_renderer_icon_constructor;
#line 1467 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_cell_renderer_icon_signals[GRANITE_WIDGETS_SOURCE_LIST_CELL_RENDERER_ICON_ACTIVATED_SIGNAL] = g_signal_new ("activated", GRANITE_WIDGETS_SOURCE_LIST_TYPE_CELL_RENDERER_ICON, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, 1, G_TYPE_STRING);
#line 8339 "SourceList.c"
}

static void
granite_widgets_source_list_cell_renderer_icon_instance_init (GraniteWidgetsSourceListCellRendererIcon * self,
                                                              gpointer klass)
{
}

/**
     * Class responsible for rendering Item.icon and Item.activatable. It also
     * notifies about clicks through the activated() signal.
     */
static GType
granite_widgets_source_list_cell_renderer_icon_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (GraniteWidgetsSourceListCellRendererIconClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) granite_widgets_source_list_cell_renderer_icon_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GraniteWidgetsSourceListCellRendererIcon), 0, (GInstanceInitFunc) granite_widgets_source_list_cell_renderer_icon_instance_init, NULL };
	GType granite_widgets_source_list_cell_renderer_icon_type_id;
	granite_widgets_source_list_cell_renderer_icon_type_id = g_type_register_static (gtk_cell_renderer_pixbuf_get_type (), "GraniteWidgetsSourceListCellRendererIcon", &g_define_type_info, 0);
	return granite_widgets_source_list_cell_renderer_icon_type_id;
}

static GType
granite_widgets_source_list_cell_renderer_icon_get_type (void)
{
	static volatile gsize granite_widgets_source_list_cell_renderer_icon_type_id__once = 0;
	if (g_once_init_enter (&granite_widgets_source_list_cell_renderer_icon_type_id__once)) {
		GType granite_widgets_source_list_cell_renderer_icon_type_id;
		granite_widgets_source_list_cell_renderer_icon_type_id = granite_widgets_source_list_cell_renderer_icon_get_type_once ();
		g_once_init_leave (&granite_widgets_source_list_cell_renderer_icon_type_id__once, granite_widgets_source_list_cell_renderer_icon_type_id);
	}
	return granite_widgets_source_list_cell_renderer_icon_type_id__once;
}

static inline gpointer
granite_widgets_source_list_cell_renderer_spacer_get_instance_private (GraniteWidgetsSourceListCellRendererSpacer* self)
{
	return G_STRUCT_MEMBER_P (self, GraniteWidgetsSourceListCellRendererSpacer_private_offset);
}

static gint
granite_widgets_source_list_cell_renderer_spacer_get_level (GraniteWidgetsSourceListCellRendererSpacer* self)
{
	gint result;
#line 1503 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 1503 "../lib/Widgets/SourceList.vala"
	result = self->priv->_level;
#line 1503 "../lib/Widgets/SourceList.vala"
	return result;
#line 8389 "SourceList.c"
}

static void
granite_widgets_source_list_cell_renderer_spacer_set_level (GraniteWidgetsSourceListCellRendererSpacer* self,
                                                            gint value)
{
	gint old_value;
#line 1503 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 1503 "../lib/Widgets/SourceList.vala"
	old_value = granite_widgets_source_list_cell_renderer_spacer_get_level (self);
#line 1503 "../lib/Widgets/SourceList.vala"
	if (old_value != value) {
#line 1503 "../lib/Widgets/SourceList.vala"
		self->priv->_level = value;
#line 1503 "../lib/Widgets/SourceList.vala"
		g_object_notify_by_pspec ((GObject *) self, granite_widgets_source_list_cell_renderer_spacer_properties[GRANITE_WIDGETS_SOURCE_LIST_CELL_RENDERER_SPACER_LEVEL_PROPERTY]);
#line 8407 "SourceList.c"
	}
}

static GtkSizeRequestMode
granite_widgets_source_list_cell_renderer_spacer_real_get_request_mode (GtkCellRenderer* base)
{
	GraniteWidgetsSourceListCellRendererSpacer * self;
	GtkSizeRequestMode result;
#line 1505 "../lib/Widgets/SourceList.vala"
	self = (GraniteWidgetsSourceListCellRendererSpacer*) base;
#line 1506 "../lib/Widgets/SourceList.vala"
	result = GTK_SIZE_REQUEST_HEIGHT_FOR_WIDTH;
#line 1506 "../lib/Widgets/SourceList.vala"
	return result;
#line 8422 "SourceList.c"
}

static void
granite_widgets_source_list_cell_renderer_spacer_real_get_preferred_width (GtkCellRenderer* base,
                                                                           GtkWidget* widget,
                                                                           gint* min_size,
                                                                           gint* natural_size)
{
	GraniteWidgetsSourceListCellRendererSpacer * self;
	gint _vala_min_size = 0;
	gint _vala_natural_size = 0;
	guint _tmp0_;
	guint _tmp1_;
#line 1509 "../lib/Widgets/SourceList.vala"
	self = (GraniteWidgetsSourceListCellRendererSpacer*) base;
#line 1509 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (widget != NULL);
#line 1510 "../lib/Widgets/SourceList.vala"
	g_object_get ((GtkCellRenderer*) self, "xpad", &_tmp0_, NULL);
#line 1510 "../lib/Widgets/SourceList.vala"
	_tmp1_ = _tmp0_;
#line 1510 "../lib/Widgets/SourceList.vala"
	_vala_natural_size = 2 * ((gint) _tmp1_);
#line 1510 "../lib/Widgets/SourceList.vala"
	_vala_min_size = _vala_natural_size;
#line 1509 "../lib/Widgets/SourceList.vala"
	if (min_size) {
#line 1509 "../lib/Widgets/SourceList.vala"
		*min_size = _vala_min_size;
#line 8452 "SourceList.c"
	}
#line 1509 "../lib/Widgets/SourceList.vala"
	if (natural_size) {
#line 1509 "../lib/Widgets/SourceList.vala"
		*natural_size = _vala_natural_size;
#line 8458 "SourceList.c"
	}
}

static void
granite_widgets_source_list_cell_renderer_spacer_real_get_preferred_height_for_width (GtkCellRenderer* base,
                                                                                      GtkWidget* widget,
                                                                                      gint width,
                                                                                      gint* min_height,
                                                                                      gint* natural_height)
{
	GraniteWidgetsSourceListCellRendererSpacer * self;
	gint _vala_min_height = 0;
	gint _vala_natural_height = 0;
	guint _tmp0_;
	guint _tmp1_;
#line 1513 "../lib/Widgets/SourceList.vala"
	self = (GraniteWidgetsSourceListCellRendererSpacer*) base;
#line 1513 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (widget != NULL);
#line 1519 "../lib/Widgets/SourceList.vala"
	g_object_get ((GtkCellRenderer*) self, "ypad", &_tmp0_, NULL);
#line 1519 "../lib/Widgets/SourceList.vala"
	_tmp1_ = _tmp0_;
#line 1519 "../lib/Widgets/SourceList.vala"
	_vala_natural_height = 2 * ((gint) _tmp1_);
#line 1519 "../lib/Widgets/SourceList.vala"
	_vala_min_height = _vala_natural_height;
#line 1513 "../lib/Widgets/SourceList.vala"
	if (min_height) {
#line 1513 "../lib/Widgets/SourceList.vala"
		*min_height = _vala_min_height;
#line 8490 "SourceList.c"
	}
#line 1513 "../lib/Widgets/SourceList.vala"
	if (natural_height) {
#line 1513 "../lib/Widgets/SourceList.vala"
		*natural_height = _vala_natural_height;
#line 8496 "SourceList.c"
	}
}

static void
granite_widgets_source_list_cell_renderer_spacer_real_render (GtkCellRenderer* base,
                                                              cairo_t* context,
                                                              GtkWidget* widget,
                                                              GdkRectangle* bg_area,
                                                              GdkRectangle* cell_area,
                                                              GtkCellRendererState flags)
{
	GraniteWidgetsSourceListCellRendererSpacer * self;
#line 1522 "../lib/Widgets/SourceList.vala"
	self = (GraniteWidgetsSourceListCellRendererSpacer*) base;
#line 1522 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (context != NULL);
#line 1522 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (widget != NULL);
#line 1522 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (bg_area != NULL);
#line 1522 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (cell_area != NULL);
#line 8519 "SourceList.c"
}

static GraniteWidgetsSourceListCellRendererSpacer*
granite_widgets_source_list_cell_renderer_spacer_construct (GType object_type)
{
	GraniteWidgetsSourceListCellRendererSpacer * self = NULL;
#line 1499 "../lib/Widgets/SourceList.vala"
	self = (GraniteWidgetsSourceListCellRendererSpacer*) g_object_new (object_type, NULL);
#line 1499 "../lib/Widgets/SourceList.vala"
	return self;
#line 8530 "SourceList.c"
}

static GraniteWidgetsSourceListCellRendererSpacer*
granite_widgets_source_list_cell_renderer_spacer_new (void)
{
#line 1499 "../lib/Widgets/SourceList.vala"
	return granite_widgets_source_list_cell_renderer_spacer_construct (GRANITE_WIDGETS_SOURCE_LIST_TYPE_CELL_RENDERER_SPACER);
#line 8538 "SourceList.c"
}

static void
granite_widgets_source_list_cell_renderer_spacer_class_init (GraniteWidgetsSourceListCellRendererSpacerClass * klass,
                                                             gpointer klass_data)
{
#line 1499 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_cell_renderer_spacer_parent_class = g_type_class_peek_parent (klass);
#line 1499 "../lib/Widgets/SourceList.vala"
	g_type_class_adjust_private_offset (klass, &GraniteWidgetsSourceListCellRendererSpacer_private_offset);
#line 1499 "../lib/Widgets/SourceList.vala"
	((GtkCellRendererClass *) klass)->get_request_mode = (GtkSizeRequestMode (*) (GtkCellRenderer*)) granite_widgets_source_list_cell_renderer_spacer_real_get_request_mode;
#line 1499 "../lib/Widgets/SourceList.vala"
	((GtkCellRendererClass *) klass)->get_preferred_width = (void (*) (GtkCellRenderer*, GtkWidget*, gint*, gint*)) granite_widgets_source_list_cell_renderer_spacer_real_get_preferred_width;
#line 1499 "../lib/Widgets/SourceList.vala"
	((GtkCellRendererClass *) klass)->get_preferred_height_for_width = (void (*) (GtkCellRenderer*, GtkWidget*, gint, gint*, gint*)) granite_widgets_source_list_cell_renderer_spacer_real_get_preferred_height_for_width;
#line 1499 "../lib/Widgets/SourceList.vala"
	((GtkCellRendererClass *) klass)->render = (void (*) (GtkCellRenderer*, cairo_t*, GtkWidget*, GdkRectangle*, GdkRectangle*, GtkCellRendererState)) granite_widgets_source_list_cell_renderer_spacer_real_render;
#line 1499 "../lib/Widgets/SourceList.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_granite_widgets_source_list_cell_renderer_spacer_get_property;
#line 1499 "../lib/Widgets/SourceList.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_granite_widgets_source_list_cell_renderer_spacer_set_property;
#line 1499 "../lib/Widgets/SourceList.vala"
	G_OBJECT_CLASS (klass)->finalize = granite_widgets_source_list_cell_renderer_spacer_finalize;
#line 8563 "SourceList.c"
	/**
	         * Indentation level represented by this cell renderer
	         */
#line 1499 "../lib/Widgets/SourceList.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GRANITE_WIDGETS_SOURCE_LIST_CELL_RENDERER_SPACER_LEVEL_PROPERTY, granite_widgets_source_list_cell_renderer_spacer_properties[GRANITE_WIDGETS_SOURCE_LIST_CELL_RENDERER_SPACER_LEVEL_PROPERTY] = g_param_spec_int ("level", "level", "level", G_MININT, G_MAXINT, -1, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 8569 "SourceList.c"
}

static void
granite_widgets_source_list_cell_renderer_spacer_instance_init (GraniteWidgetsSourceListCellRendererSpacer * self,
                                                                gpointer klass)
{
#line 1499 "../lib/Widgets/SourceList.vala"
	self->priv = granite_widgets_source_list_cell_renderer_spacer_get_instance_private (self);
#line 1503 "../lib/Widgets/SourceList.vala"
	self->priv->_level = -1;
#line 8580 "SourceList.c"
}

static void
granite_widgets_source_list_cell_renderer_spacer_finalize (GObject * obj)
{
	GraniteWidgetsSourceListCellRendererSpacer * self;
#line 1499 "../lib/Widgets/SourceList.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GRANITE_WIDGETS_SOURCE_LIST_TYPE_CELL_RENDERER_SPACER, GraniteWidgetsSourceListCellRendererSpacer);
#line 1499 "../lib/Widgets/SourceList.vala"
	G_OBJECT_CLASS (granite_widgets_source_list_cell_renderer_spacer_parent_class)->finalize (obj);
#line 8591 "SourceList.c"
}

/**
     * A cell renderer that only adds space.
     */
static GType
granite_widgets_source_list_cell_renderer_spacer_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (GraniteWidgetsSourceListCellRendererSpacerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) granite_widgets_source_list_cell_renderer_spacer_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GraniteWidgetsSourceListCellRendererSpacer), 0, (GInstanceInitFunc) granite_widgets_source_list_cell_renderer_spacer_instance_init, NULL };
	GType granite_widgets_source_list_cell_renderer_spacer_type_id;
	granite_widgets_source_list_cell_renderer_spacer_type_id = g_type_register_static (gtk_cell_renderer_get_type (), "GraniteWidgetsSourceListCellRendererSpacer", &g_define_type_info, 0);
	GraniteWidgetsSourceListCellRendererSpacer_private_offset = g_type_add_instance_private (granite_widgets_source_list_cell_renderer_spacer_type_id, sizeof (GraniteWidgetsSourceListCellRendererSpacerPrivate));
	return granite_widgets_source_list_cell_renderer_spacer_type_id;
}

static GType
granite_widgets_source_list_cell_renderer_spacer_get_type (void)
{
	static volatile gsize granite_widgets_source_list_cell_renderer_spacer_type_id__once = 0;
	if (g_once_init_enter (&granite_widgets_source_list_cell_renderer_spacer_type_id__once)) {
		GType granite_widgets_source_list_cell_renderer_spacer_type_id;
		granite_widgets_source_list_cell_renderer_spacer_type_id = granite_widgets_source_list_cell_renderer_spacer_get_type_once ();
		g_once_init_leave (&granite_widgets_source_list_cell_renderer_spacer_type_id__once, granite_widgets_source_list_cell_renderer_spacer_type_id);
	}
	return granite_widgets_source_list_cell_renderer_spacer_type_id__once;
}

static void
_vala_granite_widgets_source_list_cell_renderer_spacer_get_property (GObject * object,
                                                                     guint property_id,
                                                                     GValue * value,
                                                                     GParamSpec * pspec)
{
	GraniteWidgetsSourceListCellRendererSpacer * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GRANITE_WIDGETS_SOURCE_LIST_TYPE_CELL_RENDERER_SPACER, GraniteWidgetsSourceListCellRendererSpacer);
#line 1499 "../lib/Widgets/SourceList.vala"
	switch (property_id) {
#line 1499 "../lib/Widgets/SourceList.vala"
		case GRANITE_WIDGETS_SOURCE_LIST_CELL_RENDERER_SPACER_LEVEL_PROPERTY:
#line 1499 "../lib/Widgets/SourceList.vala"
		g_value_set_int (value, granite_widgets_source_list_cell_renderer_spacer_get_level (self));
#line 1499 "../lib/Widgets/SourceList.vala"
		break;
#line 8635 "SourceList.c"
		default:
#line 1499 "../lib/Widgets/SourceList.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 1499 "../lib/Widgets/SourceList.vala"
		break;
#line 8641 "SourceList.c"
	}
}

static void
_vala_granite_widgets_source_list_cell_renderer_spacer_set_property (GObject * object,
                                                                     guint property_id,
                                                                     const GValue * value,
                                                                     GParamSpec * pspec)
{
	GraniteWidgetsSourceListCellRendererSpacer * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GRANITE_WIDGETS_SOURCE_LIST_TYPE_CELL_RENDERER_SPACER, GraniteWidgetsSourceListCellRendererSpacer);
#line 1499 "../lib/Widgets/SourceList.vala"
	switch (property_id) {
#line 1499 "../lib/Widgets/SourceList.vala"
		case GRANITE_WIDGETS_SOURCE_LIST_CELL_RENDERER_SPACER_LEVEL_PROPERTY:
#line 1499 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_cell_renderer_spacer_set_level (self, g_value_get_int (value));
#line 1499 "../lib/Widgets/SourceList.vala"
		break;
#line 8661 "SourceList.c"
		default:
#line 1499 "../lib/Widgets/SourceList.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 1499 "../lib/Widgets/SourceList.vala"
		break;
#line 8667 "SourceList.c"
	}
}

static inline gpointer
granite_widgets_source_list_tree_get_instance_private (GraniteWidgetsSourceListTree* self)
{
	return G_STRUCT_MEMBER_P (self, GraniteWidgetsSourceListTree_private_offset);
}

static GType
granite_widgets_source_list_tree_column_get_type_once (void)
{
	static const GEnumValue values[] = {{GRANITE_WIDGETS_SOURCE_LIST_TREE_COLUMN_ITEM, "GRANITE_WIDGETS_SOURCE_LIST_TREE_COLUMN_ITEM", "item"}, {GRANITE_WIDGETS_SOURCE_LIST_TREE_COLUMN_N_COLS, "GRANITE_WIDGETS_SOURCE_LIST_TREE_COLUMN_N_COLS", "n-cols"}, {0, NULL, NULL}};
	GType granite_widgets_source_list_tree_column_type_id;
	granite_widgets_source_list_tree_column_type_id = g_enum_register_static ("GraniteWidgetsSourceListTreeColumn", values);
	return granite_widgets_source_list_tree_column_type_id;
}

static GType
granite_widgets_source_list_tree_column_get_type (void)
{
	static volatile gsize granite_widgets_source_list_tree_column_type_id__once = 0;
	if (g_once_init_enter (&granite_widgets_source_list_tree_column_type_id__once)) {
		GType granite_widgets_source_list_tree_column_type_id;
		granite_widgets_source_list_tree_column_type_id = granite_widgets_source_list_tree_column_get_type_once ();
		g_once_init_leave (&granite_widgets_source_list_tree_column_type_id__once, granite_widgets_source_list_tree_column_type_id);
	}
	return granite_widgets_source_list_tree_column_type_id__once;
}

static GraniteWidgetsSourceListDataModel*
granite_widgets_source_list_tree_get_data_model (GraniteWidgetsSourceListTree* self)
{
	GraniteWidgetsSourceListDataModel* result;
	GraniteWidgetsSourceListDataModel* _tmp0_;
#line 1542 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 1542 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->_data_model;
#line 1542 "../lib/Widgets/SourceList.vala"
	result = _tmp0_;
#line 1542 "../lib/Widgets/SourceList.vala"
	return result;
#line 8711 "SourceList.c"
}

static void
granite_widgets_source_list_tree_set_data_model (GraniteWidgetsSourceListTree* self,
                                                 GraniteWidgetsSourceListDataModel* value)
{
	GraniteWidgetsSourceListDataModel* old_value;
#line 1542 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 1542 "../lib/Widgets/SourceList.vala"
	old_value = granite_widgets_source_list_tree_get_data_model (self);
#line 1542 "../lib/Widgets/SourceList.vala"
	if (old_value != value) {
#line 8725 "SourceList.c"
		GraniteWidgetsSourceListDataModel* _tmp0_;
#line 1542 "../lib/Widgets/SourceList.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 1542 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (self->priv->_data_model);
#line 1542 "../lib/Widgets/SourceList.vala"
		self->priv->_data_model = _tmp0_;
#line 1542 "../lib/Widgets/SourceList.vala"
		g_object_notify_by_pspec ((GObject *) self, granite_widgets_source_list_tree_properties[GRANITE_WIDGETS_SOURCE_LIST_TREE_DATA_MODEL_PROPERTY]);
#line 8735 "SourceList.c"
	}
}

static GraniteWidgetsSourceListItem*
granite_widgets_source_list_tree_get_selected_item (GraniteWidgetsSourceListTree* self)
{
	GraniteWidgetsSourceListItem* result;
	GraniteWidgetsSourceListItem* _tmp0_;
#line 1547 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 1547 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->selected;
#line 1547 "../lib/Widgets/SourceList.vala"
	result = _tmp0_;
#line 1547 "../lib/Widgets/SourceList.vala"
	return result;
#line 8752 "SourceList.c"
}

static void
granite_widgets_source_list_tree_set_selected_item (GraniteWidgetsSourceListTree* self,
                                                    GraniteWidgetsSourceListItem* value)
{
#line 1548 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 1548 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_tree_set_selected (self, value, TRUE);
#line 1548 "../lib/Widgets/SourceList.vala"
	g_object_notify_by_pspec ((GObject *) self, granite_widgets_source_list_tree_properties[GRANITE_WIDGETS_SOURCE_LIST_TREE_SELECTED_ITEM_PROPERTY]);
#line 8765 "SourceList.c"
}

static gboolean
granite_widgets_source_list_tree_get_editing (GraniteWidgetsSourceListTree* self)
{
	gboolean result;
	GtkCellRendererText* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
#line 1552 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 1552 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->text_cell;
#line 1552 "../lib/Widgets/SourceList.vala"
	g_object_get ((GtkCellRenderer*) _tmp0_, "editing", &_tmp1_, NULL);
#line 1552 "../lib/Widgets/SourceList.vala"
	_tmp2_ = _tmp1_;
#line 1552 "../lib/Widgets/SourceList.vala"
	result = _tmp2_;
#line 1552 "../lib/Widgets/SourceList.vala"
	return result;
#line 8787 "SourceList.c"
}

static PangoEllipsizeMode
granite_widgets_source_list_tree_get_ellipsize_mode (GraniteWidgetsSourceListTree* self)
{
	PangoEllipsizeMode result;
	GtkCellRendererText* _tmp0_;
	PangoEllipsizeMode _tmp1_;
	PangoEllipsizeMode _tmp2_;
#line 1556 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 1556 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->text_cell;
#line 1556 "../lib/Widgets/SourceList.vala"
	g_object_get (_tmp0_, "ellipsize", &_tmp1_, NULL);
#line 1556 "../lib/Widgets/SourceList.vala"
	_tmp2_ = _tmp1_;
#line 1556 "../lib/Widgets/SourceList.vala"
	result = _tmp2_;
#line 1556 "../lib/Widgets/SourceList.vala"
	return result;
#line 8809 "SourceList.c"
}

static void
granite_widgets_source_list_tree_set_ellipsize_mode (GraniteWidgetsSourceListTree* self,
                                                     PangoEllipsizeMode value)
{
	GtkCellRendererText* _tmp0_;
#line 1557 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 1557 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->text_cell;
#line 1557 "../lib/Widgets/SourceList.vala"
	g_object_set (_tmp0_, "ellipsize", value, NULL);
#line 1557 "../lib/Widgets/SourceList.vala"
	g_object_notify_by_pspec ((GObject *) self, granite_widgets_source_list_tree_properties[GRANITE_WIDGETS_SOURCE_LIST_TREE_ELLIPSIZE_MODE_PROPERTY]);
#line 8825 "SourceList.c"
}

static GraniteWidgetsSourceListTree*
granite_widgets_source_list_tree_construct (GType object_type,
                                            GraniteWidgetsSourceListDataModel* data_model)
{
	GraniteWidgetsSourceListTree * self = NULL;
#line 1623 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (data_model != NULL, NULL);
#line 1624 "../lib/Widgets/SourceList.vala"
	self = (GraniteWidgetsSourceListTree*) g_object_new (object_type, "data-model", data_model, NULL);
#line 1623 "../lib/Widgets/SourceList.vala"
	return self;
#line 8839 "SourceList.c"
}

static GraniteWidgetsSourceListTree*
granite_widgets_source_list_tree_new (GraniteWidgetsSourceListDataModel* data_model)
{
#line 1623 "../lib/Widgets/SourceList.vala"
	return granite_widgets_source_list_tree_construct (GRANITE_WIDGETS_SOURCE_LIST_TYPE_TREE, data_model);
#line 8847 "SourceList.c"
}

static gpointer
_gtk_target_list_ref0 (gpointer self)
{
#line 1772 "../lib/Widgets/SourceList.vala"
	return self ? gtk_target_list_ref (self) : NULL;
#line 8855 "SourceList.c"
}

static gboolean
granite_widgets_source_list_tree_real_drag_motion (GtkWidget* base,
                                                   GdkDragContext* context,
                                                   gint x,
                                                   gint y,
                                                   guint time)
{
	GraniteWidgetsSourceListTree * self;
	GtkTreePath* suggested_path = NULL;
	GtkTreePath* current_path = NULL;
	GtkTreeViewDropPosition suggested_pos = 0;
	GtkTreeViewDropPosition current_pos = 0;
	GtkTreePath* _tmp0_ = NULL;
	GtkTreeViewDropPosition _tmp1_ = 0;
	gboolean _tmp2_;
	gboolean result;
#line 1730 "../lib/Widgets/SourceList.vala"
	self = (GraniteWidgetsSourceListTree*) base;
#line 1730 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (context != NULL, FALSE);
#line 1732 "../lib/Widgets/SourceList.vala"
	if (!GTK_WIDGET_CLASS (granite_widgets_source_list_tree_parent_class)->drag_motion ((GtkWidget*) G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), context, x, y, time)) {
#line 1733 "../lib/Widgets/SourceList.vala"
		result = FALSE;
#line 1733 "../lib/Widgets/SourceList.vala"
		return result;
#line 8884 "SourceList.c"
	}
#line 1738 "../lib/Widgets/SourceList.vala"
	_tmp2_ = gtk_tree_view_get_dest_row_at_pos ((GtkTreeView*) self, x, y, &_tmp0_, &_tmp1_);
#line 1738 "../lib/Widgets/SourceList.vala"
	__vala_GtkTreePath_free0 (suggested_path);
#line 1738 "../lib/Widgets/SourceList.vala"
	suggested_path = _tmp0_;
#line 1738 "../lib/Widgets/SourceList.vala"
	suggested_pos = _tmp1_;
#line 1738 "../lib/Widgets/SourceList.vala"
	if (_tmp2_) {
#line 8896 "SourceList.c"
		GtkTreePath* _tmp3_ = NULL;
		GtkTreeViewDropPosition _tmp4_ = 0;
		gboolean _tmp5_ = FALSE;
		GtkTreePath* _tmp6_;
#line 1742 "../lib/Widgets/SourceList.vala"
		gtk_tree_view_get_drag_dest_row ((GtkTreeView*) self, &_tmp3_, &_tmp4_);
#line 1742 "../lib/Widgets/SourceList.vala"
		__vala_GtkTreePath_free0 (current_path);
#line 1742 "../lib/Widgets/SourceList.vala"
		current_path = _tmp3_;
#line 1742 "../lib/Widgets/SourceList.vala"
		current_pos = _tmp4_;
#line 1744 "../lib/Widgets/SourceList.vala"
		_tmp6_ = current_path;
#line 1744 "../lib/Widgets/SourceList.vala"
		if (_tmp6_ != NULL) {
#line 8913 "SourceList.c"
			GtkTreePath* _tmp7_;
			GtkTreePath* _tmp8_;
#line 1744 "../lib/Widgets/SourceList.vala"
			_tmp7_ = suggested_path;
#line 1744 "../lib/Widgets/SourceList.vala"
			_tmp8_ = current_path;
#line 1744 "../lib/Widgets/SourceList.vala"
			_tmp5_ = gtk_tree_path_compare (_tmp7_, _tmp8_) == 0;
#line 8922 "SourceList.c"
		} else {
#line 1744 "../lib/Widgets/SourceList.vala"
			_tmp5_ = FALSE;
#line 8926 "SourceList.c"
		}
#line 1744 "../lib/Widgets/SourceList.vala"
		if (_tmp5_) {
#line 8930 "SourceList.c"
			GtkWidget* source_widget = NULL;
			GtkWidget* _tmp9_;
			GtkWidget* _tmp10_;
			gboolean dragging_treemodel_row = FALSE;
			GtkWidget* _tmp11_;
#line 1748 "../lib/Widgets/SourceList.vala"
			_tmp9_ = gtk_drag_get_source_widget (context);
#line 1748 "../lib/Widgets/SourceList.vala"
			_tmp10_ = _g_object_ref0 (_tmp9_);
#line 1748 "../lib/Widgets/SourceList.vala"
			source_widget = _tmp10_;
#line 1749 "../lib/Widgets/SourceList.vala"
			_tmp11_ = source_widget;
#line 1749 "../lib/Widgets/SourceList.vala"
			dragging_treemodel_row = _tmp11_ == G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget);
#line 1751 "../lib/Widgets/SourceList.vala"
			if (dragging_treemodel_row) {
#line 1754 "../lib/Widgets/SourceList.vala"
				if (current_pos != GTK_TREE_VIEW_DROP_BEFORE) {
#line 1755 "../lib/Widgets/SourceList.vala"
					if (current_pos == GTK_TREE_VIEW_DROP_INTO_OR_BEFORE) {
#line 8952 "SourceList.c"
						GtkTreePath* _tmp12_;
#line 1756 "../lib/Widgets/SourceList.vala"
						_tmp12_ = current_path;
#line 1756 "../lib/Widgets/SourceList.vala"
						gtk_tree_view_set_drag_dest_row ((GtkTreeView*) self, _tmp12_, GTK_TREE_VIEW_DROP_BEFORE);
#line 8958 "SourceList.c"
					} else {
#line 1758 "../lib/Widgets/SourceList.vala"
						gtk_tree_view_set_drag_dest_row ((GtkTreeView*) self, NULL, GTK_TREE_VIEW_DROP_AFTER);
#line 8962 "SourceList.c"
					}
				}
			} else {
				GraniteWidgetsSourceListDragDest* dest = NULL;
				GraniteWidgetsSourceListDataModel* _tmp15_;
				GtkTreePath* _tmp16_;
				GraniteWidgetsSourceListItem* _tmp17_;
				GraniteWidgetsSourceListDragDest* _tmp18_;
				GraniteWidgetsSourceListDragDest* _tmp19_;
#line 1763 "../lib/Widgets/SourceList.vala"
				if (current_pos == GTK_TREE_VIEW_DROP_BEFORE) {
#line 8974 "SourceList.c"
					GtkTreePath* _tmp13_;
#line 1764 "../lib/Widgets/SourceList.vala"
					_tmp13_ = current_path;
#line 1764 "../lib/Widgets/SourceList.vala"
					gtk_tree_view_set_drag_dest_row ((GtkTreeView*) self, _tmp13_, GTK_TREE_VIEW_DROP_INTO_OR_BEFORE);
#line 8980 "SourceList.c"
				} else {
#line 1765 "../lib/Widgets/SourceList.vala"
					if (current_pos == GTK_TREE_VIEW_DROP_AFTER) {
#line 8984 "SourceList.c"
						GtkTreePath* _tmp14_;
#line 1766 "../lib/Widgets/SourceList.vala"
						_tmp14_ = current_path;
#line 1766 "../lib/Widgets/SourceList.vala"
						gtk_tree_view_set_drag_dest_row ((GtkTreeView*) self, _tmp14_, GTK_TREE_VIEW_DROP_INTO_OR_AFTER);
#line 8990 "SourceList.c"
					}
				}
#line 1769 "../lib/Widgets/SourceList.vala"
				_tmp15_ = self->priv->_data_model;
#line 1769 "../lib/Widgets/SourceList.vala"
				_tmp16_ = current_path;
#line 1769 "../lib/Widgets/SourceList.vala"
				_tmp17_ = granite_widgets_source_list_data_model_get_item_from_path (_tmp15_, _tmp16_);
#line 1769 "../lib/Widgets/SourceList.vala"
				_tmp18_ = GRANITE_WIDGETS_IS_SOURCE_LIST_DRAG_DEST (_tmp17_) ? ((GraniteWidgetsSourceListDragDest*) _tmp17_) : NULL;
#line 1769 "../lib/Widgets/SourceList.vala"
				if (_tmp18_ == NULL) {
#line 1769 "../lib/Widgets/SourceList.vala"
					_g_object_unref0 (_tmp17_);
#line 9005 "SourceList.c"
				}
#line 1769 "../lib/Widgets/SourceList.vala"
				dest = _tmp18_;
#line 1771 "../lib/Widgets/SourceList.vala"
				_tmp19_ = dest;
#line 1771 "../lib/Widgets/SourceList.vala"
				if (_tmp19_ != NULL) {
#line 9013 "SourceList.c"
					GtkTargetList* target_list = NULL;
					GtkTargetList* _tmp20_;
					GtkTargetList* _tmp21_;
					GdkAtom target = (GdkAtom) 0U;
					GtkTargetList* _tmp22_;
#line 1772 "../lib/Widgets/SourceList.vala"
					_tmp20_ = gtk_drag_dest_get_target_list ((GtkWidget*) self);
#line 1772 "../lib/Widgets/SourceList.vala"
					_tmp21_ = _gtk_target_list_ref0 (_tmp20_);
#line 1772 "../lib/Widgets/SourceList.vala"
					target_list = _tmp21_;
#line 1773 "../lib/Widgets/SourceList.vala"
					_tmp22_ = target_list;
#line 1773 "../lib/Widgets/SourceList.vala"
					target = gtk_drag_dest_find_target ((GtkWidget*) self, context, _tmp22_);
#line 1777 "../lib/Widgets/SourceList.vala"
					g_object_set_data_full ((GObject*) context, "suggested-dnd-action", (gpointer) ((gintptr) gdk_drag_context_get_suggested_action (context)), NULL);
#line 1778 "../lib/Widgets/SourceList.vala"
					gtk_drag_get_data ((GtkWidget*) self, context, target, (guint32) time);
#line 1771 "../lib/Widgets/SourceList.vala"
					_gtk_target_list_unref0 (target_list);
#line 9035 "SourceList.c"
				} else {
#line 1781 "../lib/Widgets/SourceList.vala"
					gtk_tree_view_set_drag_dest_row ((GtkTreeView*) self, NULL, GTK_TREE_VIEW_DROP_BEFORE);
#line 9039 "SourceList.c"
				}
#line 1751 "../lib/Widgets/SourceList.vala"
				_g_object_unref0 (dest);
#line 9043 "SourceList.c"
			}
#line 1744 "../lib/Widgets/SourceList.vala"
			_g_object_unref0 (source_widget);
#line 9047 "SourceList.c"
		}
	} else {
#line 1787 "../lib/Widgets/SourceList.vala"
		gtk_tree_view_set_drag_dest_row ((GtkTreeView*) self, NULL, GTK_TREE_VIEW_DROP_AFTER);
#line 1788 "../lib/Widgets/SourceList.vala"
		result = FALSE;
#line 1788 "../lib/Widgets/SourceList.vala"
		__vala_GtkTreePath_free0 (current_path);
#line 1788 "../lib/Widgets/SourceList.vala"
		__vala_GtkTreePath_free0 (suggested_path);
#line 1788 "../lib/Widgets/SourceList.vala"
		return result;
#line 9060 "SourceList.c"
	}
#line 1791 "../lib/Widgets/SourceList.vala"
	result = TRUE;
#line 1791 "../lib/Widgets/SourceList.vala"
	__vala_GtkTreePath_free0 (current_path);
#line 1791 "../lib/Widgets/SourceList.vala"
	__vala_GtkTreePath_free0 (suggested_path);
#line 1791 "../lib/Widgets/SourceList.vala"
	return result;
#line 9070 "SourceList.c"
}

static void
granite_widgets_source_list_tree_real_drag_data_received (GtkWidget* base,
                                                          GdkDragContext* context,
                                                          gint x,
                                                          gint y,
                                                          GtkSelectionData* selection_data,
                                                          guint info,
                                                          guint time)
{
	GraniteWidgetsSourceListTree * self;
	GtkTargetList* target_list = NULL;
	GtkTargetList* _tmp0_;
	GtkTargetList* _tmp1_;
	GdkAtom target = (GdkAtom) 0U;
	GtkTargetList* _tmp2_;
	GtkTreePath* path = NULL;
	GtkTreeViewDropPosition pos = 0;
	gconstpointer _tmp3_;
#line 1794 "../lib/Widgets/SourceList.vala"
	self = (GraniteWidgetsSourceListTree*) base;
#line 1794 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (context != NULL);
#line 1794 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (selection_data != NULL);
#line 1802 "../lib/Widgets/SourceList.vala"
	_tmp0_ = gtk_drag_dest_get_target_list ((GtkWidget*) self);
#line 1802 "../lib/Widgets/SourceList.vala"
	_tmp1_ = _gtk_target_list_ref0 (_tmp0_);
#line 1802 "../lib/Widgets/SourceList.vala"
	target_list = _tmp1_;
#line 1803 "../lib/Widgets/SourceList.vala"
	_tmp2_ = target_list;
#line 1803 "../lib/Widgets/SourceList.vala"
	target = gtk_drag_dest_find_target ((GtkWidget*) self, context, _tmp2_);
#line 1805 "../lib/Widgets/SourceList.vala"
	if (target == gdk_atom_intern_static_string ("GTK_TREE_MODEL_ROW")) {
#line 1806 "../lib/Widgets/SourceList.vala"
		GTK_WIDGET_CLASS (granite_widgets_source_list_tree_parent_class)->drag_data_received ((GtkWidget*) G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), context, x, y, selection_data, info, time);
#line 1807 "../lib/Widgets/SourceList.vala"
		_gtk_target_list_unref0 (target_list);
#line 1807 "../lib/Widgets/SourceList.vala"
		return;
#line 9115 "SourceList.c"
	}
#line 1813 "../lib/Widgets/SourceList.vala"
	_tmp3_ = g_object_get_data ((GObject*) context, "suggested-dnd-action");
#line 1813 "../lib/Widgets/SourceList.vala"
	if (((gint) ((gintptr) _tmp3_)) != 0) {
#line 9121 "SourceList.c"
		GtkTreePath* _tmp4_ = NULL;
		GtkTreeViewDropPosition _tmp5_ = 0;
		GtkTreePath* _tmp6_;
#line 1814 "../lib/Widgets/SourceList.vala"
		g_object_set_data_full ((GObject*) context, "suggested-dnd-action", (gpointer) ((gintptr) 0), NULL);
#line 1816 "../lib/Widgets/SourceList.vala"
		gtk_tree_view_get_drag_dest_row ((GtkTreeView*) self, &_tmp4_, &_tmp5_);
#line 1816 "../lib/Widgets/SourceList.vala"
		__vala_GtkTreePath_free0 (path);
#line 1816 "../lib/Widgets/SourceList.vala"
		path = _tmp4_;
#line 1816 "../lib/Widgets/SourceList.vala"
		pos = _tmp5_;
#line 1818 "../lib/Widgets/SourceList.vala"
		_tmp6_ = path;
#line 1818 "../lib/Widgets/SourceList.vala"
		if (_tmp6_ != NULL) {
#line 9139 "SourceList.c"
			GraniteWidgetsSourceListDragDest* dest = NULL;
			GraniteWidgetsSourceListDataModel* _tmp7_;
			GtkTreePath* _tmp8_;
			GraniteWidgetsSourceListItem* _tmp9_;
			GraniteWidgetsSourceListDragDest* _tmp10_;
			gboolean _tmp11_ = FALSE;
			GraniteWidgetsSourceListDragDest* _tmp12_;
#line 1820 "../lib/Widgets/SourceList.vala"
			_tmp7_ = self->priv->_data_model;
#line 1820 "../lib/Widgets/SourceList.vala"
			_tmp8_ = path;
#line 1820 "../lib/Widgets/SourceList.vala"
			_tmp9_ = granite_widgets_source_list_data_model_get_item_from_path (_tmp7_, _tmp8_);
#line 1820 "../lib/Widgets/SourceList.vala"
			_tmp10_ = GRANITE_WIDGETS_IS_SOURCE_LIST_DRAG_DEST (_tmp9_) ? ((GraniteWidgetsSourceListDragDest*) _tmp9_) : NULL;
#line 1820 "../lib/Widgets/SourceList.vala"
			if (_tmp10_ == NULL) {
#line 1820 "../lib/Widgets/SourceList.vala"
				_g_object_unref0 (_tmp9_);
#line 9159 "SourceList.c"
			}
#line 1820 "../lib/Widgets/SourceList.vala"
			dest = _tmp10_;
#line 1822 "../lib/Widgets/SourceList.vala"
			_tmp12_ = dest;
#line 1822 "../lib/Widgets/SourceList.vala"
			if (_tmp12_ == NULL) {
#line 1822 "../lib/Widgets/SourceList.vala"
				_tmp11_ = TRUE;
#line 9169 "SourceList.c"
			} else {
				GraniteWidgetsSourceListDragDest* _tmp13_;
#line 1822 "../lib/Widgets/SourceList.vala"
				_tmp13_ = dest;
#line 1822 "../lib/Widgets/SourceList.vala"
				_tmp11_ = !granite_widgets_source_list_drag_dest_data_drop_possible (_tmp13_, context, selection_data);
#line 9176 "SourceList.c"
			}
#line 1822 "../lib/Widgets/SourceList.vala"
			if (_tmp11_) {
#line 1825 "../lib/Widgets/SourceList.vala"
				gtk_tree_view_set_drag_dest_row ((GtkTreeView*) self, NULL, GTK_TREE_VIEW_DROP_BEFORE);
#line 1826 "../lib/Widgets/SourceList.vala"
				gdk_drag_status (context, 0, (guint32) time);
#line 1827 "../lib/Widgets/SourceList.vala"
				_g_object_unref0 (dest);
#line 1827 "../lib/Widgets/SourceList.vala"
				__vala_GtkTreePath_free0 (path);
#line 1827 "../lib/Widgets/SourceList.vala"
				_gtk_target_list_unref0 (target_list);
#line 1827 "../lib/Widgets/SourceList.vala"
				return;
#line 9192 "SourceList.c"
			}
#line 1818 "../lib/Widgets/SourceList.vala"
			_g_object_unref0 (dest);
#line 9196 "SourceList.c"
		}
#line 1831 "../lib/Widgets/SourceList.vala"
		gdk_drag_status (context, gdk_drag_context_get_suggested_action (context), (guint32) time);
#line 9200 "SourceList.c"
	} else {
		GtkTreePath* _tmp14_ = NULL;
		GtkTreeViewDropPosition _tmp15_ = 0;
		gboolean _tmp16_;
#line 1833 "../lib/Widgets/SourceList.vala"
		_tmp16_ = gtk_tree_view_get_dest_row_at_pos ((GtkTreeView*) self, x, y, &_tmp14_, &_tmp15_);
#line 1833 "../lib/Widgets/SourceList.vala"
		__vala_GtkTreePath_free0 (path);
#line 1833 "../lib/Widgets/SourceList.vala"
		path = _tmp14_;
#line 1833 "../lib/Widgets/SourceList.vala"
		pos = _tmp15_;
#line 1833 "../lib/Widgets/SourceList.vala"
		if (_tmp16_) {
#line 9215 "SourceList.c"
			GraniteWidgetsSourceListDragDest* drag_dest = NULL;
			GraniteWidgetsSourceListDataModel* _tmp17_;
			GtkTreePath* _tmp18_;
			GraniteWidgetsSourceListItem* _tmp19_;
			GraniteWidgetsSourceListDragDest* _tmp20_;
			GraniteWidgetsSourceListDragDest* _tmp21_;
#line 1839 "../lib/Widgets/SourceList.vala"
			_tmp17_ = self->priv->_data_model;
#line 1839 "../lib/Widgets/SourceList.vala"
			_tmp18_ = path;
#line 1839 "../lib/Widgets/SourceList.vala"
			_tmp19_ = granite_widgets_source_list_data_model_get_item_from_path (_tmp17_, _tmp18_);
#line 1839 "../lib/Widgets/SourceList.vala"
			_tmp20_ = GRANITE_WIDGETS_IS_SOURCE_LIST_DRAG_DEST (_tmp19_) ? ((GraniteWidgetsSourceListDragDest*) _tmp19_) : NULL;
#line 1839 "../lib/Widgets/SourceList.vala"
			if (_tmp20_ == NULL) {
#line 1839 "../lib/Widgets/SourceList.vala"
				_g_object_unref0 (_tmp19_);
#line 9234 "SourceList.c"
			}
#line 1839 "../lib/Widgets/SourceList.vala"
			drag_dest = _tmp20_;
#line 1841 "../lib/Widgets/SourceList.vala"
			_tmp21_ = drag_dest;
#line 1841 "../lib/Widgets/SourceList.vala"
			if (_tmp21_ != NULL) {
#line 9242 "SourceList.c"
				GdkDragAction action = 0U;
				GraniteWidgetsSourceListDragDest* _tmp22_;
#line 1842 "../lib/Widgets/SourceList.vala"
				_tmp22_ = drag_dest;
#line 1842 "../lib/Widgets/SourceList.vala"
				action = granite_widgets_source_list_drag_dest_data_received (_tmp22_, context, selection_data);
#line 1843 "../lib/Widgets/SourceList.vala"
				gtk_drag_finish (context, action != 0, action == GDK_ACTION_MOVE, (guint32) time);
#line 1844 "../lib/Widgets/SourceList.vala"
				_g_object_unref0 (drag_dest);
#line 1844 "../lib/Widgets/SourceList.vala"
				__vala_GtkTreePath_free0 (path);
#line 1844 "../lib/Widgets/SourceList.vala"
				_gtk_target_list_unref0 (target_list);
#line 1844 "../lib/Widgets/SourceList.vala"
				return;
#line 9259 "SourceList.c"
			}
#line 1833 "../lib/Widgets/SourceList.vala"
			_g_object_unref0 (drag_dest);
#line 9263 "SourceList.c"
		}
#line 1849 "../lib/Widgets/SourceList.vala"
		gtk_drag_finish (context, FALSE, FALSE, (guint32) time);
#line 9267 "SourceList.c"
	}
#line 1794 "../lib/Widgets/SourceList.vala"
	__vala_GtkTreePath_free0 (path);
#line 1794 "../lib/Widgets/SourceList.vala"
	_gtk_target_list_unref0 (target_list);
#line 9273 "SourceList.c"
}

static void
granite_widgets_source_list_tree_configure_drag_source (GraniteWidgetsSourceListTree* self,
                                                        GtkTargetEntry* src_entries,
                                                        gint src_entries_length1)
{
	GtkTargetEntry* entries = NULL;
	gint _tmp0_ = 0;
	GtkTargetEntry* _tmp1_;
	gint entries_length1;
	gint _entries_size_;
#line 1853 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 1855 "../lib/Widgets/SourceList.vala"
	_tmp1_ = granite_widgets_source_list_tree_append_row_target_entry (src_entries, (gint) src_entries_length1, &_tmp0_);
#line 1855 "../lib/Widgets/SourceList.vala"
	entries = _tmp1_;
#line 1855 "../lib/Widgets/SourceList.vala"
	entries_length1 = _tmp0_;
#line 1855 "../lib/Widgets/SourceList.vala"
	_entries_size_ = entries_length1;
#line 1857 "../lib/Widgets/SourceList.vala"
	gtk_tree_view_unset_rows_drag_source ((GtkTreeView*) self);
#line 1858 "../lib/Widgets/SourceList.vala"
	gtk_tree_view_enable_model_drag_source ((GtkTreeView*) self, GDK_BUTTON1_MASK, entries, (gint) entries_length1, GDK_ACTION_MOVE);
#line 1853 "../lib/Widgets/SourceList.vala"
	entries = (g_free (entries), NULL);
#line 9302 "SourceList.c"
}

static void
granite_widgets_source_list_tree_configure_drag_dest (GraniteWidgetsSourceListTree* self,
                                                      GtkTargetEntry* dest_entries,
                                                      gint dest_entries_length1,
                                                      GdkDragAction actions)
{
	GtkTargetEntry* entries = NULL;
	gint _tmp0_ = 0;
	GtkTargetEntry* _tmp1_;
	gint entries_length1;
	gint _entries_size_;
#line 1861 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 1863 "../lib/Widgets/SourceList.vala"
	_tmp1_ = granite_widgets_source_list_tree_append_row_target_entry (dest_entries, (gint) dest_entries_length1, &_tmp0_);
#line 1863 "../lib/Widgets/SourceList.vala"
	entries = _tmp1_;
#line 1863 "../lib/Widgets/SourceList.vala"
	entries_length1 = _tmp0_;
#line 1863 "../lib/Widgets/SourceList.vala"
	_entries_size_ = entries_length1;
#line 1865 "../lib/Widgets/SourceList.vala"
	gtk_tree_view_unset_rows_drag_dest ((GtkTreeView*) self);
#line 1868 "../lib/Widgets/SourceList.vala"
	gtk_tree_view_enable_model_drag_dest ((GtkTreeView*) self, entries, (gint) entries_length1, GDK_ACTION_MOVE | actions);
#line 1861 "../lib/Widgets/SourceList.vala"
	entries = (g_free (entries), NULL);
#line 9332 "SourceList.c"
}

static gboolean
granite_widgets_source_list_tree_on_query_tooltip (GraniteWidgetsSourceListTree* self,
                                                   gint x,
                                                   gint y,
                                                   gboolean keyboard_tooltip,
                                                   GtkTooltip* tooltip)
{
	GtkTreePath* path = NULL;
	GtkTreeViewColumn* column = NULL;
	GtkTreeViewColumn* _tmp0_;
	GtkTreeViewColumn* _tmp1_;
	GtkTreePath* _tmp2_ = NULL;
	GtkTreePath* _tmp3_;
	GraniteWidgetsSourceListItem* item = NULL;
	GraniteWidgetsSourceListDataModel* _tmp4_;
	GtkTreePath* _tmp5_;
	GraniteWidgetsSourceListItem* _tmp6_;
	GraniteWidgetsSourceListItem* _tmp7_;
	gboolean result;
#line 1871 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 1871 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (tooltip != NULL, FALSE);
#line 1873 "../lib/Widgets/SourceList.vala"
	_tmp0_ = gtk_tree_view_get_column ((GtkTreeView*) self, (gint) GRANITE_WIDGETS_SOURCE_LIST_TREE_COLUMN_ITEM);
#line 1873 "../lib/Widgets/SourceList.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 1873 "../lib/Widgets/SourceList.vala"
	column = _tmp1_;
#line 1875 "../lib/Widgets/SourceList.vala"
	gtk_tree_view_get_tooltip_context ((GtkTreeView*) self, &x, &y, keyboard_tooltip, NULL, &_tmp2_, NULL);
#line 1875 "../lib/Widgets/SourceList.vala"
	__vala_GtkTreePath_free0 (path);
#line 1875 "../lib/Widgets/SourceList.vala"
	path = _tmp2_;
#line 1876 "../lib/Widgets/SourceList.vala"
	_tmp3_ = path;
#line 1876 "../lib/Widgets/SourceList.vala"
	if (_tmp3_ == NULL) {
#line 1877 "../lib/Widgets/SourceList.vala"
		result = FALSE;
#line 1877 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (column);
#line 1877 "../lib/Widgets/SourceList.vala"
		__vala_GtkTreePath_free0 (path);
#line 1877 "../lib/Widgets/SourceList.vala"
		return result;
#line 9382 "SourceList.c"
	}
#line 1880 "../lib/Widgets/SourceList.vala"
	_tmp4_ = self->priv->_data_model;
#line 1880 "../lib/Widgets/SourceList.vala"
	_tmp5_ = path;
#line 1880 "../lib/Widgets/SourceList.vala"
	_tmp6_ = granite_widgets_source_list_data_model_get_item_from_path (_tmp4_, _tmp5_);
#line 1880 "../lib/Widgets/SourceList.vala"
	item = _tmp6_;
#line 1881 "../lib/Widgets/SourceList.vala"
	_tmp7_ = item;
#line 1881 "../lib/Widgets/SourceList.vala"
	if (_tmp7_ != NULL) {
#line 9396 "SourceList.c"
		gboolean should_show = FALSE;
		GdkRectangle start_cell_area = {0};
		GtkTreePath* _tmp8_;
		GtkTreeViewColumn* _tmp9_;
		GdkRectangle _tmp10_ = {0};
		GtkTreePath* _tmp11_;
		GraniteWidgetsSourceListItem* _tmp12_;
		const gchar* _tmp13_;
		const gchar* _tmp14_;
		gboolean _tmp24_ = FALSE;
		GtkTreeViewColumn* _tmp25_;
		GtkTreePath* _tmp26_;
		GtkCellRendererText* _tmp27_;
		GdkRectangle _tmp28_;
#line 1882 "../lib/Widgets/SourceList.vala"
		should_show = FALSE;
#line 1885 "../lib/Widgets/SourceList.vala"
		_tmp8_ = path;
#line 1885 "../lib/Widgets/SourceList.vala"
		_tmp9_ = column;
#line 1885 "../lib/Widgets/SourceList.vala"
		gtk_tree_view_get_cell_area ((GtkTreeView*) self, _tmp8_, _tmp9_, &_tmp10_);
#line 1885 "../lib/Widgets/SourceList.vala"
		start_cell_area = _tmp10_;
#line 1887 "../lib/Widgets/SourceList.vala"
		_tmp11_ = path;
#line 1887 "../lib/Widgets/SourceList.vala"
		gtk_tree_view_set_tooltip_row ((GtkTreeView*) self, tooltip, _tmp11_);
#line 1889 "../lib/Widgets/SourceList.vala"
		_tmp12_ = item;
#line 1889 "../lib/Widgets/SourceList.vala"
		_tmp13_ = granite_widgets_source_list_item_get_tooltip (_tmp12_);
#line 1889 "../lib/Widgets/SourceList.vala"
		_tmp14_ = _tmp13_;
#line 1889 "../lib/Widgets/SourceList.vala"
		if (_tmp14_ == NULL) {
#line 9433 "SourceList.c"
			GraniteWidgetsSourceListItem* _tmp15_;
			const gchar* _tmp16_;
			const gchar* _tmp17_;
#line 1890 "../lib/Widgets/SourceList.vala"
			_tmp15_ = item;
#line 1890 "../lib/Widgets/SourceList.vala"
			_tmp16_ = granite_widgets_source_list_item_get_name (_tmp15_);
#line 1890 "../lib/Widgets/SourceList.vala"
			_tmp17_ = _tmp16_;
#line 1890 "../lib/Widgets/SourceList.vala"
			gtk_tooltip_set_markup (tooltip, _tmp17_);
#line 1891 "../lib/Widgets/SourceList.vala"
			should_show = TRUE;
#line 9447 "SourceList.c"
		} else {
			GraniteWidgetsSourceListItem* _tmp18_;
			const gchar* _tmp19_;
			const gchar* _tmp20_;
#line 1892 "../lib/Widgets/SourceList.vala"
			_tmp18_ = item;
#line 1892 "../lib/Widgets/SourceList.vala"
			_tmp19_ = granite_widgets_source_list_item_get_tooltip (_tmp18_);
#line 1892 "../lib/Widgets/SourceList.vala"
			_tmp20_ = _tmp19_;
#line 1892 "../lib/Widgets/SourceList.vala"
			if (g_strcmp0 (_tmp20_, "") != 0) {
#line 9460 "SourceList.c"
				GraniteWidgetsSourceListItem* _tmp21_;
				const gchar* _tmp22_;
				const gchar* _tmp23_;
#line 1893 "../lib/Widgets/SourceList.vala"
				_tmp21_ = item;
#line 1893 "../lib/Widgets/SourceList.vala"
				_tmp22_ = granite_widgets_source_list_item_get_tooltip (_tmp21_);
#line 1893 "../lib/Widgets/SourceList.vala"
				_tmp23_ = _tmp22_;
#line 1893 "../lib/Widgets/SourceList.vala"
				gtk_tooltip_set_markup (tooltip, _tmp23_);
#line 1894 "../lib/Widgets/SourceList.vala"
				should_show = TRUE;
#line 9474 "SourceList.c"
			}
		}
#line 1897 "../lib/Widgets/SourceList.vala"
		if (keyboard_tooltip) {
#line 1898 "../lib/Widgets/SourceList.vala"
			result = should_show;
#line 1898 "../lib/Widgets/SourceList.vala"
			_g_object_unref0 (item);
#line 1898 "../lib/Widgets/SourceList.vala"
			_g_object_unref0 (column);
#line 1898 "../lib/Widgets/SourceList.vala"
			__vala_GtkTreePath_free0 (path);
#line 1898 "../lib/Widgets/SourceList.vala"
			return result;
#line 9489 "SourceList.c"
		}
#line 1901 "../lib/Widgets/SourceList.vala"
		_tmp25_ = column;
#line 1901 "../lib/Widgets/SourceList.vala"
		_tmp26_ = path;
#line 1901 "../lib/Widgets/SourceList.vala"
		_tmp27_ = self->priv->text_cell;
#line 1901 "../lib/Widgets/SourceList.vala"
		_tmp28_ = start_cell_area;
#line 1901 "../lib/Widgets/SourceList.vala"
		if (granite_widgets_source_list_tree_over_cell (self, _tmp25_, _tmp26_, (GtkCellRenderer*) _tmp27_, x - _tmp28_.x)) {
#line 1901 "../lib/Widgets/SourceList.vala"
			_tmp24_ = TRUE;
#line 9503 "SourceList.c"
		} else {
			GtkTreeViewColumn* _tmp29_;
			GtkTreePath* _tmp30_;
			GraniteWidgetsSourceListCellRendererIcon* _tmp31_;
			GdkRectangle _tmp32_;
#line 1902 "../lib/Widgets/SourceList.vala"
			_tmp29_ = column;
#line 1902 "../lib/Widgets/SourceList.vala"
			_tmp30_ = path;
#line 1902 "../lib/Widgets/SourceList.vala"
			_tmp31_ = self->priv->icon_cell;
#line 1902 "../lib/Widgets/SourceList.vala"
			_tmp32_ = start_cell_area;
#line 1902 "../lib/Widgets/SourceList.vala"
			_tmp24_ = granite_widgets_source_list_tree_over_cell (self, _tmp29_, _tmp30_, (GtkCellRenderer*) _tmp31_, x - _tmp32_.x);
#line 9519 "SourceList.c"
		}
#line 1901 "../lib/Widgets/SourceList.vala"
		if (_tmp24_) {
#line 1904 "../lib/Widgets/SourceList.vala"
			result = should_show;
#line 1904 "../lib/Widgets/SourceList.vala"
			_g_object_unref0 (item);
#line 1904 "../lib/Widgets/SourceList.vala"
			_g_object_unref0 (column);
#line 1904 "../lib/Widgets/SourceList.vala"
			__vala_GtkTreePath_free0 (path);
#line 1904 "../lib/Widgets/SourceList.vala"
			return result;
#line 9533 "SourceList.c"
		} else {
			GtkTreeViewColumn* _tmp33_;
			GtkTreePath* _tmp34_;
			GraniteWidgetsSourceListCellRendererIcon* _tmp35_;
			GdkRectangle _tmp36_;
#line 1905 "../lib/Widgets/SourceList.vala"
			_tmp33_ = column;
#line 1905 "../lib/Widgets/SourceList.vala"
			_tmp34_ = path;
#line 1905 "../lib/Widgets/SourceList.vala"
			_tmp35_ = self->priv->activatable_cell;
#line 1905 "../lib/Widgets/SourceList.vala"
			_tmp36_ = start_cell_area;
#line 1905 "../lib/Widgets/SourceList.vala"
			if (granite_widgets_source_list_tree_over_cell (self, _tmp33_, _tmp34_, (GtkCellRenderer*) _tmp35_, x - _tmp36_.x)) {
#line 9549 "SourceList.c"
				GraniteWidgetsSourceListItem* _tmp37_;
				const gchar* _tmp38_;
				const gchar* _tmp39_;
#line 1906 "../lib/Widgets/SourceList.vala"
				_tmp37_ = item;
#line 1906 "../lib/Widgets/SourceList.vala"
				_tmp38_ = granite_widgets_source_list_item_get_activatable_tooltip (_tmp37_);
#line 1906 "../lib/Widgets/SourceList.vala"
				_tmp39_ = _tmp38_;
#line 1906 "../lib/Widgets/SourceList.vala"
				if (g_strcmp0 (_tmp39_, "") == 0) {
#line 1907 "../lib/Widgets/SourceList.vala"
					result = FALSE;
#line 1907 "../lib/Widgets/SourceList.vala"
					_g_object_unref0 (item);
#line 1907 "../lib/Widgets/SourceList.vala"
					_g_object_unref0 (column);
#line 1907 "../lib/Widgets/SourceList.vala"
					__vala_GtkTreePath_free0 (path);
#line 1907 "../lib/Widgets/SourceList.vala"
					return result;
#line 9571 "SourceList.c"
				} else {
					GraniteWidgetsSourceListItem* _tmp40_;
					const gchar* _tmp41_;
					const gchar* _tmp42_;
#line 1909 "../lib/Widgets/SourceList.vala"
					_tmp40_ = item;
#line 1909 "../lib/Widgets/SourceList.vala"
					_tmp41_ = granite_widgets_source_list_item_get_activatable_tooltip (_tmp40_);
#line 1909 "../lib/Widgets/SourceList.vala"
					_tmp42_ = _tmp41_;
#line 1909 "../lib/Widgets/SourceList.vala"
					gtk_tooltip_set_markup (tooltip, _tmp42_);
#line 1910 "../lib/Widgets/SourceList.vala"
					result = TRUE;
#line 1910 "../lib/Widgets/SourceList.vala"
					_g_object_unref0 (item);
#line 1910 "../lib/Widgets/SourceList.vala"
					_g_object_unref0 (column);
#line 1910 "../lib/Widgets/SourceList.vala"
					__vala_GtkTreePath_free0 (path);
#line 1910 "../lib/Widgets/SourceList.vala"
					return result;
#line 9594 "SourceList.c"
				}
			}
		}
	}
#line 1915 "../lib/Widgets/SourceList.vala"
	result = FALSE;
#line 1915 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (item);
#line 1915 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (column);
#line 1915 "../lib/Widgets/SourceList.vala"
	__vala_GtkTreePath_free0 (path);
#line 1915 "../lib/Widgets/SourceList.vala"
	return result;
#line 9609 "SourceList.c"
}

static void
_vala_array_add2 (GtkTargetEntry* * array,
                  gint* length,
                  gint* size,
                  const GtkTargetEntry* value)
{
#line 1926 "../lib/Widgets/SourceList.vala"
	if ((*length) == (*size)) {
#line 1926 "../lib/Widgets/SourceList.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1926 "../lib/Widgets/SourceList.vala"
		*array = g_renew (GtkTargetEntry, *array, *size);
#line 9624 "SourceList.c"
	}
#line 1926 "../lib/Widgets/SourceList.vala"
	(*array)[(*length)++] = *value;
#line 9628 "SourceList.c"
}

static void
_vala_array_add3 (GtkTargetEntry* * array,
                  gint* length,
                  gint* size,
                  const GtkTargetEntry* value)
{
#line 1930 "../lib/Widgets/SourceList.vala"
	if ((*length) == (*size)) {
#line 1930 "../lib/Widgets/SourceList.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1930 "../lib/Widgets/SourceList.vala"
		*array = g_renew (GtkTargetEntry, *array, *size);
#line 9643 "SourceList.c"
	}
#line 1930 "../lib/Widgets/SourceList.vala"
	(*array)[(*length)++] = *value;
#line 9647 "SourceList.c"
}

static GtkTargetEntry*
granite_widgets_source_list_tree_append_row_target_entry (GtkTargetEntry* orig,
                                                          gint orig_length1,
                                                          gint* result_length1)
{
#line 1919 "../lib/Widgets/SourceList.vala"
	static const GtkTargetEntry row_target_entry = {"GTK_TREE_MODEL_ROW", (guint) GTK_TARGET_SAME_WIDGET, (guint) 0};
#line 9657 "SourceList.c"
	GtkTargetEntry* entries = NULL;
	GtkTargetEntry* _tmp0_;
	gint entries_length1;
	gint _entries_size_;
	GtkTargetEntry* _tmp2_;
	gint _tmp2__length1;
	GtkTargetEntry* result;
#line 1925 "../lib/Widgets/SourceList.vala"
	_tmp0_ = g_new0 (GtkTargetEntry, 0);
#line 1925 "../lib/Widgets/SourceList.vala"
	entries = _tmp0_;
#line 1925 "../lib/Widgets/SourceList.vala"
	entries_length1 = 0;
#line 1925 "../lib/Widgets/SourceList.vala"
	_entries_size_ = entries_length1;
#line 1926 "../lib/Widgets/SourceList.vala"
	_vala_array_add2 (&entries, &entries_length1, &_entries_size_, &row_target_entry);
#line 1928 "../lib/Widgets/SourceList.vala"
	if (orig != NULL) {
#line 9677 "SourceList.c"
		{
			GtkTargetEntry* target_entry_collection = NULL;
			gint target_entry_collection_length1 = 0;
			gint _target_entry_collection_size_ = 0;
			gint target_entry_it = 0;
#line 1929 "../lib/Widgets/SourceList.vala"
			target_entry_collection = orig;
#line 1929 "../lib/Widgets/SourceList.vala"
			target_entry_collection_length1 = orig_length1;
#line 1929 "../lib/Widgets/SourceList.vala"
			for (target_entry_it = 0; target_entry_it < target_entry_collection_length1; target_entry_it = target_entry_it + 1) {
#line 9689 "SourceList.c"
				GtkTargetEntry target_entry = {0};
#line 1929 "../lib/Widgets/SourceList.vala"
				target_entry = target_entry_collection[target_entry_it];
#line 9693 "SourceList.c"
				{
					GtkTargetEntry _tmp1_;
#line 1930 "../lib/Widgets/SourceList.vala"
					_tmp1_ = target_entry;
#line 1930 "../lib/Widgets/SourceList.vala"
					_vala_array_add3 (&entries, &entries_length1, &_entries_size_, &_tmp1_);
#line 9700 "SourceList.c"
				}
			}
		}
	}
#line 1933 "../lib/Widgets/SourceList.vala"
	_tmp2_ = entries;
#line 1933 "../lib/Widgets/SourceList.vala"
	_tmp2__length1 = entries_length1;
#line 1933 "../lib/Widgets/SourceList.vala"
	if (result_length1) {
#line 1933 "../lib/Widgets/SourceList.vala"
		*result_length1 = _tmp2__length1;
#line 9713 "SourceList.c"
	}
#line 1933 "../lib/Widgets/SourceList.vala"
	result = _tmp2_;
#line 1933 "../lib/Widgets/SourceList.vala"
	return result;
#line 9719 "SourceList.c"
}

static void
_granite_widgets_source_list_tree_on_model_item_updated_granite_widgets_source_list_data_model_item_updated (GraniteWidgetsSourceListDataModel* _sender,
                                                                                                             GraniteWidgetsSourceListItem* item,
                                                                                                             gpointer self)
{
#line 1937 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_tree_on_model_item_updated ((GraniteWidgetsSourceListTree*) self, item);
#line 9729 "SourceList.c"
}

static void
granite_widgets_source_list_tree_enable_item_property_monitor (GraniteWidgetsSourceListTree* self)
{
	GraniteWidgetsSourceListDataModel* _tmp0_;
#line 1936 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 1937 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->_data_model;
#line 1937 "../lib/Widgets/SourceList.vala"
	g_signal_connect_object (_tmp0_, "item-updated", (GCallback) _granite_widgets_source_list_tree_on_model_item_updated_granite_widgets_source_list_data_model_item_updated, self, G_CONNECT_AFTER);
#line 9742 "SourceList.c"
}

static void
granite_widgets_source_list_tree_disable_item_property_monitor (GraniteWidgetsSourceListTree* self)
{
	GraniteWidgetsSourceListDataModel* _tmp0_;
	guint _tmp1_;
#line 1940 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 1941 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->_data_model;
#line 1941 "../lib/Widgets/SourceList.vala"
	g_signal_parse_name ("item-updated", GRANITE_WIDGETS_SOURCE_LIST_TYPE_DATA_MODEL, &_tmp1_, NULL, FALSE);
#line 1941 "../lib/Widgets/SourceList.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _granite_widgets_source_list_tree_on_model_item_updated_granite_widgets_source_list_data_model_item_updated, self);
#line 9758 "SourceList.c"
}

static void
granite_widgets_source_list_tree_on_model_item_updated (GraniteWidgetsSourceListTree* self,
                                                        GraniteWidgetsSourceListItem* item)
{
	GraniteWidgetsSourceListExpandableItem* expandable_item = NULL;
	GraniteWidgetsSourceListExpandableItem* _tmp0_;
	GraniteWidgetsSourceListExpandableItem* _tmp1_;
#line 1944 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 1944 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (item != NULL);
#line 1947 "../lib/Widgets/SourceList.vala"
	_tmp0_ = _g_object_ref0 (GRANITE_WIDGETS_SOURCE_LIST_IS_EXPANDABLE_ITEM (item) ? ((GraniteWidgetsSourceListExpandableItem*) item) : NULL);
#line 1947 "../lib/Widgets/SourceList.vala"
	expandable_item = _tmp0_;
#line 1948 "../lib/Widgets/SourceList.vala"
	_tmp1_ = expandable_item;
#line 1948 "../lib/Widgets/SourceList.vala"
	if (_tmp1_ != NULL) {
#line 9780 "SourceList.c"
		GraniteWidgetsSourceListExpandableItem* _tmp2_;
#line 1949 "../lib/Widgets/SourceList.vala"
		_tmp2_ = expandable_item;
#line 1949 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_tree_update_expansion (self, _tmp2_);
#line 9786 "SourceList.c"
	}
#line 1944 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (expandable_item);
#line 9790 "SourceList.c"
}

static void
_granite_widgets_source_list_tree_spacer_cell_data_func_gtk_cell_layout_data_func (GtkCellLayout* cell_layout,
                                                                                   GtkCellRenderer* cell,
                                                                                   GtkTreeModel* tree_model,
                                                                                   GtkTreeIter* iter,
                                                                                   gpointer self)
{
#line 1994 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_tree_spacer_cell_data_func (cell_layout, cell, tree_model, iter);
#line 9802 "SourceList.c"
}

static void
granite_widgets_source_list_tree_add_spacer_cell_for_level (GraniteWidgetsSourceListTree* self,
                                                            gint level,
                                                            gboolean check_previous)
{
	GeeHashMap* _tmp0_;
	GeeHashMap* _tmp2_;
#line 1952 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 1952 "../lib/Widgets/SourceList.vala"
	_vala_return_if_fail (level > 0, "level > 0");
#line 1956 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->spacer_cells;
#line 1956 "../lib/Widgets/SourceList.vala"
	if (_tmp0_ == NULL) {
#line 9820 "SourceList.c"
		GeeHashMap* _tmp1_;
#line 1957 "../lib/Widgets/SourceList.vala"
		_tmp1_ = gee_hash_map_new (G_TYPE_INT, NULL, NULL, GRANITE_WIDGETS_SOURCE_LIST_TYPE_CELL_RENDERER_SPACER, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 1957 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (self->priv->spacer_cells);
#line 1957 "../lib/Widgets/SourceList.vala"
		self->priv->spacer_cells = _tmp1_;
#line 9828 "SourceList.c"
	}
#line 1959 "../lib/Widgets/SourceList.vala"
	_tmp2_ = self->priv->spacer_cells;
#line 1959 "../lib/Widgets/SourceList.vala"
	if (!gee_abstract_map_has_key ((GeeAbstractMap*) _tmp2_, (gpointer) ((gintptr) level))) {
#line 9834 "SourceList.c"
		GraniteWidgetsSourceListCellRendererSpacer* spacer_cell = NULL;
		GraniteWidgetsSourceListCellRendererSpacer* _tmp3_;
		GraniteWidgetsSourceListCellRendererSpacer* _tmp4_;
		GeeHashMap* _tmp5_;
		GraniteWidgetsSourceListCellRendererSpacer* _tmp6_;
		guint cell_xpadding = 0U;
		GraniteWidgetsSourceListCellRendererSpacer* _tmp9_;
		GtkTreeViewColumn* item_column = NULL;
		GtkTreeViewColumn* _tmp10_;
		GtkTreeViewColumn* _tmp11_;
		GtkTreeViewColumn* _tmp12_;
		GraniteWidgetsSourceListCellRendererSpacer* _tmp13_;
		GtkTreeViewColumn* _tmp14_;
		GraniteWidgetsSourceListCellRendererSpacer* _tmp15_;
#line 1960 "../lib/Widgets/SourceList.vala"
		_tmp3_ = granite_widgets_source_list_cell_renderer_spacer_new ();
#line 1960 "../lib/Widgets/SourceList.vala"
		g_object_ref_sink (_tmp3_);
#line 1960 "../lib/Widgets/SourceList.vala"
		spacer_cell = _tmp3_;
#line 1961 "../lib/Widgets/SourceList.vala"
		_tmp4_ = spacer_cell;
#line 1961 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_cell_renderer_spacer_set_level (_tmp4_, level);
#line 1962 "../lib/Widgets/SourceList.vala"
		_tmp5_ = self->priv->spacer_cells;
#line 1962 "../lib/Widgets/SourceList.vala"
		_tmp6_ = spacer_cell;
#line 1962 "../lib/Widgets/SourceList.vala"
		gee_abstract_map_set ((GeeAbstractMap*) _tmp5_, (gpointer) ((gintptr) level), _tmp6_);
#line 1972 "../lib/Widgets/SourceList.vala"
		switch (level) {
#line 1972 "../lib/Widgets/SourceList.vala"
			case 1:
#line 9869 "SourceList.c"
			{
				gint left_padding = 0;
				gint _tmp7_ = 0;
#line 1975 "../lib/Widgets/SourceList.vala"
				gtk_widget_style_get ((GtkWidget*) self, GRANITE_WIDGETS_SOURCE_LIST_TREE_STYLE_PROP_LEFT_PADDING, &_tmp7_, NULL);
#line 1975 "../lib/Widgets/SourceList.vala"
				left_padding = _tmp7_;
#line 1976 "../lib/Widgets/SourceList.vala"
				cell_xpadding = (guint) (left_padding / 2);
#line 1977 "../lib/Widgets/SourceList.vala"
				break;
#line 9881 "SourceList.c"
			}
#line 1972 "../lib/Widgets/SourceList.vala"
			case 2:
#line 9885 "SourceList.c"
			{
#line 1980 "../lib/Widgets/SourceList.vala"
				cell_xpadding = (guint) 0;
#line 1981 "../lib/Widgets/SourceList.vala"
				break;
#line 9891 "SourceList.c"
			}
			default:
			{
				gint level_indentation = 0;
				gint _tmp8_ = 0;
#line 1985 "../lib/Widgets/SourceList.vala"
				gtk_widget_style_get ((GtkWidget*) self, GRANITE_WIDGETS_SOURCE_LIST_TREE_STYLE_PROP_LEVEL_INDENTATION, &_tmp8_, NULL);
#line 1985 "../lib/Widgets/SourceList.vala"
				level_indentation = _tmp8_;
#line 1986 "../lib/Widgets/SourceList.vala"
				cell_xpadding = (guint) (level_indentation / 2);
#line 1987 "../lib/Widgets/SourceList.vala"
				break;
#line 9905 "SourceList.c"
			}
		}
#line 1990 "../lib/Widgets/SourceList.vala"
		_tmp9_ = spacer_cell;
#line 1990 "../lib/Widgets/SourceList.vala"
		g_object_set ((GtkCellRenderer*) _tmp9_, "xpad", cell_xpadding, NULL);
#line 1992 "../lib/Widgets/SourceList.vala"
		_tmp10_ = gtk_tree_view_get_column ((GtkTreeView*) self, (gint) GRANITE_WIDGETS_SOURCE_LIST_TREE_COLUMN_ITEM);
#line 1992 "../lib/Widgets/SourceList.vala"
		_tmp11_ = _g_object_ref0 (_tmp10_);
#line 1992 "../lib/Widgets/SourceList.vala"
		item_column = _tmp11_;
#line 1993 "../lib/Widgets/SourceList.vala"
		_tmp12_ = item_column;
#line 1993 "../lib/Widgets/SourceList.vala"
		_tmp13_ = spacer_cell;
#line 1993 "../lib/Widgets/SourceList.vala"
		gtk_cell_layout_pack_start ((GtkCellLayout*) _tmp12_, (GtkCellRenderer*) _tmp13_, FALSE);
#line 1994 "../lib/Widgets/SourceList.vala"
		_tmp14_ = item_column;
#line 1994 "../lib/Widgets/SourceList.vala"
		_tmp15_ = spacer_cell;
#line 1994 "../lib/Widgets/SourceList.vala"
		gtk_cell_layout_set_cell_data_func ((GtkCellLayout*) _tmp14_, (GtkCellRenderer*) _tmp15_, _granite_widgets_source_list_tree_spacer_cell_data_func_gtk_cell_layout_data_func, NULL, NULL);
#line 1997 "../lib/Widgets/SourceList.vala"
		if (check_previous) {
#line 9932 "SourceList.c"
			{
				gint i = 0;
#line 1998 "../lib/Widgets/SourceList.vala"
				i = level - 1;
#line 9937 "SourceList.c"
				{
					gboolean _tmp16_ = FALSE;
#line 1998 "../lib/Widgets/SourceList.vala"
					_tmp16_ = TRUE;
#line 1998 "../lib/Widgets/SourceList.vala"
					while (TRUE) {
#line 1998 "../lib/Widgets/SourceList.vala"
						if (!_tmp16_) {
#line 9946 "SourceList.c"
							gint _tmp17_;
#line 1998 "../lib/Widgets/SourceList.vala"
							_tmp17_ = i;
#line 1998 "../lib/Widgets/SourceList.vala"
							i = _tmp17_ - 1;
#line 9952 "SourceList.c"
						}
#line 1998 "../lib/Widgets/SourceList.vala"
						_tmp16_ = FALSE;
#line 1998 "../lib/Widgets/SourceList.vala"
						if (!(i > 0)) {
#line 1998 "../lib/Widgets/SourceList.vala"
							break;
#line 9960 "SourceList.c"
						}
#line 1999 "../lib/Widgets/SourceList.vala"
						granite_widgets_source_list_tree_add_spacer_cell_for_level (self, i, FALSE);
#line 9964 "SourceList.c"
					}
				}
			}
		}
#line 1959 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (item_column);
#line 1959 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (spacer_cell);
#line 9973 "SourceList.c"
	}
}

/**
         * Evaluates whether the item at the specified path can be selected or not.
         */
static gboolean
granite_widgets_source_list_tree_select_func (GraniteWidgetsSourceListTree* self,
                                              GtkTreeSelection* selection,
                                              GtkTreeModel* model,
                                              GtkTreePath* path,
                                              gboolean path_currently_selected)
{
	gboolean selectable = FALSE;
	GraniteWidgetsSourceListItem* item = NULL;
	GraniteWidgetsSourceListDataModel* _tmp0_;
	GraniteWidgetsSourceListItem* _tmp1_;
	GraniteWidgetsSourceListItem* _tmp2_;
	gboolean result;
#line 2007 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 2007 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (selection != NULL, FALSE);
#line 2007 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (model != NULL, FALSE);
#line 2007 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (path != NULL, FALSE);
#line 2013 "../lib/Widgets/SourceList.vala"
	selectable = FALSE;
#line 2014 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->_data_model;
#line 2014 "../lib/Widgets/SourceList.vala"
	_tmp1_ = granite_widgets_source_list_data_model_get_item_from_path (_tmp0_, path);
#line 2014 "../lib/Widgets/SourceList.vala"
	item = _tmp1_;
#line 2016 "../lib/Widgets/SourceList.vala"
	_tmp2_ = item;
#line 2016 "../lib/Widgets/SourceList.vala"
	if (_tmp2_ != NULL) {
#line 10013 "SourceList.c"
		GraniteWidgetsSourceListDataModel* _tmp3_;
		GraniteWidgetsSourceListItem* _tmp4_;
#line 2018 "../lib/Widgets/SourceList.vala"
		_tmp3_ = self->priv->_data_model;
#line 2018 "../lib/Widgets/SourceList.vala"
		_tmp4_ = item;
#line 2018 "../lib/Widgets/SourceList.vala"
		if (!granite_widgets_source_list_data_model_is_category (_tmp3_, _tmp4_, NULL, path)) {
#line 10022 "SourceList.c"
			GraniteWidgetsSourceListItem* _tmp5_;
			gboolean _tmp6_;
			gboolean _tmp7_;
#line 2019 "../lib/Widgets/SourceList.vala"
			_tmp5_ = item;
#line 2019 "../lib/Widgets/SourceList.vala"
			_tmp6_ = granite_widgets_source_list_item_get_selectable (_tmp5_);
#line 2019 "../lib/Widgets/SourceList.vala"
			_tmp7_ = _tmp6_;
#line 2019 "../lib/Widgets/SourceList.vala"
			selectable = _tmp7_;
#line 10034 "SourceList.c"
		}
	}
#line 2022 "../lib/Widgets/SourceList.vala"
	result = selectable;
#line 2022 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (item);
#line 2022 "../lib/Widgets/SourceList.vala"
	return result;
#line 10043 "SourceList.c"
}

static void
__vala_GtkTreePath_free0_ (gpointer var)
{
#line 2029 "../lib/Widgets/SourceList.vala"
	(var == NULL) ? NULL : (var = (_vala_GtkTreePath_free (var), NULL));
#line 10051 "SourceList.c"
}

static inline void
_g_list_free___vala_GtkTreePath_free0_ (GList* self)
{
#line 2029 "../lib/Widgets/SourceList.vala"
	g_list_free_full (self, (GDestroyNotify) __vala_GtkTreePath_free0_);
#line 10059 "SourceList.c"
}

static GtkTreePath*
granite_widgets_source_list_tree_get_selected_path (GraniteWidgetsSourceListTree* self)
{
	GtkTreePath* selected_path = NULL;
	GtkTreeSelection* selection = NULL;
	GtkTreeSelection* _tmp0_;
	GtkTreeSelection* _tmp1_;
	GtkTreeSelection* _tmp2_;
	GtkTreePath* result;
#line 2025 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 2026 "../lib/Widgets/SourceList.vala"
	selected_path = NULL;
#line 2027 "../lib/Widgets/SourceList.vala"
	_tmp0_ = gtk_tree_view_get_selection ((GtkTreeView*) self);
#line 2027 "../lib/Widgets/SourceList.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 2027 "../lib/Widgets/SourceList.vala"
	selection = _tmp1_;
#line 2029 "../lib/Widgets/SourceList.vala"
	_tmp2_ = selection;
#line 2029 "../lib/Widgets/SourceList.vala"
	if (_tmp2_ != NULL) {
#line 10085 "SourceList.c"
		GtkTreeModel* model = NULL;
		GList* selected_rows = NULL;
		GtkTreeSelection* _tmp3_;
		GtkTreeModel* _tmp4_ = NULL;
		GList* _tmp5_;
		GtkTreeModel* _tmp6_;
		GList* _tmp7_;
#line 2031 "../lib/Widgets/SourceList.vala"
		_tmp3_ = selection;
#line 2031 "../lib/Widgets/SourceList.vala"
		_tmp5_ = gtk_tree_selection_get_selected_rows (_tmp3_, &_tmp4_);
#line 2031 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (model);
#line 2031 "../lib/Widgets/SourceList.vala"
		_tmp6_ = _g_object_ref0 (_tmp4_);
#line 2031 "../lib/Widgets/SourceList.vala"
		model = _tmp6_;
#line 2031 "../lib/Widgets/SourceList.vala"
		selected_rows = _tmp5_;
#line 2032 "../lib/Widgets/SourceList.vala"
		_tmp7_ = selected_rows;
#line 2032 "../lib/Widgets/SourceList.vala"
		if (g_list_length (_tmp7_) == ((guint) 1)) {
#line 10109 "SourceList.c"
			GList* _tmp8_;
			gconstpointer _tmp9_;
			GtkTreePath* _tmp10_;
#line 2033 "../lib/Widgets/SourceList.vala"
			_tmp8_ = selected_rows;
#line 2033 "../lib/Widgets/SourceList.vala"
			_tmp9_ = g_list_nth_data (_tmp8_, (guint) 0);
#line 2033 "../lib/Widgets/SourceList.vala"
			_tmp10_ = __vala_GtkTreePath_copy0 ((GtkTreePath*) _tmp9_);
#line 2033 "../lib/Widgets/SourceList.vala"
			__vala_GtkTreePath_free0 (selected_path);
#line 2033 "../lib/Widgets/SourceList.vala"
			selected_path = _tmp10_;
#line 10123 "SourceList.c"
		}
#line 2029 "../lib/Widgets/SourceList.vala"
		(selected_rows == NULL) ? NULL : (selected_rows = (_g_list_free___vala_GtkTreePath_free0_ (selected_rows), NULL));
#line 2029 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (model);
#line 10129 "SourceList.c"
	}
#line 2036 "../lib/Widgets/SourceList.vala"
	result = selected_path;
#line 2036 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (selection);
#line 2036 "../lib/Widgets/SourceList.vala"
	return result;
#line 10137 "SourceList.c"
}

static void
granite_widgets_source_list_tree_set_selected (GraniteWidgetsSourceListTree* self,
                                               GraniteWidgetsSourceListItem* item,
                                               gboolean scroll_to_item)
{
#line 2039 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 2040 "../lib/Widgets/SourceList.vala"
	if (item == NULL) {
#line 10149 "SourceList.c"
		GtkTreeSelection* selection = NULL;
		GtkTreeSelection* _tmp0_;
		GtkTreeSelection* _tmp1_;
		GtkTreeSelection* _tmp2_;
#line 2041 "../lib/Widgets/SourceList.vala"
		_tmp0_ = gtk_tree_view_get_selection ((GtkTreeView*) self);
#line 2041 "../lib/Widgets/SourceList.vala"
		_tmp1_ = _g_object_ref0 (_tmp0_);
#line 2041 "../lib/Widgets/SourceList.vala"
		selection = _tmp1_;
#line 2042 "../lib/Widgets/SourceList.vala"
		_tmp2_ = selection;
#line 2042 "../lib/Widgets/SourceList.vala"
		if (_tmp2_ != NULL) {
#line 10164 "SourceList.c"
			GtkTreeSelection* _tmp3_;
#line 2043 "../lib/Widgets/SourceList.vala"
			_tmp3_ = selection;
#line 2043 "../lib/Widgets/SourceList.vala"
			gtk_tree_selection_unselect_all (_tmp3_);
#line 10170 "SourceList.c"
		}
#line 2054 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (self->priv->selected);
#line 2054 "../lib/Widgets/SourceList.vala"
		self->priv->selected = NULL;
#line 2055 "../lib/Widgets/SourceList.vala"
		g_signal_emit (self, granite_widgets_source_list_tree_signals[GRANITE_WIDGETS_SOURCE_LIST_TREE_ITEM_SELECTED_SIGNAL], 0, NULL);
#line 2040 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (selection);
#line 10180 "SourceList.c"
	} else {
		gboolean _tmp4_;
		gboolean _tmp5_;
#line 2056 "../lib/Widgets/SourceList.vala"
		_tmp4_ = granite_widgets_source_list_item_get_selectable (item);
#line 2056 "../lib/Widgets/SourceList.vala"
		_tmp5_ = _tmp4_;
#line 2056 "../lib/Widgets/SourceList.vala"
		if (_tmp5_) {
#line 10190 "SourceList.c"
			GtkTreePath* to_select = NULL;
			GraniteWidgetsSourceListDataModel* _tmp6_;
			GtkTreePath* _tmp7_;
			GtkTreePath* _tmp8_;
#line 2057 "../lib/Widgets/SourceList.vala"
			if (scroll_to_item) {
#line 2058 "../lib/Widgets/SourceList.vala"
				granite_widgets_source_list_tree_scroll_to_item (self, item, FALSE, (gfloat) 0);
#line 10199 "SourceList.c"
			}
#line 2060 "../lib/Widgets/SourceList.vala"
			_tmp6_ = self->priv->_data_model;
#line 2060 "../lib/Widgets/SourceList.vala"
			_tmp7_ = granite_widgets_source_list_data_model_get_item_path (_tmp6_, item);
#line 2060 "../lib/Widgets/SourceList.vala"
			to_select = _tmp7_;
#line 2061 "../lib/Widgets/SourceList.vala"
			_tmp8_ = to_select;
#line 2061 "../lib/Widgets/SourceList.vala"
			if (_tmp8_ != NULL) {
#line 10211 "SourceList.c"
				GtkTreePath* _tmp9_;
				GtkTreeViewColumn* _tmp10_;
				GtkCellRendererText* _tmp11_;
#line 2062 "../lib/Widgets/SourceList.vala"
				_tmp9_ = to_select;
#line 2062 "../lib/Widgets/SourceList.vala"
				_tmp10_ = gtk_tree_view_get_column ((GtkTreeView*) self, (gint) GRANITE_WIDGETS_SOURCE_LIST_TREE_COLUMN_ITEM);
#line 2062 "../lib/Widgets/SourceList.vala"
				_tmp11_ = self->priv->text_cell;
#line 2062 "../lib/Widgets/SourceList.vala"
				gtk_tree_view_set_cursor_on_cell ((GtkTreeView*) self, _tmp9_, _tmp10_, (GtkCellRenderer*) _tmp11_, FALSE);
#line 10223 "SourceList.c"
			}
#line 2056 "../lib/Widgets/SourceList.vala"
			__vala_GtkTreePath_free0 (to_select);
#line 10227 "SourceList.c"
		}
	}
}

static void
granite_widgets_source_list_tree_real_cursor_changed (GtkTreeView* base)
{
	GraniteWidgetsSourceListTree * self;
	GtkTreePath* path = NULL;
	GtkTreePath* _tmp0_;
	GraniteWidgetsSourceListItem* _tmp1_ = NULL;
	GtkTreePath* _tmp2_;
	GraniteWidgetsSourceListItem* new_item = NULL;
	GraniteWidgetsSourceListItem* _tmp6_;
	gboolean _tmp7_ = FALSE;
	GraniteWidgetsSourceListItem* _tmp8_;
#line 2066 "../lib/Widgets/SourceList.vala"
	self = (GraniteWidgetsSourceListTree*) base;
#line 2067 "../lib/Widgets/SourceList.vala"
	_tmp0_ = granite_widgets_source_list_tree_get_selected_path (self);
#line 2067 "../lib/Widgets/SourceList.vala"
	path = _tmp0_;
#line 2068 "../lib/Widgets/SourceList.vala"
	_tmp2_ = path;
#line 2068 "../lib/Widgets/SourceList.vala"
	if (_tmp2_ != NULL) {
#line 10254 "SourceList.c"
		GraniteWidgetsSourceListDataModel* _tmp3_;
		GtkTreePath* _tmp4_;
		GraniteWidgetsSourceListItem* _tmp5_;
#line 2068 "../lib/Widgets/SourceList.vala"
		_tmp3_ = self->priv->_data_model;
#line 2068 "../lib/Widgets/SourceList.vala"
		_tmp4_ = path;
#line 2068 "../lib/Widgets/SourceList.vala"
		_tmp5_ = granite_widgets_source_list_data_model_get_item_from_path (_tmp3_, _tmp4_);
#line 2068 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (_tmp1_);
#line 2068 "../lib/Widgets/SourceList.vala"
		_tmp1_ = _tmp5_;
#line 10268 "SourceList.c"
	} else {
#line 2068 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (_tmp1_);
#line 2068 "../lib/Widgets/SourceList.vala"
		_tmp1_ = NULL;
#line 10274 "SourceList.c"
	}
#line 2068 "../lib/Widgets/SourceList.vala"
	_tmp6_ = _g_object_ref0 (_tmp1_);
#line 2068 "../lib/Widgets/SourceList.vala"
	new_item = _tmp6_;
#line 2081 "../lib/Widgets/SourceList.vala"
	_tmp8_ = new_item;
#line 2081 "../lib/Widgets/SourceList.vala"
	if (_tmp8_ != NULL) {
#line 10284 "SourceList.c"
		GraniteWidgetsSourceListItem* _tmp9_;
		GraniteWidgetsSourceListItem* _tmp10_;
#line 2081 "../lib/Widgets/SourceList.vala"
		_tmp9_ = new_item;
#line 2081 "../lib/Widgets/SourceList.vala"
		_tmp10_ = self->priv->selected;
#line 2081 "../lib/Widgets/SourceList.vala"
		_tmp7_ = _tmp9_ != _tmp10_;
#line 10293 "SourceList.c"
	} else {
#line 2081 "../lib/Widgets/SourceList.vala"
		_tmp7_ = FALSE;
#line 10297 "SourceList.c"
	}
#line 2081 "../lib/Widgets/SourceList.vala"
	if (_tmp7_) {
#line 10301 "SourceList.c"
		GraniteWidgetsSourceListItem* _tmp11_;
		GraniteWidgetsSourceListItem* _tmp12_;
		GraniteWidgetsSourceListItem* _tmp13_;
#line 2082 "../lib/Widgets/SourceList.vala"
		_tmp11_ = new_item;
#line 2082 "../lib/Widgets/SourceList.vala"
		_tmp12_ = _g_object_ref0 (_tmp11_);
#line 2082 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (self->priv->selected);
#line 2082 "../lib/Widgets/SourceList.vala"
		self->priv->selected = _tmp12_;
#line 2083 "../lib/Widgets/SourceList.vala"
		_tmp13_ = new_item;
#line 2083 "../lib/Widgets/SourceList.vala"
		g_signal_emit (self, granite_widgets_source_list_tree_signals[GRANITE_WIDGETS_SOURCE_LIST_TREE_ITEM_SELECTED_SIGNAL], 0, _tmp13_);
#line 10317 "SourceList.c"
	}
#line 2066 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (new_item);
#line 2066 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (_tmp1_);
#line 2066 "../lib/Widgets/SourceList.vala"
	__vala_GtkTreePath_free0 (path);
#line 10325 "SourceList.c"
}

static gboolean
granite_widgets_source_list_tree_scroll_to_item (GraniteWidgetsSourceListTree* self,
                                                 GraniteWidgetsSourceListItem* item,
                                                 gboolean use_align,
                                                 gfloat row_align)
{
	gboolean scrolled = FALSE;
	GtkTreePath* path = NULL;
	GraniteWidgetsSourceListDataModel* _tmp0_;
	GtkTreePath* _tmp1_;
	GtkTreePath* _tmp2_;
	gboolean result;
#line 2087 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 2087 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (item != NULL, FALSE);
#line 2088 "../lib/Widgets/SourceList.vala"
	scrolled = FALSE;
#line 2090 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->_data_model;
#line 2090 "../lib/Widgets/SourceList.vala"
	_tmp1_ = granite_widgets_source_list_data_model_get_item_path (_tmp0_, item);
#line 2090 "../lib/Widgets/SourceList.vala"
	path = _tmp1_;
#line 2091 "../lib/Widgets/SourceList.vala"
	_tmp2_ = path;
#line 2091 "../lib/Widgets/SourceList.vala"
	if (_tmp2_ != NULL) {
#line 10356 "SourceList.c"
		GtkTreePath* _tmp3_;
#line 2092 "../lib/Widgets/SourceList.vala"
		_tmp3_ = path;
#line 2092 "../lib/Widgets/SourceList.vala"
		gtk_tree_view_scroll_to_cell ((GtkTreeView*) self, _tmp3_, NULL, use_align, row_align, (gfloat) 0);
#line 2093 "../lib/Widgets/SourceList.vala"
		scrolled = TRUE;
#line 10364 "SourceList.c"
	}
#line 2096 "../lib/Widgets/SourceList.vala"
	result = scrolled;
#line 2096 "../lib/Widgets/SourceList.vala"
	__vala_GtkTreePath_free0 (path);
#line 2096 "../lib/Widgets/SourceList.vala"
	return result;
#line 10372 "SourceList.c"
}

static gboolean
granite_widgets_source_list_tree_start_editing_item (GraniteWidgetsSourceListTree* self,
                                                     GraniteWidgetsSourceListItem* item)
{
	gboolean _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
	gboolean _tmp3_;
	gboolean _tmp4_ = FALSE;
	gboolean _tmp5_;
	gboolean _tmp6_;
	GtkTreePath* path = NULL;
	GraniteWidgetsSourceListDataModel* _tmp8_;
	GtkTreePath* _tmp9_;
	GtkTreePath* _tmp10_;
	gboolean _tmp17_;
	gboolean _tmp18_;
	gboolean result;
#line 2099 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 2099 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (item != NULL, FALSE);
#line 2099 "../lib/Widgets/SourceList.vala"
	_tmp0_ = granite_widgets_source_list_item_get_editable (item);
#line 2099 "../lib/Widgets/SourceList.vala"
	_tmp1_ = _tmp0_;
#line 2099 "../lib/Widgets/SourceList.vala"
	_vala_return_val_if_fail (_tmp1_, "item.editable", FALSE);
#line 2099 "../lib/Widgets/SourceList.vala"
	_tmp2_ = granite_widgets_source_list_item_get_selectable (item);
#line 2099 "../lib/Widgets/SourceList.vala"
	_tmp3_ = _tmp2_;
#line 2099 "../lib/Widgets/SourceList.vala"
	_vala_return_val_if_fail (_tmp3_, "item.selectable", FALSE);
#line 2100 "../lib/Widgets/SourceList.vala"
	_tmp5_ = granite_widgets_source_list_tree_get_editing (self);
#line 2100 "../lib/Widgets/SourceList.vala"
	_tmp6_ = _tmp5_;
#line 2100 "../lib/Widgets/SourceList.vala"
	if (_tmp6_) {
#line 10415 "SourceList.c"
		GraniteWidgetsSourceListItem* _tmp7_;
#line 2100 "../lib/Widgets/SourceList.vala"
		_tmp7_ = self->priv->edited;
#line 2100 "../lib/Widgets/SourceList.vala"
		_tmp4_ = item == _tmp7_;
#line 10421 "SourceList.c"
	} else {
#line 2100 "../lib/Widgets/SourceList.vala"
		_tmp4_ = FALSE;
#line 10425 "SourceList.c"
	}
#line 2100 "../lib/Widgets/SourceList.vala"
	if (_tmp4_) {
#line 2101 "../lib/Widgets/SourceList.vala"
		result = FALSE;
#line 2101 "../lib/Widgets/SourceList.vala"
		return result;
#line 10433 "SourceList.c"
	}
#line 2103 "../lib/Widgets/SourceList.vala"
	_tmp8_ = self->priv->_data_model;
#line 2103 "../lib/Widgets/SourceList.vala"
	_tmp9_ = granite_widgets_source_list_data_model_get_item_path (_tmp8_, item);
#line 2103 "../lib/Widgets/SourceList.vala"
	path = _tmp9_;
#line 2104 "../lib/Widgets/SourceList.vala"
	_tmp10_ = path;
#line 2104 "../lib/Widgets/SourceList.vala"
	if (_tmp10_ != NULL) {
#line 10445 "SourceList.c"
		GtkCellRendererText* _tmp11_;
		GtkTreePath* _tmp12_;
		GtkTreeViewColumn* _tmp13_;
		GtkCellRendererText* _tmp14_;
#line 2105 "../lib/Widgets/SourceList.vala"
		self->priv->edited = item;
#line 2106 "../lib/Widgets/SourceList.vala"
		_tmp11_ = self->priv->text_cell;
#line 2106 "../lib/Widgets/SourceList.vala"
		g_object_set (_tmp11_, "editable", TRUE, NULL);
#line 2107 "../lib/Widgets/SourceList.vala"
		_tmp12_ = path;
#line 2107 "../lib/Widgets/SourceList.vala"
		_tmp13_ = gtk_tree_view_get_column ((GtkTreeView*) self, (gint) GRANITE_WIDGETS_SOURCE_LIST_TREE_COLUMN_ITEM);
#line 2107 "../lib/Widgets/SourceList.vala"
		_tmp14_ = self->priv->text_cell;
#line 2107 "../lib/Widgets/SourceList.vala"
		gtk_tree_view_set_cursor_on_cell ((GtkTreeView*) self, _tmp12_, _tmp13_, (GtkCellRenderer*) _tmp14_, TRUE);
#line 10464 "SourceList.c"
	} else {
		const gchar* _tmp15_;
		const gchar* _tmp16_;
#line 2109 "../lib/Widgets/SourceList.vala"
		_tmp15_ = granite_widgets_source_list_item_get_name (item);
#line 2109 "../lib/Widgets/SourceList.vala"
		_tmp16_ = _tmp15_;
#line 2109 "../lib/Widgets/SourceList.vala"
		g_warning ("SourceList.vala:2109: Could not edit \"%s\": path not found", _tmp16_);
#line 10474 "SourceList.c"
	}
#line 2112 "../lib/Widgets/SourceList.vala"
	_tmp17_ = granite_widgets_source_list_tree_get_editing (self);
#line 2112 "../lib/Widgets/SourceList.vala"
	_tmp18_ = _tmp17_;
#line 2112 "../lib/Widgets/SourceList.vala"
	result = _tmp18_;
#line 2112 "../lib/Widgets/SourceList.vala"
	__vala_GtkTreePath_free0 (path);
#line 2112 "../lib/Widgets/SourceList.vala"
	return result;
#line 10486 "SourceList.c"
}

static void
granite_widgets_source_list_tree_stop_editing (GraniteWidgetsSourceListTree* self)
{
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_;
	gboolean _tmp2_;
#line 2115 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 2116 "../lib/Widgets/SourceList.vala"
	_tmp1_ = granite_widgets_source_list_tree_get_editing (self);
#line 2116 "../lib/Widgets/SourceList.vala"
	_tmp2_ = _tmp1_;
#line 2116 "../lib/Widgets/SourceList.vala"
	if (_tmp2_) {
#line 10503 "SourceList.c"
		GraniteWidgetsSourceListItem* _tmp3_;
#line 2116 "../lib/Widgets/SourceList.vala"
		_tmp3_ = self->priv->edited;
#line 2116 "../lib/Widgets/SourceList.vala"
		_tmp0_ = _tmp3_ != NULL;
#line 10509 "SourceList.c"
	} else {
#line 2116 "../lib/Widgets/SourceList.vala"
		_tmp0_ = FALSE;
#line 10513 "SourceList.c"
	}
#line 2116 "../lib/Widgets/SourceList.vala"
	if (_tmp0_) {
#line 10517 "SourceList.c"
		GtkTreePath* path = NULL;
		GraniteWidgetsSourceListDataModel* _tmp4_;
		GraniteWidgetsSourceListItem* _tmp5_;
		GtkTreePath* _tmp6_;
		GtkTreePath* _tmp7_;
#line 2117 "../lib/Widgets/SourceList.vala"
		_tmp4_ = self->priv->_data_model;
#line 2117 "../lib/Widgets/SourceList.vala"
		_tmp5_ = self->priv->edited;
#line 2117 "../lib/Widgets/SourceList.vala"
		_tmp6_ = granite_widgets_source_list_data_model_get_item_path (_tmp4_, _tmp5_);
#line 2117 "../lib/Widgets/SourceList.vala"
		path = _tmp6_;
#line 2121 "../lib/Widgets/SourceList.vala"
		_tmp7_ = path;
#line 2121 "../lib/Widgets/SourceList.vala"
		if (_tmp7_ != NULL) {
#line 10535 "SourceList.c"
			GtkTreePath* _tmp8_;
			GtkTreeViewColumn* _tmp9_;
			GtkCellRendererText* _tmp10_;
#line 2122 "../lib/Widgets/SourceList.vala"
			_tmp8_ = path;
#line 2122 "../lib/Widgets/SourceList.vala"
			_tmp9_ = gtk_tree_view_get_column ((GtkTreeView*) self, (gint) GRANITE_WIDGETS_SOURCE_LIST_TREE_COLUMN_ITEM);
#line 2122 "../lib/Widgets/SourceList.vala"
			_tmp10_ = self->priv->text_cell;
#line 2122 "../lib/Widgets/SourceList.vala"
			gtk_tree_view_set_cursor_on_cell ((GtkTreeView*) self, _tmp8_, _tmp9_, (GtkCellRenderer*) _tmp10_, FALSE);
#line 10547 "SourceList.c"
		}
#line 2116 "../lib/Widgets/SourceList.vala"
		__vala_GtkTreePath_free0 (path);
#line 10551 "SourceList.c"
	}
}

static void
_granite_widgets_source_list_tree_on_editing_done_gtk_cell_editable_editing_done (GtkCellEditable* _sender,
                                                                                  gpointer self)
{
#line 2129 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_tree_on_editing_done ((GraniteWidgetsSourceListTree*) self);
#line 10561 "SourceList.c"
}

static void
granite_widgets_source_list_tree_on_editing_started (GraniteWidgetsSourceListTree* self,
                                                     GtkCellEditable* editable,
                                                     const gchar* path)
{
	GtkEntry* _tmp0_;
	GtkEntry* _tmp1_;
#line 2126 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 2126 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (editable != NULL);
#line 2126 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (path != NULL);
#line 2127 "../lib/Widgets/SourceList.vala"
	_tmp0_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (editable, gtk_entry_get_type ()) ? ((GtkEntry*) editable) : NULL);
#line 2127 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (self->priv->editable_entry);
#line 2127 "../lib/Widgets/SourceList.vala"
	self->priv->editable_entry = _tmp0_;
#line 2128 "../lib/Widgets/SourceList.vala"
	_tmp1_ = self->priv->editable_entry;
#line 2128 "../lib/Widgets/SourceList.vala"
	if (_tmp1_ != NULL) {
#line 10587 "SourceList.c"
		GtkEntry* _tmp2_;
		GtkEntry* _tmp3_;
#line 2129 "../lib/Widgets/SourceList.vala"
		_tmp2_ = self->priv->editable_entry;
#line 2129 "../lib/Widgets/SourceList.vala"
		g_signal_connect_object ((GtkCellEditable*) _tmp2_, "editing-done", (GCallback) _granite_widgets_source_list_tree_on_editing_done_gtk_cell_editable_editing_done, self, 0);
#line 2130 "../lib/Widgets/SourceList.vala"
		_tmp3_ = self->priv->editable_entry;
#line 2130 "../lib/Widgets/SourceList.vala"
		g_object_set (_tmp3_, "editable", TRUE, NULL);
#line 10598 "SourceList.c"
	}
}

static void
granite_widgets_source_list_tree_on_editing_canceled (GraniteWidgetsSourceListTree* self)
{
	GtkEntry* _tmp0_;
	GtkCellRendererText* _tmp4_;
#line 2134 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 2135 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->editable_entry;
#line 2135 "../lib/Widgets/SourceList.vala"
	if (_tmp0_ != NULL) {
#line 10613 "SourceList.c"
		GtkEntry* _tmp1_;
		GtkEntry* _tmp2_;
		guint _tmp3_;
#line 2136 "../lib/Widgets/SourceList.vala"
		_tmp1_ = self->priv->editable_entry;
#line 2136 "../lib/Widgets/SourceList.vala"
		g_object_set (_tmp1_, "editable", FALSE, NULL);
#line 2137 "../lib/Widgets/SourceList.vala"
		_tmp2_ = self->priv->editable_entry;
#line 2137 "../lib/Widgets/SourceList.vala"
		g_signal_parse_name ("editing-done", gtk_cell_editable_get_type (), &_tmp3_, NULL, FALSE);
#line 2137 "../lib/Widgets/SourceList.vala"
		g_signal_handlers_disconnect_matched ((GtkCellEditable*) _tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _granite_widgets_source_list_tree_on_editing_done_gtk_cell_editable_editing_done, self);
#line 10627 "SourceList.c"
	}
#line 2140 "../lib/Widgets/SourceList.vala"
	_tmp4_ = self->priv->text_cell;
#line 2140 "../lib/Widgets/SourceList.vala"
	g_object_set (_tmp4_, "editable", FALSE, NULL);
#line 2141 "../lib/Widgets/SourceList.vala"
	self->priv->edited = NULL;
#line 10635 "SourceList.c"
}

static void
granite_widgets_source_list_tree_on_editing_done (GraniteWidgetsSourceListTree* self)
{
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	GraniteWidgetsSourceListItem* _tmp2_;
#line 2144 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 2145 "../lib/Widgets/SourceList.vala"
	_tmp2_ = self->priv->edited;
#line 2145 "../lib/Widgets/SourceList.vala"
	if (_tmp2_ != NULL) {
#line 10650 "SourceList.c"
		GraniteWidgetsSourceListItem* _tmp3_;
		gboolean _tmp4_;
		gboolean _tmp5_;
#line 2145 "../lib/Widgets/SourceList.vala"
		_tmp3_ = self->priv->edited;
#line 2145 "../lib/Widgets/SourceList.vala"
		_tmp4_ = granite_widgets_source_list_item_get_editable (_tmp3_);
#line 2145 "../lib/Widgets/SourceList.vala"
		_tmp5_ = _tmp4_;
#line 2145 "../lib/Widgets/SourceList.vala"
		_tmp1_ = _tmp5_;
#line 10662 "SourceList.c"
	} else {
#line 2145 "../lib/Widgets/SourceList.vala"
		_tmp1_ = FALSE;
#line 10666 "SourceList.c"
	}
#line 2145 "../lib/Widgets/SourceList.vala"
	if (_tmp1_) {
#line 10670 "SourceList.c"
		GtkEntry* _tmp6_;
#line 2145 "../lib/Widgets/SourceList.vala"
		_tmp6_ = self->priv->editable_entry;
#line 2145 "../lib/Widgets/SourceList.vala"
		_tmp0_ = _tmp6_ != NULL;
#line 10676 "SourceList.c"
	} else {
#line 2145 "../lib/Widgets/SourceList.vala"
		_tmp0_ = FALSE;
#line 10680 "SourceList.c"
	}
#line 2145 "../lib/Widgets/SourceList.vala"
	if (_tmp0_) {
#line 10684 "SourceList.c"
		GraniteWidgetsSourceListItem* _tmp7_;
		GtkEntry* _tmp8_;
		const gchar* _tmp9_;
#line 2146 "../lib/Widgets/SourceList.vala"
		_tmp7_ = self->priv->edited;
#line 2146 "../lib/Widgets/SourceList.vala"
		_tmp8_ = self->priv->editable_entry;
#line 2146 "../lib/Widgets/SourceList.vala"
		_tmp9_ = gtk_entry_get_text (_tmp8_);
#line 2146 "../lib/Widgets/SourceList.vala"
		g_signal_emit (_tmp7_, granite_widgets_source_list_item_signals[GRANITE_WIDGETS_SOURCE_LIST_ITEM_EDITED_SIGNAL], 0, _tmp9_);
#line 10696 "SourceList.c"
	}
#line 2149 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_tree_on_editing_canceled (self);
#line 10700 "SourceList.c"
}

static void
granite_widgets_source_list_tree_on_activatable_activated (GraniteWidgetsSourceListTree* self,
                                                           const gchar* item_path_str)
{
	GraniteWidgetsSourceListItem* item = NULL;
	GraniteWidgetsSourceListItem* _tmp0_;
	GraniteWidgetsSourceListItem* _tmp1_;
#line 2152 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 2152 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (item_path_str != NULL);
#line 2153 "../lib/Widgets/SourceList.vala"
	_tmp0_ = granite_widgets_source_list_tree_get_item_from_path_string (self, item_path_str);
#line 2153 "../lib/Widgets/SourceList.vala"
	item = _tmp0_;
#line 2154 "../lib/Widgets/SourceList.vala"
	_tmp1_ = item;
#line 2154 "../lib/Widgets/SourceList.vala"
	if (_tmp1_ != NULL) {
#line 10722 "SourceList.c"
		GraniteWidgetsSourceListItem* _tmp2_;
#line 2155 "../lib/Widgets/SourceList.vala"
		_tmp2_ = item;
#line 2155 "../lib/Widgets/SourceList.vala"
		g_signal_emit (_tmp2_, granite_widgets_source_list_item_signals[GRANITE_WIDGETS_SOURCE_LIST_ITEM_ACTION_ACTIVATED_SIGNAL], 0);
#line 10728 "SourceList.c"
	}
#line 2152 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (item);
#line 10732 "SourceList.c"
}

static GraniteWidgetsSourceListItem*
granite_widgets_source_list_tree_get_item_from_path_string (GraniteWidgetsSourceListTree* self,
                                                            const gchar* item_path_str)
{
	GtkTreePath* item_path = NULL;
	GtkTreePath* _tmp0_;
	GraniteWidgetsSourceListDataModel* _tmp1_;
	GraniteWidgetsSourceListItem* _tmp2_;
	GraniteWidgetsSourceListItem* result;
#line 2158 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 2158 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (item_path_str != NULL, NULL);
#line 2159 "../lib/Widgets/SourceList.vala"
	_tmp0_ = gtk_tree_path_new_from_string (item_path_str);
#line 2159 "../lib/Widgets/SourceList.vala"
	item_path = _tmp0_;
#line 2160 "../lib/Widgets/SourceList.vala"
	_tmp1_ = self->priv->_data_model;
#line 2160 "../lib/Widgets/SourceList.vala"
	_tmp2_ = granite_widgets_source_list_data_model_get_item_from_path (_tmp1_, item_path);
#line 2160 "../lib/Widgets/SourceList.vala"
	result = _tmp2_;
#line 2160 "../lib/Widgets/SourceList.vala"
	__vala_GtkTreePath_free0 (item_path);
#line 2160 "../lib/Widgets/SourceList.vala"
	return result;
#line 10762 "SourceList.c"
}

static gboolean
granite_widgets_source_list_tree_toggle_expansion (GraniteWidgetsSourceListTree* self,
                                                   GraniteWidgetsSourceListExpandableItem* item)
{
	gboolean _tmp0_;
	gboolean _tmp1_;
	gboolean result;
#line 2163 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 2163 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (item != NULL, FALSE);
#line 2164 "../lib/Widgets/SourceList.vala"
	_tmp0_ = granite_widgets_source_list_expandable_item_get_collapsible (item);
#line 2164 "../lib/Widgets/SourceList.vala"
	_tmp1_ = _tmp0_;
#line 2164 "../lib/Widgets/SourceList.vala"
	if (_tmp1_) {
#line 10782 "SourceList.c"
		gboolean _tmp2_;
		gboolean _tmp3_;
#line 2165 "../lib/Widgets/SourceList.vala"
		_tmp2_ = granite_widgets_source_list_expandable_item_get_expanded (item);
#line 2165 "../lib/Widgets/SourceList.vala"
		_tmp3_ = _tmp2_;
#line 2165 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_expandable_item_set_expanded (item, !_tmp3_);
#line 2166 "../lib/Widgets/SourceList.vala"
		result = TRUE;
#line 2166 "../lib/Widgets/SourceList.vala"
		return result;
#line 10795 "SourceList.c"
	}
#line 2168 "../lib/Widgets/SourceList.vala"
	result = FALSE;
#line 2168 "../lib/Widgets/SourceList.vala"
	return result;
#line 10801 "SourceList.c"
}

/**
         * Updates the tree to reflect the ''expanded'' property of expandable_item.
         */
static void
granite_widgets_source_list_tree_update_expansion (GraniteWidgetsSourceListTree* self,
                                                   GraniteWidgetsSourceListExpandableItem* expandable_item)
{
	GtkTreePath* path = NULL;
	GraniteWidgetsSourceListDataModel* _tmp0_;
	GtkTreePath* _tmp1_;
	GtkTreePath* _tmp2_;
#line 2174 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 2174 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (expandable_item != NULL);
#line 2175 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->_data_model;
#line 2175 "../lib/Widgets/SourceList.vala"
	_tmp1_ = granite_widgets_source_list_data_model_get_item_path (_tmp0_, (GraniteWidgetsSourceListItem*) expandable_item);
#line 2175 "../lib/Widgets/SourceList.vala"
	path = _tmp1_;
#line 2177 "../lib/Widgets/SourceList.vala"
	_tmp2_ = path;
#line 2177 "../lib/Widgets/SourceList.vala"
	if (_tmp2_ != NULL) {
#line 10829 "SourceList.c"
		GtkTreePath* _tmp3_;
		gboolean _tmp4_;
		gboolean _tmp5_;
#line 2181 "../lib/Widgets/SourceList.vala"
		_tmp3_ = path;
#line 2181 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_tree_add_spacer_cell_for_level (self, gtk_tree_path_get_depth (_tmp3_) + 1, TRUE);
#line 2183 "../lib/Widgets/SourceList.vala"
		_tmp4_ = granite_widgets_source_list_expandable_item_get_expanded (expandable_item);
#line 2183 "../lib/Widgets/SourceList.vala"
		_tmp5_ = _tmp4_;
#line 2183 "../lib/Widgets/SourceList.vala"
		if (_tmp5_) {
#line 10843 "SourceList.c"
			GtkTreePath* _tmp6_;
			gboolean _tmp7_ = FALSE;
			GraniteWidgetsSourceListItem* _tmp8_;
#line 2184 "../lib/Widgets/SourceList.vala"
			_tmp6_ = path;
#line 2184 "../lib/Widgets/SourceList.vala"
			gtk_tree_view_expand_row ((GtkTreeView*) self, _tmp6_, FALSE);
#line 2192 "../lib/Widgets/SourceList.vala"
			_tmp8_ = self->priv->selected;
#line 2192 "../lib/Widgets/SourceList.vala"
			if (_tmp8_ != NULL) {
#line 10855 "SourceList.c"
				GraniteWidgetsSourceListItem* _tmp9_;
				GraniteWidgetsSourceListExpandableItem* _tmp10_;
				GraniteWidgetsSourceListExpandableItem* _tmp11_;
#line 2192 "../lib/Widgets/SourceList.vala"
				_tmp9_ = self->priv->selected;
#line 2192 "../lib/Widgets/SourceList.vala"
				_tmp10_ = granite_widgets_source_list_item_get_parent (_tmp9_);
#line 2192 "../lib/Widgets/SourceList.vala"
				_tmp11_ = _tmp10_;
#line 2192 "../lib/Widgets/SourceList.vala"
				_tmp7_ = _tmp11_ == expandable_item;
#line 10867 "SourceList.c"
			} else {
#line 2192 "../lib/Widgets/SourceList.vala"
				_tmp7_ = FALSE;
#line 10871 "SourceList.c"
			}
#line 2192 "../lib/Widgets/SourceList.vala"
			if (_tmp7_) {
#line 10875 "SourceList.c"
				GraniteWidgetsSourceListItem* _tmp12_;
#line 2193 "../lib/Widgets/SourceList.vala"
				_tmp12_ = self->priv->selected;
#line 2193 "../lib/Widgets/SourceList.vala"
				granite_widgets_source_list_tree_set_selected (self, _tmp12_, TRUE);
#line 10881 "SourceList.c"
			}
			{
				GeeIterator* _child_item_it = NULL;
				GeeCollection* _tmp13_;
				GeeCollection* _tmp14_;
				GeeCollection* _tmp15_;
				GeeIterator* _tmp16_;
				GeeIterator* _tmp17_;
#line 2198 "../lib/Widgets/SourceList.vala"
				_tmp13_ = granite_widgets_source_list_expandable_item_get_children (expandable_item);
#line 2198 "../lib/Widgets/SourceList.vala"
				_tmp14_ = _tmp13_;
#line 2198 "../lib/Widgets/SourceList.vala"
				_tmp15_ = _tmp14_;
#line 2198 "../lib/Widgets/SourceList.vala"
				_tmp16_ = gee_iterable_iterator ((GeeIterable*) _tmp15_);
#line 2198 "../lib/Widgets/SourceList.vala"
				_tmp17_ = _tmp16_;
#line 2198 "../lib/Widgets/SourceList.vala"
				_g_object_unref0 (_tmp15_);
#line 2198 "../lib/Widgets/SourceList.vala"
				_child_item_it = _tmp17_;
#line 2198 "../lib/Widgets/SourceList.vala"
				while (TRUE) {
#line 10906 "SourceList.c"
					GeeIterator* _tmp18_;
					GraniteWidgetsSourceListItem* child_item = NULL;
					GeeIterator* _tmp19_;
					gpointer _tmp20_;
					GraniteWidgetsSourceListExpandableItem* child_expandable_item = NULL;
					GraniteWidgetsSourceListItem* _tmp21_;
					GraniteWidgetsSourceListExpandableItem* _tmp22_;
					GraniteWidgetsSourceListExpandableItem* _tmp23_;
#line 2198 "../lib/Widgets/SourceList.vala"
					_tmp18_ = _child_item_it;
#line 2198 "../lib/Widgets/SourceList.vala"
					if (!gee_iterator_next (_tmp18_)) {
#line 2198 "../lib/Widgets/SourceList.vala"
						break;
#line 10921 "SourceList.c"
					}
#line 2198 "../lib/Widgets/SourceList.vala"
					_tmp19_ = _child_item_it;
#line 2198 "../lib/Widgets/SourceList.vala"
					_tmp20_ = gee_iterator_get (_tmp19_);
#line 2198 "../lib/Widgets/SourceList.vala"
					child_item = (GraniteWidgetsSourceListItem*) _tmp20_;
#line 2199 "../lib/Widgets/SourceList.vala"
					_tmp21_ = child_item;
#line 2199 "../lib/Widgets/SourceList.vala"
					_tmp22_ = _g_object_ref0 (GRANITE_WIDGETS_SOURCE_LIST_IS_EXPANDABLE_ITEM (_tmp21_) ? ((GraniteWidgetsSourceListExpandableItem*) _tmp21_) : NULL);
#line 2199 "../lib/Widgets/SourceList.vala"
					child_expandable_item = _tmp22_;
#line 2200 "../lib/Widgets/SourceList.vala"
					_tmp23_ = child_expandable_item;
#line 2200 "../lib/Widgets/SourceList.vala"
					if (_tmp23_ != NULL) {
#line 10939 "SourceList.c"
						GraniteWidgetsSourceListExpandableItem* _tmp24_;
#line 2201 "../lib/Widgets/SourceList.vala"
						_tmp24_ = child_expandable_item;
#line 2201 "../lib/Widgets/SourceList.vala"
						granite_widgets_source_list_tree_update_expansion (self, _tmp24_);
#line 10945 "SourceList.c"
					}
#line 2198 "../lib/Widgets/SourceList.vala"
					_g_object_unref0 (child_expandable_item);
#line 2198 "../lib/Widgets/SourceList.vala"
					_g_object_unref0 (child_item);
#line 10951 "SourceList.c"
				}
#line 2198 "../lib/Widgets/SourceList.vala"
				_g_object_unref0 (_child_item_it);
#line 10955 "SourceList.c"
			}
		} else {
			GtkTreePath* _tmp25_;
#line 2204 "../lib/Widgets/SourceList.vala"
			_tmp25_ = path;
#line 2204 "../lib/Widgets/SourceList.vala"
			gtk_tree_view_collapse_row ((GtkTreeView*) self, _tmp25_);
#line 10963 "SourceList.c"
		}
	}
#line 2174 "../lib/Widgets/SourceList.vala"
	__vala_GtkTreePath_free0 (path);
#line 10968 "SourceList.c"
}

static void
granite_widgets_source_list_tree_real_row_expanded (GtkTreeView* base,
                                                    GtkTreeIter* iter,
                                                    GtkTreePath* path)
{
	GraniteWidgetsSourceListTree * self;
	GraniteWidgetsSourceListExpandableItem* item = NULL;
	GraniteWidgetsSourceListDataModel* _tmp0_;
	GtkTreeIter _tmp1_;
	GraniteWidgetsSourceListItem* _tmp2_;
	GraniteWidgetsSourceListExpandableItem* _tmp3_;
#line 2209 "../lib/Widgets/SourceList.vala"
	self = (GraniteWidgetsSourceListTree*) base;
#line 2209 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (iter != NULL);
#line 2209 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (path != NULL);
#line 2210 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->_data_model;
#line 2210 "../lib/Widgets/SourceList.vala"
	_tmp1_ = *iter;
#line 2210 "../lib/Widgets/SourceList.vala"
	_tmp2_ = granite_widgets_source_list_data_model_get_item (_tmp0_, &_tmp1_);
#line 2210 "../lib/Widgets/SourceList.vala"
	_tmp3_ = GRANITE_WIDGETS_SOURCE_LIST_IS_EXPANDABLE_ITEM (_tmp2_) ? ((GraniteWidgetsSourceListExpandableItem*) _tmp2_) : NULL;
#line 2210 "../lib/Widgets/SourceList.vala"
	if (_tmp3_ == NULL) {
#line 2210 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (_tmp2_);
#line 11000 "SourceList.c"
	}
#line 2210 "../lib/Widgets/SourceList.vala"
	item = _tmp3_;
#line 2211 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (item != NULL);
#line 2213 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_tree_disable_item_property_monitor (self);
#line 2214 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_expandable_item_set_expanded (item, TRUE);
#line 2215 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_tree_enable_item_property_monitor (self);
#line 2209 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (item);
#line 11014 "SourceList.c"
}

static void
granite_widgets_source_list_tree_real_row_collapsed (GtkTreeView* base,
                                                     GtkTreeIter* iter,
                                                     GtkTreePath* path)
{
	GraniteWidgetsSourceListTree * self;
	GraniteWidgetsSourceListExpandableItem* item = NULL;
	GraniteWidgetsSourceListDataModel* _tmp0_;
	GtkTreeIter _tmp1_;
	GraniteWidgetsSourceListItem* _tmp2_;
	GraniteWidgetsSourceListExpandableItem* _tmp3_;
#line 2218 "../lib/Widgets/SourceList.vala"
	self = (GraniteWidgetsSourceListTree*) base;
#line 2218 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (iter != NULL);
#line 2218 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (path != NULL);
#line 2219 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->_data_model;
#line 2219 "../lib/Widgets/SourceList.vala"
	_tmp1_ = *iter;
#line 2219 "../lib/Widgets/SourceList.vala"
	_tmp2_ = granite_widgets_source_list_data_model_get_item (_tmp0_, &_tmp1_);
#line 2219 "../lib/Widgets/SourceList.vala"
	_tmp3_ = GRANITE_WIDGETS_SOURCE_LIST_IS_EXPANDABLE_ITEM (_tmp2_) ? ((GraniteWidgetsSourceListExpandableItem*) _tmp2_) : NULL;
#line 2219 "../lib/Widgets/SourceList.vala"
	if (_tmp3_ == NULL) {
#line 2219 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (_tmp2_);
#line 11046 "SourceList.c"
	}
#line 2219 "../lib/Widgets/SourceList.vala"
	item = _tmp3_;
#line 2220 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (item != NULL);
#line 2222 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_tree_disable_item_property_monitor (self);
#line 2223 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_expandable_item_set_expanded (item, FALSE);
#line 2224 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_tree_enable_item_property_monitor (self);
#line 2218 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (item);
#line 11060 "SourceList.c"
}

static void
granite_widgets_source_list_tree_real_row_activated (GtkTreeView* base,
                                                     GtkTreePath* path,
                                                     GtkTreeViewColumn* column)
{
	GraniteWidgetsSourceListTree * self;
	GtkTreeViewColumn* _tmp0_;
#line 2227 "../lib/Widgets/SourceList.vala"
	self = (GraniteWidgetsSourceListTree*) base;
#line 2227 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (path != NULL);
#line 2227 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (column != NULL);
#line 2228 "../lib/Widgets/SourceList.vala"
	_tmp0_ = gtk_tree_view_get_column ((GtkTreeView*) self, (gint) GRANITE_WIDGETS_SOURCE_LIST_TREE_COLUMN_ITEM);
#line 2228 "../lib/Widgets/SourceList.vala"
	if (column == _tmp0_) {
#line 11080 "SourceList.c"
		GraniteWidgetsSourceListItem* item = NULL;
		GraniteWidgetsSourceListDataModel* _tmp1_;
		GraniteWidgetsSourceListItem* _tmp2_;
		GraniteWidgetsSourceListItem* _tmp3_;
#line 2229 "../lib/Widgets/SourceList.vala"
		_tmp1_ = self->priv->_data_model;
#line 2229 "../lib/Widgets/SourceList.vala"
		_tmp2_ = granite_widgets_source_list_data_model_get_item_from_path (_tmp1_, path);
#line 2229 "../lib/Widgets/SourceList.vala"
		item = _tmp2_;
#line 2230 "../lib/Widgets/SourceList.vala"
		_tmp3_ = item;
#line 2230 "../lib/Widgets/SourceList.vala"
		if (_tmp3_ != NULL) {
#line 11095 "SourceList.c"
			GraniteWidgetsSourceListItem* _tmp4_;
#line 2231 "../lib/Widgets/SourceList.vala"
			_tmp4_ = item;
#line 2231 "../lib/Widgets/SourceList.vala"
			g_signal_emit (_tmp4_, granite_widgets_source_list_item_signals[GRANITE_WIDGETS_SOURCE_LIST_ITEM_ACTIVATED_SIGNAL], 0);
#line 11101 "SourceList.c"
		}
#line 2228 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (item);
#line 11105 "SourceList.c"
	}
}

static gboolean
granite_widgets_source_list_tree_real_key_release_event (GtkWidget* base,
                                                         GdkEventKey* event)
{
	GraniteWidgetsSourceListTree * self;
	GraniteWidgetsSourceListItem* _tmp0_;
	GraniteWidgetsSourceListItem* _tmp1_;
	gboolean result;
#line 2235 "../lib/Widgets/SourceList.vala"
	self = (GraniteWidgetsSourceListTree*) base;
#line 2235 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 2236 "../lib/Widgets/SourceList.vala"
	_tmp0_ = granite_widgets_source_list_tree_get_selected_item (self);
#line 2236 "../lib/Widgets/SourceList.vala"
	_tmp1_ = _tmp0_;
#line 2236 "../lib/Widgets/SourceList.vala"
	if (_tmp1_ != NULL) {
#line 2237 "../lib/Widgets/SourceList.vala"
		switch (event->keyval) {
#line 2237 "../lib/Widgets/SourceList.vala"
			case GDK_KEY_F2:
#line 11131 "SourceList.c"
			{
				GdkModifierType modifiers = 0U;
				gboolean _tmp2_ = FALSE;
#line 2239 "../lib/Widgets/SourceList.vala"
				modifiers = gtk_accelerator_get_default_mod_mask ();
#line 2241 "../lib/Widgets/SourceList.vala"
				if ((event->state & modifiers) == 0) {
#line 11139 "SourceList.c"
					GraniteWidgetsSourceListItem* _tmp3_;
					GraniteWidgetsSourceListItem* _tmp4_;
					gboolean _tmp5_;
					gboolean _tmp6_;
#line 2241 "../lib/Widgets/SourceList.vala"
					_tmp3_ = granite_widgets_source_list_tree_get_selected_item (self);
#line 2241 "../lib/Widgets/SourceList.vala"
					_tmp4_ = _tmp3_;
#line 2241 "../lib/Widgets/SourceList.vala"
					_tmp5_ = granite_widgets_source_list_item_get_editable (_tmp4_);
#line 2241 "../lib/Widgets/SourceList.vala"
					_tmp6_ = _tmp5_;
#line 2241 "../lib/Widgets/SourceList.vala"
					_tmp2_ = _tmp6_;
#line 11154 "SourceList.c"
				} else {
#line 2241 "../lib/Widgets/SourceList.vala"
					_tmp2_ = FALSE;
#line 11158 "SourceList.c"
				}
#line 2241 "../lib/Widgets/SourceList.vala"
				if (_tmp2_) {
#line 11162 "SourceList.c"
					GraniteWidgetsSourceListItem* _tmp7_;
					GraniteWidgetsSourceListItem* _tmp8_;
#line 2242 "../lib/Widgets/SourceList.vala"
					_tmp7_ = granite_widgets_source_list_tree_get_selected_item (self);
#line 2242 "../lib/Widgets/SourceList.vala"
					_tmp8_ = _tmp7_;
#line 2242 "../lib/Widgets/SourceList.vala"
					granite_widgets_source_list_tree_start_editing_item (self, _tmp8_);
#line 11171 "SourceList.c"
				}
#line 2243 "../lib/Widgets/SourceList.vala"
				break;
#line 11175 "SourceList.c"
			}
			default:
#line 2237 "../lib/Widgets/SourceList.vala"
			break;
#line 11180 "SourceList.c"
		}
	}
#line 2247 "../lib/Widgets/SourceList.vala"
	result = GTK_WIDGET_CLASS (granite_widgets_source_list_tree_parent_class)->key_release_event ((GtkWidget*) G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), event);
#line 2247 "../lib/Widgets/SourceList.vala"
	return result;
#line 11187 "SourceList.c"
}

static gboolean
granite_widgets_source_list_tree_real_button_release_event (GtkWidget* base,
                                                            GdkEventButton* event)
{
	GraniteWidgetsSourceListTree * self;
	gboolean _tmp0_ = FALSE;
	gboolean result;
#line 2250 "../lib/Widgets/SourceList.vala"
	self = (GraniteWidgetsSourceListTree*) base;
#line 2250 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 2251 "../lib/Widgets/SourceList.vala"
	if (self->priv->unselectable_item_clicked) {
#line 11203 "SourceList.c"
		GdkWindow* _tmp1_;
		GdkWindow* _tmp2_;
#line 2251 "../lib/Widgets/SourceList.vala"
		_tmp1_ = event->window;
#line 2251 "../lib/Widgets/SourceList.vala"
		_tmp2_ = gtk_tree_view_get_bin_window ((GtkTreeView*) self);
#line 2251 "../lib/Widgets/SourceList.vala"
		_tmp0_ = _tmp1_ == _tmp2_;
#line 11212 "SourceList.c"
	} else {
#line 2251 "../lib/Widgets/SourceList.vala"
		_tmp0_ = FALSE;
#line 11216 "SourceList.c"
	}
#line 2251 "../lib/Widgets/SourceList.vala"
	if (_tmp0_) {
#line 11220 "SourceList.c"
		GtkTreePath* path = NULL;
		GtkTreeViewColumn* column = NULL;
		gint x = 0;
		gint y = 0;
		gint cell_x = 0;
		gint cell_y = 0;
		GtkTreePath* _tmp3_ = NULL;
		GtkTreeViewColumn* _tmp4_ = NULL;
		gint _tmp5_ = 0;
		gint _tmp6_ = 0;
		gboolean _tmp7_;
		GtkTreeViewColumn* _tmp8_;
#line 2252 "../lib/Widgets/SourceList.vala"
		self->priv->unselectable_item_clicked = FALSE;
#line 2256 "../lib/Widgets/SourceList.vala"
		x = (gint) event->x;
#line 2256 "../lib/Widgets/SourceList.vala"
		y = (gint) event->y;
#line 2258 "../lib/Widgets/SourceList.vala"
		_tmp7_ = gtk_tree_view_get_path_at_pos ((GtkTreeView*) self, x, y, &_tmp3_, &_tmp4_, &_tmp5_, &_tmp6_);
#line 2258 "../lib/Widgets/SourceList.vala"
		__vala_GtkTreePath_free0 (path);
#line 2258 "../lib/Widgets/SourceList.vala"
		path = _tmp3_;
#line 2258 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (column);
#line 2258 "../lib/Widgets/SourceList.vala"
		_tmp8_ = _g_object_ref0 (_tmp4_);
#line 2258 "../lib/Widgets/SourceList.vala"
		column = _tmp8_;
#line 2258 "../lib/Widgets/SourceList.vala"
		cell_x = _tmp5_;
#line 2258 "../lib/Widgets/SourceList.vala"
		cell_y = _tmp6_;
#line 2258 "../lib/Widgets/SourceList.vala"
		if (_tmp7_) {
#line 11257 "SourceList.c"
			GraniteWidgetsSourceListExpandableItem* item = NULL;
			GraniteWidgetsSourceListDataModel* _tmp9_;
			GtkTreePath* _tmp10_;
			GraniteWidgetsSourceListItem* _tmp11_;
			GraniteWidgetsSourceListExpandableItem* _tmp12_;
			GraniteWidgetsSourceListExpandableItem* _tmp13_;
#line 2259 "../lib/Widgets/SourceList.vala"
			_tmp9_ = self->priv->_data_model;
#line 2259 "../lib/Widgets/SourceList.vala"
			_tmp10_ = path;
#line 2259 "../lib/Widgets/SourceList.vala"
			_tmp11_ = granite_widgets_source_list_data_model_get_item_from_path (_tmp9_, _tmp10_);
#line 2259 "../lib/Widgets/SourceList.vala"
			_tmp12_ = GRANITE_WIDGETS_SOURCE_LIST_IS_EXPANDABLE_ITEM (_tmp11_) ? ((GraniteWidgetsSourceListExpandableItem*) _tmp11_) : NULL;
#line 2259 "../lib/Widgets/SourceList.vala"
			if (_tmp12_ == NULL) {
#line 2259 "../lib/Widgets/SourceList.vala"
				_g_object_unref0 (_tmp11_);
#line 11276 "SourceList.c"
			}
#line 2259 "../lib/Widgets/SourceList.vala"
			item = _tmp12_;
#line 2261 "../lib/Widgets/SourceList.vala"
			_tmp13_ = item;
#line 2261 "../lib/Widgets/SourceList.vala"
			if (_tmp13_ != NULL) {
#line 11284 "SourceList.c"
				gboolean _tmp14_ = FALSE;
				GraniteWidgetsSourceListExpandableItem* _tmp15_;
				gboolean _tmp16_;
				gboolean _tmp17_;
#line 2262 "../lib/Widgets/SourceList.vala"
				_tmp15_ = item;
#line 2262 "../lib/Widgets/SourceList.vala"
				_tmp16_ = granite_widgets_source_list_item_get_selectable ((GraniteWidgetsSourceListItem*) _tmp15_);
#line 2262 "../lib/Widgets/SourceList.vala"
				_tmp17_ = _tmp16_;
#line 2262 "../lib/Widgets/SourceList.vala"
				if (!_tmp17_) {
#line 2262 "../lib/Widgets/SourceList.vala"
					_tmp14_ = TRUE;
#line 11299 "SourceList.c"
				} else {
					GraniteWidgetsSourceListDataModel* _tmp18_;
					GraniteWidgetsSourceListExpandableItem* _tmp19_;
					GtkTreePath* _tmp20_;
#line 2262 "../lib/Widgets/SourceList.vala"
					_tmp18_ = self->priv->_data_model;
#line 2262 "../lib/Widgets/SourceList.vala"
					_tmp19_ = item;
#line 2262 "../lib/Widgets/SourceList.vala"
					_tmp20_ = path;
#line 2262 "../lib/Widgets/SourceList.vala"
					_tmp14_ = granite_widgets_source_list_data_model_is_category (_tmp18_, (GraniteWidgetsSourceListItem*) _tmp19_, NULL, _tmp20_);
#line 11312 "SourceList.c"
				}
#line 2262 "../lib/Widgets/SourceList.vala"
				if (_tmp14_) {
#line 11316 "SourceList.c"
					GraniteWidgetsSourceListExpandableItem* _tmp21_;
#line 2263 "../lib/Widgets/SourceList.vala"
					_tmp21_ = item;
#line 2263 "../lib/Widgets/SourceList.vala"
					granite_widgets_source_list_tree_toggle_expansion (self, _tmp21_);
#line 11322 "SourceList.c"
				}
			}
#line 2258 "../lib/Widgets/SourceList.vala"
			_g_object_unref0 (item);
#line 11327 "SourceList.c"
		}
#line 2251 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (column);
#line 2251 "../lib/Widgets/SourceList.vala"
		__vala_GtkTreePath_free0 (path);
#line 11333 "SourceList.c"
	}
#line 2268 "../lib/Widgets/SourceList.vala"
	result = GTK_WIDGET_CLASS (granite_widgets_source_list_tree_parent_class)->button_release_event ((GtkWidget*) G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), event);
#line 2268 "../lib/Widgets/SourceList.vala"
	return result;
#line 11339 "SourceList.c"
}

static gboolean
granite_widgets_source_list_tree_real_button_press_event (GtkWidget* base,
                                                          GdkEventButton* event)
{
	GraniteWidgetsSourceListTree * self;
	GdkWindow* _tmp0_;
	GdkWindow* _tmp1_;
	GtkTreePath* path = NULL;
	GtkTreeViewColumn* column = NULL;
	gint x = 0;
	gint y = 0;
	gint cell_x = 0;
	gint cell_y = 0;
	GtkTreePath* _tmp2_ = NULL;
	GtkTreeViewColumn* _tmp3_ = NULL;
	gint _tmp4_ = 0;
	gint _tmp5_ = 0;
	gboolean _tmp6_;
	GtkTreeViewColumn* _tmp7_;
	gboolean result;
#line 2271 "../lib/Widgets/SourceList.vala"
	self = (GraniteWidgetsSourceListTree*) base;
#line 2271 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 2272 "../lib/Widgets/SourceList.vala"
	_tmp0_ = event->window;
#line 2272 "../lib/Widgets/SourceList.vala"
	_tmp1_ = gtk_tree_view_get_bin_window ((GtkTreeView*) self);
#line 2272 "../lib/Widgets/SourceList.vala"
	if (_tmp0_ != _tmp1_) {
#line 2273 "../lib/Widgets/SourceList.vala"
		result = GTK_WIDGET_CLASS (granite_widgets_source_list_tree_parent_class)->button_press_event ((GtkWidget*) G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), event);
#line 2273 "../lib/Widgets/SourceList.vala"
		return result;
#line 11376 "SourceList.c"
	}
#line 2277 "../lib/Widgets/SourceList.vala"
	x = (gint) event->x;
#line 2277 "../lib/Widgets/SourceList.vala"
	y = (gint) event->y;
#line 2279 "../lib/Widgets/SourceList.vala"
	_tmp6_ = gtk_tree_view_get_path_at_pos ((GtkTreeView*) self, x, y, &_tmp2_, &_tmp3_, &_tmp4_, &_tmp5_);
#line 2279 "../lib/Widgets/SourceList.vala"
	__vala_GtkTreePath_free0 (path);
#line 2279 "../lib/Widgets/SourceList.vala"
	path = _tmp2_;
#line 2279 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (column);
#line 2279 "../lib/Widgets/SourceList.vala"
	_tmp7_ = _g_object_ref0 (_tmp3_);
#line 2279 "../lib/Widgets/SourceList.vala"
	column = _tmp7_;
#line 2279 "../lib/Widgets/SourceList.vala"
	cell_x = _tmp4_;
#line 2279 "../lib/Widgets/SourceList.vala"
	cell_y = _tmp5_;
#line 2279 "../lib/Widgets/SourceList.vala"
	if (_tmp6_) {
#line 11400 "SourceList.c"
		GraniteWidgetsSourceListItem* item = NULL;
		GraniteWidgetsSourceListDataModel* _tmp8_;
		GtkTreePath* _tmp9_;
		GraniteWidgetsSourceListItem* _tmp10_;
		GdkRectangle start_cell_area = {0};
		GtkTreePath* _tmp11_;
		GtkTreeViewColumn* _tmp12_;
		GdkRectangle _tmp13_ = {0};
		GdkRectangle _tmp14_;
		gboolean _tmp15_ = FALSE;
		GraniteWidgetsSourceListItem* _tmp16_;
#line 2280 "../lib/Widgets/SourceList.vala"
		_tmp8_ = self->priv->_data_model;
#line 2280 "../lib/Widgets/SourceList.vala"
		_tmp9_ = path;
#line 2280 "../lib/Widgets/SourceList.vala"
		_tmp10_ = granite_widgets_source_list_data_model_get_item_from_path (_tmp8_, _tmp9_);
#line 2280 "../lib/Widgets/SourceList.vala"
		item = _tmp10_;
#line 2284 "../lib/Widgets/SourceList.vala"
		_tmp11_ = path;
#line 2284 "../lib/Widgets/SourceList.vala"
		_tmp12_ = gtk_tree_view_get_column ((GtkTreeView*) self, 0);
#line 2284 "../lib/Widgets/SourceList.vala"
		gtk_tree_view_get_cell_area ((GtkTreeView*) self, _tmp11_, _tmp12_, &_tmp13_);
#line 2284 "../lib/Widgets/SourceList.vala"
		start_cell_area = _tmp13_;
#line 2285 "../lib/Widgets/SourceList.vala"
		_tmp14_ = start_cell_area;
#line 2285 "../lib/Widgets/SourceList.vala"
		cell_x -= _tmp14_.x;
#line 2287 "../lib/Widgets/SourceList.vala"
		_tmp16_ = item;
#line 2287 "../lib/Widgets/SourceList.vala"
		if (_tmp16_ != NULL) {
#line 11436 "SourceList.c"
			GtkTreeViewColumn* _tmp17_;
			GtkTreeViewColumn* _tmp18_;
#line 2287 "../lib/Widgets/SourceList.vala"
			_tmp17_ = column;
#line 2287 "../lib/Widgets/SourceList.vala"
			_tmp18_ = gtk_tree_view_get_column ((GtkTreeView*) self, (gint) GRANITE_WIDGETS_SOURCE_LIST_TREE_COLUMN_ITEM);
#line 2287 "../lib/Widgets/SourceList.vala"
			_tmp15_ = _tmp17_ == _tmp18_;
#line 11445 "SourceList.c"
		} else {
#line 2287 "../lib/Widgets/SourceList.vala"
			_tmp15_ = FALSE;
#line 11449 "SourceList.c"
		}
#line 2287 "../lib/Widgets/SourceList.vala"
		if (_tmp15_) {
#line 2289 "../lib/Widgets/SourceList.vala"
			granite_widgets_source_list_tree_stop_editing (self);
#line 2291 "../lib/Widgets/SourceList.vala"
			if (event->button == ((guint) GDK_BUTTON_SECONDARY)) {
#line 11457 "SourceList.c"
				GraniteWidgetsSourceListItem* _tmp19_;
#line 2292 "../lib/Widgets/SourceList.vala"
				_tmp19_ = item;
#line 2292 "../lib/Widgets/SourceList.vala"
				granite_widgets_source_list_tree_popup_context_menu (self, _tmp19_, event);
#line 2293 "../lib/Widgets/SourceList.vala"
				result = TRUE;
#line 2293 "../lib/Widgets/SourceList.vala"
				_g_object_unref0 (item);
#line 2293 "../lib/Widgets/SourceList.vala"
				_g_object_unref0 (column);
#line 2293 "../lib/Widgets/SourceList.vala"
				__vala_GtkTreePath_free0 (path);
#line 2293 "../lib/Widgets/SourceList.vala"
				return result;
#line 11473 "SourceList.c"
			} else {
#line 2294 "../lib/Widgets/SourceList.vala"
				if (event->button == ((guint) GDK_BUTTON_PRIMARY)) {
#line 11477 "SourceList.c"
					gboolean is_expandable = FALSE;
					GraniteWidgetsSourceListItem* _tmp20_;
					gboolean _tmp21_ = FALSE;
					gboolean is_category = FALSE;
#line 2296 "../lib/Widgets/SourceList.vala"
					_tmp20_ = item;
#line 2296 "../lib/Widgets/SourceList.vala"
					is_expandable = GRANITE_WIDGETS_SOURCE_LIST_IS_EXPANDABLE_ITEM (_tmp20_);
#line 2297 "../lib/Widgets/SourceList.vala"
					if (is_expandable) {
#line 11488 "SourceList.c"
						GraniteWidgetsSourceListDataModel* _tmp22_;
						GraniteWidgetsSourceListItem* _tmp23_;
						GtkTreePath* _tmp24_;
#line 2297 "../lib/Widgets/SourceList.vala"
						_tmp22_ = self->priv->_data_model;
#line 2297 "../lib/Widgets/SourceList.vala"
						_tmp23_ = item;
#line 2297 "../lib/Widgets/SourceList.vala"
						_tmp24_ = path;
#line 2297 "../lib/Widgets/SourceList.vala"
						_tmp21_ = granite_widgets_source_list_data_model_is_category (_tmp22_, _tmp23_, NULL, _tmp24_);
#line 11500 "SourceList.c"
					} else {
#line 2297 "../lib/Widgets/SourceList.vala"
						_tmp21_ = FALSE;
#line 11504 "SourceList.c"
					}
#line 2297 "../lib/Widgets/SourceList.vala"
					is_category = _tmp21_;
#line 2299 "../lib/Widgets/SourceList.vala"
					if (event->type == GDK_BUTTON_PRESS) {
#line 2300 "../lib/Widgets/SourceList.vala"
						if (is_expandable) {
#line 11512 "SourceList.c"
							gboolean _tmp25_ = FALSE;
							gboolean _tmp33_ = FALSE;
							gboolean _tmp34_ = FALSE;
#line 2306 "../lib/Widgets/SourceList.vala"
							if (is_category) {
#line 2306 "../lib/Widgets/SourceList.vala"
								_tmp25_ = TRUE;
#line 11520 "SourceList.c"
							} else {
								gboolean _tmp26_ = FALSE;
								GraniteWidgetsSourceListItem* _tmp27_;
								gboolean _tmp28_;
								gboolean _tmp29_;
#line 2307 "../lib/Widgets/SourceList.vala"
								_tmp27_ = item;
#line 2307 "../lib/Widgets/SourceList.vala"
								_tmp28_ = granite_widgets_source_list_item_get_selectable (_tmp27_);
#line 2307 "../lib/Widgets/SourceList.vala"
								_tmp29_ = _tmp28_;
#line 2307 "../lib/Widgets/SourceList.vala"
								if (!_tmp29_) {
#line 11534 "SourceList.c"
									GtkTreeViewColumn* _tmp30_;
									GtkTreePath* _tmp31_;
									GraniteWidgetsSourceListCellRendererIcon* _tmp32_;
#line 2307 "../lib/Widgets/SourceList.vala"
									_tmp30_ = column;
#line 2307 "../lib/Widgets/SourceList.vala"
									_tmp31_ = path;
#line 2307 "../lib/Widgets/SourceList.vala"
									_tmp32_ = self->priv->activatable_cell;
#line 2307 "../lib/Widgets/SourceList.vala"
									_tmp26_ = !granite_widgets_source_list_tree_over_cell (self, _tmp30_, _tmp31_, (GtkCellRenderer*) _tmp32_, cell_x);
#line 11546 "SourceList.c"
								} else {
#line 2307 "../lib/Widgets/SourceList.vala"
									_tmp26_ = FALSE;
#line 11550 "SourceList.c"
								}
#line 2307 "../lib/Widgets/SourceList.vala"
								_tmp25_ = _tmp26_;
#line 11554 "SourceList.c"
							}
#line 2306 "../lib/Widgets/SourceList.vala"
							self->priv->unselectable_item_clicked = _tmp25_;
#line 2309 "../lib/Widgets/SourceList.vala"
							if (!self->priv->unselectable_item_clicked) {
#line 11560 "SourceList.c"
								GtkTreeViewColumn* _tmp35_;
								GtkTreePath* _tmp36_;
#line 2310 "../lib/Widgets/SourceList.vala"
								_tmp35_ = column;
#line 2310 "../lib/Widgets/SourceList.vala"
								_tmp36_ = path;
#line 2310 "../lib/Widgets/SourceList.vala"
								_tmp34_ = granite_widgets_source_list_tree_over_primary_expander (self, _tmp35_, _tmp36_, cell_x);
#line 11569 "SourceList.c"
							} else {
#line 2309 "../lib/Widgets/SourceList.vala"
								_tmp34_ = FALSE;
#line 11573 "SourceList.c"
							}
#line 2309 "../lib/Widgets/SourceList.vala"
							if (_tmp34_) {
#line 11577 "SourceList.c"
								GraniteWidgetsSourceListItem* _tmp37_;
#line 2311 "../lib/Widgets/SourceList.vala"
								_tmp37_ = item;
#line 2311 "../lib/Widgets/SourceList.vala"
								_tmp33_ = granite_widgets_source_list_tree_toggle_expansion (self, GRANITE_WIDGETS_SOURCE_LIST_IS_EXPANDABLE_ITEM (_tmp37_) ? ((GraniteWidgetsSourceListExpandableItem*) _tmp37_) : NULL);
#line 11583 "SourceList.c"
							} else {
#line 2309 "../lib/Widgets/SourceList.vala"
								_tmp33_ = FALSE;
#line 11587 "SourceList.c"
							}
#line 2309 "../lib/Widgets/SourceList.vala"
							if (_tmp33_) {
#line 2312 "../lib/Widgets/SourceList.vala"
								result = TRUE;
#line 2312 "../lib/Widgets/SourceList.vala"
								_g_object_unref0 (item);
#line 2312 "../lib/Widgets/SourceList.vala"
								_g_object_unref0 (column);
#line 2312 "../lib/Widgets/SourceList.vala"
								__vala_GtkTreePath_free0 (path);
#line 2312 "../lib/Widgets/SourceList.vala"
								return result;
#line 11601 "SourceList.c"
							}
						}
					} else {
						gboolean _tmp38_ = FALSE;
						gboolean _tmp39_ = FALSE;
						gboolean _tmp40_ = FALSE;
						gboolean _tmp41_ = FALSE;
						gboolean _tmp42_ = FALSE;
#line 2315 "../lib/Widgets/SourceList.vala"
						if (event->type == GDK_2BUTTON_PRESS) {
#line 2316 "../lib/Widgets/SourceList.vala"
							_tmp42_ = !is_category;
#line 11614 "SourceList.c"
						} else {
#line 2315 "../lib/Widgets/SourceList.vala"
							_tmp42_ = FALSE;
#line 11618 "SourceList.c"
						}
#line 2315 "../lib/Widgets/SourceList.vala"
						if (_tmp42_) {
#line 11622 "SourceList.c"
							GraniteWidgetsSourceListItem* _tmp43_;
							gboolean _tmp44_;
							gboolean _tmp45_;
#line 2317 "../lib/Widgets/SourceList.vala"
							_tmp43_ = item;
#line 2317 "../lib/Widgets/SourceList.vala"
							_tmp44_ = granite_widgets_source_list_item_get_editable (_tmp43_);
#line 2317 "../lib/Widgets/SourceList.vala"
							_tmp45_ = _tmp44_;
#line 2317 "../lib/Widgets/SourceList.vala"
							_tmp41_ = _tmp45_;
#line 11634 "SourceList.c"
						} else {
#line 2315 "../lib/Widgets/SourceList.vala"
							_tmp41_ = FALSE;
#line 11638 "SourceList.c"
						}
#line 2315 "../lib/Widgets/SourceList.vala"
						if (_tmp41_) {
#line 11642 "SourceList.c"
							GraniteWidgetsSourceListItem* _tmp46_;
							gboolean _tmp47_;
							gboolean _tmp48_;
#line 2318 "../lib/Widgets/SourceList.vala"
							_tmp46_ = item;
#line 2318 "../lib/Widgets/SourceList.vala"
							_tmp47_ = granite_widgets_source_list_item_get_selectable (_tmp46_);
#line 2318 "../lib/Widgets/SourceList.vala"
							_tmp48_ = _tmp47_;
#line 2318 "../lib/Widgets/SourceList.vala"
							_tmp40_ = _tmp48_;
#line 11654 "SourceList.c"
						} else {
#line 2315 "../lib/Widgets/SourceList.vala"
							_tmp40_ = FALSE;
#line 11658 "SourceList.c"
						}
#line 2315 "../lib/Widgets/SourceList.vala"
						if (_tmp40_) {
#line 11662 "SourceList.c"
							GtkTreeViewColumn* _tmp49_;
							GtkTreePath* _tmp50_;
							GtkCellRendererText* _tmp51_;
#line 2319 "../lib/Widgets/SourceList.vala"
							_tmp49_ = column;
#line 2319 "../lib/Widgets/SourceList.vala"
							_tmp50_ = path;
#line 2319 "../lib/Widgets/SourceList.vala"
							_tmp51_ = self->priv->text_cell;
#line 2319 "../lib/Widgets/SourceList.vala"
							_tmp39_ = granite_widgets_source_list_tree_over_cell (self, _tmp49_, _tmp50_, (GtkCellRenderer*) _tmp51_, cell_x);
#line 11674 "SourceList.c"
						} else {
#line 2315 "../lib/Widgets/SourceList.vala"
							_tmp39_ = FALSE;
#line 11678 "SourceList.c"
						}
#line 2315 "../lib/Widgets/SourceList.vala"
						if (_tmp39_) {
#line 11682 "SourceList.c"
							GraniteWidgetsSourceListItem* _tmp52_;
#line 2320 "../lib/Widgets/SourceList.vala"
							_tmp52_ = item;
#line 2320 "../lib/Widgets/SourceList.vala"
							_tmp38_ = granite_widgets_source_list_tree_start_editing_item (self, _tmp52_);
#line 11688 "SourceList.c"
						} else {
#line 2315 "../lib/Widgets/SourceList.vala"
							_tmp38_ = FALSE;
#line 11692 "SourceList.c"
						}
#line 2314 "../lib/Widgets/SourceList.vala"
						if (_tmp38_) {
#line 2323 "../lib/Widgets/SourceList.vala"
							result = TRUE;
#line 2323 "../lib/Widgets/SourceList.vala"
							_g_object_unref0 (item);
#line 2323 "../lib/Widgets/SourceList.vala"
							_g_object_unref0 (column);
#line 2323 "../lib/Widgets/SourceList.vala"
							__vala_GtkTreePath_free0 (path);
#line 2323 "../lib/Widgets/SourceList.vala"
							return result;
#line 11706 "SourceList.c"
						}
					}
				}
			}
		}
#line 2279 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (item);
#line 11714 "SourceList.c"
	}
#line 2329 "../lib/Widgets/SourceList.vala"
	result = GTK_WIDGET_CLASS (granite_widgets_source_list_tree_parent_class)->button_press_event ((GtkWidget*) G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), event);
#line 2329 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (column);
#line 2329 "../lib/Widgets/SourceList.vala"
	__vala_GtkTreePath_free0 (path);
#line 2329 "../lib/Widgets/SourceList.vala"
	return result;
#line 11724 "SourceList.c"
}

static gboolean
granite_widgets_source_list_tree_over_primary_expander (GraniteWidgetsSourceListTree* self,
                                                        GtkTreeViewColumn* col,
                                                        GtkTreePath* path,
                                                        gint x)
{
	GtkTreeIter iter = {0};
	GtkTreeModel* _tmp0_;
	GtkTreeModel* _tmp1_;
	GtkTreeIter _tmp2_ = {0};
	gboolean _tmp3_;
	GraniteWidgetsCellRendererExpander* _tmp4_;
	GtkTreeModel* _tmp5_;
	GtkTreeModel* _tmp6_;
	GtkTreeIter _tmp7_;
	GraniteWidgetsCellRendererExpander* _tmp8_;
	gboolean _tmp9_;
	gboolean _tmp10_;
	GtkTreeModel* _tmp11_;
	GtkTreeModel* _tmp12_;
	GtkTreeIter _tmp13_;
	gint indentation_level = 0;
	GraniteWidgetsSourceListCellRendererSpacer* last_spacer_cell = NULL;
	GeeHashMap* _tmp14_;
	gpointer _tmp15_;
	GraniteWidgetsSourceListCellRendererSpacer* _tmp16_;
	gboolean result;
#line 2332 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 2332 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (col != NULL, FALSE);
#line 2332 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (path != NULL, FALSE);
#line 2334 "../lib/Widgets/SourceList.vala"
	_tmp0_ = gtk_tree_view_get_model ((GtkTreeView*) self);
#line 2334 "../lib/Widgets/SourceList.vala"
	_tmp1_ = _tmp0_;
#line 2334 "../lib/Widgets/SourceList.vala"
	_tmp3_ = gtk_tree_model_get_iter (_tmp1_, &_tmp2_, path);
#line 2334 "../lib/Widgets/SourceList.vala"
	iter = _tmp2_;
#line 2334 "../lib/Widgets/SourceList.vala"
	if (!_tmp3_) {
#line 2335 "../lib/Widgets/SourceList.vala"
		result = FALSE;
#line 2335 "../lib/Widgets/SourceList.vala"
		return result;
#line 11774 "SourceList.c"
	}
#line 2338 "../lib/Widgets/SourceList.vala"
	_tmp4_ = self->priv->primary_expander_cell;
#line 2338 "../lib/Widgets/SourceList.vala"
	_tmp5_ = gtk_tree_view_get_model ((GtkTreeView*) self);
#line 2338 "../lib/Widgets/SourceList.vala"
	_tmp6_ = _tmp5_;
#line 2338 "../lib/Widgets/SourceList.vala"
	_tmp7_ = iter;
#line 2338 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_tree_expander_cell_data_func (self, (GtkCellLayout*) col, (GtkCellRenderer*) _tmp4_, _tmp6_, &_tmp7_);
#line 2340 "../lib/Widgets/SourceList.vala"
	_tmp8_ = self->priv->primary_expander_cell;
#line 2340 "../lib/Widgets/SourceList.vala"
	_tmp9_ = gtk_cell_renderer_get_visible ((GtkCellRenderer*) _tmp8_);
#line 2340 "../lib/Widgets/SourceList.vala"
	_tmp10_ = _tmp9_;
#line 2340 "../lib/Widgets/SourceList.vala"
	if (!_tmp10_) {
#line 2341 "../lib/Widgets/SourceList.vala"
		result = FALSE;
#line 2341 "../lib/Widgets/SourceList.vala"
		return result;
#line 11798 "SourceList.c"
	}
#line 2344 "../lib/Widgets/SourceList.vala"
	_tmp11_ = gtk_tree_view_get_model ((GtkTreeView*) self);
#line 2344 "../lib/Widgets/SourceList.vala"
	_tmp12_ = _tmp11_;
#line 2344 "../lib/Widgets/SourceList.vala"
	_tmp13_ = iter;
#line 2344 "../lib/Widgets/SourceList.vala"
	if (gtk_tree_model_iter_n_children (_tmp12_, &_tmp13_) < 1) {
#line 2345 "../lib/Widgets/SourceList.vala"
		result = FALSE;
#line 2345 "../lib/Widgets/SourceList.vala"
		return result;
#line 11812 "SourceList.c"
	}
#line 2353 "../lib/Widgets/SourceList.vala"
	indentation_level = gtk_tree_path_get_depth (path);
#line 2354 "../lib/Widgets/SourceList.vala"
	_tmp14_ = self->priv->spacer_cells;
#line 2354 "../lib/Widgets/SourceList.vala"
	_tmp15_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp14_, (gpointer) ((gintptr) indentation_level));
#line 2354 "../lib/Widgets/SourceList.vala"
	last_spacer_cell = (GraniteWidgetsSourceListCellRendererSpacer*) _tmp15_;
#line 2356 "../lib/Widgets/SourceList.vala"
	_tmp16_ = last_spacer_cell;
#line 2356 "../lib/Widgets/SourceList.vala"
	if (_tmp16_ != NULL) {
#line 11826 "SourceList.c"
		gint cell_x = 0;
		gint cell_width = 0;
		GraniteWidgetsSourceListCellRendererSpacer* _tmp17_;
		gint _tmp18_ = 0;
		gint _tmp19_ = 0;
		gboolean _tmp20_;
#line 2359 "../lib/Widgets/SourceList.vala"
		_tmp17_ = last_spacer_cell;
#line 2359 "../lib/Widgets/SourceList.vala"
		_tmp20_ = gtk_tree_view_column_cell_get_position (col, (GtkCellRenderer*) _tmp17_, &_tmp18_, &_tmp19_);
#line 2359 "../lib/Widgets/SourceList.vala"
		cell_x = _tmp18_;
#line 2359 "../lib/Widgets/SourceList.vala"
		cell_width = _tmp19_;
#line 2359 "../lib/Widgets/SourceList.vala"
		if (_tmp20_) {
#line 11843 "SourceList.c"
			gint expander_width = 0;
			GraniteWidgetsCellRendererExpander* _tmp21_;
			GtkTextDirection dir = 0;
			gboolean _tmp23_ = FALSE;
#line 2361 "../lib/Widgets/SourceList.vala"
			_tmp21_ = self->priv->primary_expander_cell;
#line 2361 "../lib/Widgets/SourceList.vala"
			expander_width = granite_widgets_source_list_tree_get_cell_width (self, (GtkCellRenderer*) _tmp21_) + 1;
#line 2363 "../lib/Widgets/SourceList.vala"
			dir = gtk_widget_get_direction ((GtkWidget*) self);
#line 2364 "../lib/Widgets/SourceList.vala"
			if (dir == GTK_TEXT_DIR_NONE) {
#line 2365 "../lib/Widgets/SourceList.vala"
				dir = gtk_widget_get_default_direction ();
#line 11858 "SourceList.c"
			}
#line 2368 "../lib/Widgets/SourceList.vala"
			if (dir == GTK_TEXT_DIR_LTR) {
#line 11862 "SourceList.c"
				gint indentation_offset = 0;
				gboolean _tmp22_ = FALSE;
#line 2369 "../lib/Widgets/SourceList.vala"
				indentation_offset = cell_x + cell_width;
#line 2370 "../lib/Widgets/SourceList.vala"
				if (x >= indentation_offset) {
#line 2370 "../lib/Widgets/SourceList.vala"
					_tmp22_ = x <= (indentation_offset + expander_width);
#line 11871 "SourceList.c"
				} else {
#line 2370 "../lib/Widgets/SourceList.vala"
					_tmp22_ = FALSE;
#line 11875 "SourceList.c"
				}
#line 2370 "../lib/Widgets/SourceList.vala"
				result = _tmp22_;
#line 2370 "../lib/Widgets/SourceList.vala"
				_g_object_unref0 (last_spacer_cell);
#line 2370 "../lib/Widgets/SourceList.vala"
				return result;
#line 11883 "SourceList.c"
			}
#line 2373 "../lib/Widgets/SourceList.vala"
			if (x <= cell_x) {
#line 2373 "../lib/Widgets/SourceList.vala"
				_tmp23_ = x >= (cell_x - expander_width);
#line 11889 "SourceList.c"
			} else {
#line 2373 "../lib/Widgets/SourceList.vala"
				_tmp23_ = FALSE;
#line 11893 "SourceList.c"
			}
#line 2373 "../lib/Widgets/SourceList.vala"
			result = _tmp23_;
#line 2373 "../lib/Widgets/SourceList.vala"
			_g_object_unref0 (last_spacer_cell);
#line 2373 "../lib/Widgets/SourceList.vala"
			return result;
#line 11901 "SourceList.c"
		}
	}
#line 2377 "../lib/Widgets/SourceList.vala"
	result = FALSE;
#line 2377 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (last_spacer_cell);
#line 2377 "../lib/Widgets/SourceList.vala"
	return result;
#line 11910 "SourceList.c"
}

static gboolean
granite_widgets_source_list_tree_over_cell (GraniteWidgetsSourceListTree* self,
                                            GtkTreeViewColumn* col,
                                            GtkTreePath* path,
                                            GtkCellRenderer* cell,
                                            gint x)
{
	gint cell_x = 0;
	gint cell_width = 0;
	gboolean found = FALSE;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	gboolean _tmp2_;
	gboolean _tmp3_ = FALSE;
	gboolean _tmp4_ = FALSE;
	gboolean result;
#line 2380 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 2380 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (col != NULL, FALSE);
#line 2380 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (path != NULL, FALSE);
#line 2380 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (cell != NULL, FALSE);
#line 2382 "../lib/Widgets/SourceList.vala"
	_tmp2_ = gtk_tree_view_column_cell_get_position (col, cell, &_tmp0_, &_tmp1_);
#line 2382 "../lib/Widgets/SourceList.vala"
	cell_x = _tmp0_;
#line 2382 "../lib/Widgets/SourceList.vala"
	cell_width = _tmp1_;
#line 2382 "../lib/Widgets/SourceList.vala"
	found = _tmp2_;
#line 2383 "../lib/Widgets/SourceList.vala"
	if (found) {
#line 2383 "../lib/Widgets/SourceList.vala"
		_tmp4_ = x > cell_x;
#line 11949 "SourceList.c"
	} else {
#line 2383 "../lib/Widgets/SourceList.vala"
		_tmp4_ = FALSE;
#line 11953 "SourceList.c"
	}
#line 2383 "../lib/Widgets/SourceList.vala"
	if (_tmp4_) {
#line 2383 "../lib/Widgets/SourceList.vala"
		_tmp3_ = x < (cell_x + cell_width);
#line 11959 "SourceList.c"
	} else {
#line 2383 "../lib/Widgets/SourceList.vala"
		_tmp3_ = FALSE;
#line 11963 "SourceList.c"
	}
#line 2383 "../lib/Widgets/SourceList.vala"
	result = _tmp3_;
#line 2383 "../lib/Widgets/SourceList.vala"
	return result;
#line 11969 "SourceList.c"
}

static gint
granite_widgets_source_list_tree_get_cell_width (GraniteWidgetsSourceListTree* self,
                                                 GtkCellRenderer* cell_renderer)
{
	GtkRequisition min_req = {0};
	GtkRequisition _tmp0_ = {0};
	GtkRequisition _tmp1_;
	gint result;
#line 2386 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 2386 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (cell_renderer != NULL, 0);
#line 2388 "../lib/Widgets/SourceList.vala"
	gtk_cell_renderer_get_preferred_size (cell_renderer, (GtkWidget*) self, &_tmp0_, NULL);
#line 2388 "../lib/Widgets/SourceList.vala"
	min_req = _tmp0_;
#line 2389 "../lib/Widgets/SourceList.vala"
	_tmp1_ = min_req;
#line 2389 "../lib/Widgets/SourceList.vala"
	result = _tmp1_.width;
#line 2389 "../lib/Widgets/SourceList.vala"
	return result;
#line 11994 "SourceList.c"
}

static gboolean
granite_widgets_source_list_tree_real_popup_menu (GtkWidget* base)
{
	GraniteWidgetsSourceListTree * self;
	gboolean result;
#line 2392 "../lib/Widgets/SourceList.vala"
	self = (GraniteWidgetsSourceListTree*) base;
#line 2393 "../lib/Widgets/SourceList.vala"
	result = granite_widgets_source_list_tree_popup_context_menu (self, NULL, NULL);
#line 2393 "../lib/Widgets/SourceList.vala"
	return result;
#line 12008 "SourceList.c"
}

static gboolean
granite_widgets_source_list_tree_popup_context_menu (GraniteWidgetsSourceListTree* self,
                                                     GraniteWidgetsSourceListItem* item,
                                                     GdkEventButton* event)
{
	gboolean result;
#line 2396 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 2397 "../lib/Widgets/SourceList.vala"
	if (item == NULL) {
#line 12021 "SourceList.c"
		GraniteWidgetsSourceListItem* _tmp0_;
		GraniteWidgetsSourceListItem* _tmp1_;
#line 2398 "../lib/Widgets/SourceList.vala"
		_tmp0_ = granite_widgets_source_list_tree_get_selected_item (self);
#line 2398 "../lib/Widgets/SourceList.vala"
		_tmp1_ = _tmp0_;
#line 2398 "../lib/Widgets/SourceList.vala"
		item = _tmp1_;
#line 12030 "SourceList.c"
	}
#line 2400 "../lib/Widgets/SourceList.vala"
	if (item != NULL) {
#line 12034 "SourceList.c"
		GtkMenu* menu = NULL;
		GtkMenu* _tmp2_;
		GtkMenu* _tmp3_;
#line 2401 "../lib/Widgets/SourceList.vala"
		_tmp2_ = granite_widgets_source_list_item_get_context_menu (item);
#line 2401 "../lib/Widgets/SourceList.vala"
		menu = _tmp2_;
#line 2402 "../lib/Widgets/SourceList.vala"
		_tmp3_ = menu;
#line 2402 "../lib/Widgets/SourceList.vala"
		if (_tmp3_ != NULL) {
#line 12046 "SourceList.c"
			GtkMenu* _tmp4_;
			GtkMenu* _tmp5_;
#line 2403 "../lib/Widgets/SourceList.vala"
			_tmp4_ = menu;
#line 2403 "../lib/Widgets/SourceList.vala"
			g_object_set (_tmp4_, "attach-widget", (GtkWidget*) self, NULL);
#line 2404 "../lib/Widgets/SourceList.vala"
			_tmp5_ = menu;
#line 2404 "../lib/Widgets/SourceList.vala"
			gtk_menu_popup_at_pointer (_tmp5_, (GdkEvent*) event);
#line 2405 "../lib/Widgets/SourceList.vala"
			if (event == NULL) {
#line 12059 "SourceList.c"
				GtkMenu* _tmp6_;
#line 2406 "../lib/Widgets/SourceList.vala"
				_tmp6_ = menu;
#line 2406 "../lib/Widgets/SourceList.vala"
				gtk_menu_shell_select_first ((GtkMenuShell*) _tmp6_, FALSE);
#line 12065 "SourceList.c"
			}
#line 2409 "../lib/Widgets/SourceList.vala"
			result = TRUE;
#line 2409 "../lib/Widgets/SourceList.vala"
			_g_object_unref0 (menu);
#line 2409 "../lib/Widgets/SourceList.vala"
			return result;
#line 12073 "SourceList.c"
		}
#line 2400 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (menu);
#line 12077 "SourceList.c"
	}
#line 2413 "../lib/Widgets/SourceList.vala"
	result = FALSE;
#line 2413 "../lib/Widgets/SourceList.vala"
	return result;
#line 12083 "SourceList.c"
}

static GraniteWidgetsSourceListItem*
granite_widgets_source_list_tree_get_item_from_model (GtkTreeModel* model,
                                                      GtkTreeIter* iter)
{
	GraniteWidgetsSourceListDataModel* data_model = NULL;
	GraniteWidgetsSourceListDataModel* _tmp0_;
	GtkTreeIter _tmp1_;
	GraniteWidgetsSourceListItem* _tmp2_;
	GraniteWidgetsSourceListItem* result;
#line 2416 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (model != NULL, NULL);
#line 2416 "../lib/Widgets/SourceList.vala"
	g_return_val_if_fail (iter != NULL, NULL);
#line 2417 "../lib/Widgets/SourceList.vala"
	_tmp0_ = _g_object_ref0 (GRANITE_WIDGETS_SOURCE_LIST_IS_DATA_MODEL (model) ? ((GraniteWidgetsSourceListDataModel*) model) : NULL);
#line 2417 "../lib/Widgets/SourceList.vala"
	data_model = _tmp0_;
#line 2418 "../lib/Widgets/SourceList.vala"
	_vala_assert (data_model != NULL, "data_model != null");
#line 2419 "../lib/Widgets/SourceList.vala"
	_tmp1_ = *iter;
#line 2419 "../lib/Widgets/SourceList.vala"
	_tmp2_ = granite_widgets_source_list_data_model_get_item (data_model, &_tmp1_);
#line 2419 "../lib/Widgets/SourceList.vala"
	result = _tmp2_;
#line 2419 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (data_model);
#line 2419 "../lib/Widgets/SourceList.vala"
	return result;
#line 12115 "SourceList.c"
}

static void
granite_widgets_source_list_tree_spacer_cell_data_func (GtkCellLayout* layout,
                                                        GtkCellRenderer* renderer,
                                                        GtkTreeModel* model,
                                                        GtkTreeIter* iter)
{
	GraniteWidgetsSourceListCellRendererSpacer* spacer = NULL;
	GraniteWidgetsSourceListCellRendererSpacer* _tmp0_;
	GraniteWidgetsSourceListCellRendererSpacer* _tmp1_;
	GraniteWidgetsSourceListCellRendererSpacer* _tmp2_;
	gint _tmp3_;
	gint _tmp4_;
	GtkTreePath* path = NULL;
	GtkTreeIter _tmp5_;
	GtkTreePath* _tmp6_;
	gint level = 0;
	GtkTreePath* _tmp7_;
	GraniteWidgetsSourceListCellRendererSpacer* _tmp9_;
	gint _tmp10_;
	gint _tmp11_;
#line 2422 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (layout != NULL);
#line 2422 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (renderer != NULL);
#line 2422 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (model != NULL);
#line 2422 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (iter != NULL);
#line 2428 "../lib/Widgets/SourceList.vala"
	_tmp0_ = _g_object_ref0 (GRANITE_WIDGETS_SOURCE_LIST_IS_CELL_RENDERER_SPACER (renderer) ? ((GraniteWidgetsSourceListCellRendererSpacer*) renderer) : NULL);
#line 2428 "../lib/Widgets/SourceList.vala"
	spacer = _tmp0_;
#line 2429 "../lib/Widgets/SourceList.vala"
	_tmp1_ = spacer;
#line 2429 "../lib/Widgets/SourceList.vala"
	_vala_assert (_tmp1_ != NULL, "spacer != null");
#line 2430 "../lib/Widgets/SourceList.vala"
	_tmp2_ = spacer;
#line 2430 "../lib/Widgets/SourceList.vala"
	_tmp3_ = granite_widgets_source_list_cell_renderer_spacer_get_level (_tmp2_);
#line 2430 "../lib/Widgets/SourceList.vala"
	_tmp4_ = _tmp3_;
#line 2430 "../lib/Widgets/SourceList.vala"
	_vala_assert (_tmp4_ > 0, "spacer.level > 0");
#line 2432 "../lib/Widgets/SourceList.vala"
	_tmp5_ = *iter;
#line 2432 "../lib/Widgets/SourceList.vala"
	_tmp6_ = gtk_tree_model_get_path (model, &_tmp5_);
#line 2432 "../lib/Widgets/SourceList.vala"
	path = _tmp6_;
#line 2434 "../lib/Widgets/SourceList.vala"
	level = -1;
#line 2435 "../lib/Widgets/SourceList.vala"
	_tmp7_ = path;
#line 2435 "../lib/Widgets/SourceList.vala"
	if (_tmp7_ != NULL) {
#line 12174 "SourceList.c"
		GtkTreePath* _tmp8_;
#line 2436 "../lib/Widgets/SourceList.vala"
		_tmp8_ = path;
#line 2436 "../lib/Widgets/SourceList.vala"
		level = gtk_tree_path_get_depth (_tmp8_);
#line 12180 "SourceList.c"
	}
#line 2438 "../lib/Widgets/SourceList.vala"
	_tmp9_ = spacer;
#line 2438 "../lib/Widgets/SourceList.vala"
	_tmp10_ = granite_widgets_source_list_cell_renderer_spacer_get_level (_tmp9_);
#line 2438 "../lib/Widgets/SourceList.vala"
	_tmp11_ = _tmp10_;
#line 2438 "../lib/Widgets/SourceList.vala"
	gtk_cell_renderer_set_visible (renderer, _tmp11_ <= level);
#line 2422 "../lib/Widgets/SourceList.vala"
	__vala_GtkTreePath_free0 (path);
#line 2422 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (spacer);
#line 12194 "SourceList.c"
}

static void
granite_widgets_source_list_tree_name_cell_data_func (GraniteWidgetsSourceListTree* self,
                                                      GtkCellLayout* layout,
                                                      GtkCellRenderer* renderer,
                                                      GtkTreeModel* model,
                                                      GtkTreeIter* iter)
{
	GtkCellRendererText* text_renderer = NULL;
	GtkCellRendererText* _tmp0_;
	GtkCellRendererText* _tmp1_;
	GString* text = NULL;
	GString* _tmp2_;
	PangoWeight weight = 0;
	gboolean use_markup = FALSE;
	GraniteWidgetsSourceListItem* item = NULL;
	GtkTreeIter _tmp3_;
	GraniteWidgetsSourceListItem* _tmp4_;
	GraniteWidgetsSourceListItem* _tmp5_;
	GtkCellRendererText* _tmp20_;
#line 2441 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 2441 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (layout != NULL);
#line 2441 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (renderer != NULL);
#line 2441 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (model != NULL);
#line 2441 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (iter != NULL);
#line 2447 "../lib/Widgets/SourceList.vala"
	_tmp0_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (renderer, gtk_cell_renderer_text_get_type ()) ? ((GtkCellRendererText*) renderer) : NULL);
#line 2447 "../lib/Widgets/SourceList.vala"
	text_renderer = _tmp0_;
#line 2448 "../lib/Widgets/SourceList.vala"
	_tmp1_ = text_renderer;
#line 2448 "../lib/Widgets/SourceList.vala"
	_vala_assert (_tmp1_ != NULL, "text_renderer != null");
#line 2450 "../lib/Widgets/SourceList.vala"
	_tmp2_ = g_string_new ("");
#line 2450 "../lib/Widgets/SourceList.vala"
	text = _tmp2_;
#line 2451 "../lib/Widgets/SourceList.vala"
	weight = PANGO_WEIGHT_NORMAL;
#line 2452 "../lib/Widgets/SourceList.vala"
	use_markup = FALSE;
#line 2454 "../lib/Widgets/SourceList.vala"
	_tmp3_ = *iter;
#line 2454 "../lib/Widgets/SourceList.vala"
	_tmp4_ = granite_widgets_source_list_tree_get_item_from_model (model, &_tmp3_);
#line 2454 "../lib/Widgets/SourceList.vala"
	item = _tmp4_;
#line 2455 "../lib/Widgets/SourceList.vala"
	_tmp5_ = item;
#line 2455 "../lib/Widgets/SourceList.vala"
	if (_tmp5_ != NULL) {
#line 12252 "SourceList.c"
		GraniteWidgetsSourceListItem* _tmp6_;
		const gchar* _tmp7_;
		const gchar* _tmp8_;
		GraniteWidgetsSourceListDataModel* _tmp17_;
		GraniteWidgetsSourceListItem* _tmp18_;
		GtkTreeIter _tmp19_;
#line 2456 "../lib/Widgets/SourceList.vala"
		_tmp6_ = item;
#line 2456 "../lib/Widgets/SourceList.vala"
		_tmp7_ = granite_widgets_source_list_item_get_markup (_tmp6_);
#line 2456 "../lib/Widgets/SourceList.vala"
		_tmp8_ = _tmp7_;
#line 2456 "../lib/Widgets/SourceList.vala"
		if (_tmp8_ != NULL) {
#line 12267 "SourceList.c"
			GString* _tmp9_;
			GraniteWidgetsSourceListItem* _tmp10_;
			const gchar* _tmp11_;
			const gchar* _tmp12_;
#line 2457 "../lib/Widgets/SourceList.vala"
			_tmp9_ = text;
#line 2457 "../lib/Widgets/SourceList.vala"
			_tmp10_ = item;
#line 2457 "../lib/Widgets/SourceList.vala"
			_tmp11_ = granite_widgets_source_list_item_get_markup (_tmp10_);
#line 2457 "../lib/Widgets/SourceList.vala"
			_tmp12_ = _tmp11_;
#line 2457 "../lib/Widgets/SourceList.vala"
			g_string_append (_tmp9_, _tmp12_);
#line 2458 "../lib/Widgets/SourceList.vala"
			use_markup = TRUE;
#line 12284 "SourceList.c"
		} else {
			GString* _tmp13_;
			GraniteWidgetsSourceListItem* _tmp14_;
			const gchar* _tmp15_;
			const gchar* _tmp16_;
#line 2460 "../lib/Widgets/SourceList.vala"
			_tmp13_ = text;
#line 2460 "../lib/Widgets/SourceList.vala"
			_tmp14_ = item;
#line 2460 "../lib/Widgets/SourceList.vala"
			_tmp15_ = granite_widgets_source_list_item_get_name (_tmp14_);
#line 2460 "../lib/Widgets/SourceList.vala"
			_tmp16_ = _tmp15_;
#line 2460 "../lib/Widgets/SourceList.vala"
			g_string_append (_tmp13_, _tmp16_);
#line 12300 "SourceList.c"
		}
#line 2463 "../lib/Widgets/SourceList.vala"
		_tmp17_ = self->priv->_data_model;
#line 2463 "../lib/Widgets/SourceList.vala"
		_tmp18_ = item;
#line 2463 "../lib/Widgets/SourceList.vala"
		_tmp19_ = *iter;
#line 2463 "../lib/Widgets/SourceList.vala"
		if (granite_widgets_source_list_data_model_is_category (_tmp17_, _tmp18_, &_tmp19_, NULL)) {
#line 2464 "../lib/Widgets/SourceList.vala"
			weight = PANGO_WEIGHT_BOLD;
#line 12312 "SourceList.c"
		}
	}
#line 2467 "../lib/Widgets/SourceList.vala"
	_tmp20_ = text_renderer;
#line 2467 "../lib/Widgets/SourceList.vala"
	g_object_set (_tmp20_, "weight", (gint) weight, NULL);
#line 2468 "../lib/Widgets/SourceList.vala"
	if (use_markup) {
#line 12321 "SourceList.c"
		GtkCellRendererText* _tmp21_;
		GString* _tmp22_;
		const gchar* _tmp23_;
#line 2469 "../lib/Widgets/SourceList.vala"
		_tmp21_ = text_renderer;
#line 2469 "../lib/Widgets/SourceList.vala"
		_tmp22_ = text;
#line 2469 "../lib/Widgets/SourceList.vala"
		_tmp23_ = _tmp22_->str;
#line 2469 "../lib/Widgets/SourceList.vala"
		g_object_set (_tmp21_, "markup", _tmp23_, NULL);
#line 12333 "SourceList.c"
	} else {
		GtkCellRendererText* _tmp24_;
		GString* _tmp25_;
		const gchar* _tmp26_;
#line 2471 "../lib/Widgets/SourceList.vala"
		_tmp24_ = text_renderer;
#line 2471 "../lib/Widgets/SourceList.vala"
		_tmp25_ = text;
#line 2471 "../lib/Widgets/SourceList.vala"
		_tmp26_ = _tmp25_->str;
#line 2471 "../lib/Widgets/SourceList.vala"
		g_object_set (_tmp24_, "text", _tmp26_, NULL);
#line 12346 "SourceList.c"
	}
#line 2441 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (item);
#line 2441 "../lib/Widgets/SourceList.vala"
	_g_string_free0 (text);
#line 2441 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (text_renderer);
#line 12354 "SourceList.c"
}

static void
granite_widgets_source_list_tree_badge_cell_data_func (GraniteWidgetsSourceListTree* self,
                                                       GtkCellLayout* layout,
                                                       GtkCellRenderer* renderer,
                                                       GtkTreeModel* model,
                                                       GtkTreeIter* iter)
{
	GraniteWidgetsCellRendererBadge* badge_renderer = NULL;
	GraniteWidgetsCellRendererBadge* _tmp0_;
	GraniteWidgetsCellRendererBadge* _tmp1_;
	gchar* text = NULL;
	gchar* _tmp2_;
	gboolean visible = FALSE;
	GraniteWidgetsSourceListItem* item = NULL;
	GtkTreeIter _tmp3_;
	GraniteWidgetsSourceListItem* _tmp4_;
	GraniteWidgetsSourceListItem* _tmp5_;
	GraniteWidgetsCellRendererBadge* _tmp23_;
	GraniteWidgetsCellRendererBadge* _tmp24_;
	const gchar* _tmp25_;
#line 2475 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 2475 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (layout != NULL);
#line 2475 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (renderer != NULL);
#line 2475 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (model != NULL);
#line 2475 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (iter != NULL);
#line 2481 "../lib/Widgets/SourceList.vala"
	_tmp0_ = _g_object_ref0 (GRANITE_WIDGETS_IS_CELL_RENDERER_BADGE (renderer) ? ((GraniteWidgetsCellRendererBadge*) renderer) : NULL);
#line 2481 "../lib/Widgets/SourceList.vala"
	badge_renderer = _tmp0_;
#line 2482 "../lib/Widgets/SourceList.vala"
	_tmp1_ = badge_renderer;
#line 2482 "../lib/Widgets/SourceList.vala"
	_vala_assert (_tmp1_ != NULL, "badge_renderer != null");
#line 2484 "../lib/Widgets/SourceList.vala"
	_tmp2_ = g_strdup ("");
#line 2484 "../lib/Widgets/SourceList.vala"
	text = _tmp2_;
#line 2485 "../lib/Widgets/SourceList.vala"
	visible = FALSE;
#line 2487 "../lib/Widgets/SourceList.vala"
	_tmp3_ = *iter;
#line 2487 "../lib/Widgets/SourceList.vala"
	_tmp4_ = granite_widgets_source_list_tree_get_item_from_model (model, &_tmp3_);
#line 2487 "../lib/Widgets/SourceList.vala"
	item = _tmp4_;
#line 2488 "../lib/Widgets/SourceList.vala"
	_tmp5_ = item;
#line 2488 "../lib/Widgets/SourceList.vala"
	if (_tmp5_ != NULL) {
#line 12411 "SourceList.c"
		gboolean _tmp6_ = FALSE;
		gboolean _tmp7_ = FALSE;
		GraniteWidgetsSourceListDataModel* _tmp8_;
		GraniteWidgetsSourceListItem* _tmp9_;
		GtkTreeIter _tmp10_;
#line 2490 "../lib/Widgets/SourceList.vala"
		_tmp8_ = self->priv->_data_model;
#line 2490 "../lib/Widgets/SourceList.vala"
		_tmp9_ = item;
#line 2490 "../lib/Widgets/SourceList.vala"
		_tmp10_ = *iter;
#line 2490 "../lib/Widgets/SourceList.vala"
		if (!granite_widgets_source_list_data_model_is_category (_tmp8_, _tmp9_, &_tmp10_, NULL)) {
#line 12425 "SourceList.c"
			GraniteWidgetsSourceListItem* _tmp11_;
			const gchar* _tmp12_;
			const gchar* _tmp13_;
#line 2491 "../lib/Widgets/SourceList.vala"
			_tmp11_ = item;
#line 2491 "../lib/Widgets/SourceList.vala"
			_tmp12_ = granite_widgets_source_list_item_get_badge (_tmp11_);
#line 2491 "../lib/Widgets/SourceList.vala"
			_tmp13_ = _tmp12_;
#line 2491 "../lib/Widgets/SourceList.vala"
			_tmp7_ = _tmp13_ != NULL;
#line 12437 "SourceList.c"
		} else {
#line 2490 "../lib/Widgets/SourceList.vala"
			_tmp7_ = FALSE;
#line 12441 "SourceList.c"
		}
#line 2490 "../lib/Widgets/SourceList.vala"
		if (_tmp7_) {
#line 12445 "SourceList.c"
			GraniteWidgetsSourceListItem* _tmp14_;
			const gchar* _tmp15_;
			const gchar* _tmp16_;
			gchar* _tmp17_;
			gchar* _tmp18_;
#line 2492 "../lib/Widgets/SourceList.vala"
			_tmp14_ = item;
#line 2492 "../lib/Widgets/SourceList.vala"
			_tmp15_ = granite_widgets_source_list_item_get_badge (_tmp14_);
#line 2492 "../lib/Widgets/SourceList.vala"
			_tmp16_ = _tmp15_;
#line 2492 "../lib/Widgets/SourceList.vala"
			_tmp17_ = string_strip (_tmp16_);
#line 2492 "../lib/Widgets/SourceList.vala"
			_tmp18_ = _tmp17_;
#line 2492 "../lib/Widgets/SourceList.vala"
			_tmp6_ = g_strcmp0 (_tmp18_, "") != 0;
#line 2492 "../lib/Widgets/SourceList.vala"
			_g_free0 (_tmp18_);
#line 12465 "SourceList.c"
		} else {
#line 2490 "../lib/Widgets/SourceList.vala"
			_tmp6_ = FALSE;
#line 12469 "SourceList.c"
		}
#line 2490 "../lib/Widgets/SourceList.vala"
		visible = _tmp6_;
#line 2494 "../lib/Widgets/SourceList.vala"
		if (visible) {
#line 12475 "SourceList.c"
			GraniteWidgetsSourceListItem* _tmp19_;
			const gchar* _tmp20_;
			const gchar* _tmp21_;
			gchar* _tmp22_;
#line 2495 "../lib/Widgets/SourceList.vala"
			_tmp19_ = item;
#line 2495 "../lib/Widgets/SourceList.vala"
			_tmp20_ = granite_widgets_source_list_item_get_badge (_tmp19_);
#line 2495 "../lib/Widgets/SourceList.vala"
			_tmp21_ = _tmp20_;
#line 2495 "../lib/Widgets/SourceList.vala"
			_tmp22_ = g_strdup (_tmp21_);
#line 2495 "../lib/Widgets/SourceList.vala"
			_g_free0 (text);
#line 2495 "../lib/Widgets/SourceList.vala"
			text = _tmp22_;
#line 12492 "SourceList.c"
		}
	}
#line 2498 "../lib/Widgets/SourceList.vala"
	_tmp23_ = badge_renderer;
#line 2498 "../lib/Widgets/SourceList.vala"
	gtk_cell_renderer_set_visible ((GtkCellRenderer*) _tmp23_, visible);
#line 2499 "../lib/Widgets/SourceList.vala"
	_tmp24_ = badge_renderer;
#line 2499 "../lib/Widgets/SourceList.vala"
	_tmp25_ = text;
#line 2499 "../lib/Widgets/SourceList.vala"
	granite_widgets_cell_renderer_badge_set_text (_tmp24_, _tmp25_);
#line 2475 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (item);
#line 2475 "../lib/Widgets/SourceList.vala"
	_g_free0 (text);
#line 2475 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (badge_renderer);
#line 12511 "SourceList.c"
}

static void
granite_widgets_source_list_tree_icon_cell_data_func (GraniteWidgetsSourceListTree* self,
                                                      GtkCellLayout* layout,
                                                      GtkCellRenderer* renderer,
                                                      GtkTreeModel* model,
                                                      GtkTreeIter* iter)
{
	GraniteWidgetsSourceListCellRendererIcon* icon_renderer = NULL;
	GraniteWidgetsSourceListCellRendererIcon* _tmp0_;
	GraniteWidgetsSourceListCellRendererIcon* _tmp1_;
	gboolean visible = FALSE;
	GIcon* icon = NULL;
	GraniteWidgetsSourceListItem* item = NULL;
	GtkTreeIter _tmp2_;
	GraniteWidgetsSourceListItem* _tmp3_;
	GraniteWidgetsSourceListItem* _tmp4_;
	gboolean _tmp20_ = FALSE;
	GraniteWidgetsSourceListCellRendererIcon* _tmp22_;
	GIcon* _tmp23_ = NULL;
	GraniteWidgetsSourceListCellRendererIcon* _tmp25_;
#line 2502 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 2502 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (layout != NULL);
#line 2502 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (renderer != NULL);
#line 2502 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (model != NULL);
#line 2502 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (iter != NULL);
#line 2507 "../lib/Widgets/SourceList.vala"
	_tmp0_ = _g_object_ref0 (GRANITE_WIDGETS_SOURCE_LIST_IS_CELL_RENDERER_ICON (renderer) ? ((GraniteWidgetsSourceListCellRendererIcon*) renderer) : NULL);
#line 2507 "../lib/Widgets/SourceList.vala"
	icon_renderer = _tmp0_;
#line 2508 "../lib/Widgets/SourceList.vala"
	_tmp1_ = icon_renderer;
#line 2508 "../lib/Widgets/SourceList.vala"
	_vala_assert (_tmp1_ != NULL, "icon_renderer != null");
#line 2510 "../lib/Widgets/SourceList.vala"
	visible = FALSE;
#line 2511 "../lib/Widgets/SourceList.vala"
	icon = NULL;
#line 2513 "../lib/Widgets/SourceList.vala"
	_tmp2_ = *iter;
#line 2513 "../lib/Widgets/SourceList.vala"
	_tmp3_ = granite_widgets_source_list_tree_get_item_from_model (model, &_tmp2_);
#line 2513 "../lib/Widgets/SourceList.vala"
	item = _tmp3_;
#line 2514 "../lib/Widgets/SourceList.vala"
	_tmp4_ = item;
#line 2514 "../lib/Widgets/SourceList.vala"
	if (_tmp4_ != NULL) {
#line 12566 "SourceList.c"
		GraniteWidgetsSourceListDataModel* _tmp5_;
		GraniteWidgetsSourceListItem* _tmp6_;
		GtkTreeIter _tmp7_;
#line 2516 "../lib/Widgets/SourceList.vala"
		_tmp5_ = self->priv->_data_model;
#line 2516 "../lib/Widgets/SourceList.vala"
		_tmp6_ = item;
#line 2516 "../lib/Widgets/SourceList.vala"
		_tmp7_ = *iter;
#line 2516 "../lib/Widgets/SourceList.vala"
		visible = !granite_widgets_source_list_data_model_is_category (_tmp5_, _tmp6_, &_tmp7_, NULL);
#line 2518 "../lib/Widgets/SourceList.vala"
		if (visible) {
#line 12580 "SourceList.c"
			GraniteWidgetsSourceListCellRendererIcon* _tmp8_;
			GraniteWidgetsSourceListCellRendererIcon* _tmp9_;
#line 2519 "../lib/Widgets/SourceList.vala"
			_tmp8_ = icon_renderer;
#line 2519 "../lib/Widgets/SourceList.vala"
			_tmp9_ = self->priv->icon_cell;
#line 2519 "../lib/Widgets/SourceList.vala"
			if (_tmp8_ == _tmp9_) {
#line 12589 "SourceList.c"
				GraniteWidgetsSourceListItem* _tmp10_;
				GIcon* _tmp11_;
				GIcon* _tmp12_;
				GIcon* _tmp13_;
#line 2520 "../lib/Widgets/SourceList.vala"
				_tmp10_ = item;
#line 2520 "../lib/Widgets/SourceList.vala"
				_tmp11_ = granite_widgets_source_list_item_get_icon (_tmp10_);
#line 2520 "../lib/Widgets/SourceList.vala"
				_tmp12_ = _tmp11_;
#line 2520 "../lib/Widgets/SourceList.vala"
				_tmp13_ = _g_object_ref0 (_tmp12_);
#line 2520 "../lib/Widgets/SourceList.vala"
				_g_object_unref0 (icon);
#line 2520 "../lib/Widgets/SourceList.vala"
				icon = _tmp13_;
#line 12606 "SourceList.c"
			} else {
				GraniteWidgetsSourceListCellRendererIcon* _tmp14_;
				GraniteWidgetsSourceListCellRendererIcon* _tmp15_;
#line 2521 "../lib/Widgets/SourceList.vala"
				_tmp14_ = icon_renderer;
#line 2521 "../lib/Widgets/SourceList.vala"
				_tmp15_ = self->priv->activatable_cell;
#line 2521 "../lib/Widgets/SourceList.vala"
				if (_tmp14_ == _tmp15_) {
#line 12616 "SourceList.c"
					GraniteWidgetsSourceListItem* _tmp16_;
					GIcon* _tmp17_;
					GIcon* _tmp18_;
					GIcon* _tmp19_;
#line 2522 "../lib/Widgets/SourceList.vala"
					_tmp16_ = item;
#line 2522 "../lib/Widgets/SourceList.vala"
					_tmp17_ = granite_widgets_source_list_item_get_activatable (_tmp16_);
#line 2522 "../lib/Widgets/SourceList.vala"
					_tmp18_ = _tmp17_;
#line 2522 "../lib/Widgets/SourceList.vala"
					_tmp19_ = _g_object_ref0 (_tmp18_);
#line 2522 "../lib/Widgets/SourceList.vala"
					_g_object_unref0 (icon);
#line 2522 "../lib/Widgets/SourceList.vala"
					icon = _tmp19_;
#line 12633 "SourceList.c"
				} else {
#line 2524 "../lib/Widgets/SourceList.vala"
					g_assert_not_reached ();
#line 12637 "SourceList.c"
				}
			}
		}
	}
#line 2528 "../lib/Widgets/SourceList.vala"
	if (visible) {
#line 12644 "SourceList.c"
		GIcon* _tmp21_;
#line 2528 "../lib/Widgets/SourceList.vala"
		_tmp21_ = icon;
#line 2528 "../lib/Widgets/SourceList.vala"
		_tmp20_ = _tmp21_ != NULL;
#line 12650 "SourceList.c"
	} else {
#line 2528 "../lib/Widgets/SourceList.vala"
		_tmp20_ = FALSE;
#line 12654 "SourceList.c"
	}
#line 2528 "../lib/Widgets/SourceList.vala"
	visible = _tmp20_;
#line 2530 "../lib/Widgets/SourceList.vala"
	_tmp22_ = icon_renderer;
#line 2530 "../lib/Widgets/SourceList.vala"
	gtk_cell_renderer_set_visible ((GtkCellRenderer*) _tmp22_, visible);
#line 2531 "../lib/Widgets/SourceList.vala"
	if (visible) {
#line 12664 "SourceList.c"
		GIcon* _tmp24_;
#line 2531 "../lib/Widgets/SourceList.vala"
		_tmp24_ = icon;
#line 2531 "../lib/Widgets/SourceList.vala"
		_tmp23_ = _tmp24_;
#line 12670 "SourceList.c"
	} else {
#line 2531 "../lib/Widgets/SourceList.vala"
		_tmp23_ = NULL;
#line 12674 "SourceList.c"
	}
#line 2531 "../lib/Widgets/SourceList.vala"
	_tmp25_ = icon_renderer;
#line 2531 "../lib/Widgets/SourceList.vala"
	g_object_set ((GtkCellRendererPixbuf*) _tmp25_, "gicon", _tmp23_, NULL);
#line 2502 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (item);
#line 2502 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (icon);
#line 2502 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (icon_renderer);
#line 12686 "SourceList.c"
}

/**
         * Controls expander visibility.
         */
static void
granite_widgets_source_list_tree_expander_cell_data_func (GraniteWidgetsSourceListTree* self,
                                                          GtkCellLayout* layout,
                                                          GtkCellRenderer* renderer,
                                                          GtkTreeModel* model,
                                                          GtkTreeIter* iter)
{
	GraniteWidgetsSourceListItem* item = NULL;
	GtkTreeIter _tmp0_;
	GraniteWidgetsSourceListItem* _tmp1_;
	GraniteWidgetsSourceListItem* _tmp2_;
	GraniteWidgetsCellRendererExpander* _tmp12_;
#line 2537 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (self != NULL);
#line 2537 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (layout != NULL);
#line 2537 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (renderer != NULL);
#line 2537 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (model != NULL);
#line 2537 "../lib/Widgets/SourceList.vala"
	g_return_if_fail (iter != NULL);
#line 2543 "../lib/Widgets/SourceList.vala"
	_tmp0_ = *iter;
#line 2543 "../lib/Widgets/SourceList.vala"
	_tmp1_ = granite_widgets_source_list_tree_get_item_from_model (model, &_tmp0_);
#line 2543 "../lib/Widgets/SourceList.vala"
	item = _tmp1_;
#line 2544 "../lib/Widgets/SourceList.vala"
	_tmp2_ = item;
#line 2544 "../lib/Widgets/SourceList.vala"
	if (_tmp2_ != NULL) {
#line 12724 "SourceList.c"
		GraniteWidgetsSourceListExpandableItem* expandable_item = NULL;
		GraniteWidgetsSourceListItem* _tmp3_;
		GraniteWidgetsSourceListExpandableItem* _tmp4_;
		GraniteWidgetsSourceListExpandableItem* _tmp5_;
#line 2548 "../lib/Widgets/SourceList.vala"
		_tmp3_ = item;
#line 2548 "../lib/Widgets/SourceList.vala"
		_tmp4_ = _g_object_ref0 (GRANITE_WIDGETS_SOURCE_LIST_IS_EXPANDABLE_ITEM (_tmp3_) ? ((GraniteWidgetsSourceListExpandableItem*) _tmp3_) : NULL);
#line 2548 "../lib/Widgets/SourceList.vala"
		expandable_item = _tmp4_;
#line 2549 "../lib/Widgets/SourceList.vala"
		_tmp5_ = expandable_item;
#line 2549 "../lib/Widgets/SourceList.vala"
		if (_tmp5_ != NULL) {
#line 12739 "SourceList.c"
			gboolean _tmp6_ = FALSE;
			gboolean _tmp7_;
			gboolean _tmp8_;
#line 2550 "../lib/Widgets/SourceList.vala"
			g_object_get (renderer, "is-expander", &_tmp7_, NULL);
#line 2550 "../lib/Widgets/SourceList.vala"
			_tmp8_ = _tmp7_;
#line 2550 "../lib/Widgets/SourceList.vala"
			if (_tmp8_) {
#line 12749 "SourceList.c"
				GraniteWidgetsSourceListExpandableItem* _tmp9_;
				gboolean _tmp10_;
				gboolean _tmp11_;
#line 2550 "../lib/Widgets/SourceList.vala"
				_tmp9_ = expandable_item;
#line 2550 "../lib/Widgets/SourceList.vala"
				_tmp10_ = granite_widgets_source_list_expandable_item_get_collapsible (_tmp9_);
#line 2550 "../lib/Widgets/SourceList.vala"
				_tmp11_ = _tmp10_;
#line 2550 "../lib/Widgets/SourceList.vala"
				_tmp6_ = _tmp11_;
#line 12761 "SourceList.c"
			} else {
#line 2550 "../lib/Widgets/SourceList.vala"
				_tmp6_ = FALSE;
#line 12765 "SourceList.c"
			}
#line 2550 "../lib/Widgets/SourceList.vala"
			g_object_set (renderer, "is-expander", _tmp6_, NULL);
#line 12769 "SourceList.c"
		}
#line 2544 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (expandable_item);
#line 12773 "SourceList.c"
	}
#line 2553 "../lib/Widgets/SourceList.vala"
	_tmp12_ = self->priv->primary_expander_cell;
#line 2553 "../lib/Widgets/SourceList.vala"
	if (renderer == G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, gtk_cell_renderer_get_type (), GtkCellRenderer)) {
#line 12779 "SourceList.c"
		GraniteWidgetsSourceListDataModel* _tmp13_;
		GtkTreeIter _tmp14_;
#line 2554 "../lib/Widgets/SourceList.vala"
		_tmp13_ = self->priv->_data_model;
#line 2554 "../lib/Widgets/SourceList.vala"
		_tmp14_ = *iter;
#line 2554 "../lib/Widgets/SourceList.vala"
		gtk_cell_renderer_set_visible (renderer, !granite_widgets_source_list_data_model_is_iter_at_root_level (_tmp13_, &_tmp14_));
#line 12788 "SourceList.c"
	} else {
		GraniteWidgetsCellRendererExpander* _tmp15_;
#line 2555 "../lib/Widgets/SourceList.vala"
		_tmp15_ = self->priv->secondary_expander_cell;
#line 2555 "../lib/Widgets/SourceList.vala"
		if (renderer == G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, gtk_cell_renderer_get_type (), GtkCellRenderer)) {
#line 12795 "SourceList.c"
			GraniteWidgetsSourceListDataModel* _tmp16_;
			GraniteWidgetsSourceListItem* _tmp17_;
			GtkTreeIter _tmp18_;
#line 2556 "../lib/Widgets/SourceList.vala"
			_tmp16_ = self->priv->_data_model;
#line 2556 "../lib/Widgets/SourceList.vala"
			_tmp17_ = item;
#line 2556 "../lib/Widgets/SourceList.vala"
			_tmp18_ = *iter;
#line 2556 "../lib/Widgets/SourceList.vala"
			gtk_cell_renderer_set_visible (renderer, granite_widgets_source_list_data_model_is_category (_tmp16_, _tmp17_, &_tmp18_, NULL));
#line 12807 "SourceList.c"
		} else {
#line 2558 "../lib/Widgets/SourceList.vala"
			g_assert_not_reached ();
#line 12811 "SourceList.c"
		}
	}
#line 2537 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (item);
#line 12816 "SourceList.c"
}

static void
_granite_widgets_source_list_tree_expander_cell_data_func_gtk_cell_layout_data_func (GtkCellLayout* cell_layout,
                                                                                     GtkCellRenderer* cell,
                                                                                     GtkTreeModel* tree_model,
                                                                                     GtkTreeIter* iter,
                                                                                     gpointer self)
{
#line 1668 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_tree_expander_cell_data_func ((GraniteWidgetsSourceListTree*) self, cell_layout, cell, tree_model, iter);
#line 12828 "SourceList.c"
}

static void
_granite_widgets_source_list_tree_on_activatable_activated_granite_widgets_source_list_cell_renderer_icon_activated (GraniteWidgetsSourceListCellRendererIcon* _sender,
                                                                                                                     const gchar* path,
                                                                                                                     gpointer self)
{
#line 1672 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_tree_on_activatable_activated ((GraniteWidgetsSourceListTree*) self, path);
#line 12838 "SourceList.c"
}

static void
_granite_widgets_source_list_tree_icon_cell_data_func_gtk_cell_layout_data_func (GtkCellLayout* cell_layout,
                                                                                 GtkCellRenderer* cell,
                                                                                 GtkTreeModel* tree_model,
                                                                                 GtkTreeIter* iter,
                                                                                 gpointer self)
{
#line 1674 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_tree_icon_cell_data_func ((GraniteWidgetsSourceListTree*) self, cell_layout, cell, tree_model, iter);
#line 12850 "SourceList.c"
}

static void
_granite_widgets_source_list_tree_badge_cell_data_func_gtk_cell_layout_data_func (GtkCellLayout* cell_layout,
                                                                                  GtkCellRenderer* cell,
                                                                                  GtkTreeModel* tree_model,
                                                                                  GtkTreeIter* iter,
                                                                                  gpointer self)
{
#line 1680 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_tree_badge_cell_data_func ((GraniteWidgetsSourceListTree*) self, cell_layout, cell, tree_model, iter);
#line 12862 "SourceList.c"
}

static void
_granite_widgets_source_list_tree_on_editing_started_gtk_cell_renderer_editing_started (GtkCellRenderer* _sender,
                                                                                        GtkCellEditable* editable,
                                                                                        const gchar* path,
                                                                                        gpointer self)
{
#line 1685 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_tree_on_editing_started ((GraniteWidgetsSourceListTree*) self, editable, path);
#line 12873 "SourceList.c"
}

static void
_granite_widgets_source_list_tree_on_editing_canceled_gtk_cell_renderer_editing_canceled (GtkCellRenderer* _sender,
                                                                                          gpointer self)
{
#line 1686 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_tree_on_editing_canceled ((GraniteWidgetsSourceListTree*) self);
#line 12882 "SourceList.c"
}

static void
_granite_widgets_source_list_tree_name_cell_data_func_gtk_cell_layout_data_func (GtkCellLayout* cell_layout,
                                                                                 GtkCellRenderer* cell,
                                                                                 GtkTreeModel* tree_model,
                                                                                 GtkTreeIter* iter,
                                                                                 gpointer self)
{
#line 1690 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_tree_name_cell_data_func ((GraniteWidgetsSourceListTree*) self, cell_layout, cell, tree_model, iter);
#line 12894 "SourceList.c"
}

static gboolean
_granite_widgets_source_list_tree_select_func_gtk_tree_selection_func (GtkTreeSelection* selection,
                                                                       GtkTreeModel* model,
                                                                       GtkTreePath* path,
                                                                       gboolean path_currently_selected,
                                                                       gpointer self)
{
	gboolean result;
	result = granite_widgets_source_list_tree_select_func ((GraniteWidgetsSourceListTree*) self, selection, model, path, path_currently_selected);
#line 1710 "../lib/Widgets/SourceList.vala"
	return result;
#line 12908 "SourceList.c"
}

static gboolean
_granite_widgets_source_list_tree_on_query_tooltip_gtk_widget_query_tooltip (GtkWidget* _sender,
                                                                             gint x,
                                                                             gint y,
                                                                             gboolean keyboard_tooltip,
                                                                             GtkTooltip* tooltip,
                                                                             gpointer self)
{
	gboolean result;
	result = granite_widgets_source_list_tree_on_query_tooltip ((GraniteWidgetsSourceListTree*) self, x, y, keyboard_tooltip, tooltip);
#line 1722 "../lib/Widgets/SourceList.vala"
	return result;
#line 12923 "SourceList.c"
}

static GObject *
granite_widgets_source_list_tree_constructor (GType type,
                                              guint n_construct_properties,
                                              GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GraniteWidgetsSourceListTree * self;
	GtkStyleContext* style_context = NULL;
	GtkStyleContext* _tmp0_;
	GtkStyleContext* _tmp1_;
	GtkStyleContext* _tmp2_;
	GtkCssProvider* css_provider = NULL;
	GtkCssProvider* _tmp3_;
	GraniteWidgetsSourceListDataModel* _tmp9_;
	GtkTreeViewColumn* item_column = NULL;
	GtkTreeViewColumn* _tmp10_;
	GtkTreeViewColumn* _tmp11_;
	GtkTreeViewColumn* _tmp12_;
	GraniteWidgetsCellRendererExpander* _tmp13_;
	GraniteWidgetsCellRendererExpander* _tmp14_;
	GraniteWidgetsCellRendererExpander* _tmp15_;
	GtkTreeViewColumn* _tmp16_;
	GraniteWidgetsCellRendererExpander* _tmp17_;
	GtkTreeViewColumn* _tmp18_;
	GraniteWidgetsCellRendererExpander* _tmp19_;
	GraniteWidgetsSourceListCellRendererIcon* _tmp20_;
	GraniteWidgetsSourceListCellRendererIcon* _tmp21_;
	GraniteWidgetsSourceListCellRendererIcon* _tmp22_;
	GtkTreeViewColumn* _tmp23_;
	GraniteWidgetsSourceListCellRendererIcon* _tmp24_;
	GtkTreeViewColumn* _tmp25_;
	GraniteWidgetsSourceListCellRendererIcon* _tmp26_;
	GraniteWidgetsCellRendererBadge* _tmp27_;
	GraniteWidgetsCellRendererBadge* _tmp28_;
	GraniteWidgetsCellRendererBadge* _tmp29_;
	GtkTreeViewColumn* _tmp30_;
	GraniteWidgetsCellRendererBadge* _tmp31_;
	GtkTreeViewColumn* _tmp32_;
	GraniteWidgetsCellRendererBadge* _tmp33_;
	GtkCellRendererText* _tmp34_;
	GtkCellRendererText* _tmp35_;
	GtkCellRendererText* _tmp36_;
	GtkCellRendererText* _tmp37_;
	GtkCellRendererText* _tmp38_;
	GtkCellRendererText* _tmp39_;
	GtkCellRendererText* _tmp40_;
	GtkTreeViewColumn* _tmp41_;
	GtkCellRendererText* _tmp42_;
	GtkTreeViewColumn* _tmp43_;
	GtkCellRendererText* _tmp44_;
	GraniteWidgetsSourceListCellRendererIcon* _tmp45_;
	GraniteWidgetsSourceListCellRendererIcon* _tmp46_;
	GtkTreeViewColumn* _tmp47_;
	GraniteWidgetsSourceListCellRendererIcon* _tmp48_;
	GtkTreeViewColumn* _tmp49_;
	GraniteWidgetsSourceListCellRendererIcon* _tmp50_;
	GraniteWidgetsCellRendererExpander* _tmp51_;
	gint expander_spacing = 0;
	gint _tmp52_ = 0;
	GraniteWidgetsCellRendererExpander* _tmp53_;
	GtkTreeViewColumn* _tmp54_;
	GraniteWidgetsCellRendererExpander* _tmp55_;
	GtkTreeViewColumn* _tmp56_;
	GraniteWidgetsCellRendererExpander* _tmp57_;
	GtkTreeSelection* selection = NULL;
	GtkTreeSelection* _tmp58_;
	GtkTreeSelection* _tmp59_;
	GtkTreeSelection* _tmp60_;
	GtkTreeSelection* _tmp61_;
	GError* _inner_error0_ = NULL;
#line 1627 "../lib/Widgets/SourceList.vala"
	parent_class = G_OBJECT_CLASS (granite_widgets_source_list_tree_parent_class);
#line 1627 "../lib/Widgets/SourceList.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 1627 "../lib/Widgets/SourceList.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GRANITE_WIDGETS_SOURCE_LIST_TYPE_TREE, GraniteWidgetsSourceListTree);
#line 1628 "../lib/Widgets/SourceList.vala"
	_tmp0_ = gtk_widget_get_style_context ((GtkWidget*) self);
#line 1628 "../lib/Widgets/SourceList.vala"
	style_context = _tmp0_;
#line 1629 "../lib/Widgets/SourceList.vala"
	_tmp1_ = style_context;
#line 1629 "../lib/Widgets/SourceList.vala"
	gtk_style_context_add_class (_tmp1_, GTK_STYLE_CLASS_SIDEBAR);
#line 1630 "../lib/Widgets/SourceList.vala"
	_tmp2_ = style_context;
#line 1630 "../lib/Widgets/SourceList.vala"
	gtk_style_context_add_class (_tmp2_, GRANITE_STYLE_CLASS_SOURCE_LIST);
#line 1632 "../lib/Widgets/SourceList.vala"
	_tmp3_ = gtk_css_provider_new ();
#line 1632 "../lib/Widgets/SourceList.vala"
	css_provider = _tmp3_;
#line 13019 "SourceList.c"
	{
		GtkCssProvider* _tmp4_;
		GtkStyleContext* _tmp5_;
		GtkCssProvider* _tmp6_;
#line 1634 "../lib/Widgets/SourceList.vala"
		_tmp4_ = css_provider;
#line 1634 "../lib/Widgets/SourceList.vala"
		gtk_css_provider_load_from_data (_tmp4_, GRANITE_WIDGETS_SOURCE_LIST_TREE_DEFAULT_STYLESHEET, (gssize) -1, &_inner_error0_);
#line 1634 "../lib/Widgets/SourceList.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 13030 "SourceList.c"
			goto __catch0_g_error;
		}
#line 1635 "../lib/Widgets/SourceList.vala"
		_tmp5_ = style_context;
#line 1635 "../lib/Widgets/SourceList.vala"
		_tmp6_ = css_provider;
#line 1635 "../lib/Widgets/SourceList.vala"
		gtk_style_context_add_provider (_tmp5_, (GtkStyleProvider*) _tmp6_, (guint) GTK_STYLE_PROVIDER_PRIORITY_FALLBACK);
#line 13039 "SourceList.c"
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		GError* _tmp7_;
		const gchar* _tmp8_;
#line 1633 "../lib/Widgets/SourceList.vala"
		e = _inner_error0_;
#line 1633 "../lib/Widgets/SourceList.vala"
		_inner_error0_ = NULL;
#line 1637 "../lib/Widgets/SourceList.vala"
		_tmp7_ = e;
#line 1637 "../lib/Widgets/SourceList.vala"
		_tmp8_ = _tmp7_->message;
#line 1637 "../lib/Widgets/SourceList.vala"
		g_warning ("SourceList.vala:1637: Could not create CSS Provider: %s\n" \
"Stylesheet:\n" \
"%s", _tmp8_, GRANITE_WIDGETS_SOURCE_LIST_TREE_DEFAULT_STYLESHEET);
#line 1633 "../lib/Widgets/SourceList.vala"
		_g_error_free0 (e);
#line 13059 "SourceList.c"
	}
	__finally0:
#line 1633 "../lib/Widgets/SourceList.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1633 "../lib/Widgets/SourceList.vala"
		_g_object_unref0 (css_provider);
#line 1633 "../lib/Widgets/SourceList.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 1633 "../lib/Widgets/SourceList.vala"
		g_clear_error (&_inner_error0_);
#line 13070 "SourceList.c"
	}
#line 1640 "../lib/Widgets/SourceList.vala"
	_tmp9_ = self->priv->_data_model;
#line 1640 "../lib/Widgets/SourceList.vala"
	gtk_tree_view_set_model ((GtkTreeView*) self, (GtkTreeModel*) _tmp9_);
#line 1642 "../lib/Widgets/SourceList.vala"
	gtk_widget_set_valign ((GtkWidget*) self, GTK_ALIGN_FILL);
#line 1642 "../lib/Widgets/SourceList.vala"
	gtk_widget_set_halign ((GtkWidget*) self, GTK_ALIGN_FILL);
#line 1643 "../lib/Widgets/SourceList.vala"
	g_object_set ((GtkWidget*) self, "expand", TRUE, NULL);
#line 1645 "../lib/Widgets/SourceList.vala"
	gtk_tree_view_set_enable_search ((GtkTreeView*) self, FALSE);
#line 1646 "../lib/Widgets/SourceList.vala"
	gtk_tree_view_set_headers_visible ((GtkTreeView*) self, FALSE);
#line 1647 "../lib/Widgets/SourceList.vala"
	g_object_set ((GtkTreeView*) self, "enable-grid-lines", GTK_TREE_VIEW_GRID_LINES_NONE, NULL);
#line 1650 "../lib/Widgets/SourceList.vala"
	gtk_tree_view_set_expander_column ((GtkTreeView*) self, NULL);
#line 1651 "../lib/Widgets/SourceList.vala"
	gtk_tree_view_set_show_expanders ((GtkTreeView*) self, FALSE);
#line 1653 "../lib/Widgets/SourceList.vala"
	_tmp10_ = gtk_tree_view_column_new ();
#line 1653 "../lib/Widgets/SourceList.vala"
	g_object_ref_sink (_tmp10_);
#line 1653 "../lib/Widgets/SourceList.vala"
	item_column = _tmp10_;
#line 1654 "../lib/Widgets/SourceList.vala"
	_tmp11_ = item_column;
#line 1654 "../lib/Widgets/SourceList.vala"
	gtk_tree_view_column_set_expand (_tmp11_, TRUE);
#line 1656 "../lib/Widgets/SourceList.vala"
	_tmp12_ = item_column;
#line 1656 "../lib/Widgets/SourceList.vala"
	gtk_tree_view_insert_column ((GtkTreeView*) self, _tmp12_, (gint) GRANITE_WIDGETS_SOURCE_LIST_TREE_COLUMN_ITEM);
#line 1664 "../lib/Widgets/SourceList.vala"
	_tmp13_ = granite_widgets_cell_renderer_expander_new ();
#line 1664 "../lib/Widgets/SourceList.vala"
	g_object_ref_sink (_tmp13_);
#line 1664 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (self->priv->secondary_expander_cell);
#line 1664 "../lib/Widgets/SourceList.vala"
	self->priv->secondary_expander_cell = _tmp13_;
#line 1665 "../lib/Widgets/SourceList.vala"
	_tmp14_ = self->priv->secondary_expander_cell;
#line 1665 "../lib/Widgets/SourceList.vala"
	granite_widgets_cell_renderer_expander_set_is_category_expander (_tmp14_, TRUE);
#line 1666 "../lib/Widgets/SourceList.vala"
	_tmp15_ = self->priv->secondary_expander_cell;
#line 1666 "../lib/Widgets/SourceList.vala"
	g_object_set ((GtkCellRenderer*) _tmp15_, "xpad", (guint) 10, NULL);
#line 1667 "../lib/Widgets/SourceList.vala"
	_tmp16_ = item_column;
#line 1667 "../lib/Widgets/SourceList.vala"
	_tmp17_ = self->priv->secondary_expander_cell;
#line 1667 "../lib/Widgets/SourceList.vala"
	gtk_cell_layout_pack_end ((GtkCellLayout*) _tmp16_, (GtkCellRenderer*) _tmp17_, FALSE);
#line 1668 "../lib/Widgets/SourceList.vala"
	_tmp18_ = item_column;
#line 1668 "../lib/Widgets/SourceList.vala"
	_tmp19_ = self->priv->secondary_expander_cell;
#line 1668 "../lib/Widgets/SourceList.vala"
	gtk_cell_layout_set_cell_data_func ((GtkCellLayout*) _tmp18_, (GtkCellRenderer*) _tmp19_, _granite_widgets_source_list_tree_expander_cell_data_func_gtk_cell_layout_data_func, g_object_ref (self), g_object_unref);
#line 1670 "../lib/Widgets/SourceList.vala"
	_tmp20_ = granite_widgets_source_list_cell_renderer_icon_new ();
#line 1670 "../lib/Widgets/SourceList.vala"
	g_object_ref_sink (_tmp20_);
#line 1670 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (self->priv->activatable_cell);
#line 1670 "../lib/Widgets/SourceList.vala"
	self->priv->activatable_cell = _tmp20_;
#line 1671 "../lib/Widgets/SourceList.vala"
	_tmp21_ = self->priv->activatable_cell;
#line 1671 "../lib/Widgets/SourceList.vala"
	g_object_set ((GtkCellRenderer*) _tmp21_, "xpad", (guint) 6, NULL);
#line 1672 "../lib/Widgets/SourceList.vala"
	_tmp22_ = self->priv->activatable_cell;
#line 1672 "../lib/Widgets/SourceList.vala"
	g_signal_connect_object (_tmp22_, "activated", (GCallback) _granite_widgets_source_list_tree_on_activatable_activated_granite_widgets_source_list_cell_renderer_icon_activated, self, 0);
#line 1673 "../lib/Widgets/SourceList.vala"
	_tmp23_ = item_column;
#line 1673 "../lib/Widgets/SourceList.vala"
	_tmp24_ = self->priv->activatable_cell;
#line 1673 "../lib/Widgets/SourceList.vala"
	gtk_cell_layout_pack_end ((GtkCellLayout*) _tmp23_, (GtkCellRenderer*) _tmp24_, FALSE);
#line 1674 "../lib/Widgets/SourceList.vala"
	_tmp25_ = item_column;
#line 1674 "../lib/Widgets/SourceList.vala"
	_tmp26_ = self->priv->activatable_cell;
#line 1674 "../lib/Widgets/SourceList.vala"
	gtk_cell_layout_set_cell_data_func ((GtkCellLayout*) _tmp25_, (GtkCellRenderer*) _tmp26_, _granite_widgets_source_list_tree_icon_cell_data_func_gtk_cell_layout_data_func, g_object_ref (self), g_object_unref);
#line 1676 "../lib/Widgets/SourceList.vala"
	_tmp27_ = granite_widgets_cell_renderer_badge_new ();
#line 1676 "../lib/Widgets/SourceList.vala"
	g_object_ref_sink (_tmp27_);
#line 1676 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (self->priv->badge_cell);
#line 1676 "../lib/Widgets/SourceList.vala"
	self->priv->badge_cell = _tmp27_;
#line 1677 "../lib/Widgets/SourceList.vala"
	_tmp28_ = self->priv->badge_cell;
#line 1677 "../lib/Widgets/SourceList.vala"
	g_object_set ((GtkCellRenderer*) _tmp28_, "xpad", (guint) 1, NULL);
#line 1678 "../lib/Widgets/SourceList.vala"
	_tmp29_ = self->priv->badge_cell;
#line 1678 "../lib/Widgets/SourceList.vala"
	g_object_set ((GtkCellRenderer*) _tmp29_, "xalign", (gfloat) 1, NULL);
#line 1679 "../lib/Widgets/SourceList.vala"
	_tmp30_ = item_column;
#line 1679 "../lib/Widgets/SourceList.vala"
	_tmp31_ = self->priv->badge_cell;
#line 1679 "../lib/Widgets/SourceList.vala"
	gtk_cell_layout_pack_end ((GtkCellLayout*) _tmp30_, (GtkCellRenderer*) _tmp31_, FALSE);
#line 1680 "../lib/Widgets/SourceList.vala"
	_tmp32_ = item_column;
#line 1680 "../lib/Widgets/SourceList.vala"
	_tmp33_ = self->priv->badge_cell;
#line 1680 "../lib/Widgets/SourceList.vala"
	gtk_cell_layout_set_cell_data_func ((GtkCellLayout*) _tmp32_, (GtkCellRenderer*) _tmp33_, _granite_widgets_source_list_tree_badge_cell_data_func_gtk_cell_layout_data_func, g_object_ref (self), g_object_unref);
#line 1682 "../lib/Widgets/SourceList.vala"
	_tmp34_ = (GtkCellRendererText*) gtk_cell_renderer_text_new ();
#line 1682 "../lib/Widgets/SourceList.vala"
	g_object_ref_sink (_tmp34_);
#line 1682 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (self->priv->text_cell);
#line 1682 "../lib/Widgets/SourceList.vala"
	self->priv->text_cell = _tmp34_;
#line 1683 "../lib/Widgets/SourceList.vala"
	_tmp35_ = self->priv->text_cell;
#line 1683 "../lib/Widgets/SourceList.vala"
	g_object_set (_tmp35_, "editable-set", TRUE, NULL);
#line 1684 "../lib/Widgets/SourceList.vala"
	_tmp36_ = self->priv->text_cell;
#line 1684 "../lib/Widgets/SourceList.vala"
	g_object_set (_tmp36_, "editable", FALSE, NULL);
#line 1685 "../lib/Widgets/SourceList.vala"
	_tmp37_ = self->priv->text_cell;
#line 1685 "../lib/Widgets/SourceList.vala"
	g_signal_connect_object ((GtkCellRenderer*) _tmp37_, "editing-started", (GCallback) _granite_widgets_source_list_tree_on_editing_started_gtk_cell_renderer_editing_started, self, 0);
#line 1686 "../lib/Widgets/SourceList.vala"
	_tmp38_ = self->priv->text_cell;
#line 1686 "../lib/Widgets/SourceList.vala"
	g_signal_connect_object ((GtkCellRenderer*) _tmp38_, "editing-canceled", (GCallback) _granite_widgets_source_list_tree_on_editing_canceled_gtk_cell_renderer_editing_canceled, self, 0);
#line 1687 "../lib/Widgets/SourceList.vala"
	_tmp39_ = self->priv->text_cell;
#line 1687 "../lib/Widgets/SourceList.vala"
	g_object_set (_tmp39_, "ellipsize", PANGO_ELLIPSIZE_END, NULL);
#line 1688 "../lib/Widgets/SourceList.vala"
	_tmp40_ = self->priv->text_cell;
#line 1688 "../lib/Widgets/SourceList.vala"
	g_object_set ((GtkCellRenderer*) _tmp40_, "xalign", (gfloat) 0, NULL);
#line 1689 "../lib/Widgets/SourceList.vala"
	_tmp41_ = item_column;
#line 1689 "../lib/Widgets/SourceList.vala"
	_tmp42_ = self->priv->text_cell;
#line 1689 "../lib/Widgets/SourceList.vala"
	gtk_cell_layout_pack_end ((GtkCellLayout*) _tmp41_, (GtkCellRenderer*) _tmp42_, TRUE);
#line 1690 "../lib/Widgets/SourceList.vala"
	_tmp43_ = item_column;
#line 1690 "../lib/Widgets/SourceList.vala"
	_tmp44_ = self->priv->text_cell;
#line 1690 "../lib/Widgets/SourceList.vala"
	gtk_cell_layout_set_cell_data_func ((GtkCellLayout*) _tmp43_, (GtkCellRenderer*) _tmp44_, _granite_widgets_source_list_tree_name_cell_data_func_gtk_cell_layout_data_func, g_object_ref (self), g_object_unref);
#line 1692 "../lib/Widgets/SourceList.vala"
	_tmp45_ = granite_widgets_source_list_cell_renderer_icon_new ();
#line 1692 "../lib/Widgets/SourceList.vala"
	g_object_ref_sink (_tmp45_);
#line 1692 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (self->priv->icon_cell);
#line 1692 "../lib/Widgets/SourceList.vala"
	self->priv->icon_cell = _tmp45_;
#line 1693 "../lib/Widgets/SourceList.vala"
	_tmp46_ = self->priv->icon_cell;
#line 1693 "../lib/Widgets/SourceList.vala"
	g_object_set ((GtkCellRenderer*) _tmp46_, "xpad", (guint) 2, NULL);
#line 1694 "../lib/Widgets/SourceList.vala"
	_tmp47_ = item_column;
#line 1694 "../lib/Widgets/SourceList.vala"
	_tmp48_ = self->priv->icon_cell;
#line 1694 "../lib/Widgets/SourceList.vala"
	gtk_cell_layout_pack_end ((GtkCellLayout*) _tmp47_, (GtkCellRenderer*) _tmp48_, FALSE);
#line 1695 "../lib/Widgets/SourceList.vala"
	_tmp49_ = item_column;
#line 1695 "../lib/Widgets/SourceList.vala"
	_tmp50_ = self->priv->icon_cell;
#line 1695 "../lib/Widgets/SourceList.vala"
	gtk_cell_layout_set_cell_data_func ((GtkCellLayout*) _tmp49_, (GtkCellRenderer*) _tmp50_, _granite_widgets_source_list_tree_icon_cell_data_func_gtk_cell_layout_data_func, g_object_ref (self), g_object_unref);
#line 1698 "../lib/Widgets/SourceList.vala"
	_tmp51_ = granite_widgets_cell_renderer_expander_new ();
#line 1698 "../lib/Widgets/SourceList.vala"
	g_object_ref_sink (_tmp51_);
#line 1698 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (self->priv->primary_expander_cell);
#line 1698 "../lib/Widgets/SourceList.vala"
	self->priv->primary_expander_cell = _tmp51_;
#line 1701 "../lib/Widgets/SourceList.vala"
	gtk_widget_style_get ((GtkWidget*) self, GRANITE_WIDGETS_SOURCE_LIST_TREE_STYLE_PROP_EXPANDER_SPACING, &_tmp52_, NULL);
#line 1701 "../lib/Widgets/SourceList.vala"
	expander_spacing = _tmp52_;
#line 1702 "../lib/Widgets/SourceList.vala"
	_tmp53_ = self->priv->primary_expander_cell;
#line 1702 "../lib/Widgets/SourceList.vala"
	g_object_set ((GtkCellRenderer*) _tmp53_, "xpad", (guint) (expander_spacing / 2), NULL);
#line 1704 "../lib/Widgets/SourceList.vala"
	_tmp54_ = item_column;
#line 1704 "../lib/Widgets/SourceList.vala"
	_tmp55_ = self->priv->primary_expander_cell;
#line 1704 "../lib/Widgets/SourceList.vala"
	gtk_cell_layout_pack_end ((GtkCellLayout*) _tmp54_, (GtkCellRenderer*) _tmp55_, FALSE);
#line 1705 "../lib/Widgets/SourceList.vala"
	_tmp56_ = item_column;
#line 1705 "../lib/Widgets/SourceList.vala"
	_tmp57_ = self->priv->primary_expander_cell;
#line 1705 "../lib/Widgets/SourceList.vala"
	gtk_cell_layout_set_cell_data_func ((GtkCellLayout*) _tmp56_, (GtkCellRenderer*) _tmp57_, _granite_widgets_source_list_tree_expander_cell_data_func_gtk_cell_layout_data_func, g_object_ref (self), g_object_unref);
#line 1708 "../lib/Widgets/SourceList.vala"
	_tmp58_ = gtk_tree_view_get_selection ((GtkTreeView*) self);
#line 1708 "../lib/Widgets/SourceList.vala"
	_tmp59_ = _g_object_ref0 (_tmp58_);
#line 1708 "../lib/Widgets/SourceList.vala"
	selection = _tmp59_;
#line 1709 "../lib/Widgets/SourceList.vala"
	_tmp60_ = selection;
#line 1709 "../lib/Widgets/SourceList.vala"
	gtk_tree_selection_set_mode (_tmp60_, GTK_SELECTION_BROWSE);
#line 1710 "../lib/Widgets/SourceList.vala"
	_tmp61_ = selection;
#line 1710 "../lib/Widgets/SourceList.vala"
	gtk_tree_selection_set_select_function (_tmp61_, _granite_widgets_source_list_tree_select_func_gtk_tree_selection_func, g_object_ref (self), g_object_unref);
#line 1713 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_tree_enable_item_property_monitor (self);
#line 1716 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_tree_add_spacer_cell_for_level (self, 1, TRUE);
#line 1719 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_tree_configure_drag_source (self, NULL, (gint) 0);
#line 1720 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_tree_configure_drag_dest (self, NULL, (gint) 0, 0);
#line 1722 "../lib/Widgets/SourceList.vala"
	g_signal_connect_object ((GtkWidget*) self, "query-tooltip", (GCallback) _granite_widgets_source_list_tree_on_query_tooltip_gtk_widget_query_tooltip, self, G_CONNECT_AFTER);
#line 1723 "../lib/Widgets/SourceList.vala"
	gtk_widget_set_has_tooltip ((GtkWidget*) self, TRUE);
#line 1627 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (selection);
#line 1627 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (item_column);
#line 1627 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (css_provider);
#line 1627 "../lib/Widgets/SourceList.vala"
	return obj;
#line 13320 "SourceList.c"
}

static void
granite_widgets_source_list_tree_class_init (GraniteWidgetsSourceListTreeClass * klass,
                                             gpointer klass_data)
{
	GParamSpecInt* _tmp0_;
	GParamSpecInt* _tmp1_;
	GParamSpecInt* _tmp2_;
	GParamSpecInt* _tmp3_;
	GParamSpecInt* _tmp4_;
	GParamSpecInt* _tmp5_;
#line 1540 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_tree_parent_class = g_type_class_peek_parent (klass);
#line 1540 "../lib/Widgets/SourceList.vala"
	g_type_class_adjust_private_offset (klass, &GraniteWidgetsSourceListTree_private_offset);
#line 1540 "../lib/Widgets/SourceList.vala"
	((GtkWidgetClass *) klass)->drag_motion = (gboolean (*) (GtkWidget*, GdkDragContext*, gint, gint, guint)) granite_widgets_source_list_tree_real_drag_motion;
#line 1540 "../lib/Widgets/SourceList.vala"
	((GtkWidgetClass *) klass)->drag_data_received = (void (*) (GtkWidget*, GdkDragContext*, gint, gint, GtkSelectionData*, guint, guint)) granite_widgets_source_list_tree_real_drag_data_received;
#line 1540 "../lib/Widgets/SourceList.vala"
	((GtkTreeViewClass *) klass)->cursor_changed = (void (*) (GtkTreeView*)) granite_widgets_source_list_tree_real_cursor_changed;
#line 1540 "../lib/Widgets/SourceList.vala"
	((GtkTreeViewClass *) klass)->row_expanded = (void (*) (GtkTreeView*, GtkTreeIter*, GtkTreePath*)) granite_widgets_source_list_tree_real_row_expanded;
#line 1540 "../lib/Widgets/SourceList.vala"
	((GtkTreeViewClass *) klass)->row_collapsed = (void (*) (GtkTreeView*, GtkTreeIter*, GtkTreePath*)) granite_widgets_source_list_tree_real_row_collapsed;
#line 1540 "../lib/Widgets/SourceList.vala"
	((GtkTreeViewClass *) klass)->row_activated = (void (*) (GtkTreeView*, GtkTreePath*, GtkTreeViewColumn*)) granite_widgets_source_list_tree_real_row_activated;
#line 1540 "../lib/Widgets/SourceList.vala"
	((GtkWidgetClass *) klass)->key_release_event = (gboolean (*) (GtkWidget*, GdkEventKey*)) granite_widgets_source_list_tree_real_key_release_event;
#line 1540 "../lib/Widgets/SourceList.vala"
	((GtkWidgetClass *) klass)->button_release_event = (gboolean (*) (GtkWidget*, GdkEventButton*)) granite_widgets_source_list_tree_real_button_release_event;
#line 1540 "../lib/Widgets/SourceList.vala"
	((GtkWidgetClass *) klass)->button_press_event = (gboolean (*) (GtkWidget*, GdkEventButton*)) granite_widgets_source_list_tree_real_button_press_event;
#line 1540 "../lib/Widgets/SourceList.vala"
	((GtkWidgetClass *) klass)->popup_menu = (gboolean (*) (GtkWidget*)) granite_widgets_source_list_tree_real_popup_menu;
#line 1540 "../lib/Widgets/SourceList.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_granite_widgets_source_list_tree_get_property;
#line 1540 "../lib/Widgets/SourceList.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_granite_widgets_source_list_tree_set_property;
#line 1540 "../lib/Widgets/SourceList.vala"
	G_OBJECT_CLASS (klass)->constructor = granite_widgets_source_list_tree_constructor;
#line 1540 "../lib/Widgets/SourceList.vala"
	G_OBJECT_CLASS (klass)->finalize = granite_widgets_source_list_tree_finalize;
#line 1540 "../lib/Widgets/SourceList.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GRANITE_WIDGETS_SOURCE_LIST_TREE_DATA_MODEL_PROPERTY, granite_widgets_source_list_tree_properties[GRANITE_WIDGETS_SOURCE_LIST_TREE_DATA_MODEL_PROPERTY] = g_param_spec_object ("data-model", "data-model", "data-model", GRANITE_WIDGETS_SOURCE_LIST_TYPE_DATA_MODEL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
#line 1540 "../lib/Widgets/SourceList.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GRANITE_WIDGETS_SOURCE_LIST_TREE_SELECTED_ITEM_PROPERTY, granite_widgets_source_list_tree_properties[GRANITE_WIDGETS_SOURCE_LIST_TREE_SELECTED_ITEM_PROPERTY] = g_param_spec_object ("selected-item", "selected-item", "selected-item", GRANITE_WIDGETS_SOURCE_LIST_TYPE_ITEM, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 1540 "../lib/Widgets/SourceList.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GRANITE_WIDGETS_SOURCE_LIST_TREE_EDITING_PROPERTY, granite_widgets_source_list_tree_properties[GRANITE_WIDGETS_SOURCE_LIST_TREE_EDITING_PROPERTY] = g_param_spec_boolean ("editing", "editing", "editing", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
#line 1540 "../lib/Widgets/SourceList.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GRANITE_WIDGETS_SOURCE_LIST_TREE_ELLIPSIZE_MODE_PROPERTY, granite_widgets_source_list_tree_properties[GRANITE_WIDGETS_SOURCE_LIST_TREE_ELLIPSIZE_MODE_PROPERTY] = g_param_spec_enum ("ellipsize-mode", "ellipsize-mode", "ellipsize-mode", pango_ellipsize_mode_get_type (), 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 1540 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_tree_signals[GRANITE_WIDGETS_SOURCE_LIST_TREE_ITEM_SELECTED_SIGNAL] = g_signal_new ("item-selected", GRANITE_WIDGETS_SOURCE_LIST_TYPE_TREE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, GRANITE_WIDGETS_SOURCE_LIST_TYPE_ITEM);
#line 1592 "../lib/Widgets/SourceList.vala"
	_tmp0_ = (GParamSpecInt*) g_param_spec_int (GRANITE_WIDGETS_SOURCE_LIST_TREE_STYLE_PROP_LEVEL_INDENTATION, "Level Indentation", "Space to add at the beginning of every indentation level. Must be an e" \
"ven number.", 1, 50, 6, G_PARAM_READABLE);
#line 1592 "../lib/Widgets/SourceList.vala"
	_tmp1_ = _tmp0_;
#line 1592 "../lib/Widgets/SourceList.vala"
	gtk_widget_class_install_style_property (GTK_WIDGET_CLASS (klass), (GParamSpec*) _tmp1_);
#line 1592 "../lib/Widgets/SourceList.vala"
	_g_param_spec_unref0 (_tmp1_);
#line 1602 "../lib/Widgets/SourceList.vala"
	_tmp2_ = (GParamSpecInt*) g_param_spec_int (GRANITE_WIDGETS_SOURCE_LIST_TREE_STYLE_PROP_LEFT_PADDING, "Left Padding", "Padding added to the left side of the tree. Must be an even number.", 1, 50, 4, G_PARAM_READABLE);
#line 1602 "../lib/Widgets/SourceList.vala"
	_tmp3_ = _tmp2_;
#line 1602 "../lib/Widgets/SourceList.vala"
	gtk_widget_class_install_style_property (GTK_WIDGET_CLASS (klass), (GParamSpec*) _tmp3_);
#line 1602 "../lib/Widgets/SourceList.vala"
	_g_param_spec_unref0 (_tmp3_);
#line 1612 "../lib/Widgets/SourceList.vala"
	_tmp4_ = (GParamSpecInt*) g_param_spec_int (GRANITE_WIDGETS_SOURCE_LIST_TREE_STYLE_PROP_EXPANDER_SPACING, "Expander Spacing", "Space added between an item and its expander. Must be an even number.", 1, 50, 4, G_PARAM_READABLE);
#line 1612 "../lib/Widgets/SourceList.vala"
	_tmp5_ = _tmp4_;
#line 1612 "../lib/Widgets/SourceList.vala"
	gtk_widget_class_install_style_property (GTK_WIDGET_CLASS (klass), (GParamSpec*) _tmp5_);
#line 1612 "../lib/Widgets/SourceList.vala"
	_g_param_spec_unref0 (_tmp5_);
#line 13399 "SourceList.c"
}

static void
granite_widgets_source_list_tree_instance_init (GraniteWidgetsSourceListTree * self,
                                                gpointer klass)
{
#line 1540 "../lib/Widgets/SourceList.vala"
	self->priv = granite_widgets_source_list_tree_get_instance_private (self);
#line 1576 "../lib/Widgets/SourceList.vala"
	self->priv->unselectable_item_clicked = FALSE;
#line 13410 "SourceList.c"
}

static void
granite_widgets_source_list_tree_finalize (GObject * obj)
{
	GraniteWidgetsSourceListTree * self;
#line 1540 "../lib/Widgets/SourceList.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GRANITE_WIDGETS_SOURCE_LIST_TYPE_TREE, GraniteWidgetsSourceListTree);
#line 1727 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_tree_disable_item_property_monitor (self);
#line 1542 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (self->priv->_data_model);
#line 1565 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (self->priv->selected);
#line 1568 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (self->priv->editable_entry);
#line 1569 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (self->priv->text_cell);
#line 1570 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (self->priv->icon_cell);
#line 1571 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (self->priv->activatable_cell);
#line 1572 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (self->priv->badge_cell);
#line 1573 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (self->priv->primary_expander_cell);
#line 1574 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (self->priv->secondary_expander_cell);
#line 1575 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (self->priv->spacer_cells);
#line 1540 "../lib/Widgets/SourceList.vala"
	G_OBJECT_CLASS (granite_widgets_source_list_tree_parent_class)->finalize (obj);
#line 13443 "SourceList.c"
}

/**
     * The tree that actually displays the items.
     *
     * All the user interaction happens here.
     */
static GType
granite_widgets_source_list_tree_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (GraniteWidgetsSourceListTreeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) granite_widgets_source_list_tree_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GraniteWidgetsSourceListTree), 0, (GInstanceInitFunc) granite_widgets_source_list_tree_instance_init, NULL };
	GType granite_widgets_source_list_tree_type_id;
	granite_widgets_source_list_tree_type_id = g_type_register_static (gtk_tree_view_get_type (), "GraniteWidgetsSourceListTree", &g_define_type_info, 0);
	GraniteWidgetsSourceListTree_private_offset = g_type_add_instance_private (granite_widgets_source_list_tree_type_id, sizeof (GraniteWidgetsSourceListTreePrivate));
	return granite_widgets_source_list_tree_type_id;
}

static GType
granite_widgets_source_list_tree_get_type (void)
{
	static volatile gsize granite_widgets_source_list_tree_type_id__once = 0;
	if (g_once_init_enter (&granite_widgets_source_list_tree_type_id__once)) {
		GType granite_widgets_source_list_tree_type_id;
		granite_widgets_source_list_tree_type_id = granite_widgets_source_list_tree_get_type_once ();
		g_once_init_leave (&granite_widgets_source_list_tree_type_id__once, granite_widgets_source_list_tree_type_id);
	}
	return granite_widgets_source_list_tree_type_id__once;
}

static void
_vala_granite_widgets_source_list_tree_get_property (GObject * object,
                                                     guint property_id,
                                                     GValue * value,
                                                     GParamSpec * pspec)
{
	GraniteWidgetsSourceListTree * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GRANITE_WIDGETS_SOURCE_LIST_TYPE_TREE, GraniteWidgetsSourceListTree);
#line 1540 "../lib/Widgets/SourceList.vala"
	switch (property_id) {
#line 1540 "../lib/Widgets/SourceList.vala"
		case GRANITE_WIDGETS_SOURCE_LIST_TREE_DATA_MODEL_PROPERTY:
#line 1540 "../lib/Widgets/SourceList.vala"
		g_value_set_object (value, granite_widgets_source_list_tree_get_data_model (self));
#line 1540 "../lib/Widgets/SourceList.vala"
		break;
#line 1540 "../lib/Widgets/SourceList.vala"
		case GRANITE_WIDGETS_SOURCE_LIST_TREE_SELECTED_ITEM_PROPERTY:
#line 1540 "../lib/Widgets/SourceList.vala"
		g_value_set_object (value, granite_widgets_source_list_tree_get_selected_item (self));
#line 1540 "../lib/Widgets/SourceList.vala"
		break;
#line 1540 "../lib/Widgets/SourceList.vala"
		case GRANITE_WIDGETS_SOURCE_LIST_TREE_EDITING_PROPERTY:
#line 1540 "../lib/Widgets/SourceList.vala"
		g_value_set_boolean (value, granite_widgets_source_list_tree_get_editing (self));
#line 1540 "../lib/Widgets/SourceList.vala"
		break;
#line 1540 "../lib/Widgets/SourceList.vala"
		case GRANITE_WIDGETS_SOURCE_LIST_TREE_ELLIPSIZE_MODE_PROPERTY:
#line 1540 "../lib/Widgets/SourceList.vala"
		g_value_set_enum (value, granite_widgets_source_list_tree_get_ellipsize_mode (self));
#line 1540 "../lib/Widgets/SourceList.vala"
		break;
#line 13507 "SourceList.c"
		default:
#line 1540 "../lib/Widgets/SourceList.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 1540 "../lib/Widgets/SourceList.vala"
		break;
#line 13513 "SourceList.c"
	}
}

static void
_vala_granite_widgets_source_list_tree_set_property (GObject * object,
                                                     guint property_id,
                                                     const GValue * value,
                                                     GParamSpec * pspec)
{
	GraniteWidgetsSourceListTree * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GRANITE_WIDGETS_SOURCE_LIST_TYPE_TREE, GraniteWidgetsSourceListTree);
#line 1540 "../lib/Widgets/SourceList.vala"
	switch (property_id) {
#line 1540 "../lib/Widgets/SourceList.vala"
		case GRANITE_WIDGETS_SOURCE_LIST_TREE_DATA_MODEL_PROPERTY:
#line 1540 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_tree_set_data_model (self, g_value_get_object (value));
#line 1540 "../lib/Widgets/SourceList.vala"
		break;
#line 1540 "../lib/Widgets/SourceList.vala"
		case GRANITE_WIDGETS_SOURCE_LIST_TREE_SELECTED_ITEM_PROPERTY:
#line 1540 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_tree_set_selected_item (self, g_value_get_object (value));
#line 1540 "../lib/Widgets/SourceList.vala"
		break;
#line 1540 "../lib/Widgets/SourceList.vala"
		case GRANITE_WIDGETS_SOURCE_LIST_TREE_ELLIPSIZE_MODE_PROPERTY:
#line 1540 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_tree_set_ellipsize_mode (self, g_value_get_enum (value));
#line 1540 "../lib/Widgets/SourceList.vala"
		break;
#line 13545 "SourceList.c"
		default:
#line 1540 "../lib/Widgets/SourceList.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 1540 "../lib/Widgets/SourceList.vala"
		break;
#line 13551 "SourceList.c"
	}
}

static void
_granite_widgets_source_list___lambda81_ (GraniteWidgetsSourceList* self,
                                          GraniteWidgetsSourceListItem* item)
{
#line 2669 "../lib/Widgets/SourceList.vala"
	g_signal_emit (self, granite_widgets_source_list_signals[GRANITE_WIDGETS_SOURCE_LIST_ITEM_SELECTED_SIGNAL], 0, item);
#line 13561 "SourceList.c"
}

static void
__granite_widgets_source_list___lambda81__granite_widgets_source_list_tree_item_selected (GraniteWidgetsSourceListTree* _sender,
                                                                                          GraniteWidgetsSourceListItem* item,
                                                                                          gpointer self)
{
#line 2669 "../lib/Widgets/SourceList.vala"
	_granite_widgets_source_list___lambda81_ ((GraniteWidgetsSourceList*) self, item);
#line 13571 "SourceList.c"
}

static GObject *
granite_widgets_source_list_constructor (GType type,
                                         guint n_construct_properties,
                                         GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GraniteWidgetsSourceList * self;
	GraniteWidgetsSourceListDataModel* _tmp0_;
	GraniteWidgetsSourceListTree* _tmp1_;
	GraniteWidgetsSourceListTree* _tmp2_;
	GraniteWidgetsSourceListTree* _tmp3_;
#line 2662 "../lib/Widgets/SourceList.vala"
	parent_class = G_OBJECT_CLASS (granite_widgets_source_list_parent_class);
#line 2662 "../lib/Widgets/SourceList.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 2662 "../lib/Widgets/SourceList.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GRANITE_WIDGETS_TYPE_SOURCE_LIST, GraniteWidgetsSourceList);
#line 2663 "../lib/Widgets/SourceList.vala"
	_tmp0_ = self->priv->data_model;
#line 2663 "../lib/Widgets/SourceList.vala"
	_tmp1_ = granite_widgets_source_list_tree_new (_tmp0_);
#line 2663 "../lib/Widgets/SourceList.vala"
	g_object_ref_sink (_tmp1_);
#line 2663 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (self->priv->tree);
#line 2663 "../lib/Widgets/SourceList.vala"
	self->priv->tree = _tmp1_;
#line 2665 "../lib/Widgets/SourceList.vala"
	gtk_scrolled_window_set_policy ((GtkScrolledWindow*) self, GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
#line 2666 "../lib/Widgets/SourceList.vala"
	_tmp2_ = self->priv->tree;
#line 2666 "../lib/Widgets/SourceList.vala"
	gtk_container_add ((GtkContainer*) self, (GtkWidget*) _tmp2_);
#line 2667 "../lib/Widgets/SourceList.vala"
	gtk_widget_show_all ((GtkWidget*) self);
#line 2669 "../lib/Widgets/SourceList.vala"
	_tmp3_ = self->priv->tree;
#line 2669 "../lib/Widgets/SourceList.vala"
	g_signal_connect_object (_tmp3_, "item-selected", (GCallback) __granite_widgets_source_list___lambda81__granite_widgets_source_list_tree_item_selected, self, 0);
#line 2662 "../lib/Widgets/SourceList.vala"
	return obj;
#line 13616 "SourceList.c"
}

static void
granite_widgets_source_list_class_init (GraniteWidgetsSourceListClass * klass,
                                        gpointer klass_data)
{
#line 220 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_parent_class = g_type_class_peek_parent (klass);
#line 220 "../lib/Widgets/SourceList.vala"
	g_type_class_adjust_private_offset (klass, &GraniteWidgetsSourceList_private_offset);
#line 220 "../lib/Widgets/SourceList.vala"
	((GraniteWidgetsSourceListClass *) klass)->item_selected = granite_widgets_source_list_real_item_selected;
#line 220 "../lib/Widgets/SourceList.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_granite_widgets_source_list_get_property;
#line 220 "../lib/Widgets/SourceList.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_granite_widgets_source_list_set_property;
#line 220 "../lib/Widgets/SourceList.vala"
	G_OBJECT_CLASS (klass)->constructor = granite_widgets_source_list_constructor;
#line 220 "../lib/Widgets/SourceList.vala"
	G_OBJECT_CLASS (klass)->finalize = granite_widgets_source_list_finalize;
#line 13637 "SourceList.c"
	/**
	     * Root-level expandable item.
	     *
	     * This item contains the first-level source list items. It //only serves as an item container//.
	     * It is used to add and remove items to/from the widget.
	     *
	     * Internally, it allows the source list to connect to its {@link Granite.Widgets.SourceList.ExpandableItem.child_added}
	     * and {@link Granite.Widgets.SourceList.ExpandableItem.child_removed} signals in order to monitor
	     * new children additions/removals.
	     *
	     * @since 0.2
	     */
#line 220 "../lib/Widgets/SourceList.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GRANITE_WIDGETS_SOURCE_LIST_ROOT_PROPERTY, granite_widgets_source_list_properties[GRANITE_WIDGETS_SOURCE_LIST_ROOT_PROPERTY] = g_param_spec_object ("root", "root", "root", GRANITE_WIDGETS_SOURCE_LIST_TYPE_EXPANDABLE_ITEM, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 13652 "SourceList.c"
	/**
	     * The current selected item.
	     *
	     * Setting it to //null// un-selects the previously selected item, if there was any.
	     * {@link Granite.Widgets.SourceList.ExpandableItem.expand_with_parents} is called on the
	     * item's parent to make sure it's possible to select it.
	     *
	     * @since 0.2
	     */
#line 220 "../lib/Widgets/SourceList.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GRANITE_WIDGETS_SOURCE_LIST_SELECTED_PROPERTY, granite_widgets_source_list_properties[GRANITE_WIDGETS_SOURCE_LIST_SELECTED_PROPERTY] = g_param_spec_object ("selected", "selected", "selected", GRANITE_WIDGETS_SOURCE_LIST_TYPE_ITEM, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 13664 "SourceList.c"
	/**
	     * Text ellipsize mode.
	     *
	     * @since 0.2
	     */
#line 220 "../lib/Widgets/SourceList.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GRANITE_WIDGETS_SOURCE_LIST_ELLIPSIZE_MODE_PROPERTY, granite_widgets_source_list_properties[GRANITE_WIDGETS_SOURCE_LIST_ELLIPSIZE_MODE_PROPERTY] = g_param_spec_enum ("ellipsize-mode", "ellipsize-mode", "ellipsize-mode", pango_ellipsize_mode_get_type (), 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 13672 "SourceList.c"
	/**
	     * Whether an item is being edited.
	     *
	     * @see Granite.Widgets.SourceList.start_editing_item
	     * @since 0.2
	     */
#line 220 "../lib/Widgets/SourceList.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GRANITE_WIDGETS_SOURCE_LIST_EDITING_PROPERTY, granite_widgets_source_list_properties[GRANITE_WIDGETS_SOURCE_LIST_EDITING_PROPERTY] = g_param_spec_boolean ("editing", "editing", "editing", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
#line 13681 "SourceList.c"
	/**
	     * Emitted when the source list selection changes.
	     *
	     * @param item Selected item; //null// if nothing is selected.
	     * @since 0.2
	     */
#line 220 "../lib/Widgets/SourceList.vala"
	granite_widgets_source_list_signals[GRANITE_WIDGETS_SOURCE_LIST_ITEM_SELECTED_SIGNAL] = g_signal_new ("item-selected", GRANITE_WIDGETS_TYPE_SOURCE_LIST, G_SIGNAL_RUN_LAST, G_STRUCT_OFFSET (GraniteWidgetsSourceListClass, item_selected), NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, GRANITE_WIDGETS_SOURCE_LIST_TYPE_ITEM);
#line 13690 "SourceList.c"
}

static void
granite_widgets_source_list_instance_init (GraniteWidgetsSourceList * self,
                                           gpointer klass)
{
	GraniteWidgetsSourceListDataModel* _tmp0_;
#line 220 "../lib/Widgets/SourceList.vala"
	self->priv = granite_widgets_source_list_get_instance_private (self);
#line 2650 "../lib/Widgets/SourceList.vala"
	_tmp0_ = granite_widgets_source_list_data_model_new ();
#line 2650 "../lib/Widgets/SourceList.vala"
	self->priv->data_model = _tmp0_;
#line 13704 "SourceList.c"
}

static void
granite_widgets_source_list_finalize (GObject * obj)
{
	GraniteWidgetsSourceList * self;
#line 220 "../lib/Widgets/SourceList.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GRANITE_WIDGETS_TYPE_SOURCE_LIST, GraniteWidgetsSourceList);
#line 2649 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (self->priv->tree);
#line 2650 "../lib/Widgets/SourceList.vala"
	_g_object_unref0 (self->priv->data_model);
#line 220 "../lib/Widgets/SourceList.vala"
	G_OBJECT_CLASS (granite_widgets_source_list_parent_class)->finalize (obj);
#line 13719 "SourceList.c"
}

/**
 * A widget that can display a list of items organized in categories.
 *
 * The source list widget consists of a collection of items, some of which are also expandable (and
 * thus can contain more items). All the items displayed in the source list are children of the widget's
 * root item. The API is meant to be used as follows:
 *
 * 1. Create the items you want to display in the source list, setting the appropriate values for their
 * properties. The desired hierarchy is achieved by creating expandable items and adding items to them.
 * These will be displayed as descendants in the widget's tree structure. The expandable items that are
 * not nested inside any other item are considered to be at root level, and should be added to
 * the widget's root item.<<BR>>
 *
 * Expandable items located at the root level are treated as categories, and only support text.
 *
 * ''Example''<<BR>>
 * The final tree will have the following structure:
 * {{{
 * Libraries
 *   Music
 * Stores
 *   My Store
 *      Music
 *      Podcasts
 * Devices
 *   Player 1
 *   Player 2
 * }}}
 *
 * {{{
 * var library_category = new Granite.Widgets.SourceList.ExpandableItem ("Libraries");
 * var store_category = new Granite.Widgets.SourceList.ExpandableItem ("Stores");
 * var device_category = new Granite.Widgets.SourceList.ExpandableItem ("Devices");
 *
 * var music_item = new Granite.Widgets.SourceList.Item ("Music");
 *
 * // "Libraries" will be the parent category of "Music"
 * library_category.add (music_item);
 *
 * // We plan to add sub-items to the store, so let's use an expandable item
 * var my_store_item = new Granite.Widgets.SourceList.ExpandableItem ("My Store");
 * store_category.add (my_store_item);
 *
 * var my_store_podcast_item = new Granite.Widgets.SourceList.Item ("Podcasts");
 * var my_store_music_item = new Granite.Widgets.SourceList.Item ("Music");
 *
 * my_store_item.add (my_store_music_item);
 * my_store_item.add (my_store_podcast_item);
 *
 * var player1_item = new Granite.Widgets.SourceList.Item ("Player 1");
 * var player2_item = new Granite.Widgets.SourceList.Item ("Player 2");
 *
 * device_category.add (player1_item);
 * device_category.add (player2_item);
 * }}}
 *
 * 2. Create a source list widget.<<BR>>
 * {{{
 * var source_list = new Granite.Widgets.SourceList ();
 * }}}
 *
 * 3. Add root-level items to the {@link Granite.Widgets.SourceList.root} item.
 * This item only serves as a container, and all its properties are ignored by the widget.
 *
 * {{{
 * // This will add the main categories (including their children) to the source list. After
 * // having being added to be widget, any other item added to any of these items
 * // (or any other child item in a deeper level) will be automatically added too.
 * // There's no need to deal with the source list widget directly.
 *
 * var root = source_list.root;
 *
 * root.add (library_category);
 * root.add (store_category);
 * root.add (device_category);
 * }}}
 *
 * The steps mentioned above are enough for initializing the source list. Future changes to the items'
 * properties are ''automatically'' reflected by the widget.
 *
 * Final steps would involve connecting handlers to the source list events, being
 * {@link Granite.Widgets.SourceList.item_selected} the most important, as it indicates that
 * the selection was modified.
 *
 * Pack the source list into the GUI using the {@link Gtk.Paned} widget.
 * This is usually done as follows:
 * {{{
 * var pane = new Gtk.Paned (Gtk.Orientation.HORIZONTAL);
 * pane.pack1 (source_list, false, false);
 * pane.pack2 (content_area, true, false);
 * }}}
 *
 * @since 0.2
 * @see Gtk.Paned
 */
static GType
granite_widgets_source_list_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (GraniteWidgetsSourceListClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) granite_widgets_source_list_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GraniteWidgetsSourceList), 0, (GInstanceInitFunc) granite_widgets_source_list_instance_init, NULL };
	GType granite_widgets_source_list_type_id;
	granite_widgets_source_list_type_id = g_type_register_static (gtk_scrolled_window_get_type (), "GraniteWidgetsSourceList", &g_define_type_info, 0);
	GraniteWidgetsSourceList_private_offset = g_type_add_instance_private (granite_widgets_source_list_type_id, sizeof (GraniteWidgetsSourceListPrivate));
	return granite_widgets_source_list_type_id;
}

GType
granite_widgets_source_list_get_type (void)
{
	static volatile gsize granite_widgets_source_list_type_id__once = 0;
	if (g_once_init_enter (&granite_widgets_source_list_type_id__once)) {
		GType granite_widgets_source_list_type_id;
		granite_widgets_source_list_type_id = granite_widgets_source_list_get_type_once ();
		g_once_init_leave (&granite_widgets_source_list_type_id__once, granite_widgets_source_list_type_id);
	}
	return granite_widgets_source_list_type_id__once;
}

static void
_vala_granite_widgets_source_list_get_property (GObject * object,
                                                guint property_id,
                                                GValue * value,
                                                GParamSpec * pspec)
{
	GraniteWidgetsSourceList * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GRANITE_WIDGETS_TYPE_SOURCE_LIST, GraniteWidgetsSourceList);
#line 220 "../lib/Widgets/SourceList.vala"
	switch (property_id) {
#line 220 "../lib/Widgets/SourceList.vala"
		case GRANITE_WIDGETS_SOURCE_LIST_ROOT_PROPERTY:
#line 220 "../lib/Widgets/SourceList.vala"
		g_value_set_object (value, granite_widgets_source_list_get_root (self));
#line 220 "../lib/Widgets/SourceList.vala"
		break;
#line 220 "../lib/Widgets/SourceList.vala"
		case GRANITE_WIDGETS_SOURCE_LIST_SELECTED_PROPERTY:
#line 220 "../lib/Widgets/SourceList.vala"
		g_value_set_object (value, granite_widgets_source_list_get_selected (self));
#line 220 "../lib/Widgets/SourceList.vala"
		break;
#line 220 "../lib/Widgets/SourceList.vala"
		case GRANITE_WIDGETS_SOURCE_LIST_ELLIPSIZE_MODE_PROPERTY:
#line 220 "../lib/Widgets/SourceList.vala"
		g_value_set_enum (value, granite_widgets_source_list_get_ellipsize_mode (self));
#line 220 "../lib/Widgets/SourceList.vala"
		break;
#line 220 "../lib/Widgets/SourceList.vala"
		case GRANITE_WIDGETS_SOURCE_LIST_EDITING_PROPERTY:
#line 220 "../lib/Widgets/SourceList.vala"
		g_value_set_boolean (value, granite_widgets_source_list_get_editing (self));
#line 220 "../lib/Widgets/SourceList.vala"
		break;
#line 13873 "SourceList.c"
		default:
#line 220 "../lib/Widgets/SourceList.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 220 "../lib/Widgets/SourceList.vala"
		break;
#line 13879 "SourceList.c"
	}
}

static void
_vala_granite_widgets_source_list_set_property (GObject * object,
                                                guint property_id,
                                                const GValue * value,
                                                GParamSpec * pspec)
{
	GraniteWidgetsSourceList * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GRANITE_WIDGETS_TYPE_SOURCE_LIST, GraniteWidgetsSourceList);
#line 220 "../lib/Widgets/SourceList.vala"
	switch (property_id) {
#line 220 "../lib/Widgets/SourceList.vala"
		case GRANITE_WIDGETS_SOURCE_LIST_ROOT_PROPERTY:
#line 220 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_set_root (self, g_value_get_object (value));
#line 220 "../lib/Widgets/SourceList.vala"
		break;
#line 220 "../lib/Widgets/SourceList.vala"
		case GRANITE_WIDGETS_SOURCE_LIST_SELECTED_PROPERTY:
#line 220 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_set_selected (self, g_value_get_object (value));
#line 220 "../lib/Widgets/SourceList.vala"
		break;
#line 220 "../lib/Widgets/SourceList.vala"
		case GRANITE_WIDGETS_SOURCE_LIST_ELLIPSIZE_MODE_PROPERTY:
#line 220 "../lib/Widgets/SourceList.vala"
		granite_widgets_source_list_set_ellipsize_mode (self, g_value_get_enum (value));
#line 220 "../lib/Widgets/SourceList.vala"
		break;
#line 13911 "SourceList.c"
		default:
#line 220 "../lib/Widgets/SourceList.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 220 "../lib/Widgets/SourceList.vala"
		break;
#line 13917 "SourceList.c"
	}
}

static inline gpointer
_vala_memdup2 (gconstpointer mem,
               gsize byte_size)
{
	gpointer new_mem;
	if (mem && byte_size != 0) {
		new_mem = g_malloc (byte_size);
		memcpy (new_mem, mem, byte_size);
	} else {
		new_mem = NULL;
	}
	return new_mem;
}

